@@ -28,7 +28,7 @@
 #include <QtCore/QList>
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-template <class T> class QStack;
+#include <QStack>
 #endif
 
 class KAction;
@@ -361,9 +361,9 @@ class KTEXTEDITOR_EXPORT SmartRange : public Range
      * Find the child after \p range, if any.
      * The order is determined by the range end-cursors.
      *
-     * \param range to seach backwards from
+     * \param range to seach forwards from
      *
-     * \return the range before \p range if one exists, otherwise null.
+     * \return the range after \p range if one exists, otherwise null.
      */
     SmartRange* childAfter( const SmartRange * range ) const;
 
@@ -522,6 +522,8 @@ class KTEXTEDITOR_EXPORT SmartRange : public Range
     /**
      * Register a notifier to receive signals indicating change of state of this range.
      *
+     * NOTE: Make sure you call @c removeNotifier() when deleting the notifier before the range.
+     *
      * \param notifier notifier to register. Ownership is not transferred.
      */
     void addNotifier(SmartRangeNotifier* notifier);
@@ -557,6 +559,8 @@ class KTEXTEDITOR_EXPORT SmartRange : public Range
      * Register a SmartRangeWatcher to receive calls indicating change of state
      * of this range. To finish receiving notifications, call removeWatcher().
      *
+     * NOTE: Make sure you call @c removeWachter() when deleting the notifier before the range.
+     *
      * \param watcher the instance of a class which is to receive
      *                notifications about changes to this range.
      */
