@@ -29,7 +29,7 @@
 // widget
 #include <QtGui/QWidget>
 
-class QMenu;
+#include <QMenu>
 
 namespace KTextEditor
 {
@@ -138,6 +138,10 @@ class Document;
  *      KXMLGUIClient
  * \author Christoph Cullmann \<cullmann@kde.org\>
  */
+// KDE5: consider deriving from QFrame instead of QWidget, since e.g. the Oxygen style
+// http://lxr.kde.org/source/kde/kde-workspace/kstyles/oxygen/oxygenstyle.cpp#614
+// checks for a QFrame and then KStyle::pixelMetric returns a better margin (Frame_FrameWidth)
+// This is needed because the Oxygen "focus border" paints over the line numbers otherwise.
 class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
 {
   Q_OBJECT
@@ -188,6 +192,7 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
      * whatever other edit modes are supported. The string should be
      * translated (i18n), as this is a user aimed representation of the view
      * state, which should be shown in the GUI, for example in the status bar.
+     * This string may be rich-text.
      * \return
      * \see viewModeChanged()
      */
@@ -198,8 +203,9 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
      * These correspond to various modes the text editor might be in.
      */
     enum EditMode {
-      EditInsert = 0,   /**< Insert mode. Characters will be added. */
-      EditOverwrite = 1 /**< Overwrite mode. Characters will be replaced. */
+      EditInsert = 0,    /**< Insert mode. Characters will be added. */
+      EditOverwrite = 1, /**< Overwrite mode. Characters will be replaced. */
+      EditViMode = 2     /**< Vi mode. The view will behave like the editor vi(m) @since 4.11 */
     };
 
     /**
@@ -226,8 +232,8 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
     void focusIn ( KTextEditor::View *view );
 
     /**
-     * This signal is emitted whenever the \p view looses the focus.
-     * \param view view which looses focus
+     * This signal is emitted whenever the \p view loses the focus.
+     * \param view view which lost focus
      * \see focusIn()
      */
     void focusOut ( KTextEditor::View *view );
@@ -280,6 +286,10 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
      * \note any previously assigned menu is not deleted.  If you are finished
      *       with the previous menu, you may delete it.
      *
+     * \warning Use this with care! Plugin xml gui clients are not merged
+     *          into this menu!
+     * \warning !!!!!! DON'T USE THIS FUNCTION, UNLESS YOU ARE SURE YOU DON'T WANT PLUGINS TO WORK !!!!!!
+     *
      * \param menu new context menu object for this view
      * \see contextMenu()
      */
@@ -287,7 +297,9 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
 
     /**
      * Get the context menu for this view. The return value can be NULL
-     * if no context menu object was set.
+     * if no context menu object was set and kxmlgui is not initialized yet.
+     * If there is no user set menu, the kxmlgui menu is returned. Do not delete this menu, if
+     * if it is the xmlgui menu.
      * \return context menu object
      * \see setContextMenu()
      */
@@ -300,7 +312,30 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
      * \note to use this menu, you will next need to call setContextMenu(),
      *       as this does not assign the new context menu.
      *
-     * \param menu the menu to be populated, or null to create a new menu
+     * \warning This contains only basic options from the editor component
+     *          (katepart). Plugins are \p not merged/integrated into it!
+     *          If you want to be a better citizen and take full advantage
+     *          of KTextEditor plugins do something like:
+     * \code
+     * KXMLGUIClient* client = view;
+     * // search parent XmlGuiClient
+     * while (client->parentClient()) {
+     *   client = client->parentClient();
+     * }
+     *    
+     * if (client->factory()) {
+     *   QList<QWidget*> conts = client->factory()->containers("menu");       
+     *   foreach (QWidget *w, conts) {
+     *     if (w->objectName() == "ktexteditor_popup") {
+     *       // do something with the menu (ie adding an onshow handler)
+     *       break;
+     *     }
+     *   }
+     * }
+     * \endcode
+     * \warning or simply use the aboutToShow, aboutToHide signals !!!!!
+     *
+     * \param menu the menu to be populated, or null to create a new menu.
      * \return the menu, whether created or passed initially
      */
     virtual QMenu* defaultContextMenu(QMenu* menu = 0L) const = 0;
@@ -591,7 +626,9 @@ class KTEXTEDITOR_EXPORT View :  public QWidget, public KXMLGUIClient
  *
  * \see KTextEditor::View
  * \since 4.2
- * \note KDE5: merge into KTextEditor::View
+ * \note KDE5: merge into KTextEditor::View (or name it ViewportInterface
+ *       and add accessors to the QScrollBars and convenience functions like
+ *       cursorToCoordinate(), scollLines(int count), etc.
  */
 class KTEXTEDITOR_EXPORT CoordinatesToCursorInterface
 {
