@@ -27,7 +27,6 @@
 #include <fcntl.h>
 #include <unistd.h>
 
-#include "kconfigbackend.h"
 #include "kconfiggroup.h"
 #include <kde_file.h>
 #include <kstringhandler.h>
@@ -37,6 +36,7 @@
 #include <kcomponentdata.h>
 #include <ktoolinvocation.h>
 #include <kaboutdata.h>
+#include <kshell.h>
 #include <kdebug.h>
 
 #include <qbytearray.h>
@@ -51,48 +51,15 @@
 #include <QtCore/QSet>
 #include <QtCore/QStack>
 
-bool KConfigPrivate::mappingsRegistered=false;
-
 KConfigPrivate::KConfigPrivate(const KComponentData &componentData_, KConfig::OpenFlags flags,
                                const char* resource)
     : openFlags(flags), resourceType(resource), mBackend(0),
-      bDynamicBackend(true),  bDirty(false), bReadDefaults(false),
+      bDirty(false), bReadDefaults(false),
       bFileImmutable(false), bForceGlobal(false), bSuppressGlobal(false),
       componentData(componentData_), configState(KConfigBase::NoAccess)
 {
     sGlobalFileName = componentData.dirs()->saveLocation("config", QString(), false) + QLatin1String("kdeglobals");
 
-    static int use_etc_kderc = -1;
-    if (use_etc_kderc < 0)
-        use_etc_kderc = getenv("KDE_SKIP_KDERC") != 0 ? 0 : 1; // for unit tests
-    if (use_etc_kderc) {
-
-        etc_kderc =
-#ifdef Q_WS_WIN
-            QFile::decodeName( qgetenv("WINDIR") + "/kde4rc" );
-#else
-            QLatin1String("/etc/kde4rc");
-#endif
-        if (!KStandardDirs::checkAccess(etc_kderc, R_OK)) {
-            etc_kderc.clear();
-        }
-    }
-
-//    if (!mappingsRegistered) {
-//        KEntryMap tmp;
-//        if (!etc_kderc.isEmpty()) {
-//            KSharedPtr<KConfigBackend> backend = KConfigBackend::create(componentData, etc_kderc, QLatin1String("INI"));
-//            backend->parseConfig( "en_US", tmp, KConfigBackend::ParseDefaults);
-//        }
-//        const QString kde4rc(QDir::home().filePath(".kde4rc"));
-//        if (KStandardDirs::checkAccess(kde4rc, R_OK)) {
-//            KSharedPtr<KConfigBackend> backend = KConfigBackend::create(componentData, kde4rc, QLatin1String("INI"));
-//            backend->parseConfig( "en_US", tmp, KConfigBackend::ParseOptions());
-//        }
-//        KConfigBackend::registerMappings(tmp);
-//        mappingsRegistered = true;
-//    }
-
     setLocale(KGlobal::hasLocale() ? KGlobal::locale()->language() : KLocale::defaultLanguage());
 }
 
@@ -152,91 +119,6 @@ void KConfigPrivate::copyGroup(const QByteArray& source, const QByteArray& desti
     }
 }
 
-QString KConfigPrivate::expandString(const QString& value)
-{
-    QString aValue = value;
-
-    // check for environment variables and make necessary translations
-    int nDollarPos = aValue.indexOf( QLatin1Char('$') );
-    while( nDollarPos != -1 && nDollarPos+1 < aValue.length()) {
-        // there is at least one $
-        if( aValue[nDollarPos+1] == QLatin1Char('(') ) {
-            int nEndPos = nDollarPos+1;
-            // the next character is not $
-            while ( (nEndPos <= aValue.length()) && (aValue[nEndPos]!=QLatin1Char(')')) )
-                nEndPos++;
-            nEndPos++;
-            QString cmd = aValue.mid( nDollarPos+2, nEndPos-nDollarPos-3 );
-
-            QString result;
-            QByteArray oldpath = qgetenv( "PATH" );
-            QByteArray newpath;
-            if (KGlobal::hasMainComponent()) {
-                newpath = QFile::encodeName(KGlobal::dirs()->resourceDirs("exe").join(QChar::fromLatin1(KPATH_SEPARATOR)));
-                if (!newpath.isEmpty() && !oldpath.isEmpty())
-                    newpath += KPATH_SEPARATOR;
-            }
-            newpath += oldpath;
-            setenv( "PATH", newpath, 1/*overwrite*/ );
-// FIXME: wince does not have pipes
-#ifndef _WIN32_WCE
-            FILE *fs = popen(QFile::encodeName(cmd).data(), "r");
-            if (fs) {
-                QTextStream ts(fs, QIODevice::ReadOnly);
-                result = ts.readAll().trimmed();
-                pclose(fs);
-            }
-#endif
-            setenv( "PATH", oldpath, 1/*overwrite*/ );
-            aValue.replace( nDollarPos, nEndPos-nDollarPos, result );
-            nDollarPos += result.length();
-        } else if( aValue[nDollarPos+1] != QLatin1Char('$') ) {
-            int nEndPos = nDollarPos+1;
-            // the next character is not $
-            QString aVarName;
-            if ( aValue[nEndPos] == QLatin1Char('{') ) {
-                while ( (nEndPos <= aValue.length()) && (aValue[nEndPos] != QLatin1Char('}')) )
-                    nEndPos++;
-                nEndPos++;
-                aVarName = aValue.mid( nDollarPos+2, nEndPos-nDollarPos-3 );
-            } else {
-                while ( nEndPos <= aValue.length() &&
-                        (aValue[nEndPos].isNumber() ||
-                        aValue[nEndPos].isLetter() ||
-                        aValue[nEndPos] == QLatin1Char('_') ) )
-                    nEndPos++;
-                aVarName = aValue.mid( nDollarPos+1, nEndPos-nDollarPos-1 );
-            }
-            QString env;
-            if (!aVarName.isEmpty()) {
-#ifdef Q_OS_WIN
-                if (aVarName == QLatin1String("HOME"))
-                    env = QDir::homePath();
-                else
-#endif
-                {
-                    QByteArray pEnv = qgetenv( aVarName.toLatin1() );
-                    if( !pEnv.isEmpty() )
-                    // !!! Sergey A. Sukiyazov <corwin@micom.don.ru> !!!
-                    // An environment variable may contain values in 8bit
-                    // locale specified encoding or UTF8 encoding
-                        env = KStringHandler::from8Bit( pEnv );
-                }
-                aValue.replace(nDollarPos, nEndPos-nDollarPos, env);
-                nDollarPos += env.length();
-            } else
-                aValue.remove( nDollarPos, nEndPos-nDollarPos );
-        } else {
-            // remove one of the dollar signs
-            aValue.remove( nDollarPos, 1 );
-            nDollarPos++;
-        }
-        nDollarPos = aValue.indexOf( QLatin1Char('$'), nDollarPos );
-    }
-
-    return aValue;
-}
-
 
 KConfig::KConfig( const QString& file, OpenFlags mode,
                   const char* resourceType)
@@ -258,17 +140,6 @@ KConfig::KConfig( const KComponentData& componentData, const QString& file, Open
     reparseConfiguration();
 }
 
-KConfig::KConfig(const QString& file, const QString& backend, const char* resourceType)
-    : d_ptr(new KConfigPrivate(KGlobal::mainComponent(), SimpleConfig, resourceType))
-{
-    d_ptr->mBackend = KConfigBackend::create(d_ptr->componentData, file, backend);
-    d_ptr->bDynamicBackend = false;
-    d_ptr->changeFileName(file, ""); // set the local file name
-
-    // read initial information off disk
-    reparseConfiguration();
-}
-
 KConfig::KConfig(KConfigPrivate &d)
     : d_ptr(&d)
 {
@@ -294,10 +165,10 @@ QStringList KConfig::groupList() const
     QSet<QString> groups;
 
     for (KEntryMap::ConstIterator entryMapIt( d->entryMap.constBegin() ); entryMapIt != d->entryMap.constEnd(); ++entryMapIt) {
-        const KEntryKey& key = entryMapIt.key();	
+        const KEntryKey& key = entryMapIt.key();
         const QByteArray group = key.mGroup;
         if (key.mKey.isNull() && !group.isEmpty() && group != "<default>" && group != "$Version") {
-            const QString groupname = QString::fromUtf8(group);
+            const QString groupname = QString::fromUtf8(group, group.size());
             groups << groupname.left(groupname.indexOf(QLatin1Char('\x1d')));
         }
     }
@@ -402,7 +273,7 @@ QMap<QString,QString> KConfig::entryMap(const QString& aGroup) const
                 // with the non-localized entry
                 if (!theMap.contains(key)) {
                     if (it->bExpand) {
-                        theMap.insert(key,KConfigPrivate::expandString(QString::fromUtf8(it->mValue.constData())));
+                        theMap.insert(key,KShell::envExpand(QString::fromUtf8(it->mValue.constData())));
                     } else {
                         theMap.insert(key,QString::fromUtf8(it->mValue.constData()));
                     }
@@ -456,13 +327,15 @@ void KConfig::sync()
         d->bDirty = false; // will revert to true if a config write fails
 
         if (d->wantGlobals() && writeGlobals) {
-            KSharedPtr<KConfigBackend> tmp = KConfigBackend::create(componentData(), d->sGlobalFileName);
+            KConfigIniBackend *tmp = new KConfigIniBackend();
+            tmp->setFilePath(d->sGlobalFileName);
             if (d->configState == ReadWrite && !tmp->lock(componentData())) {
                 qWarning() << "couldn't lock global file";
                 d->bDirty = true;
+                tmp->deleteLater();
                 return;
             }
-            if (!tmp->writeConfig(utf8Locale, d->entryMap, KConfigBackend::WriteGlobal, d->componentData)) {
+            if (!tmp->writeConfig(utf8Locale, d->entryMap, KConfigIniBackend::WriteGlobal)) {
                 d->bDirty = true;
                 // TODO KDE5: return false? (to tell the app that writing wasn't possible, e.g.
                 // config file is immutable or disk full)
@@ -470,10 +343,11 @@ void KConfig::sync()
             if (tmp->isLocked()) {
                 tmp->unlock();
             }
+            tmp->deleteLater();
         }
 
         if (writeLocals) {
-            if (!d->mBackend->writeConfig(utf8Locale, d->entryMap, KConfigBackend::WriteOptions(), d->componentData)) {
+            if (!d->mBackend->writeConfig(utf8Locale, d->entryMap, KConfigIniBackend::WriteOptions())) {
                 d->bDirty = true;
                 // TODO KDE5: return false? (to tell the app that writing wasn't possible, e.g.
                 // config file is immutable or disk full)
@@ -502,17 +376,6 @@ bool KConfig::isDirty() const
     return d->bDirty;
 }
 
-void KConfig::checkUpdate(const QString &id, const QString &updateFile)
-{
-    const KConfigGroup cg(this, "$Version");
-    const QString cfg_id = updateFile+QLatin1Char(':')+id;
-    const QStringList ids = cg.readEntry("update_info", QStringList());
-    if (!ids.contains(cfg_id)) {
-        KToolInvocation::kdeinitExecWait(QString::fromLatin1("kconf_update"), QStringList() << QString::fromLatin1("--check") << updateFile);
-        reparseConfiguration();
-    }
-}
-
 KConfig* KConfig::copyTo(const QString &file, KConfig *config) const
 {
     Q_D(const KConfig);
@@ -570,16 +433,11 @@ void KConfigPrivate::changeFileName(const QString& name, const char* type)
         return;
     }
 
-#ifndef Q_OS_WIN
     bSuppressGlobal = (file == sGlobalFileName);
-#else
-    bSuppressGlobal = (file.compare(sGlobalFileName, Qt::CaseInsensitive) == 0);
-#endif
 
-    if (bDynamicBackend || !mBackend) // allow dynamic changing of backend
-        mBackend = KConfigBackend::create(componentData, file);
-    else
-        mBackend->setFilePath(file);
+    if (!mBackend)
+        mBackend = new KConfigIniBackend();
+    mBackend->setFilePath(file);
 
     configState = mBackend->accessMode();
 }
@@ -613,10 +471,6 @@ QStringList KConfigPrivate::getGlobalFiles() const
     QStringList globalFiles;
     foreach (const QString& dir1, dirs->findAllResources("config", QLatin1String("kdeglobals")))
         globalFiles.push_front(dir1);
-    foreach (const QString& dir2, dirs->findAllResources("config", QLatin1String("system.kdeglobals")))
-        globalFiles.push_front(dir2);
-    if (!etc_kderc.isEmpty())
-        globalFiles.push_front(etc_kderc);
     return globalFiles;
 }
 
@@ -625,21 +479,20 @@ void KConfigPrivate::parseGlobalFiles()
     const QStringList globalFiles = getGlobalFiles();
 //    qDebug() << "parsing global files" << globalFiles;
 
-    // TODO: can we cache the values in etc_kderc / other global files
-    //       on a per-application basis?
+    // TODO: can we cache the values in global files on a per-application basis?
     const QByteArray utf8Locale = locale.toUtf8();
     foreach(const QString& file, globalFiles) {
-        KConfigBackend::ParseOptions parseOpts = KConfigBackend::ParseGlobal|KConfigBackend::ParseExpansions;
-#ifndef Q_OS_WIN
+        KConfigIniBackend::ParseOptions parseOpts = KConfigIniBackend::ParseGlobal|KConfigIniBackend::ParseExpansions;
         if (file != sGlobalFileName)
-#else
-        if (file.compare(sGlobalFileName, Qt::CaseInsensitive) != 0)
-#endif
-            parseOpts |= KConfigBackend::ParseDefaults;
+            parseOpts |= KConfigIniBackend::ParseDefaults;
 
-        KSharedPtr<KConfigBackend> backend = KConfigBackend::create(componentData, file);
-        if ( backend->parseConfig( utf8Locale, entryMap, parseOpts) == KConfigBackend::ParseImmutable)
+        KConfigIniBackend *backend = new KConfigIniBackend();
+        backend->setFilePath(file);
+        if ( backend->parseConfig( utf8Locale, entryMap, parseOpts) == KConfigIniBackend::ParseImmutable) {
+            backend->deleteLater();
             break;
+        }
+        backend->deleteLater();
     }
 }
 
@@ -669,33 +522,29 @@ void KConfigPrivate::parseConfigFiles()
 
         const QByteArray utf8Locale = locale.toUtf8();
         foreach(const QString& file, files) {
-#ifndef Q_OS_WIN
             if (file == mBackend->filePath()) {
-#else
-            if (file.compare(mBackend->filePath(), Qt::CaseInsensitive) == 0) {
-#endif
-                switch (mBackend->parseConfig(utf8Locale, entryMap, KConfigBackend::ParseExpansions)) {
-                case KConfigBackend::ParseOk:
+                switch (mBackend->parseConfig(utf8Locale, entryMap, KConfigIniBackend::ParseExpansions)) {
+                case KConfigIniBackend::ParseOk:
                     break;
-                case KConfigBackend::ParseImmutable:
+                case KConfigIniBackend::ParseImmutable:
                     bFileImmutable = true;
                     break;
-                case KConfigBackend::ParseOpenError:
+                case KConfigIniBackend::ParseOpenError:
                     configState = KConfigBase::NoAccess;
                     break;
                 }
             } else {
-                KSharedPtr<KConfigBackend> backend = KConfigBackend::create(componentData, file);
+                KConfigIniBackend *backend = new KConfigIniBackend();
+                backend->setFilePath(file);
                 bFileImmutable = (backend->parseConfig(utf8Locale, entryMap,
-                                        KConfigBackend::ParseDefaults|KConfigBackend::ParseExpansions)
-                                  == KConfigBackend::ParseImmutable);
+                                        KConfigIniBackend::ParseDefaults|KConfigIniBackend::ParseExpansions)
+                                  == KConfigIniBackend::ParseImmutable);
+                backend->deleteLater();
             }
 
             if (bFileImmutable)
                 break;
         }
-        if (componentData.dirs()->isRestrictedResource(resourceType, fileName))
-            bFileImmutable = true;
     }
 }
 
@@ -766,21 +615,7 @@ bool KConfig::isGroupImmutableImpl(const QByteArray& aGroup) const
     return isImmutable() || d->entryMap.getEntryOption(aGroup, 0, 0, KEntryMap::EntryImmutable);
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KConfig::setForceGlobal(bool b)
-{
-    Q_D(KConfig);
-    d->bForceGlobal = b;
-}
-#endif
 
-#ifndef KDE_NO_DEPRECATED
-bool KConfig::forceGlobal() const
-{
-    Q_D(const KConfig);
-    return d->bForceGlobal;
-}
-#endif
 
 KConfigGroup KConfig::groupImpl(const QByteArray &group)
 {
@@ -911,8 +746,4 @@ QString KConfigPrivate::lookupData(const QByteArray& group, const char* key,
     return entryMap.getEntry(group, key, QString(), flags, expand);
 }
 
-void KConfig::virtual_hook(int /*id*/, void* /*data*/)
-{
-	/* nothing */
-}
 
