@@ -23,12 +23,13 @@
 #include "kconfigini_p.h"
 
 #include "kconfig.h"
-#include "kconfigbackend.h"
 #include "bufferfragment_p.h"
 #include "kconfigdata.h"
 #include <ksavefile.h>
 #include <kde_file.h>
 #include "kstandarddirs.h"
+#include <kdebug.h>
+#include <klocale.h>
 
 #include <qdatetime.h>
 #include <qdir.h>
@@ -38,8 +39,6 @@
 #include <qmetaobject.h>
 #include <qregexp.h>
 
-extern bool kde_kiosk_exception;
-
 static QByteArray lookup(const KConfigIniBackend::BufferFragment& fragment, QHash<KConfigIniBackend::BufferFragment, QByteArray>* cache)
 {
     QHash<KConfigIniBackend::BufferFragment, QByteArray>::iterator it = cache->find(fragment);
@@ -56,7 +55,8 @@ QString KConfigIniBackend::warningProlog(const QFile &file, int line)
 }
 
 KConfigIniBackend::KConfigIniBackend()
- : KConfigBackend()
+    : QObject(), QSharedData(),
+    m_lockfile(nullptr)
 {
 }
 
@@ -64,16 +64,15 @@ KConfigIniBackend::~KConfigIniBackend()
 {
 }
 
-KConfigBackend::ParseInfo
-        KConfigIniBackend::parseConfig(const QByteArray& currentLocale, KEntryMap& entryMap,
-                                       ParseOptions options)
+KConfigIniBackend::ParseInfo KConfigIniBackend::parseConfig(const QByteArray& currentLocale,
+    KEntryMap& entryMap, ParseOptions options)
 {
     return parseConfig(currentLocale, entryMap, options, false);
 }
 
 // merging==true is the merging that happens at the beginning of writeConfig:
 // merge changes in the on-disk file with the changes in the KConfig object.
-KConfigBackend::ParseInfo
+KConfigIniBackend::ParseInfo
 KConfigIniBackend::parseConfig(const QByteArray& currentLocale, KEntryMap& entryMap,
                                ParseOptions options, bool merging)
 {
@@ -141,9 +140,9 @@ KConfigIniBackend::parseConfig(const QByteArray& currentLocale, KEntryMap& entry
                     line.at(start) == '$' && line.at(start + 1) == 'i')
                 {
                     if (newGroup.isEmpty())
-                        fileOptionImmutable = !kde_kiosk_exception;
+                        fileOptionImmutable = true;
                     else
-                        groupOptionImmutable = !kde_kiosk_exception;
+                        groupOptionImmutable = true;
                 }
                 else {
                     if (!newGroup.isEmpty())
@@ -201,8 +200,7 @@ KConfigIniBackend::parseConfig(const QByteArray& currentLocale, KEntryMap& entry
                     while (i < end) {
                         switch (aKey.at(i)) {
                             case 'i':
-                                if (!kde_kiosk_exception)
-                                    entryOptions |= KEntryMap::EntryImmutable;
+                                entryOptions |= KEntryMap::EntryImmutable;
                                 break;
                             case 'e':
                                 if (allowExecutableValues)
@@ -378,7 +376,7 @@ void KConfigIniBackend::writeEntries(const QByteArray& locale, QFile& file, cons
 }
 
 bool KConfigIniBackend::writeConfig(const QByteArray& locale, KEntryMap& entryMap,
-                                    WriteOptions options, const KComponentData &data)
+                                    WriteOptions options)
 {
     Q_ASSERT(!filePath().isEmpty());
 
@@ -448,7 +446,7 @@ bool KConfigIniBackend::writeConfig(const QByteArray& locale, KEntryMap& entryMa
     }
 
     if (createNew) {
-        KSaveFile file( filePath(), data );
+        KSaveFile file( filePath() );
         if (!file.open()) {
             return false;
         }
@@ -592,24 +590,27 @@ bool KConfigIniBackend::lock(const KComponentData& componentData)
 {
     Q_ASSERT(!filePath().isEmpty());
 
-    if (!lockFile) {
-        lockFile = new KLockFile(filePath() + QLatin1String(".lock"), componentData);
+    if (!m_lockfile) {
+        m_lockfile = new KLockFile(filePath());
     }
 
-    if (lockFile->lock() == KLockFile::LockStale) // attempt to break the lock
-        lockFile->lock(KLockFile::ForceFlag);
-    return lockFile->isLocked();
+    if (m_lockfile->lock() == KLockFile::LockStale) {
+        // attempt to break the lock
+        m_lockfile->lock(KLockFile::ForceFlag);
+    }
+    return m_lockfile->isLocked();
 }
 
 void KConfigIniBackend::unlock()
 {
-    lockFile->unlock();
-    lockFile.clear();
+    m_lockfile->unlock();
+    delete m_lockfile;
+    m_lockfile = nullptr;
 }
 
 bool KConfigIniBackend::isLocked() const
 {
-    return lockFile && lockFile->isLocked();
+    return m_lockfile && m_lockfile->isLocked();
 }
 
 QByteArray KConfigIniBackend::stringToPrintable(const QByteArray& aString, StringType type)
@@ -623,9 +624,8 @@ QByteArray KConfigIniBackend::stringToPrintable(const QByteArray& aString, Strin
         return aString;
     const int l = aString.length();
 
-    QByteArray result; // Guesstimated that it's good to avoid data() initialization for a length of l*4
-    result.resize(l * 4); // Maximum 4x as long as source string due to \x<ab> escape sequences
-    register const char *s = aString.constData();
+    QByteArray result(l * 4, Qt::Uninitialized); // Maximum 4x as long as source string due to \x<ab> escape sequences
+    const char *s = aString.constData();
     int i = 0;
     char *data = result.data();
     char *start = data;
@@ -772,3 +772,33 @@ void KConfigIniBackend::printableToString(BufferFragment* aString, const QFile&
     }
     aString->truncate(r - aString->constData());
 }
+
+QString KConfigIniBackend::filePath() const
+{
+    return m_localFileName;
+}
+
+void KConfigIniBackend::setLocalFilePath(const QString& file)
+{
+    m_localFileName = file;
+}
+
+QDateTime KConfigIniBackend::lastModified() const
+{
+    return m_lastModified;
+}
+
+void KConfigIniBackend::setLastModified(const QDateTime& dt)
+{
+    m_lastModified = dt;
+}
+
+qint64 KConfigIniBackend::size() const
+{
+    return m_size;
+}
+
+void KConfigIniBackend::setSize(qint64 sz)
+{
+    m_size = sz;
+}
\ No newline at end of file
