@@ -25,7 +25,6 @@
 #include "kstandarddirs.h"
 #include "kglobal.h"
 #include "kdebug.h"
-#include "kstringhandler.h"
 
 KConfigSkeletonItem::KConfigSkeletonItem(const QString & _group,
                                          const QString & _key)
@@ -139,8 +138,6 @@ void KCoreConfigSkeleton::ItemString::writeConfig( KConfig *config )
       cg.revertToDefault( mKey );
     else if ( mType == Path )
       cg.writePathEntry( mKey, mReference );
-    else if ( mType == Password )
-      cg.writeEntry( mKey, KStringHandler::obscure( mReference ) );
     else
       cg.writeEntry( mKey, mReference );
   }
@@ -155,11 +152,6 @@ void KCoreConfigSkeleton::ItemString::readConfig( KConfig *config )
   {
     mReference = cg.readPathEntry( mKey, mDefault );
   }
-  else if ( mType == Password )
-  {
-    QString val = cg.readEntry( mKey, KStringHandler::obscure( mDefault ) );
-    mReference = KStringHandler::obscure( val );
-  }
   else
   {
     mReference = cg.readEntry( mKey, mDefault );
@@ -185,13 +177,6 @@ QVariant KCoreConfigSkeleton::ItemString::property() const
   return QVariant(mReference);
 }
 
-KCoreConfigSkeleton::ItemPassword::ItemPassword( const QString &_group, const QString &_key,
-                                    QString &reference,
-                                    const QString &defaultValue)
-  : ItemString( _group, _key, reference, defaultValue, Password )
-{
-}
-
 KCoreConfigSkeleton::ItemPath::ItemPath( const QString &_group, const QString &_key,
                                     QString &reference,
                                     const QString &defaultValue)
@@ -436,18 +421,7 @@ KCoreConfigSkeleton::ItemEnum::ItemEnum( const QString &_group, const QString &_
                                      qint32 defaultValue )
   : ItemInt( _group, _key, reference, defaultValue )
 {
-    foreach (const ItemEnum::Choice &c, choices) {
-        ItemEnum::Choice2 cc = { c.name, c.label, QString(), c.whatsThis };
-        mChoices.append(cc);
-    }
-}
-
-KCoreConfigSkeleton::ItemEnum::ItemEnum( const QString &_group, const QString &_key,
-                                     qint32 &reference,
-                                     const QList<Choice2> &choices,
-                                     qint32 defaultValue )
-  : ItemInt( _group, _key, reference, defaultValue ), mChoices(choices)
-{
+    mChoices = choices;
 }
 
 void KCoreConfigSkeleton::ItemEnum::readConfig( KConfig *config )
@@ -462,7 +436,7 @@ void KCoreConfigSkeleton::ItemEnum::readConfig( KConfig *config )
     int i = 0;
     mReference = -1;
     QString tmp = cg.readEntry( mKey, QString() ).toLower();
-    for(QList<Choice2>::ConstIterator it = mChoices.constBegin();
+    for(QList<Choice>::ConstIterator it = mChoices.constBegin();
         it != mChoices.constEnd(); ++it, ++i)
     {
       if ((*it).name.toLower() == tmp)
@@ -494,16 +468,6 @@ void KCoreConfigSkeleton::ItemEnum::writeConfig( KConfig *config )
 }
 
 QList<KCoreConfigSkeleton::ItemEnum::Choice> KCoreConfigSkeleton::ItemEnum::choices() const
-{
-    QList<KCoreConfigSkeleton::ItemEnum::Choice> r;
-    foreach (const KCoreConfigSkeleton::ItemEnum::Choice2 &c, mChoices) {
-        KCoreConfigSkeleton::ItemEnum::Choice cc = { c.name, c.label, c.whatsThis };
-        r.append(cc);
-    }
-    return r;
-}
-
-QList<KCoreConfigSkeleton::ItemEnum::Choice2> KCoreConfigSkeleton::ItemEnum::choices2() const
 {
     return mChoices;
 }
@@ -636,7 +600,7 @@ void KCoreConfigSkeleton::ItemULongLong::setMaxValue(quint64 v)
 KCoreConfigSkeleton::ItemDouble::ItemDouble( const QString &_group, const QString &_key,
                                     double &reference, double defaultValue )
   : KConfigSkeletonGenericItem<double>( _group, _key, reference, defaultValue )
-  ,mHasMin(false), mHasMax(false)
+  , mHasMin(false), mHasMax(false)
 {
 }
 
@@ -973,7 +937,8 @@ QVariant KCoreConfigSkeleton::ItemIntList::property() const
     return qVariantFromValue< QList<int> >(mReference);
 }
 
-static int kCoreConfigSkeletionDebugArea() { static int s_area = KDebug::registerArea("kdecore (KConfigSkeleton)"); return s_area; }
+// see kdebug.areas
+static int kCoreConfigSkeletionDebugArea() { return 184; }
 
 KCoreConfigSkeleton::KCoreConfigSkeleton(const QString &configname, QObject* parent)
   : QObject(parent),
@@ -1125,16 +1090,6 @@ KCoreConfigSkeleton::ItemString *KCoreConfigSkeleton::addItemString( const QStri
   return item;
 }
 
-KCoreConfigSkeleton::ItemPassword *KCoreConfigSkeleton::addItemPassword( const QString &name, QString &reference,
-                                       const QString &defaultValue, const QString &key )
-{
-  KCoreConfigSkeleton::ItemPassword *item;
-  item = new KCoreConfigSkeleton::ItemPassword( d->mCurrentGroup, key.isNull() ? name : key,
-                                          reference, defaultValue );
-  addItem( item, name );
-  return item;
-}
-
 KCoreConfigSkeleton::ItemPath *KCoreConfigSkeleton::addItemPath( const QString &name, QString &reference,
                                    const QString &defaultValue, const QString &key )
 {
@@ -1195,16 +1150,6 @@ KCoreConfigSkeleton::ItemLongLong *KCoreConfigSkeleton::addItemLongLong( const Q
   return item;
 }
 
-#ifndef KDE_NO_DEPRECATED
-KCoreConfigSkeleton::ItemLongLong *KCoreConfigSkeleton::addItemInt64(
-        const QString& name,
-        qint64 &reference,
-        qint64 defaultValue,
-        const QString & key)
-{
-    return addItemLongLong(name, reference, defaultValue, key);
-}
-#endif
 
 KCoreConfigSkeleton::ItemULongLong *KCoreConfigSkeleton::addItemULongLong( const QString &name, quint64 &reference,
                                      quint64 defaultValue, const QString &key )
@@ -1216,16 +1161,6 @@ KCoreConfigSkeleton::ItemULongLong *KCoreConfigSkeleton::addItemULongLong( const
   return item;
 }
 
-#ifndef KDE_NO_DEPRECATED
-KCoreConfigSkeleton::ItemULongLong *KCoreConfigSkeleton::addItemUInt64(
-        const QString & name,
-        quint64 &reference,
-        quint64 defaultValue,
-        const QString & key)
-{
-    return addItemULongLong(name, reference, defaultValue, key);
-}
-#endif
 
 KCoreConfigSkeleton::ItemDouble *KCoreConfigSkeleton::addItemDouble( const QString &name, double &reference,
                                      double defaultValue, const QString &key )
@@ -1297,26 +1232,16 @@ KCoreConfigSkeleton::ItemIntList *KCoreConfigSkeleton::addItemIntList( const QSt
   return item;
 }
 
-bool KCoreConfigSkeleton::isImmutable(const QString &name)
-{
-  return const_cast<const KCoreConfigSkeleton*>(this)->isImmutable(name);
-}
-
 bool KCoreConfigSkeleton::isImmutable(const QString &name) const
 {
   KConfigSkeletonItem *item = findItem(name);
   return !item || item->isImmutable();
 }
 
-KConfigSkeletonItem *KCoreConfigSkeleton::findItem(const QString &name)
-{
-  return const_cast<const KCoreConfigSkeleton*>(this)->findItem(name);
-}
-
 KConfigSkeletonItem *KCoreConfigSkeleton::findItem(const QString &name) const
 {
   return d->mItemDict.value(name);
 }
 
-#include "kcoreconfigskeleton.moc"
+#include "moc_kcoreconfigskeleton.cpp"
 
