@@ -28,8 +28,8 @@
 #include "kdebug.h"
 #include "klocale.h"
 
-#include <QtCore/QDate>
-#include <QtCore/QCharRef>
+#include <QtCore/qdatetime.h>
+#include <QtCore/qstring.h>
 
 static int hebrewDaysElapsed(int y);
 
