@@ -1,6 +1,6 @@
 /*
     This file is part of the KDE libraries
-    Copyright (c) 2005-2008 David Jarvie <djarvie@kde.org>
+    Copyright (c) 2005-2011 David Jarvie <djarvie@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -26,12 +26,11 @@
 #ifndef _KDATETIME_H_
 #define _KDATETIME_H_
 
-#include <kdecore_export.h>
 #include <ktimezone.h>
 
-#include <QtCore/QSharedDataPointer>
+#include <QMetaType>
+#include <QDataStream>
 
-class QDataStream;
 class KDateTimePrivate;
 class KDateTimeSpecPrivate;
 
@@ -123,7 +122,7 @@ class KDateTimeSpecPrivate;
  * conversions even after the copy is performed. A separate copy of the data is
  * created whenever a non-const method is called. If you want to force the
  * creation of a separate copy of the data (e.g. if you want two copies to
- * cache different time zone conversions), call detach(). 
+ * cache different time zone conversions), call detach().
  *
  * @section compatibility QDateTime Considerations
  *
@@ -435,10 +434,15 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
                      *   with, if not local time, the UTC offset appended. The
                      *   time may be omitted to indicate a date-only value.
                      */
-        LocalDate   /**< Same format as Qt::LocalDate (i.e. locale dependent)
+        LocalDate,  /**< Same format as Qt::SystemLocaleShortDate (i.e. locale dependent)
                      *   with, if not local time, the UTC offset appended. The
                      *   time may be omitted to indicate a date-only value.
                      */
+        RFC3339Date /**< RFC 3339 format,
+                     *   i.e. "YYYY-MM-DDThh:mm:ss[.sss](Z|±hh:mm)".
+                     *   There is no valid date-only format.
+                     */
+
     };
 
     /**
@@ -1119,7 +1123,7 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      * expressed in UTC.
      *
      * @return current date/time
-     * @see currentLocalDateTime(), currentDateTime()
+     * @see currentLocalDateTime(), currentDateTime(), currentLocalDate(), currentLocalTime()
      */
     static KDateTime currentUtcDateTime();
 
@@ -1127,68 +1131,92 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      * Returns the current date and time, as reported by the system clock,
      * expressed in a given time specification.
      *
+     * @note To fetch the current date and time expressed in UTC or in the local
+     * system time zone, it is more efficient to use currentUtcDateTime() or
+     * currentLocalDateTime().
+     *
      * @param spec time specification
      * @return current date/time
      * @see currentUtcDateTime(), currentLocalDateTime()
      */
     static KDateTime currentDateTime(const Spec &spec);
 
+    /**
+     * Returns the current date in the local time zone, as reported by the
+     * system clock.
+     *
+     * @return current date
+     * @see currentLocalDateTime(), currentLocalTime()
+     * @since 4.3
+     */
+    static QDate currentLocalDate();
+
+    /**
+     * Returns the current time of day in the local time zone, as reported
+     * by the system clock.
+     *
+     * @return current date
+     * @see currentLocalDateTime(), currentLocalDate()
+     * @since 4.3
+     */
+    static QTime currentLocalTime();
+
     /**
      * Returns the date/time as a string. The @p format parameter determines the
      * format of the result string. The @p format codes used for the date and time
      * components follow those used elsewhere in KDE, and are similar but not
      * identical to those used by strftime(3). Conversion specifiers are
-     * introduced by a '%' character, and are replaced in @p format as follows:
+     * introduced by a '\%' character, and are replaced in @p format as follows:
      *
      * \b Date
      *
-     * - %y   2-digit year excluding century (00 - 99). Conversion is undefined
-     *        if year < 0.
-     * - %Y   full year number
-     * - %:m  month number, without leading zero (1 - 12)
-     * - %m   month number, 2 digits (01 - 12)
-     * - %b   abbreviated month name in current locale
-     * - %B   full month name in current locale
-     * - %:b  abbreviated month name in English (Jan, Feb, ...)
-     * - %:B  full month name in English
-     * - %e   day of the month (1 - 31)
-     * - %d   day of the month, 2 digits (01 - 31)
-     * - %a   abbreviated weekday name in current locale
-     * - %A   full weekday name in current locale
-     * - %:a  abbreviated weekday name in English (Mon, Tue, ...)
-     * - %:A  full weekday name in English
+     * - \%y   2-digit year excluding century (00 - 99). Conversion is undefined
+     *         if year < 0.
+     * - \%Y   full year number
+     * -  %:m  month number, without leading zero (1 - 12)
+     * - \%m   month number, 2 digits (01 - 12)
+     * - \%b   abbreviated month name in current locale
+     * - \%B   full month name in current locale
+     * -  %:b  abbreviated month name in English (Jan, Feb, ...)
+     * -  %:B  full month name in English
+     * - \%e   day of the month (1 - 31)
+     * - \%d   day of the month, 2 digits (01 - 31)
+     * - \%a   abbreviated weekday name in current locale
+     * - \%A   full weekday name in current locale
+     * -  %:a  abbreviated weekday name in English (Mon, Tue, ...)
+     * -  %:A  full weekday name in English
      *
      * \b Time
      *
-     * - %H   hour in the 24 hour clock, 2 digits (00 - 23)
-     * - %k   hour in the 24 hour clock, without leading zero (0 - 23)
-     * - %I   hour in the 12 hour clock, 2 digits (01 - 12)
-     * - %l   hour in the 12 hour clock, without leading zero (1 - 12)
-     * - %M   minute, 2 digits (00 - 59)
-     * - %S   seconds (00 - 59)
-     * - %:S  seconds preceded with ':', but omitted if seconds value is zero
-     * - %:s  milliseconds, 3 digits (000 - 999)
-     * - %P   "am" or "pm" in the current locale, or if undefined there, in English
-     * - %p   "AM" or "PM" in the current locale, or if undefined there, in English
-     * - %:P  "am" or "pm"
-     * - %:p  "AM" or "PM"
+     * - \%H   hour in the 24 hour clock, 2 digits (00 - 23)
+     * - \%k   hour in the 24 hour clock, without leading zero (0 - 23)
+     * - \%I   hour in the 12 hour clock, 2 digits (01 - 12)
+     * - \%l   hour in the 12 hour clock, without leading zero (1 - 12)
+     * - \%M   minute, 2 digits (00 - 59)
+     * - \%S   seconds (00 - 59)
+     * -  %:S  seconds preceded with ':', but omitted if seconds value is zero
+     * -  %:s  milliseconds, 3 digits (000 - 999)
+     * - \%P   "am" or "pm" in the current locale, or if undefined there, in English
+     * - \%p   "AM" or "PM" in the current locale, or if undefined there, in English
+     * -  %:P  "am" or "pm"
+     * -  %:p  "AM" or "PM"
      *
      * \b Time zone
      *
-     * - %:u  UTC offset of the time zone in hours, e.g. -02. If the offset
-     *        is not a whole number of hours, the output is the same as for '%U'.
-     * - %z   UTC offset of the time zone in hours and minutes, e.g. -0200.
-     * - %:z  UTC offset of the time zone in hours and minutes, e.g. +02:00.
-     * - %Z   time zone abbreviation, e.g. UTC, EDT, GMT. This is not guaranteed
-     *        to be unique among different time zones. If not applicable (i.e. if
-     *        the instance is type OffsetFromUTC), the UTC offset is substituted.
-     * - %:Z  time zone name, e.g. Europe/London. This is system dependent. If
-     *        not applicable (i.e. if the instance is type OffsetFromUTC), the
-     *        UTC offset is substituted.
+     * -  %:u  UTC offset of the time zone in hours, e.g. -02. If the offset
+     *         is not a whole number of hours, the output is the same as for '\%U'.
+     * - \%z   UTC offset of the time zone in hours and minutes, e.g. -0200.
+     * -  %:z  UTC offset of the time zone in hours and minutes, e.g. +02:00.
+     * - \%Z   time zone abbreviation, e.g. UTC, EDT, GMT. This is not guaranteed
+     *         to be unique among different time zones. If not applicable (i.e. if
+     *         the instance is type OffsetFromUTC), the UTC offset is substituted.
+     * -  %:Z  time zone name, e.g. Europe/London. This is system dependent. If
+     *         not applicable (i.e. if the instance is type OffsetFromUTC), the
+     *         UTC offset is substituted.
      *
      * \b Other
      *
-     * - %%   literal '%' character
+     * -  %%   literal '\%' character
      *
      * Note that if the instance has a time specification of ClockTime, the
      * time zone or UTC offset in the result will be blank.
@@ -1207,8 +1235,8 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      * parameter, with the UTC offset appended.
      *
      * Note that if the instance has a time specification of ClockTime, the UTC
-     * offset in the result will be blank, except for RFC 2822 format in which
-     * it will be the offset for the local system time zone.
+     * offset in the result will be blank, except for RFC 2822 and RFC 3339
+     * formats in which it will be the offset for the local system time zone.
      *
      * If the instance is date-only, the time will when @p format permits be
      * omitted from the output string. This applies to @p format = QtTextDate
@@ -1237,8 +1265,9 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      * present in the string:
      * - if the UTC offset is zero the result is type @c UTC.
      * - if the UTC offset is non-zero, the result is type @c OffsetFromUTC.
-     * - if there is no UTC offset, the result is by default type
-     *   @c ClockTime. You can use setFromStringDefault() to change this default.
+     * - if there is no UTC offset (when @p format permits this), the result is
+     *   by default type @c ClockTime. You can use setFromStringDefault() to
+     *   change this default.
      *
      * If no time is found in @p string, a date-only value is returned, except
      * when the specified @p format does not permit the time to be omitted, in
@@ -1246,8 +1275,8 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      * ISODate when @p string includes a time zone specification, and for
      * RFCDate in all cases.
      *
-     * For RFC format strings, you should normally set @p format to
-     * RFCDate. Only set it to RFCDateDay if you want to return an error
+     * For RFC format strings (not RFC 3339), you should normally set @p format
+     * to RFCDate. Only set it to RFCDateDay if you want to return an error
      * when the day of the week is omitted.
      *
      * For @p format = ISODate or RFCDate[Day], if an invalid KDateTime is
@@ -1285,65 +1314,65 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      *
      * \b Date
      *
-     * - %y   year excluding century (0 - 99). Years 0 - 50 return 2000 - 2050,
-     *        while years 51 - 99 return 1951 - 1999.
-     * - %Y   full year number (4 digits with optional sign)
-     * - %:Y  full year number (>= 4 digits with optional sign)
-     * - %:m  month number (1 - 12)
-     * - %m   month number, 2 digits (01 - 12)
-     * - %b
-     * - %B   month name in the current locale or, if no match, in English,
-     *        abbreviated or in full
-     * - %:b
-     * - %:B  month name in English, abbreviated or in full
-     * - %e   day of the month (1 - 31)
-     * - %d   day of the month, 2 digits (01 - 31)
-     * - %a
-     * - %A   weekday name in the current locale or, if no match, in English,
-     *        abbreviated or in full
-     * - %:a
-     * - %:A  weekday name in English, abbreviated or in full
+     * - \%y   year excluding century (0 - 99). Years 0 - 50 return 2000 - 2050,
+     *         while years 51 - 99 return 1951 - 1999.
+     * - \%Y   full year number (4 digits with optional sign)
+     * -  %:Y  full year number (>= 4 digits with optional sign)
+     * -  %:m  month number (1 - 12)
+     * - \%m   month number, 2 digits (01 - 12)
+     * - \%b
+     * - \%B   month name in the current locale or, if no match, in English,
+     *         abbreviated or in full
+     * -  %:b
+     * -  %:B  month name in English, abbreviated or in full
+     * - \%e   day of the month (1 - 31)
+     * - \%d   day of the month, 2 digits (01 - 31)
+     * - \%a
+     * - \%A   weekday name in the current locale or, if no match, in English,
+     *         abbreviated or in full
+     * -  %:a
+     * -  %:A  weekday name in English, abbreviated or in full
      *
      * \b Time
      *
-     * - %H   hour in the 24 hour clock, 2 digits (00 - 23)
-     * - %k   hour in the 24 hour clock (0 - 23)
-     * - %I   hour in the 12 hour clock, 2 digits (01 - 12)
-     * - %l   hour in the 12 hour clock (1 - 12)
-     * - %M   minute, 2 digits (00 - 59)
-     * - %:M  minute (0 - 59)
-     * - %S   seconds, 2 digits (00 - 59)
-     * - %s   seconds (0 - 59)
-     * - %:S  optional seconds value (0 - 59) preceded with ':'. If no colon is
-     *        found in @p string, no input is consumed and the seconds value is
-     *        set to zero.
-     * - %:s  fractional seconds value, preceded with a decimal point (either '.'
-     *        or the locale's decimal point symbol)
-     * - %P
-     * - %p   "am" or "pm", in the current locale or, if no match, in
-     *        English. This format is only useful when used with %I or %l.
-     * - %:P
-     * - %:p  "am" or "pm" in English. This format is only useful when used with
-     *        %I or %l.
+     * - \%H   hour in the 24 hour clock, 2 digits (00 - 23)
+     * - \%k   hour in the 24 hour clock (0 - 23)
+     * - \%I   hour in the 12 hour clock, 2 digits (01 - 12)
+     * - \%l   hour in the 12 hour clock (1 - 12)
+     * - \%M   minute, 2 digits (00 - 59)
+     * -  %:M  minute (0 - 59)
+     * - \%S   seconds, 2 digits (00 - 59)
+     * - \%s   seconds (0 - 59)
+     * -  %:S  optional seconds value (0 - 59) preceded with ':'. If no colon is
+     *         found in @p string, no input is consumed and the seconds value is
+     *         set to zero.
+     * -  %:s  fractional seconds value, preceded with a decimal point (either '.'
+     *         or the locale's decimal point symbol)
+     * - \%P
+     * - \%p   "am" or "pm", in the current locale or, if no match, in
+     *         English. This format is only useful when used with \%I or \%l.
+     * -  %:P
+     * -  %:p  "am" or "pm" in English. This format is only useful when used with
+     *         \%I or \%l.
      *
      * \b Time zone
      *
-     * - %:u
-     * - %z   UTC offset of the time zone in hours and optionally minutes,
-     *        e.g. -02, -0200.
-     * - %:z  UTC offset of the time zone in hours and minutes, colon separated,
-     *        e.g. +02:00.
-     * - %Z   time zone abbreviation, consisting of alphanumeric characters,
-     *        e.g. UTC, EDT, GMT.
-     * - %:Z  time zone name, e.g. Europe/London. The name may contain any
-     *        characters and is delimited by the following character in the
-     *        @p format string. It will not work if you follow %:Z with another
-     *        escape sequence (except %% or %t).
+     * -  %:u
+     * - \%z   UTC offset of the time zone in hours and optionally minutes,
+     *         e.g. -02, -0200.
+     * -  %:z  UTC offset of the time zone in hours and minutes, colon separated,
+     *         e.g. +02:00.
+     * - \%Z   time zone abbreviation, consisting of alphanumeric characters,
+     *         e.g. UTC, EDT, GMT.
+     * -  %:Z  time zone name, e.g. Europe/London. The name may contain any
+     *         characters and is delimited by the following character in the
+     *         @p format string. It will not work if you follow %:Z with another
+     *         escape sequence (except %% or \%t).
      *
      * \b Other
      *
-     * - %t   matches one or more whitespace characters
-     * - %%   literal '%' character
+     * - \%t   matches one or more whitespace characters
+     * -  %%   literal '\%' character
      *
      * Any other character must have a matching character in @p string, except
      * that a space will match zero or more whitespace characters in the input
@@ -1353,7 +1382,7 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      * attempts to find a matching time zone in the @p zones collection. A time
      * zone name (format code %:Z) will provide an unambiguous look up in
      * @p zones. Any other type of time zone information (an abbreviated time
-     * zone code (%Z) or UTC offset (%z, %:z, %:u) is searched for in @p zones
+     * zone code (\%Z) or UTC offset (\%z, %:z, %:u) is searched for in @p zones
      * and if only one time zone is found to match, the result is set to that
      * zone. Otherwise:
      * - If more than one match of a UTC offset is found, the action taken is
@@ -1420,6 +1449,11 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      */
     static void setFromStringDefault(const Spec &spec);
 
+    /**
+     * @return @c true if date represents night time of the day, @c false otherwise
+     * @since 4.20
+     */
+    bool isNightTime() const;
 
     /**
      * Checks whether the date/time returned by the last call to fromString()
@@ -1473,6 +1507,9 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      * the result cannot be guaranteed to be correct, since by definition they
      * contain no information about time zones or daylight savings changes.
      *
+     * If one instance is date-only and the other is date/time, they are
+     * considered unequal.
+     *
      * If both instances are date-only, they are considered simultaneous if both
      * their start of day and end of day times are simultaneous with each
      * other. (Both start and end of day times need to be considered in case a
@@ -1523,21 +1560,23 @@ class KDECORE_EXPORT KDateTime //krazy:exclude=dpointer (implicitly shared)
      */
     void detach();
 
-    friend QDataStream &operator<<(QDataStream &out, const KDateTime &dateTime);
-    friend QDataStream &operator>>(QDataStream &in, KDateTime &dateTime);
-
   private:
     QSharedDataPointer<KDateTimePrivate> d;
 };
 
+Q_DECLARE_METATYPE(KDateTime)
+Q_DECLARE_METATYPE(KDateTime::Spec)
+
+QT_BEGIN_NAMESPACE
 /** Write @p spec to the datastream @p out, in binary format. */
-QDataStream &operator<<(QDataStream &out, const KDateTime::Spec &spec);
+QDataStream KDECORE_EXPORT &operator<<(QDataStream &out, const KDateTime::Spec &spec);
 /** Read a KDateTime::Spec object into @p spec from @p in, in binary format. */
-QDataStream &operator>>(QDataStream &in, KDateTime::Spec &spec);
+QDataStream KDECORE_EXPORT &operator>>(QDataStream &in, KDateTime::Spec &spec);
 
 /** Write @p dateTime to the datastream @p out, in binary format. */
-QDataStream &operator<<(QDataStream &out, const KDateTime &dateTime);
+QDataStream KDECORE_EXPORT &operator<<(QDataStream &out, const KDateTime &dateTime);
 /** Read a KDateTime object into @p dateTime from @p in, in binary format. */
-QDataStream &operator>>(QDataStream &in, KDateTime &dateTime);
+QDataStream KDECORE_EXPORT &operator>>(QDataStream &in, KDateTime &dateTime);
+QT_END_NAMESPACE
 
 #endif
