@@ -20,7 +20,7 @@
 
 #include "kdatetimeformatter_p.h"
 
-#include <QtCore/QDate>
+#include <QtCore/qdatetime.h>
 #include <QtCore/QString>
 #include <QtCore/QStringList>
 #include <QtCore/QChar>
@@ -28,7 +28,6 @@
 #include "kdatetime.h"
 #include "ktimezone.h"
 #include "kcalendarsystem.h"
-#include "kdayperiod_p.h"
 #include "klocale_p.h"
 #include "kdebug.h"
 
