@@ -25,20 +25,17 @@
  * @author S.R.Haque <srhaque@iee.org>.
  */
 
-#ifndef _KTIMEZONES_H
-#define _KTIMEZONES_H
+#ifndef KTIMEZONES_H
+#define KTIMEZONES_H
 
 #include <kdecore_export.h>
 
 #include <sys/time.h>
 #include <ctime>
 
-#include <QtCore/QDateTime>
-#include <QtCore/QMap>
-#include <QtCore/QList>
-#include <QtCore/QString>
-#include <QtCore/QByteArray>
-#include <QtCore/QSharedDataPointer>
+#include <QtCore/qdatetime.h>
+#include <QtCore/qmap.h>
+#include <QtCore/qshareddata.h>
 
 class KTimeZone;
 class KTimeZoneBackend;
@@ -119,39 +116,7 @@ class KTimeZoneLeapSecondsPrivate;
  *
  * Access to system time zones is provided by the KSystemTimeZones class, which
  * reads the zone.tab file to obtain the list of system time zones, and creates a
- * KSystemTimeZone instance for each one. KSystemTimeZone has a
- * KSystemTimeZoneBackend backend class, and uses the KSystemTimeZoneSource
- * and KSystemTimeZoneData classes to obtain time zone data via libc library
- * functions.
- *
- * Normally, KSystemTimeZoneSource and KSystemTimeZoneData operate in the
- * background and you will not need to use them directly.
- *
- * @warning The KSystemTimeZone class uses the standard system libraries to
- * access time zone data, and its functionality is limited to what these libraries
- * provide. On many systems, dates earlier than 1902 are not handled, and on
- * non-GNU systems there is no guarantee that the time zone abbreviation returned
- * for a given date will be correct if the abbreviations applicable then were
- * not those currently in use. The KSystemTimeZones::readZone() method overcomes
- * these restrictions by reading the time zone definition directly from the
- * system time zone database files.
- *
- * \section tzfile Tzfile access
- *
- * The KTzfileTimeZone class provides access to tzfile(5) time zone definition
- * files, which are used to form the time zone database on UNIX systems. Usually,
- * for current information, it is easier to use the KSystemTimeZones class to
- * access system tzfile data. However, for dealing with past data the
- * KTzfileTimeZone class provides better guarantees of accurary, although it
- * cannot handle dates earlier than 1902. It also provides more detailed
- * information, and allows you to read non-system tzfile files. Alternatively,
- * the KSystemTimeZones::readZone() method uses the KTzfileTimeZone class to
- * read system time zone definition files.
- *
- * KTzfileTimeZone has a KTzfileTimeZoneBackend backend class, and uses the
- * KTzfileTimeZoneSource and KTzfileTimeZoneData classes to obtain time zone
- * data from tzfile files.
- *
+ * KTimeZone instance for each one.
  *
  * \section deriving Handling time zone data from other sources
  *
@@ -319,12 +284,13 @@ public:
      */
     KTimeZone zone(const QString &name) const;
 
+    /** Map of KTimeZone instances, indexed by time zone name. */
     typedef QMap<QString, KTimeZone> ZoneMap;
 
     /**
      * Returns all the time zones defined in this collection.
      *
-     * @return time zone collection
+     * @return time zone collection, indexed by time zone name
      */
     const ZoneMap zones() const;
 
@@ -428,6 +394,10 @@ public:
     class KDECORE_EXPORT Phase
     {
     public:
+        /**
+	 * Default constructor.
+	 * Creates a standard-time time zone phase with UTC offset 0.
+	 */
         Phase();
 
         /**
@@ -610,6 +580,21 @@ public:
      */
     explicit KTimeZone(const QString &name);
 
+    /**
+     * Creates a time zone.
+     *
+     * @param source      tzfile reader and parser
+     * @param name        time zone's unique name, which must be the tzfile path relative
+     *                    to the location specified for @p source
+     * @param countryCode ISO 3166 2-character country code, empty if unknown
+     * @param latitude    in degrees (between -90 and +90), UNKNOWN if not known
+     * @param longitude   in degrees (between -180 and +180), UNKNOWN if not known
+     * @param comment     description of the time zone, if any
+     */
+    KTimeZone(KTimeZoneSource *source, const QString &name,
+        const QString &countryCode = QString(), float latitude = UNKNOWN, float longitude = UNKNOWN,
+        const QString &comment = QString());
+
     KTimeZone(const KTimeZone &tz);
     KTimeZone &operator=(const KTimeZone &tz);
 
@@ -1120,6 +1105,22 @@ public:
     /** Implements KTimeZone::KTimeZone(const QString&). */
     explicit KTimeZoneBackend(const QString &name);
 
+    /**
+     * Constructs a time zone.
+     *
+     * @param source      reader/parser for the database containing this time zone. This will
+     *                    be an instance of a class derived from KTimeZoneSource.
+     * @param name        in system-dependent format. The name must be unique within any
+     *                    KTimeZones instance which contains this KTimeZone.
+     * @param countryCode ISO 3166 2-character country code, empty if unknown
+     * @param latitude    in degrees (between -90 and +90), UNKNOWN if not known
+     * @param longitude   in degrees (between -180 and +180), UNKNOWN if not known
+     * @param comment     description of the time zone, if any
+     */
+    KTimeZoneBackend(KTimeZoneSource *source, const QString &name,
+                     const QString &countryCode = QString(), float latitude = KTimeZone::UNKNOWN,
+                     float longitude = KTimeZone::UNKNOWN, const QString &comment = QString());
+
     KTimeZoneBackend(const KTimeZoneBackend &other);
     KTimeZoneBackend &operator=(const KTimeZoneBackend &other);
     virtual ~KTimeZoneBackend();
@@ -1181,23 +1182,6 @@ public:
      */
     virtual bool hasTransitions(const KTimeZone* caller) const;
 
-protected:
-    /**
-     * Constructs a time zone.
-     *
-     * @param source      reader/parser for the database containing this time zone. This will
-     *                    be an instance of a class derived from KTimeZoneSource.
-     * @param name        in system-dependent format. The name must be unique within any
-     *                    KTimeZones instance which contains this KTimeZone.
-     * @param countryCode ISO 3166 2-character country code, empty if unknown
-     * @param latitude    in degrees (between -90 and +90), UNKNOWN if not known
-     * @param longitude   in degrees (between -180 and +180), UNKNOWN if not known
-     * @param comment     description of the time zone, if any
-     */
-    KTimeZoneBackend(KTimeZoneSource *source, const QString &name,
-                     const QString &countryCode = QString(), float latitude = KTimeZone::UNKNOWN,
-                     float longitude = KTimeZone::UNKNOWN, const QString &comment = QString());
-
 private:
     KTimeZonePrivate *d;   // non-const
     friend class KTimeZone;
@@ -1226,6 +1210,19 @@ class KDECORE_EXPORT KTimeZoneSource
 {
 public:
     KTimeZoneSource();
+
+    /**
+     * Constructs a time zone source.
+     *
+     * The directory containing the time zone definition files is given by the
+     * @p location parameter, which will usually be the zoneinfo directory. For
+     * tzfile files in other locations, bear in mind that the name generated
+     * for each KTimeZone is its file path relative to @p location.
+     *
+     * @param location the local directory containing the time zone definition files
+     */
+    explicit KTimeZoneSource(const QString &location);
+
     virtual ~KTimeZoneSource();
 
     /**
@@ -1255,6 +1252,13 @@ public:
      */
     bool useZoneParse() const;
 
+    /**
+     * Returns the local directory containing the time zone definition files.
+     *
+     * @return path to time zone definition files
+     */
+    QString location() const;
+
 protected:
     /**
      * Constructor for use by derived classes, which specifies whether the
@@ -1484,6 +1488,19 @@ protected:
     /**
      * Initialise the daylight savings time phase list.
      *
+     * @param phases        list of phases
+     * @param previousPhase phase to use before the first daylight savings time
+     *                      transition
+     * @see phases()
+     * @since 4.8.3
+     */
+    void setPhases(const QList<KTimeZone::Phase> &phases, const KTimeZone::Phase& previousPhase);
+
+    /**
+     * Initialise the daylight savings time phase list.
+     * This setPhases() variant should be used when the time zone abbreviation
+     * used before the start of the first phase is not known.
+     *
      * @param phases list of phases
      * @param previousUtcOffset UTC offset to use before the start of the first
      *                          phase
@@ -1508,6 +1525,8 @@ protected:
     void setLeapSecondChanges(const QList<KTimeZone::LeapSeconds> &adjusts);
 
 private:
+    friend KTimeZoneSource;
+
     KTimeZoneDataPrivate * const d;
 };
 
