@@ -38,13 +38,14 @@
 #include <unistd.h>
 
 #include <QtCore/QDir>
-#include <QtCore/QMutableStringListIterator>
+#include <QtCore/QStringList>
 #include <QtCore/QRegExp>
 #include <QtCore/QMimeData>
 #include <QtCore/QTextCodec>
+#include <QtNetwork/QHostInfo>
 
 #ifdef DEBUG_KURL
-static int kurlDebugArea() { static int s_area = KDebug::registerArea("kdecore (KUrl)"); return s_area; }
+static const int kurlDebugArea = 181; // see kdebug.areas
 #endif
 
 static QString cleanpath( const QString &_path, bool cleanDirSeparator, bool decodeDots )
@@ -61,10 +62,10 @@ static QString cleanpath( const QString &_path, bool cleanDirSeparator, bool dec
 
   if (decodeDots)
   {
-     static const QString &encodedDot = KGlobal::staticQString("%2e");
+     static const QString encodedDot = QString::fromLatin1("%2e");
      if (path.indexOf(encodedDot, 0, Qt::CaseInsensitive) != -1)
      {
-        static const QString &encodedDOT = KGlobal::staticQString("%2E"); // Uppercase!
+        static const QString encodedDOT = QString::fromLatin1("%2E"); // Uppercase!
         path.replace(encodedDot, QString(QLatin1Char('.')));
         path.replace(encodedDOT, QString(QLatin1Char('.')));
         len = path.length();
@@ -106,11 +107,6 @@ static QString cleanpath( const QString &_path, bool cleanDirSeparator, bool dec
     orig_pos = pos;
   }
 
-#ifdef Q_WS_WIN // prepend drive letter if exists (js)
-  if (orig_pos >= 2 && path[0].isLetter() && path[1] == QLatin1Char(':') ) {
-    result.prepend(QString(path[0]) + QLatin1Char(':') );
-  }
-#endif
 
   if ( result.isEmpty() )
     result = QLatin1Char('/');
@@ -120,42 +116,6 @@ static QString cleanpath( const QString &_path, bool cleanDirSeparator, bool dec
   return result;
 }
 
-#ifdef Q_WS_WIN
-
-// returns true if provided arguments desinate letter+colon or double slash
-#define IS_DRIVE_OR_DOUBLESLASH(isletter, char1, char2, colon, slash) \
-  ((isletter && char2 == colon) || (char1 == slash && char2 == slash))
-
-// Removes file:/// or file:// or file:/ or / prefix assuming that str
-// is (nonempty) Windows absolute path with a drive letter or double slash.
-// If there was file protocol, the path is decoded from percent encoding
-static QString removeSlashOrFilePrefix(const QString& str)
-{
-  // FIXME this should maybe be replaced with some (faster?)/nicer logic
-  const int len = str.length();
-  if (str[0]==QLatin1Char('f')) {
-    if ( len > 10 && str.startsWith( QLatin1String( "file:///" ) )
-         && IS_DRIVE_OR_DOUBLESLASH(str[8].isLetter(), str[8], str[9], QLatin1Char(':'), QLatin1Char('/')) )
-      return QUrl::fromPercentEncoding( str.toLatin1() ).mid(8);
-    else if ( len > 9 && str.startsWith( QLatin1String( "file://" ) )
-              && IS_DRIVE_OR_DOUBLESLASH(str[7].isLetter(), str[7], str[8], QLatin1Char(':'), QLatin1Char('/')) )
-      return QUrl::fromPercentEncoding( str.toLatin1() ).mid(7);
-    else if ( len > 8 && str.startsWith( QLatin1String( "file:/" ) )
-              && IS_DRIVE_OR_DOUBLESLASH(str[6].isLetter(), str[6], str[7], QLatin1Char(':'), QLatin1Char('/')) )
-      return QUrl::fromPercentEncoding( str.toLatin1() ).mid(6);
-  }
-  /* No 'else' here since there can be "f:/" path. */
-
-  /* '/' + drive letter or // */
-  if ( len > 2 && str[0] == QLatin1Char('/')
-       && IS_DRIVE_OR_DOUBLESLASH(str[1].isLetter(), str[1], str[2], QLatin1Char(':'), QLatin1Char('/')) )
-    return str.mid(1);
-  /* drive letter or // */
-  else if ( len >= 2 && IS_DRIVE_OR_DOUBLESLASH(str[0].isLetter(), str[0], str[1], QLatin1Char(':'), QLatin1Char('/')) )
-    return str;
-  return QString();
-}
-#endif
 
 bool KUrl::isRelativeUrl(const QString &_url)
 {
@@ -225,21 +185,14 @@ QStringList KUrl::List::toStringList(KUrl::AdjustPathOption trailing) const
 
 static QByteArray uriListData(const KUrl::List& urls)
 {
-    QList<QByteArray> urlStringList;
-    KUrl::List::ConstIterator uit = urls.constBegin();
-    const KUrl::List::ConstIterator uEnd = urls.constEnd();
-    for (; uit != uEnd ; ++uit) {
+    QByteArray uriListData;
+    foreach(const KUrl &uit, urls) {
         // Get each URL encoded in utf8 - and since we get it in escaped
         // form on top of that, .toLatin1() is fine.
-        urlStringList.append((*uit).toMimeDataString().toLatin1());
+        uriListData += uit.toMimeDataString().toLatin1();
+        uriListData += "\r\n";
     }
 
-    QByteArray uriListData;
-    for (int i = 0, n = urlStringList.count(); i < n; ++i) {
-      uriListData += urlStringList.at(i);
-        if (i < n-1)
-          uriListData += "\r\n";
-    }
     return uriListData;
 }
 
@@ -273,8 +226,10 @@ void KUrl::List::populateMimeData( QMimeData* mimeData,
     if ( !metaData.isEmpty() )
     {
         QByteArray metaDataData; // :)
-        for( KUrl::MetaDataMap::const_iterator it = metaData.begin(); it != metaData.end(); ++it )
+        QMapIterator<QString, QString> it(metaData);
+        while(it.hasNext())
         {
+            it.next();
             metaDataData += it.key().toUtf8();
             metaDataData += "$@@$";
             metaDataData += it.value().toUtf8();
@@ -309,8 +264,8 @@ QStringList KUrl::List::mimeDataTypes()
 
 
 KUrl::List KUrl::List::fromMimeData(const QMimeData *mimeData,
-                                    DecodeOptions decodeOptions,
-                                    KUrl::MetaDataMap* metaData)
+                                    KUrl::MetaDataMap* metaData,
+                                    DecodeOptions decodeOptions)
 {
 
     KUrl::List uris;
@@ -349,14 +304,13 @@ KUrl::List KUrl::List::fromMimeData(const QMimeData *mimeData,
             Q_ASSERT(str.endsWith(QLatin1String("$@@$")));
             str.truncate( str.length() - 4 );
             const QStringList lst = str.split(QLatin1String("$@@$"));
-            QStringList::ConstIterator it = lst.begin();
             bool readingKey = true; // true, then false, then true, etc.
             QString key;
-            for ( ; it != lst.end(); ++it ) {
+            foreach(const QString &it, lst) {
                 if ( readingKey )
-                    key = *it;
+                    key = it;
                 else
-                    metaData->insert( key, *it );
+                    metaData->insert( key, it );
                 readingKey = !readingKey;
             }
             Q_ASSERT( readingKey ); // an odd number of items would be, well, odd ;-)
@@ -366,11 +320,6 @@ KUrl::List KUrl::List::fromMimeData(const QMimeData *mimeData,
     return uris;
 }
 
-KUrl::List KUrl::List::fromMimeData( const QMimeData *mimeData, KUrl::MetaDataMap* metaData )
-{
-    return fromMimeData(mimeData, PreferKdeUrls, metaData);
-}
-
 KUrl::List::operator QVariant() const
 {
   return qVariantFromValue(*this);
@@ -388,7 +337,7 @@ KUrl::List::operator QList<QUrl>() const
 ///
 
 KUrl::KUrl()
-    : QUrl(), d(0)
+    : QUrl()
 {
 }
 
@@ -398,31 +347,9 @@ KUrl::~KUrl()
 
 
 KUrl::KUrl( const QString &str )
-  : QUrl(), d(0)
+  : QUrl()
 {
   if ( !str.isEmpty() ) {
-#ifdef Q_WS_WIN
-#ifdef DEBUG_KURL
-    kDebug(kurlDebugArea()) << "KUrl::KUrl ( const QString &str = " << str.toLatin1().data() << " )";
-#endif
-    QString pathToSet;
-    // when it starts with file:// it's a url and must be valid. we don't care if the
-    // path exist/ is valid or not
-    if (!str.startsWith(QLatin1String("file://")))
-      pathToSet = removeSlashOrFilePrefix( QDir::fromNativeSeparators(str) );
-    if ( !pathToSet.isEmpty() ) {
-      // we have a prefix indicating this is a local URL
-      // remember the possible query using _setEncodedUrl(), then set up the correct path without query protocol part
-      int index = pathToSet.lastIndexOf(QLatin1Char('?'));
-      if (index == -1)
-        setPath( pathToSet );
-      else {
-        setPath( pathToSet.left( index ) );
-        _setQuery( pathToSet.mid( index + 1 ) );
-      }
-      return;
-    }
-#endif
     if ( str[0] == QLatin1Char('/') || str[0] == QLatin1Char('~') )
       setPath( str );
     else {
@@ -432,31 +359,8 @@ KUrl::KUrl( const QString &str )
 }
 
 KUrl::KUrl( const char * str )
-  : QUrl(), d(0)
+  : QUrl()
 {
-#ifdef Q_WS_WIN
-  // true if @a c is letter
-  #define IS_LETTER(c) \
-    ((c >= QLatin1Char('A') && c <= QLatin1Char('Z')) || (c >= QLatin1Char('a') && c <= QLatin1Char('z')))
-
-  // like IS_DRIVE_OR_DOUBLESLASH, but slash is prepended
-  #define IS_SLASH_AND_DRIVE_OR_DOUBLESLASH_0 \
-    ( QLatin1Char(str[0]) == QLatin1Char('/') && IS_DRIVE_OR_DOUBLESLASH(IS_LETTER(QLatin1Char(str[1])), QLatin1Char(str[1]), QLatin1Char(str[2]), QLatin1Char(':'), QLatin1Char('/')) )
-
-  // like IS_DRIVE_OR_DOUBLESLASH, with characters == str[0] and str[1]
-  #define IS_DRIVE_OR_DOUBLESLASH_0 \
-    ( IS_DRIVE_OR_DOUBLESLASH(IS_LETTER(QLatin1Char(str[0])), QLatin1Char(str[0]), QLatin1Char(str[1]), QLatin1Char(':'), QLatin1Char('/')) )
-
-#if defined(DEBUG_KURL)
-  kDebug(kurlDebugArea()) << "KUrl::KUrl " << " " << str;
-#endif
-  if ( str && str[0] && str[1] && str[2] ) {
-    if ( IS_SLASH_AND_DRIVE_OR_DOUBLESLASH_0 )
-      setPath( QString::fromUtf8( str+1 ) );
-    else if ( IS_DRIVE_OR_DOUBLESLASH_0 )
-      setPath( QString::fromUtf8( str ) );
-  }
-#endif
   if ( str && str[0] ) {
     if ( str[0] == '/' || str[0] == '~' )
       setPath( QString::fromUtf8( str ) );
@@ -466,48 +370,29 @@ KUrl::KUrl( const char * str )
 }
 
 KUrl::KUrl( const QByteArray& str )
-   : QUrl(), d(0)
+   : QUrl()
 {
   if ( !str.isEmpty() ) {
-#ifdef Q_WS_WIN
-#ifdef DEBUG_KURL
-    kDebug(kurlDebugArea()) << "KUrl::KUrl " << " " << str.data();
-#endif
-    if ( IS_SLASH_AND_DRIVE_OR_DOUBLESLASH_0 )
-      setPath( QString::fromUtf8( str.mid( 1 ) ) );
-    else if ( IS_DRIVE_OR_DOUBLESLASH_0 )
-      setPath( QString::fromUtf8( str ) );
-#else
     if ( str[0] == '/' || str[0] == '~' )
       setPath( QString::fromUtf8( str ) );
-#endif
     else
       _setEncodedUrl( str );
   }
 }
 
 KUrl::KUrl( const KUrl& _u )
-    : QUrl( _u ), d(0)
+    : QUrl( _u )
 {
-#if defined(Q_WS_WIN) && defined(DEBUG_KURL)
-    kDebug(kurlDebugArea()) << "KUrl::KUrl(KUrl) " << " path " << _u.path() << " toLocalFile " << _u.toLocalFile();
-#endif
 }
 
 KUrl::KUrl( const QUrl &u )
-    : QUrl( u ), d(0)
+    : QUrl( u )
 {
-#if defined(Q_WS_WIN) && defined(DEBUG_KURL)
-    kDebug(kurlDebugArea()) << "KUrl::KUrl(Qurl) " << " path " << u.path() << " toLocalFile " << u.toLocalFile();
-#endif
 }
 
 KUrl::KUrl( const KUrl& _u, const QString& _rel_url )
-   : QUrl(), d(0)
+   : QUrl()
 {
-#if defined(Q_WS_WIN) && defined(DEBUG_KURL)
-    kDebug(kurlDebugArea()) << "KUrl::KUrl(KUrl,QString rel_url) " << " path " << _u.path() << " toLocalFile " << _u.toLocalFile();
-#endif
 #if 0
   if (_u.hasSubUrl()) // Operate on the last suburl, not the first
   {
@@ -543,8 +428,9 @@ KUrl::KUrl( const KUrl& _u, const QString& _rel_url )
     *this = _u;
     QByteArray strRef_encoded = rUrl.mid(1).toLatin1();
     if ( strRef_encoded.isNull() )
-        strRef_encoded = ""; // we know there was an (empty) html ref, we saw the '#'
-    setEncodedFragment( strRef_encoded );
+        setFragment(QString::fromLatin1("")); // we know there was an (empty) html ref, we saw the '#'
+    else
+        setFragment(QUrl::fromPercentEncoding(strRef_encoded));
   }
   else if ( isRelativeUrl( rUrl ) )
   {
@@ -577,16 +463,16 @@ KUrl::KUrl( const KUrl& _u, const QString& _rel_url )
           strPath = QLatin1Char('/');
     }
     setPath( strPath );
-    //kDebug(kurlDebugArea()) << "url()=" << url() << " rUrl=" << rUrl;
+    //kDebug(kurlDebugArea) << "url()=" << url() << " rUrl=" << rUrl;
     const KUrl tmp( url() + rUrl);
-    //kDebug(kurlDebugArea()) << "assigning tmp=" << tmp.url();
+    //kDebug(kurlDebugArea) << "assigning tmp=" << tmp.url();
     *this = tmp;
     cleanPath(KeepDirSeparators);
   }
   else
   {
     const KUrl tmp( rUrl );
-    //kDebug(kurlDebugArea()) << "not relative; assigning tmp=" << tmp.url();
+    //kDebug(kurlDebugArea) << "not relative; assigning tmp=" << tmp.url();
     *this = tmp;
     // Preserve userinfo if applicable.
     if (!_u.userInfo().isEmpty() && userInfo().isEmpty()
@@ -620,12 +506,6 @@ KUrl::operator QVariant() const
   return qVariantFromValue(*this);
 }
 
-#ifndef KDE_NO_DEPRECATED
-bool KUrl::cmp( const KUrl &u, bool ignore_trailing ) const
-{
-  return equals( u, ignore_trailing ? CompareWithoutTrailingSlash : EqualsOptions(0) );
-}
-#endif
 
 bool KUrl::equals( const KUrl &_u, const EqualsOptions& options ) const
 {
@@ -644,15 +524,6 @@ bool KUrl::equals( const KUrl &_u, const EqualsOptions& options ) const
             path2.clear();
     }
 
-#ifdef Q_WS_WIN
-    const bool bLocal1 = isLocalFile();
-    const bool bLocal2 = _u.isLocalFile();
-    if ( !bLocal1 && bLocal2 || bLocal1 && !bLocal2 )
-      return false;
-    // local files are case insensitive
-    if ( bLocal1 && bLocal2 && 0 != QString::compare( path1, path2, Qt::CaseInsensitive ) )
-      return false;
-#endif
     if ( path1 != path2 )
       return false;
 
@@ -668,56 +539,6 @@ bool KUrl::equals( const KUrl &_u, const EqualsOptions& options ) const
   return ( *this == _u );
 }
 
-QString KUrl::protocol() const
-{
-    return scheme().toLower();
-}
-
-void KUrl::setProtocol( const QString& proto )
-{
-    setScheme( proto );
-}
-
-QString KUrl::user() const
-{
-    return userName();
-}
-
-void KUrl::setUser( const QString& user )
-{
-    setUserName( user );
-}
-
-bool KUrl::hasUser() const
-{
-    return !userName().isEmpty();
-}
-
-QString KUrl::pass() const
-{
-    return password();
-}
-
-void KUrl::setPass( const QString& pass )
-{
-    setPassword( pass );
-}
-
-bool KUrl::hasPass() const
-{
-    return !password().isEmpty();
-}
-
-bool KUrl::hasHost() const
-{
-    return !host().isEmpty();
-}
-
-bool KUrl::hasPath() const
-{
-    return !path().isEmpty();
-}
-
 KUrl KUrl::fromPath( const QString& text )
 {
     KUrl u;
@@ -735,11 +556,7 @@ void KUrl::setFileName( const QString& _txt )
 
   QString path = this->path();
   if ( path.isEmpty() )
-#ifdef Q_OS_WIN
-    path = isLocalFile() ? QDir::rootPath() : QLatin1String("/");
-#else
     path = QDir::rootPath();
-#endif
   else
   {
     int lastSlash = path.lastIndexOf( QLatin1Char('/') );
@@ -815,18 +632,7 @@ void KUrl::adjustPath( AdjustPathOption trailing )
 QString KUrl::encodedPathAndQuery( AdjustPathOption trailing , const EncodedPathAndQueryOptions &options) const
 {
     QString encodedPath;
-#ifdef Q_OS_WIN
-    // see KUrl::path()
-    if (isLocalFile()) {
-        // ### this is probably broken
-        encodedPath = trailingSlash(trailing, QUrl::toLocalFile());
-        encodedPath = QString::fromLatin1(QUrl::toPercentEncoding(encodedPath, "!$&'()*+,;=:@/"));
-    } else {
-        encodedPath = trailingSlash(trailing, QString::fromLatin1(QUrl::encodedPath()));
-    }
-#else
     encodedPath = trailingSlash(trailing, QString::fromLatin1(QUrl::encodedPath()));
-#endif
 
     if ((options & AvoidEmptyPath) && encodedPath.isEmpty()) {
         encodedPath.append(QLatin1Char('/'));
@@ -871,14 +677,7 @@ void KUrl::setEncodedPathAndQuery( const QString& _txt )
 
 QString KUrl::path( AdjustPathOption trailing ) const
 {
-#ifdef Q_WS_WIN
-#ifdef DEBUG_KURL
-  kWarning() << (isLocalFile() ? "converted to local file - the related call should be converted to toLocalFile()" : "") << QUrl::path();
-#endif
-  return trailingSlash( trailing, isLocalFile() ? QUrl::toLocalFile() : QUrl::path() );
-#else
   return trailingSlash( trailing, QUrl::path() );
-#endif
 }
 
 QString KUrl::toLocalFile( AdjustPathOption trailing ) const
@@ -888,41 +687,22 @@ QString KUrl::toLocalFile( AdjustPathOption trailing ) const
         urlWithoutHost.setHost(QString());
         return trailingSlash(trailing, urlWithoutHost.toLocalFile());
     }
-#ifdef __GNUC__
-#warning FIXME: Remove #ifdef below once upstream bug, QTBUG-20322, is fixed. Also see BR# 194746.
-#endif
-#ifndef Q_WS_WIN
+#warning FIXME: Remove condition below once QTBUG-20322 is fixed, also see BR# 194746.
     if (isLocalFile()) {
         return trailingSlash(trailing, QUrl::path());
     }
-#endif
     return trailingSlash(trailing, QUrl::toLocalFile());
 }
 
-inline static bool hasSubUrl( const QUrl& url );
-
-static inline bool isLocalFile( const QUrl& url )
-{
-  if ( url.scheme().compare(QLatin1String("file"), Qt::CaseInsensitive) != 0 || hasSubUrl( url ) )
-     return false;
-
-  if (url.host().isEmpty() || (url.host() == QLatin1String("localhost")))
-     return true;
-
-  char hostname[ 256 ];
-  hostname[ 0 ] = '\0';
-  if (!gethostname( hostname, 255 ))
-     hostname[sizeof(hostname)-1] = '\0';
-
-  for(char *p = hostname; *p; p++)
-     *p = tolower(*p);
-
-  return (url.host() == QString::fromLatin1( hostname ));
-}
-
 bool KUrl::isLocalFile() const
 {
-  return ::isLocalFile( *this );
+  if ( scheme().compare(QLatin1String("file"), Qt::CaseInsensitive) != 0 || hasSubUrl() )
+     return false;
+
+  if (host().isEmpty() || (host() == QLatin1String("localhost")))
+     return true;
+
+  return (host() == QHostInfo::localHostName().toLower());
 }
 
 void KUrl::setFileEncoding(const QString &encoding)
@@ -968,25 +748,23 @@ QString KUrl::fileEncoding() const
      q = q.mid(1);
 
   const QStringList args = q.split(QLatin1Char('&'), QString::SkipEmptyParts);
-  for(QStringList::ConstIterator it = args.begin();
-      it != args.end();
-      ++it)
+  foreach(const QString &it, args)
   {
-      QString s = QUrl::fromPercentEncoding((*it).toLatin1());
+      QString s = QUrl::fromPercentEncoding(it.toLatin1());
       if (s.startsWith(QLatin1String("charset=")))
          return s.mid(8);
   }
   return QString();
 }
 
-inline static bool hasSubUrl( const QUrl& url )
+bool KUrl::hasSubUrl() const
 {
   // The isValid call triggers QUrlPrivate::validate which needs the full encoded url,
   // all this takes too much time for isLocalFile()
-  const QString scheme = url.scheme();
-  if ( scheme.isEmpty() /*|| !isValid()*/ )
+  const QString uscheme = scheme();
+  if ( uscheme.isEmpty() /*|| !isValid()*/ )
     return false;
-  const QString ref( url.fragment() );
+  const QString ref( fragment() );
   if (ref.isEmpty())
      return false;
   switch ( ref.at(0).unicode() ) {
@@ -1021,16 +799,11 @@ inline static bool hasSubUrl( const QUrl& url )
   default:
     break;
   }
-  if ( scheme == QLatin1String("error") ) // anything that starts with error: has suburls
+  if ( uscheme == QLatin1String("error") ) // anything that starts with error: has suburls
      return true;
   return false;
 }
 
-bool KUrl::hasSubUrl() const
-{
-  return ::hasSubUrl( *this );
-}
-
 QString KUrl::url( AdjustPathOption trailing ) const
 {
   if (QString::compare(scheme(), QLatin1String("mailto"), Qt::CaseInsensitive) == 0) {
@@ -1065,7 +838,7 @@ static QString toPrettyPercentEncoding(const QString &input, bool forFragment)
   result.reserve(input.length());
   for (int i = 0; i < input.length(); ++i) {
     const QChar c = input.at(i);
-    register ushort u = c.unicode();
+    ushort u = c.unicode();
     if (u < 0x20
         || (!forFragment && u == '?') // don't escape '?' in fragments, not needed and wrong (#173101)
         || u == '#' || u == '%'
@@ -1096,7 +869,8 @@ QString KUrl::prettyUrl( AdjustPathOption trailing ) const
   QString result = scheme();
   if (!result.isEmpty())
   {
-    if (!authority().isEmpty() || result == QLatin1String("file") || path().isEmpty())
+    if (!authority().isEmpty() || result == QLatin1String("file") || (path().isEmpty()
+        && scheme().compare(QLatin1String("mailto"), Qt::CaseInsensitive) != 0))
         result += QLatin1String("://");
     else
         result += QLatin1Char(':');
@@ -1121,10 +895,6 @@ QString KUrl::prettyUrl( AdjustPathOption trailing ) const
   }
 
   tmp = path();
-#ifdef Q_WS_WIN
-  if (isLocalFile())
-    tmp.prepend(QLatin1Char('/')); // KUrl::path() returns toLocalFile() on windows so we need to add the / back to create a proper url
-#endif
   result += toPrettyPercentEncoding(tmp, false);
 
   // adjust the trailing slash, if necessary
@@ -1152,19 +922,11 @@ QString KUrl::prettyUrl( int _trailing, AdjustementFlags _flags) const
   QString u = prettyUrl(_trailing);
   if (_flags & StripFileProtocol && u.startsWith("file://")) {
     u.remove(0, 7);
-#ifdef Q_WS_WIN
-    return QDir::convertSeparators(u);
-#endif
   }
   return u;
 }
 #endif
 
-QString KUrl::pathOrUrl() const
-{
-    return pathOrUrl(LeaveTrailingSlash);
-}
-
 QString KUrl::pathOrUrl(AdjustPathOption trailing) const
 {
   if ( isLocalFile() && fragment().isNull() && encodedQuery().isNull() ) {
@@ -1179,23 +941,7 @@ QString KUrl::toMimeDataString() const // don't fold this into populateMimeData,
 {
   if ( isLocalFile() )
   {
-#if 1
     return url();
-#else
-    // According to the XDND spec, file:/ URLs for DND must have
-    // the hostname part. But in really it just breaks many apps,
-    // so it's disabled for now.
-    const QString s = url( 0, KGlobal::locale()->fileEncodingMib() );
-    if( !s.startsWith( QLatin1String ( "file://" ) ))
-    {
-        char hostname[257];
-        if ( gethostname( hostname, 255 ) == 0 )
-        {
-            hostname[256] = '\0';
-            return QString( "file://" ) + hostname + s.mid( 5 );
-        }
-    }
-#endif
   }
 
   if (hasPass()) {
@@ -1372,7 +1118,7 @@ void KUrl::addPath( const QString& _txt )
   }
 
   setPath( strPath + _txt.mid( i ) );
-  //kDebug(kurlDebugArea())<<"addPath: resultpath="<<path();
+  //kDebug(kurlDebugArea)<<"addPath: resultpath="<<path();
 }
 
 QString KUrl::directory( const DirectoryOptions& options ) const
@@ -1396,12 +1142,6 @@ QString KUrl::directory( const DirectoryOptions& options ) const
     return QString(QLatin1Char('/'));
   }
 
-#ifdef Q_WS_WIN
-  if ( i == 2 && result[1] == QLatin1Char(':') )
-  {
-    return result.left(3);
-  }
-#endif
 
   if ( options & AppendTrailingSlash )
     result = result.left( i + 1 );
@@ -1430,11 +1170,7 @@ bool KUrl::cd( const QString& _dir )
   }
 
   // absolute path ?
-#ifdef Q_OS_WIN
-  if ( !QFileInfo(_dir).isRelative() )
-#else
   if ( _dir[0] == QLatin1Char('/') )
-#endif
   {
     //m_strPath_encoded.clear();
     setPath( _dir );
@@ -1599,89 +1335,7 @@ void KUrl::_setEncodedUrl(const QByteArray& url)
     setUrl(QString::fromUtf8(url), QUrl::TolerantMode);
 }
 
-#ifndef KDE_NO_DEPRECATED
-bool urlcmp( const QString& _url1, const QString& _url2 )
-{
-  return QUrl( _url1, QUrl::TolerantMode ) == QUrl( _url2, QUrl::TolerantMode );
-#if 0
-  // Both empty ?
-  if ( _url1.isEmpty() && _url2.isEmpty() )
-    return true;
-  // Only one empty ?
-  if ( _url1.isEmpty() || _url2.isEmpty() )
-    return false;
 
-  KUrl::List list1 = KUrl::split( _url1 );
-  KUrl::List list2 = KUrl::split( _url2 );
-
-  // Malformed ?
-  if ( list1.isEmpty() || list2.isEmpty() )
-    return false;
-
-  return ( list1 == list2 );
-#endif
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-bool urlcmp( const QString& _url1, const QString& _url2, const KUrl::EqualsOptions& _options )
-{
-    // Both empty ?
-    if (_url1.isEmpty() && _url2.isEmpty())
-        return true;
-    // Only one empty ?
-    if (_url1.isEmpty() || _url2.isEmpty())
-        return false;
-
-    KUrl u1(_url1);
-    KUrl u2(_url2);
-    return u1.equals(u2, _options);
-
-#if 0 // kde3 code that supported nested urls
-
-  KUrl::List list1 = KUrl::split( _url1 );
-  KUrl::List list2 = KUrl::split( _url2 );
-
-  // Malformed ?
-  if ( list1.isEmpty() || list2.isEmpty() )
-    return false;
-
-  int size = list1.count();
-  if ( list2.count() != size )
-    return false;
-
-  if ( _ignore_ref )
-  {
-    (*list1.begin()).setRef(QString());
-    (*list2.begin()).setRef(QString());
-  }
-
-  KUrl::List::Iterator it1 = list1.begin();
-  KUrl::List::Iterator it2 = list2.begin();
-  for( ; it1 != list1.end() ; ++it1, ++it2 )
-    if ( !(*it1).equals( *it2, _ignore_trailing ) )
-      return false;
-  return true;
-#endif
-}
-#endif
-
-// static
-#ifndef KDE_NO_DEPRECATED
-KUrl KUrl::fromPathOrUrl( const QString& text )
-{
-    KUrl url;
-    if ( !text.isEmpty() )
-    {
-        if (!QDir::isRelativePath(text) || text[0] == QLatin1Char('~'))
-            url.setPath( text );
-        else
-            url = KUrl( text );
-    }
-
-    return url;
-}
-#endif
 
 static QString _relativePath(const QString &base_dir, const QString &path, bool &isParent)
 {
@@ -1769,25 +1423,11 @@ QString KUrl::relativeUrl(const KUrl &base_url, const KUrl &url)
 
 void KUrl::setPath( const QString& _path )
 {
-#if defined(Q_WS_WIN) && defined(DEBUG_KURL)
-    kDebug(kurlDebugArea()) << "KUrl::setPath " << " " << _path.toLatin1().data();
-#endif
-    if ( scheme().isEmpty() )
+    if ( scheme().isEmpty() && !_path.startsWith( QLatin1String("file:/") ) )
         setScheme( QLatin1String( "file" ) );
     QString path = KShell::tildeExpand( _path );
     if (path.isEmpty())
         path = _path;
-#ifdef Q_WS_WIN
-    const int len = path.length();
-    if( len == 2 && IS_LETTER(path[0]) && path[1] == QLatin1Char(':') )
-        path += QLatin1Char('/');
-    //This is necessary because QUrl has the "path" part including the first slash
-    //Without this QUrl doesn't understand that this is a path, and some operations fail
-    //e.g. C:/blah needs to become /C:/blah
-    else
-    if( len > 0 && path[0] != QLatin1Char('/') && scheme() == QLatin1String( "file" ) )
-        path = QLatin1Char('/') + path;
-#endif
     QUrl::setPath( path );
 }
 
@@ -1811,13 +1451,13 @@ QMap< QString, QString > KUrl::queryItems( const QueryItemsOptions &options ) co
 
   QMap< QString, QString > result;
   const QStringList items = strQueryEncoded.split( QLatin1Char('&'), QString::SkipEmptyParts );
-  for ( QStringList::const_iterator it = items.begin() ; it != items.end() ; ++it ) {
-    const int equal_pos = (*it).indexOf(QLatin1Char('='));
+  foreach(const QString &it, items) {
+    const int equal_pos = it.indexOf(QLatin1Char('='));
     if ( equal_pos > 0 ) { // = is not the first char...
-      QString name = (*it).left( equal_pos );
+      QString name = it.left( equal_pos );
       if ( options & CaseInsensitiveKeys )
 	name = name.toLower();
-      QString value = (*it).mid( equal_pos + 1 );
+      QString value = it.mid( equal_pos + 1 );
       if ( value.isEmpty() )
         result.insert( name, QString::fromLatin1("") );
       else {
@@ -1826,7 +1466,7 @@ QMap< QString, QString > KUrl::queryItems( const QueryItemsOptions &options ) co
 	result.insert( name, QUrl::fromPercentEncoding( value.toLatin1() ) );
       }
     } else if ( equal_pos < 0 ) { // no =
-      QString name = (*it);
+      QString name = it;
       if ( options & CaseInsensitiveKeys )
 	name = name.toLower();
       result.insert( name, QString() );
@@ -1898,10 +1538,10 @@ void KUrl::setRef( const QString& fragment )
 
 QString KUrl::ref() const
 {
-  if ( fragment().isNull() )
+  if ( !hasFragment() )
     return QString();
   else
-    return QString::fromLatin1( QUrl::toPercentEncoding( fragment() ) );
+    return QString::fromLatin1( encodedFragment() );
 }
 
 bool KUrl::isParentOf( const KUrl& u ) const
