@@ -19,17 +19,15 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#ifndef kurl_h
-#define kurl_h
+#ifndef KURL_H
+#define KURL_H
 
 #include <kdecore_export.h>
 
-#include <QtCore/QVariant>
-#include <QtCore/QUrl>
-#include <QtCore/QMap>
-
-class QStringList;
-class QMimeData;
+#include <QtCore/qvariant.h>
+#include <QtCore/qurl.h>
+#include <QtCore/qstringlist.h>
+#include <QtCore/qmimedata.h>
 
 class KUrlPrivate;
 
@@ -108,7 +106,7 @@ class KUrlPrivate;
  * context.
  *
  */
-class KDECORE_EXPORT KUrl : public QUrl // krazy:exclude=dpointer,qclasses (krazy can't deal with embedded classes)
+class KDECORE_EXPORT KUrl : public QUrl
 {
 public:
   typedef QMap<QString, QString> MetaDataMap;
@@ -272,16 +270,6 @@ public:
         */
       static QStringList mimeDataTypes();
 
-      /**
-       * Extract a list of KUrls from the contents of @p mimeData.
-       * Decoding will fail if @p mimeData does not contain any URLs, or if at
-       * least one extracted URL is not valid.
-       * @param mimeData the mime data to extract from; cannot be 0
-       * @param metaData optional pointer to a map holding the metadata
-       * @return the list of urls
-       */
-      static KUrl::List fromMimeData( const QMimeData *mimeData, KUrl::MetaDataMap* metaData = 0 );
-
       /**
        * Flags to be used in fromMimeData.
        * @since 4.2.3
@@ -308,14 +296,14 @@ public:
        * Decoding will fail if @p mimeData does not contain any URLs, or if at
        * least one extracted URL is not valid.
        * @param mimeData the mime data to extract from; cannot be 0
-       * @param decodeOptions options for decoding
        * @param metaData optional pointer to a map holding the metadata
+       * @param decodeOptions options for decoding
        * @return the list of urls
        * @since 4.2.3
        */
       static KUrl::List fromMimeData( const QMimeData *mimeData,
-                                      DecodeOptions decodeOptions, // TODO KDE5: = PreferKdeUrls, and merge with above
-                                      KUrl::MetaDataMap* metaData = 0 );
+                                      KUrl::MetaDataMap* metaData = 0,
+                                      DecodeOptions decodeOptions = PreferKdeUrls );
 
   };
   /**
@@ -370,68 +358,6 @@ public:
    */
   KUrl( const KUrl& _baseurl, const QString& _rel_url );
 
-  /**
-   * Returns the protocol for the URL (i.e., file, http, etc.), lowercased.
-   * @see QUrl::scheme
-   */
-  QString protocol() const;
-
-  /**
-   * Sets the protocol for the URL (i.e., file, http, etc.)
-   * @param proto the new protocol of the URL (without colon)
-   */
-  void setProtocol( const QString& proto );
-
-  /**
-   * Returns the decoded user name (login, user id, ...) included in the URL.
-   * @return the user name or QString() if there is no user name
-   */
-  QString user() const;
-
-  /**
-   * Sets the user name (login, user id, ...) included in the URL.
-   *
-   * Special characters in the user name will appear encoded in the URL.
-   * @param user the name of the user or QString() to remove the user
-   */
-  void setUser( const QString& user );
-
-  /**
-   * Test to see if this URL has a user name included in it.
-   * @return true if the URL has an non-empty user name
-   */
-  bool hasUser() const;
-
-  /**
-   * Returns the decoded password (corresponding to user()) included in the URL.
-   * @return the password or QString() if it does not exist
-   **/
-  QString pass() const;
-
-  /**
-   * Sets the password (corresponding to user()) included in the URL.
-   *
-   * Special characters in the password will appear encoded in the URL.
-   * Note that a password can only appear in a URL string if you also set
-   * a user.
-   * @param pass the password to set or QString() to remove the password
-   * @see setUser
-   * @see hasUser
-   **/
-  void setPass( const QString& pass );
-
-  /**
-   * Test to see if this URL has a password included in it.
-   * @return true if there is a non-empty password set
-   **/
-  bool hasPass() const;
-
-  /**
-   * Test to see if this URL has a hostname included in it.
-   * @return true if the URL has a host
-   **/
-  bool hasHost() const;
-
   /**
    * @param trailing use to add or remove a trailing slash to/from the path. see adjustPath
 
@@ -451,12 +377,6 @@ public:
   /// \reimp so that KUrl u; u.setPath(path); implies "file" protocol.
   void setPath( const QString& path );
 
-  /**
-   * Test to see if this URL has a path is included in it.
-   * @return true if there is a path
-   **/
-  bool hasPath() const;
-
   /**
    * Options to be used in cleanPath
    */
@@ -564,16 +484,16 @@ public:
   QString query() const;
 
   /**
-   * Returns the reference (or "fragment") of the URL.
-   * The reference is @em never decoded automatically.
-   * @return the undecoded reference, or QString() if there is none
+   * Returns the @em encoded reference (or "fragment") of the URL (everything after '#').
+   * @return the encoded reference, or QString("") if the reference part is empty,
+   *   or QString() if the URL has no reference.
    */
   QString ref() const;
 
   /**
    * Sets the reference/fragment part (everything after '#').
-   * If you have an encoded fragment already (as a QByteArray), you can call setFragment directly.
-   * @param fragment the unencoded reference (or QString() to remove it).
+   * If you have an encoded fragment already (as a QByteArray), you can call setEncodedFragment directly.
+   * @param fragment the @em encoded reference (or QString() to remove it).
    */
   void setRef( const QString& fragment );
 
@@ -586,8 +506,9 @@ public:
   bool hasRef() const;
 
   /**
-   * Returns the HTML reference (the part of the URL after "#").
-   * @return The HTML-style reference.
+   * Returns the @em unencoded reference (or "fragment") of the URL (everything after '#').
+   * @return the unencoded reference, or QString("") if the reference part is empty,
+   *   or QString() if the URL has no reference.
    * @see split
    * @see hasSubUrl
    * @see encodedHtmlRef
@@ -595,9 +516,10 @@ public:
   QString htmlRef() const;
 
   /**
-   * Returns the HTML reference (the part of the URL after "#") in
-   * encoded form.
-   * @return The HTML-style reference in its original form.
+   * Returns the @em encoded reference (or "fragment") of the URL (everything after '#').
+   * @return the encoded reference, or QString("") if the reference part is empty,
+   *   or QString() if the URL has no reference.
+   * @see ref
    */
   QString encodedHtmlRef() const;
 
@@ -836,15 +758,11 @@ public:
    * You can give the result of pathOrUrl back to the KUrl constructor, it accepts
    * both paths and urls.
    *
-   * @return the new KUrl
-   */
-  QString pathOrUrl() const;
-  /**
-   * Overload with @p trailing parameter
    * @param trailing use to add or remove a trailing slash to/from the path. see adjustPath.
+   * @return the new KUrl
    * @since 4.2
    */
-  QString pathOrUrl(AdjustPathOption trailing) const; // KDE5: merge with above. Rename to toUrlOrLocalFile?
+  QString pathOrUrl(AdjustPathOption trailing = LeaveTrailingSlash) const;
 
   /**
    * Returns the URL as a string, using the standard conventions for mime data
@@ -881,22 +799,6 @@ public:
    */
   operator QVariant() const;
 
-  /**
-   * The same as equals(), just with a less obvious name.
-   * Compares this url with @p u.
-   * @param u the URL to compare this one with.
-   * @param ignore_trailing set to true to ignore trailing '/' characters.
-   * @return True if both urls are the same. If at least one of the urls is invalid,
-   * false is returned.
-   * @see operator==. This function should be used if you want to
-   * ignore trailing '/' characters.
-   * @deprecated Use equals() instead.
-   */
-#ifndef KDE_NO_DEPRECATED
-  KDE_DEPRECATED bool cmp( const KUrl &u, bool ignore_trailing = false ) const;
-#endif
-
-
   /**
    * Flags to be used in URL comparison functions like equals, or urlcmp
    */
@@ -1005,15 +907,6 @@ public:
    */
   static KUrl fromPath( const QString& text );
 
-  /**
-   * \deprecated
-   * Since KDE4 you can pass both urls and paths to the KUrl constructors.
-   * Use KUrl(text) instead.
-   */
-#ifndef KDE_NO_DEPRECATED
-  static KDE_DEPRECATED KUrl fromPathOrUrl( const QString& text );
-#endif
-
   /**
    * Creates a KUrl from a string, using the standard conventions for mime data
    * (drag-n-drop or copy-n-paste).
@@ -1041,55 +934,6 @@ public:
                          const MetaDataMap& metaData = MetaDataMap(),
                          MimeDataFlags flags = DefaultMimeDataFlags ) const;
 
-  /**
-   * Convert unicoded string to local encoding and use %-style
-   * encoding for all common delimiters / non-ascii characters.
-   * @param str String to encode (can be QString()).
-   * @return the encoded string
-   *
-   * @deprecated use QUrl::toPercentEncoding instead, but note that it
-   * returns a QByteArray and not a QString. Which makes sense since
-   * everything is 7 bit (ascii) after being percent-encoded.
-   */
-#ifndef KDE_NO_DEPRECATED
-  static KDE_DEPRECATED QString encode_string(const QString &str) {
-    return QString::fromLatin1( QUrl::toPercentEncoding( str ).constData() ); //krazy:exclude=qclasses
-  }
-#endif
-
-  /**
-   * Convert unicoded string to local encoding and use %-style
-   * encoding for all common delimiters / non-ascii characters
-   * as well as the slash '/'.
-   * @param str String to encode
-   *
-   * @deprecated use QUrl::toPercentEncoding(str,"/") instead, but note that it
-   * returns a QByteArray and not a QString. Which makes sense since
-   * everything is 7 bit (ascii) after being percent-encoded.
-   *
-   */
-#ifndef KDE_NO_DEPRECATED
-  static KDE_DEPRECATED QString encode_string_no_slash(const QString &str) {
-      return QString::fromLatin1( QUrl::toPercentEncoding( str, "/" ).constData() ); //krazy:exclude=qclasses
-  }
-#endif
-
-  /**
-   * Decode %-style encoding and convert from local encoding to unicode.
-   * Reverse of encode_string()
-   * @param str String to decode (can be QString()).
-   *
-   * @deprecated use QUrl::fromPercentEncoding(encodedURL) instead, but
-   * note that it takes a QByteArray and not a QString. Which makes sense since
-   * everything is 7 bit (ascii) when being percent-encoded.
-   *
-   */
-#ifndef KDE_NO_DEPRECATED
-  static KDE_DEPRECATED QString decode_string(const QString &str) {
-      return QUrl::fromPercentEncoding( str.toLatin1() ); //krazy:exclude=qclasses
-  }
-#endif
-
 
   /**
    * Convenience function.
@@ -1139,13 +983,25 @@ public:
    */
   static QString relativePath(const QString &base_dir, const QString &path, bool *isParent=0);
 
+  /**
+   * Compatibility methods, do not use
+  */
+  inline QString protocol() const { return scheme().toLower(); };
+  inline void setProtocol( const QString& proto ) { setScheme( proto ); };
+  inline QString user() const { return userName(); };
+  inline void setUser( const QString& user ) { setUserName( user ); };
+  inline bool hasUser() const { return !userName().isEmpty(); };
+  inline QString pass() const { return password(); };
+  inline void setPass( const QString& pass ) { setPassword( pass ); };
+  inline bool hasPass() const { return !password().isEmpty(); };
+  inline bool hasHost() const { return !host().isEmpty(); };
+  inline bool hasPath() const { return !path().isEmpty(); };
+
 private:
   void _setQuery( const QString& query );
   void _setEncodedUrl(const QByteArray& url);
   QString toString() const; // forbidden, use url(), prettyUrl(), or pathOrUrl() instead.
   operator QString() const; // forbidden, use url(), prettyUrl(), or pathOrUrl() instead.
-private:
-  KUrlPrivate* const d; // Don't ever use this, it would break clear() (which is in QUrl)
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KUrl::EncodedPathAndQueryOptions)
@@ -1157,34 +1013,6 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(KUrl::DirectoryOptions)
 Q_DECLARE_METATYPE(KUrl)
 Q_DECLARE_METATYPE(KUrl::List)
 
-/**
- * \relates KUrl
- * Compares URLs. They are parsed, split and compared.
- * Two malformed URLs with the same string representation
- * are nevertheless considered to be unequal.
- * That means no malformed URL equals anything else.
- * @deprecated use KUrl(_url1).equals(KUrl(_url2)) instead.
- */
-#ifndef KDE_NO_DEPRECATED
-KDECORE_EXPORT_DEPRECATED bool urlcmp( const QString& _url1, const QString& _url2 ); // KDE5: remove, KUrl::equals is better API
-#endif
-
-/**
- * \relates KUrl
- * Compares URLs. They are parsed, split and compared.
- * Two malformed URLs with the same string representation
- * are nevertheless considered to be unequal.
- * That means no malformed URL equals anything else.
- *
- * @param _url1 A reference URL
- * @param _url2 A URL that will be compared with the reference URL
- * @param options a set of KUrl::EqualsOption flags
- * @deprecated use KUrl(_url1).equals(KUrl(_url2), options) instead.
- */
-#ifndef KDE_NO_DEPRECATED
-KDECORE_EXPORT_DEPRECATED bool urlcmp( const QString& _url1, const QString& _url2, const KUrl::EqualsOptions& options ); // KDE5: remove, KUrl::equals is better API
-#endif
-
 KDECORE_EXPORT uint qHash(const KUrl& kurl);
 
 #endif
