@@ -20,11 +20,8 @@
 #ifndef KCOMPOSITEJOB_H
 #define KCOMPOSITEJOB_H
 
-#include <kdecore_export.h>
 #include <kjob.h>
 
-#include <QtCore/QList>
-
 class KCompositeJobPrivate;
 /**
  * The base class for all jobs able to be composed of one
@@ -75,7 +72,7 @@ protected:
      *
      * @return true if we still have subjobs running, false otherwise
      */
-    bool hasSubjobs();
+    bool hasSubjobs() const;
 
     /**
      * Retrieves the list of the subjobs.
