@@ -23,8 +23,8 @@
 #define KJOB_H
 
 #include <kdecore_export.h>
-#include <QtCore/QObject>
-#include <QtCore/QPair>
+#include <QtCore/qobject.h>
+#include <QtCore/qpair.h>
 
 class KJobUiDelegate;
 
@@ -88,11 +88,17 @@ class KDECORE_EXPORT KJob : public QObject
     Q_FLAGS( Capabilities )
 
 public:
-    enum Unit { Bytes, Files, Directories };
+    enum Unit {
+        Bytes = 0x0000,
+        Files = 0x0001,
+        Directories= 0x0002
+    };
 
-    enum Capability { NoCapabilities = 0x0000,
-                      Killable       = 0x0001,
-                      Suspendable    = 0x0002 };
+    enum Capability {
+        NoCapabilities = 0x0000,
+        Killable       = 0x0001,
+        Suspendable    = 0x0002
+    };
 
     Q_DECLARE_FLAGS( Capabilities, Capability )
 
@@ -234,18 +240,11 @@ public:
     /**
      * Executes the job synchronously.
      *
-     * This will start a nested QEventLoop internally. Nested event loop can be dangerous and
-     * can have unintended side effects, you should avoid calling exec() whenever you can and use the
-     * asynchronous interface of KJob instead.
+     * You should avoid calling exec() whenever you can and use the asynchronous interface of KJob
+     * instead.
      *
-     * Should you indeed call this method, you need to make sure that all callers are reentrant,
-     * so that events delivered by the inner event loop don't cause non-reentrant functions to be
-     * called, which usually wreaks havoc.
-     *
-     * Note that the event loop started by this method does not process user input events, which means
-     * your user interface will effectivly be blocked. Other events like paint or network events are
-     * still being processed. The advantage of not processing user input events is that the chance of
-     * accidental reentrancy is greatly reduced. Still you should avoid calling this function.
+     * Another thing to note is that the result of the job will be emited after the execution
+     * finishes.
      *
      * @return true if the job has been executed without error, false otherwise
      */
@@ -357,11 +356,10 @@ private: // don't tell moc, doxygen or kdevelop, but those signals are in fact p
      * This is a private signal, it can't be emitted directly by subclasses of
      * KJob, use emitResult() instead.
      *
-     * Client code is not supposed to connect to this signal, signal result should
-     * be used instead.
-     *
-     * If you store a list of jobs and they might get killed silently,
-     * then you must connect to this instead of result().
+     * In general, to be notified of a job's completion, client code should connect to result()
+     * rather than finished(), so that kill(Quietly) is indeed quiet.
+     * However if you store a list of jobs and they might get killed silently,
+     * then you must connect to this instead of result(), to avoid dangling pointers in your list.
      *
      * @param job the job that emitted this signal
      * @internal
