@@ -27,14 +27,13 @@
 // Compiling this file with this flag is just crazy
 #undef QT_NO_CAST_FROM_ASCII
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QSettings>
-#include <QtCore/QTextStream>
-#include <QtXml/QDomAttr>
-#include <QtCore/QRegExp>
-#include <QtCore/QStringList>
+#include <QtCore/qcoreapplication.h>
+#include <QtCore/qfileinfo.h>
+#include <QtCore/qsettings.h>
+#include <QtCore/qtextstream.h>
+#include <QtCore/qregexp.h>
+#include <QtCore/qstringlist.h>
+#include <QtXml/qdom.h>
 
 #include <ostream>
 #include <iostream>
@@ -191,7 +190,6 @@ class CfgEntry
       QString name;
       QString context;
       QString label;
-      QString toolTip;
       QString whatsThis;
     };
     class Choices
@@ -719,10 +717,6 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element, const Cf
               choice.label = e3.text();
               choice.context = e3.attribute( "context" );
             }
-            if ( e3.tagName() == "tooltip" ) {
-              choice.toolTip = e3.text();
-              choice.context = e3.attribute( "context" );
-            }
             if ( e3.tagName() == "whatsthis" ) {
               choice.whatsThis = e3.text();
               choice.context = e3.attribute( "context" );
@@ -905,12 +899,12 @@ QString param( const QString &t )
     else if ( type == "enum" )        return "int";
     else if ( type == "path" )        return "const QString &";
     else if ( type == "pathlist" )    return "const QStringList &";
-    else if ( type == "password" )    return "const QString &";
     else if ( type == "url" )         return "const KUrl &";
     else if ( type == "urllist" )     return "const KUrl::List &";
     else {
         cerr <<"kconfig_compiler does not support type \""<< type <<"\""<<endl;
-        return "QString"; //For now, but an assert would be better
+        exit(1);
+        return "QString";
     }
 }
 
@@ -938,12 +932,12 @@ QString cppType( const QString &t )
     else if ( type == "enum" )        return "int";
     else if ( type == "path" )        return "QString";
     else if ( type == "pathlist" )    return "QStringList";
-    else if ( type == "password" )    return "QString";
     else if ( type == "url" )         return "KUrl";
     else if ( type == "urllist" )     return "KUrl::List";
     else {
         cerr<<"kconfig_compiler does not support type \""<< type <<"\""<<endl;
-        return "QString"; //For now, but an assert would be better
+        exit(1);
+        return "QString";
     }
 }
 
@@ -961,19 +955,19 @@ QString defaultValue( const QString &t )
     else if ( type == "uint" )        return "0";
     else if ( type == "bool" )        return "false";
     else if ( type == "double" )      return "0.0";
-    else if ( type == "datedime" )    return "QDateTime()";
+    else if ( type == "datetime" )    return "QDateTime()";
     else if ( type == "longlong" )    return "0";
     else if ( type == "ulonglong" )   return "0";
     else if ( type == "intlist" )     return "QList<int>()";
     else if ( type == "enum" )        return "0";
     else if ( type == "path" )        return "\"\""; // Use empty string, not null string!
     else if ( type == "pathlist" )    return "QStringList()";
-    else if ( type == "password" )    return "\"\""; // Use empty string, not null string!
     else if ( type == "url" )         return "KUrl()";
     else if ( type == "urllist" )     return "KUrl::List()";
     else {
         cerr<<"Error, kconfig_compiler does not support the \""<< type <<"\" type!"<<endl;
-        return "QString"; //For now, but an assert would be better
+        exit(1);
+        return "QString";
     }
 }
 
@@ -1212,7 +1206,7 @@ QString memberMutatorBody( CfgEntry *e, const CfgConfig &cfg )
       else
         out << enumName(e->param()) << "::enumToString[i]";
 
-        out << " )";
+    out << " )";
     }
     else
     {
@@ -1334,11 +1328,7 @@ int main( int argc, char **argv )
   parseArgs(app.arguments(), directoryName, inputFilename, codegenFilename);
 
   QString baseDir = directoryName;
-#ifdef Q_OS_WIN
-  if (!baseDir.endsWith('/') && !baseDir.endsWith('\\'))
-#else
   if (!baseDir.endsWith('/'))
-#endif
     baseDir.append("/");
 
   if (!codegenFilename.endsWith(QLatin1String(".kcfgc")))
@@ -1598,12 +1588,12 @@ int main( int argc, char **argv )
        exit(1);
      }
      Signal signal = *it;
-     h << "      " << signalEnumName(signal.name) << " = 0x" << hex << val;
+     h << "      " << signalEnumName(signal.name) << " = 0x" << QString::number(val, 16);
      if ( ++it != itEnd )
       h << ",";
      h << endl;
    }
-   h << " };" << dec << endl;
+   h << " };" << endl;
   }
   h << endl;
   // Constructor or singleton accessor
@@ -2077,13 +2067,13 @@ int main( int argc, char **argv )
       cpp << (*itEntry)->code() << endl;
     }
     if ( (*itEntry)->type() == "Enum" ) {
-      cpp << "  QList<"+cfg.inherits+"::ItemEnum::Choice2> values"
+      cpp << "  QList<"+cfg.inherits+"::ItemEnum::Choice> values"
           << (*itEntry)->name() << ";" << endl;
       const QList<CfgEntry::Choice> choices = (*itEntry)->choices().choices;
       QList<CfgEntry::Choice>::ConstIterator it;
       for( it = choices.constBegin(); it != choices.constEnd(); ++it ) {
         cpp << "  {" << endl;
-        cpp << "    "+cfg.inherits+"::ItemEnum::Choice2 choice;" << endl;
+        cpp << "    "+cfg.inherits+"::ItemEnum::Choice choice;" << endl;
         cpp << "    choice.name = QLatin1String(\"" << (*it).name << "\");" << endl;
         if ( cfg.setUserTexts ) {
           if ( !(*it).label.isEmpty() ) {
@@ -2094,14 +2084,6 @@ int main( int argc, char **argv )
               cpp << "i18n(";
             cpp << quoteString((*it).label) << ");" << endl;
           }
-          if ( !(*it).toolTip.isEmpty() ) {
-            cpp << "    choice.toolTip = ";
-            if ( !(*it).context.isEmpty() )
-              cpp << "i18nc(" + quoteString((*it).context) + ", ";
-            else
-              cpp << "i18n(";
-            cpp << quoteString((*it).toolTip) << ");" << endl;
-          }
           if ( !(*it).whatsThis.isEmpty() ) {
             cpp << "    choice.whatsThis = ";
             if ( !(*it).context.isEmpty() )
