@@ -17,28 +17,8 @@
 */
 
 #include "kcmdlineargs.h"
-#include <kdebug.h>
-
-#include <config.h>
-
-#include <sys/param.h>
-
-#include <assert.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <locale.h>
-
-#ifdef HAVE_LIMITS_H
-#include <limits.h>
-#endif
-
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtCore/QHash>
-#include <QtCore/QTextCodec>
-
+#include "kdebug.h"
+#include "kglobalsettings.h"
 #include "kaboutdata.h"
 #include "klocale.h"
 #include "kdeversion.h"
@@ -46,7 +26,19 @@
 #include "kglobal.h"
 #include "kurl.h"
 
-#include "kuitsemantics_p.h" // for escaping arguments in i18n
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QHash>
+#include <QtCore/QTextCodec>
+
+#include <sys/param.h>
+#include <assert.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <locale.h>
+#include <limits.h>
 
 // -----------------------------------------------------------------------------
 // Design notes:
@@ -73,8 +65,6 @@
 
 #ifdef Q_WS_X11
 #define DISPLAY "DISPLAY"
-#elif defined(Q_WS_QWS)
-#define DISPLAY "QWS_DISPLAY"
 #else
 #define DISPLAY "NODISPLAY"
 #endif
@@ -86,24 +76,24 @@
 class KCmdLineParsedOptions : public QHash<QByteArray,QByteArray>
 {
 public:
-   KCmdLineParsedOptions() { }
+    KCmdLineParsedOptions() { }
 };
 
 class KCmdLineParsedArgs : public QList<QByteArray>
 {
 public:
-   KCmdLineParsedArgs() { }
+    KCmdLineParsedArgs() { }
 };
 
 
 class KCmdLineArgsList: public QList<KCmdLineArgs*>
 {
 public:
-   KCmdLineArgsList() { }
-   ~KCmdLineArgsList() {
-	   while (count())
-		delete takeFirst();
-   }
+    KCmdLineArgsList() { }
+    ~KCmdLineArgsList() {
+        while (count())
+            delete takeFirst();
+    }
 };
 
 //
@@ -271,40 +261,19 @@ KCmdLineArgsStatic::KCmdLineArgsStatic () {
     //FIXME: Check if other options are specific to Qt/X11
 #ifdef Q_WS_X11
     qt_options.add("display <displayname>", ki18n("Use the X-server display 'displayname'"));
-#elif defined(Q_WS_QWS)
-    qt_options.add("display <displayname>", ki18n("Use the QWS display 'displayname'"));
-#else
 #endif
     qt_options.add("session <sessionId>", ki18n("Restore the application for the given 'sessionId'"));
-    qt_options.add("cmap", ki18n("Causes the application to install a private color\nmap on an 8-bit display"));
-    qt_options.add("ncols <count>", ki18n("Limits the number of colors allocated in the color\ncube on an 8-bit display, if the application is\nusing the QApplication::ManyColor color\nspecification"));
-    qt_options.add("nograb", ki18n("tells Qt to never grab the mouse or the keyboard"));
+    qt_options.add("nograb", ki18n("tells Katie to never grab the mouse or the keyboard"));
     qt_options.add("dograb", ki18n("running under a debugger can cause an implicit\n-nograb, use -dograb to override"));
     qt_options.add("sync", ki18n("switches to synchronous mode for debugging"));
-    qt_options.add("fn");
-    qt_options.add("font <fontname>", ki18n("defines the application font"));
-    qt_options.add("bg");
-    qt_options.add("background <color>", ki18n("sets the default background color and an\napplication palette (light and dark shades are\ncalculated)"));
-    qt_options.add("fg");
-    qt_options.add("foreground <color>", ki18n("sets the default foreground color"));
-    qt_options.add("btn");
-    qt_options.add("button <color>", ki18n("sets the default button color"));
-    qt_options.add("name <name>", ki18n("sets the application name"));
     qt_options.add("title <title>", ki18n("sets the application title (caption)"));
-    qt_options.add("testability", ki18n("load the testability framework"));
-#ifdef Q_WS_X11
-    qt_options.add("visual TrueColor", ki18n("forces the application to use a TrueColor visual on\nan 8-bit display"));
-    qt_options.add("inputstyle <inputstyle>", ki18n("sets XIM (X Input Method) input style. Possible\nvalues are onthespot, overthespot, offthespot and\nroot"));
-    qt_options.add("im <XIM server>", ki18n("set XIM server"));
-    qt_options.add("noxim", ki18n("disable XIM"));
-#endif
-#ifdef Q_WS_QWS
-    qt_options.add("qws", ki18n("forces the application to run as QWS Server"));
-#endif
     qt_options.add("reverse", ki18n("mirrors the whole layout of widgets"));
-    qt_options.add("stylesheet <file.qss>", ki18n("applies the Qt stylesheet to the application widgets"));
-    qt_options.add("graphicssystem <system>", ki18n("use a different graphics system instead of the default one, options are raster and opengl (experimental)"));
+    qt_options.add("stylesheet <file.qss>", ki18n("applies the Katie stylesheet to the application widgets"));
+#ifndef QT_KATIE
     qt_options.add("qmljsdebugger <port>", ki18n("QML JS debugger information. Application must be\nbuilt with -DQT_DECLARATIVE_DEBUG for the debugger to be\nenabled"));
+#else
+    kde_options.add("qmljsdebugger", ki18n("QML JS debugger information."));
+#endif
     // KDE options
     kde_options.add("caption <caption>",   ki18n("Use 'caption' as name in the titlebar"));
     kde_options.add("icon <icon>",         ki18n("Use 'icon' as the application icon"));
@@ -315,9 +284,7 @@ KCmdLineArgsStatic::KCmdLineArgsStatic () {
 #endif
     kde_options.add("style <style>",       ki18n("sets the application GUI style"));
     kde_options.add("geometry <geometry>", ki18n("sets the client geometry of the main widget - see man X for the argument format (usually WidthxHeight+XPos+YPos)"));
-#ifndef Q_WS_WIN
     kde_options.add("smkey <sessionKey>"); // this option is obsolete and exists only to allow smooth upgrades from sessions
-#endif
 }
 
 KCmdLineArgsStatic::~KCmdLineArgsStatic ()
@@ -462,7 +429,7 @@ KCmdLineArgs::init(int _argc, char **_argv, const KAboutData *_about, StdCmdLine
 
    // Strip path from argv[0]
    if (s->all_argc) {
-     char *p = strrchr(s->all_argv[0], QDir::separator().toAscii());
+     char *p = strrchr(s->all_argv[0], QDir::separator().toLatin1());
      if (p)
        s->appName = p+1;
      else
@@ -491,7 +458,7 @@ QString KCmdLineArgs::appName()
   */
 void KCmdLineArgs::addStdCmdLineOptions(StdCmdLineArgs stdargs) {
    if (stdargs & KCmdLineArgs::CmdLineArgQt) {
-       KCmdLineArgs::addCmdLineOptions(s->qt_options, ki18n("Qt"), "qt");
+       KCmdLineArgs::addCmdLineOptions(s->qt_options, ki18n("Katie"), "qt");
    }
    if (stdargs & KCmdLineArgs::CmdLineArgKDE) {
        KCmdLineArgs::addCmdLineOptions(s->kde_options, ki18n("KDE"), "kde");
@@ -654,13 +621,10 @@ int
 KCmdLineArgsStatic::findOption(const KCmdLineOptions &options, QByteArray &opt,
                                QByteArray &opt_name, QString &def, bool &enabled)
 {
-   int result;
-   bool inverse;
-
    for (int i = 0; i < options.d->names.size(); i++)
    {
-      result = 0;
-      inverse = false;
+      int result = 0;
+      bool inverse = false;
       opt_name = options.d->names[i];
       if (opt_name.startsWith(':') || opt_name.isEmpty())
       {
@@ -875,20 +839,13 @@ KCmdLineArgsStatic::parseAllArgs()
          {
             KCmdLineArgs::usage(option.mid(5));
          }
-#ifdef Q_WS_MAC
-         // skip the finder -psn_* hint
-         else if (option.startsWith("psn_")) // krazy:exclude=strings
-         {
-            continue;
-         }
-#endif
          else if ((option == "version") || (option == "v"))
          {
             KCmdLineArgs::enable_i18n();
             s->printQ(i18nc("@info:shell message on appcmd --version; do not translate 'Development Platform'"
                             "%3 application name, other %n version strings",
-                            "Qt: %1\n"
-                            "KDE Development Platform: %2\n"
+                            "Katie: %1\n"
+                            "Katana Development Platform: %2\n"
                             "%3: %4\n",
                             QString::fromLatin1(qVersion()),
                             QString::fromLatin1(KDE_VERSION_STRING),
@@ -921,10 +878,10 @@ KCmdLineArgsStatic::parseAllArgs()
        {
          if (!s->about->customAuthorTextEnabled ())
          {
-           if (s->about->bugAddress().isEmpty() || s->about->bugAddress() == QLatin1String("submit@bugs.kde.org") )
-             s->printQ( i18n( "Please use http://bugs.kde.org to report bugs.\n" ) );
+           if (s->about->bugAddress().isEmpty() || s->about->bugAddress() == QLatin1String(KDE_BUG_REPORT_EMAIL))
+             s->printQ( i18n( "Please use %1.\n", QLatin1String(KDE_BUG_REPORT_URL) ) );
            else
-             s->printQ( i18n( "Please report bugs to %1.\n" , s->about->bugAddress()) );
+             s->printQ( i18n( "Please report bugs to %1.\n", s->about->bugAddress()) );
          }
          else
          {
@@ -961,7 +918,7 @@ KCmdLineArgsStatic::parseAllArgs()
             if (s->ignoreUnknown)
                continue;
             KCmdLineArgs::enable_i18n();
-            KCmdLineArgs::usageError(i18n("Unexpected argument '%1'.", KuitSemantics::escape(s->decodeInput(s->all_argv[i]))));
+            KCmdLineArgs::usageError(i18n("Unexpected argument '%1'.", Qt::escape(s->decodeInput(s->all_argv[i]))));
          }
          else
          {
@@ -1005,7 +962,7 @@ int & KCmdLineArgs::qtArgc()
    return qt_argc;
 }
 
-static char** s_qt_argv;
+static char** s_qt_argv = nullptr;
 
 char **
 KCmdLineArgs::qtArgv()
@@ -1013,7 +970,7 @@ KCmdLineArgs::qtArgv()
    if (!s->argsList)
       addStdCmdLineOptions(CmdLineArgKDE|CmdLineArgQt); // Lazy bastards!
 
-   if( s_qt_argv != NULL )
+   if( s_qt_argv != nullptr )
       return s_qt_argv;
 
    if (!(s->mStdargs & KCmdLineArgs::CmdLineArgQt))
@@ -1136,7 +1093,7 @@ KCmdLineArgs::usage(const QByteArray &id)
      }
    }
 
-   s->printQ(i18n("Usage: %1 %2\n", QString::fromLocal8Bit(s->appName), KuitSemantics::escape(usage)));
+   s->printQ(i18n("Usage: %1 %2\n", QString::fromLocal8Bit(s->appName), Qt::escape(usage)));
    s->printQ(QLatin1Char('\n')+s->about->shortDescription()+QLatin1Char('\n'));
 
    s->printQ(i18n("\nGeneric options:\n"));
@@ -1276,7 +1233,7 @@ KCmdLineArgs::usage(const QByteArray &id)
                else
                {
                    s->printQ(optionFormatStringDef.arg(QString::fromLatin1(opt), -25)
-                            .arg(description, option.d->defaults[i]));
+                            .arg(description).arg(option.d->defaults[i]));
                }
                opt.clear();
             }
@@ -1419,7 +1376,7 @@ KCmdLineArgsPrivate::setOption(const QByteArray &opt, const QByteArray &value)
           addArgument(value);
       }
 
-#if defined(Q_WS_X11) || defined(Q_WS_QWS)
+#if defined(Q_WS_X11)
       // Hack coming up!
       if (argString == "-display")
       {
