@@ -31,7 +31,7 @@
 #include "klocale.h"
 #include "kconfiggroup.h"
 #include "kstandarddirs.h"
-#include <QtDebug>
+#include <QtCore/qdebug.h>
 
 KComponentData::KComponentData()
     : d(0)
@@ -137,56 +137,30 @@ void KComponentDataPrivate::lazyInit(const KComponentData &component)
         // install appdata resource type
         dirs->addResourceType("appdata", "data", aboutData.appName() + QLatin1Char('/'), true);
 
-        configInit(component);
+        Q_ASSERT(!sharedConfig);
 
-        if (dirs->addCustomized(sharedConfig.data()))
-            sharedConfig->reparseConfiguration();
+        if (!configName.isEmpty()) {
+            sharedConfig = KSharedConfig::openConfig(component, configName);
+        }
+
+        if (!sharedConfig) {
+            sharedConfig = KSharedConfig::openConfig(component);
+        }
     }
 
-#ifdef Q_OS_WIN
-    if (QCoreApplication::instance() && dirs && kdeLibraryPathsAdded != KdeLibraryPathsAddedDone) {
-#else
     // the first KComponentData sets the KDE Qt plugin paths
-    if (dirs && kdeLibraryPathsAdded != KdeLibraryPathsAddedDone) {
-#endif
+    if (kdeLibraryPathsAdded != KdeLibraryPathsAddedDone) {
         kdeLibraryPathsAdded = KdeLibraryPathsAddedDone;
-        const QStringList &plugins = dirs->resourceDirs("qtplugins");
-        QStringList::ConstIterator it = plugins.begin();
-        while (it != plugins.end()) {
-            QCoreApplication::addLibraryPath(*it);
-            ++it;
+        foreach (const QString &it, dirs->resourceDirs("lib")) {
+            QCoreApplication::addLibraryPath(it);
         }
-    }
-}
-
-bool kde_kiosk_exception = false; // flag to disable kiosk restrictions
-bool kde_kiosk_admin = false;
-
-void KComponentDataPrivate::configInit(const KComponentData &component)
-{
-    Q_ASSERT(!sharedConfig);
-
-    if (!configName.isEmpty()) {
-        sharedConfig = KSharedConfig::openConfig(component, configName);
-
-        //FIXME: this is broken and I don't know how to repair it
-        // Check whether custom config files are allowed.
-        KConfigGroup cg(sharedConfig, "KDE Action Restrictions");
-        QString kioskException = cg.readEntry("kiosk_exception");
-        if (!cg.readEntry("custom_config", true)) {
-           sharedConfig = 0;
+        foreach (const QString &it, dirs->resourceDirs("module")) {
+            QCoreApplication::addLibraryPath(it);
         }
-    }
-    
-    if (!sharedConfig) {
-        sharedConfig = KSharedConfig::openConfig(component);
-    }
 
-    // Check if we are excempt from kiosk restrictions
-    if (kde_kiosk_admin && !kde_kiosk_exception && !qgetenv("KDE_KIOSK_NO_RESTRICTIONS").isEmpty()) {
-        kde_kiosk_exception = true;
-        sharedConfig = 0;
-        configInit(component); // Reread...
+        foreach (const QString &it, dirs->resourceDirs("qtplugins")) {
+            QCoreApplication::addPluginPath(it);
+        }
     }
 }
 
@@ -235,5 +209,3 @@ QString KComponentData::catalogName() const
     return d->aboutData.catalogName();
 }
 
-void KComponentData::virtual_hook(int, void*)
-{ /*BASE::virtual_hook(id, data);*/ }
