@@ -24,19 +24,19 @@
  * Generated:	Sat May  1 02:08:43 EST 1999
  */
 
-#undef KDE3_SUPPORT
-
 #include "kglobal.h"
 #include "kglobal_p.h"
 
 #include <config.h>
 
-#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
-#endif
+#include <unistd.h> // umask
 
-#include <QtCore/QList>
-#include <QtCore/QSet>
+#include <QThread>
+#include <QAtomicInt>
+#include <QList>
+#include <QSet>
+#include <QCoreApplication>
 
 #include <kaboutdata.h>
 #include <kconfig.h>
@@ -44,36 +44,18 @@
 #include <kcharsets.h>
 #include <kstandarddirs.h>
 #include <kcomponentdata.h>
-#undef QT_NO_TRANSLATION
-#include <QtCore/QCoreApplication>
-#define QT_NO_TRANSLATION
-#include <QtCore/QTextCodec>
 #include "kcmdlineargs.h"
-#include <unistd.h> // umask
+#include "kcatalog_p.h"
 
-#ifndef NDEBUG
-#define MYASSERT(x) if (!x) \
-   qFatal("Fatal error: you need to have a KComponentData object before\n" \
-         "you do anything that requires it! Examples of this are config\n" \
-         "objects, standard directories or translations.");
-#else
-#define MYASSERT(x) /* nope */
-#endif
-
-// ~KConfig needs qrand(). qrand() depends on a Q_GLOBAL_STATIC. With this Q_CONSTRUCTOR_FUNCTION we
-// try to make qrand() live longer than any KConfig object.
-Q_CONSTRUCTOR_FUNCTION(qrand)
-
-typedef QSet<QString> KStringDict;
 mode_t s_umsk;
 
 class KGlobalPrivate
 {
     public:
         inline KGlobalPrivate()
-            : stringDict(0),
-            locale(0),
-            charsets(0)
+            : locale(0),
+            charsets(0),
+            localeIsFromFakeComponent(false)
         {
             // the umask is read here before any threads are created to avoid race conditions
             mode_t tmp = 0;
@@ -87,15 +69,14 @@ class KGlobalPrivate
             locale = 0;
             delete charsets;
             charsets = 0;
-            delete stringDict;
-            stringDict = 0;
         }
 
         KComponentData activeComponent;
         KComponentData mainComponent; // holds a refcount
-        KStringDict *stringDict;
         KLocale *locale;
         KCharsets *charsets;
+        bool localeIsFromFakeComponent;
+        QStringList catalogsToInsert;
 
         /**
          * This component may be used in applications that doesn't have a
@@ -104,8 +85,6 @@ class KGlobalPrivate
         static KComponentData initFakeComponent()
         {
             QString name = QCoreApplication::applicationName();
-            if(name.isEmpty() && QCoreApplication::instance())
-                name = qAppName();
             if(name.isEmpty())
                 name = QString::fromLatin1("kde");
             return KComponentData(name.toLatin1(), name.toLatin1(),
@@ -113,6 +92,12 @@ class KGlobalPrivate
         }
 };
 
+KCatalogLoader::KCatalogLoader(const QString &catalogName)
+{
+    KGlobal::insertCatalog(catalogName);
+}
+
+
 K_GLOBAL_STATIC(KGlobalPrivate, globalData)
 K_GLOBAL_STATIC_WITH_ARGS(KComponentData, fakeComponent, (KGlobalPrivate::initFakeComponent()))
 
@@ -145,20 +130,70 @@ bool KGlobal::hasMainComponent()
     return d->mainComponent.isValid();
 }
 
+void KGlobal::insertCatalog(const QString& catalog)
+{
+    PRIVATE_DATA;
+    if (d->locale) {
+        locale()->insertCatalog(catalog);
+    } else {
+        d->catalogsToInsert.append(catalog);
+    }
+}
+
+#ifndef QT_NO_TRANSLATION
+KDETranslator* s_kdetranslator = nullptr;
+
+static int installKDETranslator()
+{
+    QCoreApplication* coreApp = QCoreApplication::instance();
+    if (coreApp && !s_kdetranslator) { // testcase: kwrite --help: no qcore app
+        s_kdetranslator = new KDETranslator();
+        QCoreApplication::installTranslator(s_kdetranslator);
+    }
+    return 0;
+}
+Q_CONSTRUCTOR_FUNCTION(installKDETranslator);
+
+static int removeKDETranslator()
+{
+    QCoreApplication* coreApp = QCoreApplication::instance();
+    if (coreApp && s_kdetranslator) {
+        QCoreApplication::removeTranslator(s_kdetranslator);
+        delete s_kdetranslator;
+        s_kdetranslator = nullptr;
+    }
+    return 0;
+}
+Q_DESTRUCTOR_FUNCTION(removeKDETranslator);
+#endif // QT_NO_TRANSLATION
+
 KLocale *KGlobal::locale()
 {
     PRIVATE_DATA;
-    if (d->locale == 0) {
-        if (!d->mainComponent.isValid()) {
-            return 0;
+    if (d->locale == 0 || (d->localeIsFromFakeComponent && d->mainComponent.isValid() && d->mainComponent.config())) {
+        // If you hit the warning below, here's how to debug it in gdb:
+        // (gdb) set auto-solib-add on
+        // (gdb) b i18n
+        // (gdb) b KLocale::KLocale
+        // Function "KLocale::KLocale" not defined.
+        // Make breakpoint pending on future shared library load? (y or [n]) y
+        // (gdb) run
+        // And now it will stop at the first i18n call or more generally at the first construction of the KLocale object,
+        // type bt or go up to find the guilty i18n call.
+        if (d->locale != 0) {
+            qWarning("KGlobal::locale(): Warning your global KLocale is being recreated with a valid main component"
+                     " instead of a fake component, this usually means you tried to call i18n related functions before"
+                     " your main component was created. You should not do that since it most likely will not work");
         }
-
-        d->locale = new KLocale(d->mainComponent.catalogName());
-        QTextCodec::setCodecForLocale(d->locale->codecForEncoding());
-        d->mainComponent.aboutData()->translateInternalProgramName();
-        QCoreApplication* coreApp = QCoreApplication::instance();
-        if (coreApp) // testcase: kwrite --help: no qcore app
-            QCoreApplication::installTranslator(new KDETranslator(coreApp));
+        delete d->locale;
+        d->locale = 0;
+        d->locale = new KLocale(mainComponent().catalogName());
+        d->localeIsFromFakeComponent = !d->mainComponent.isValid();
+        mainComponent().aboutData()->translateInternalProgramName();
+        foreach(const QString &catalog, d->catalogsToInsert) {
+            d->locale->insertCatalog(catalog);
+        }
+        d->catalogsToInsert.clear();
     }
     return d->locale;
 }
@@ -184,14 +219,21 @@ KCharsets *KGlobal::charsets()
 
 mode_t KGlobal::umask()
 {
-    // Don't use PRIVATE_DATA here. This is called by ~KGlobalPrivate -> ~KConfig -> sync -> KSaveFile, so there's no KGlobalPrivate anymore.
+    // Don't use PRIVATE_DATA here. This is called by ~KGlobalPrivate -> ~KConfig -> sync -> KSaveFile,
+    // so there's no KGlobalPrivate anymore.
     return s_umsk;
 }
 
 KComponentData KGlobal::activeComponent()
 {
     PRIVATE_DATA;
-    MYASSERT(d->activeComponent.isValid());
+#ifndef NDEBUG
+    if (!d->activeComponent.isValid()) {
+        qFatal("Fatal error: you need to have a KComponentData object before\n"
+               "you do anything that requires it! Examples of this are config\n"
+               "objects, standard directories or translations.");
+    }
+#endif
     return d->activeComponent;
 }
 
@@ -200,7 +242,7 @@ void KGlobal::setActiveComponent(const KComponentData &c)
     PRIVATE_DATA;
     d->activeComponent = c;
     if (c.isValid() && d->locale) {
-        d->locale->setActiveCatalog(c.catalogName());
+        locale()->setActiveCatalog(c.catalogName());
     }
 }
 
@@ -214,40 +256,13 @@ void KGlobal::newComponentData(const KComponentData &c)
     KGlobal::setActiveComponent(c);
 }
 
-void KGlobal::setLocale(KLocale *locale, CopyCatalogs copy)
+void KGlobal::setLocale(KLocale *newLocale, CopyCatalogs copy)
 {
     PRIVATE_DATA;
     if (copy == DoCopyCatalogs && d->locale)
-        d->locale->copyCatalogsTo(locale);
+        locale()->copyCatalogsTo(newLocale);
     delete d->locale;
-    d->locale = locale;
-}
-
-/**
- * Create a static QString
- *
- * To be used inside functions(!) like:
- * static const QString &myString = KGlobal::staticQString("myText");
- */
-const QString &KGlobal::staticQString(const char *str)
-{
-    return staticQString(QLatin1String(str));
-}
-
-/**
- * Create a static QString
- *
- * To be used inside functions(!) like:
- * static const QString &myString = KGlobal::staticQString(i18n("My Text"));
- */
-const QString &KGlobal::staticQString(const QString &str)
-{
-    PRIVATE_DATA;
-    if (!d->stringDict) {
-        d->stringDict = new KStringDict;
-    }
-
-   return *d->stringDict->insert(str);
+    d->locale = newLocale;
 }
 
 QString KGlobal::caption()
@@ -255,16 +270,14 @@ QString KGlobal::caption()
     PRIVATE_DATA;
     // Caption set from command line ?
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs("kde");
-    if (args && args->isSet("caption")) {
+    if (args && args->isSet("caption") && !args->getOption("caption").trimmed().isEmpty()) {
         return args->getOption("caption");
-    } else {
+    } else if (d->mainComponent.isValid() && d->mainComponent.aboutData()) {
         // We have some about data ?
-        if (d->mainComponent.isValid() && d->mainComponent.aboutData()) {
-            return d->mainComponent.aboutData()->programName();
-        } else {
-            // Last resort : application name
-            return QCoreApplication::instance()->applicationName();
-        }
+        return d->mainComponent.aboutData()->programName();
+    } else {
+        // Last resort : application name
+        return QCoreApplication::instance()->applicationName();
     }
 }
 
@@ -276,27 +289,30 @@ QString KGlobal::caption()
  * e.g. a file copy for a file manager, or 'compacting folders on exit' for a mail client,
  * the job progress widget with "keep open" checked, etc.
  */
-static int s_refCount = 0;
-static bool s_allowQuit = false;
+static QAtomicInt s_allowQuit(0); // this is used a bool
+static QAtomicInt s_refCount(0);
 
 void KGlobal::ref()
 {
-    ++s_refCount;
-    //kDebug() << "KGlobal::ref() : refCount = " << s_refCount;
+    s_refCount.fetchAndAddOrdered(1);
 }
 
 void KGlobal::deref()
 {
-    --s_refCount;
-    //kDebug() << "KGlobal::deref() : refCount = " << s_refCount;
-    if (s_refCount <= 0 && s_allowQuit) {
+    const int prevRefCount = s_refCount.fetchAndAddOrdered(-1);
+    if (prevRefCount <= 1 && s_allowQuit.load()) {
         QCoreApplication::instance()->quit();
     }
 }
 
 void KGlobal::setAllowQuit(bool allowQuit)
 {
-    s_allowQuit = allowQuit;
+    if (QThread::currentThread() == qApp->thread()) {
+        s_allowQuit.fetchAndStoreOrdered(int(allowQuit));
+    }
+    else {
+        qWarning() << "KGlobal::setAllowQuit may only be called from the main thread";
+    }
 }
 
 #undef PRIVATE_DATA
