@@ -16,13 +16,13 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef _KGLOBAL_H
-#define _KGLOBAL_H
+#ifndef KGLOBAL_H
+#define KGLOBAL_H
 
 #include <kdecore_export.h>
-#include <QtCore/QAtomicPointer>
+#include <QtCore/qobject.h>
+
 #include <sys/types.h>
-#include <QtCore/QObject>
 
 //
 // WARNING!!
@@ -62,23 +62,6 @@ class KCleanUpGlobalStatic
         inline ~KCleanUpGlobalStatic() { func(); }
 };
 
-#ifdef Q_CC_MSVC
-/**
- * @internal
- *
- * MSVC seems to give anonymous structs the same name which fails at link time. So instead we name
- * the struct and hope that by adding the line number to the name it's unique enough to never clash.
- */
-# define K_GLOBAL_STATIC_STRUCT_NAME(NAME) _k_##NAME##__LINE__
-#else
-/**
- * @internal
- *
- * Make the struct of the K_GLOBAL_STATIC anonymous.
- */
-# define K_GLOBAL_STATIC_STRUCT_NAME(NAME)
-#endif
-
 /// @endcond
 
 /**
@@ -253,9 +236,9 @@ class KCleanUpGlobalStatic
  * @ingroup KDEMacros
  */
 #define K_GLOBAL_STATIC_WITH_ARGS(TYPE, NAME, ARGS)                            \
-static QBasicAtomicPointer<TYPE > _k_static_##NAME = Q_BASIC_ATOMIC_INITIALIZER(0); \
+static QAtomicPointer<TYPE > _k_static_##NAME (0);                             \
 static bool _k_static_##NAME##_destroyed;                                      \
-static struct K_GLOBAL_STATIC_STRUCT_NAME(NAME)                                \
+static struct                                                                  \
 {                                                                              \
     inline bool isDestroyed() const                                            \
     {                                                                          \
@@ -299,6 +282,28 @@ static struct K_GLOBAL_STATIC_STRUCT_NAME(NAME)                                \
     }                                                                          \
 } NAME;
 
+/**
+ * This class is useful in libraries where you want to make sure that
+ * anyone that uses your library will get the correct catalog loaded.
+ * Just declare a static KCatalogLoader in the global namespace of one of
+ * your cpp files and that will load your catalog once
+ * the global klocale is created
+ *
+ * @param catalogName The name of your catalog
+ *
+ * @since 4.6.2
+ *
+ * Example:
+ * @code
+ * static const KCatalogLoader loader("libkdepim");
+ * @endcode
+ */
+class KDECORE_EXPORT KCatalogLoader
+{
+    public:
+        KCatalogLoader(const QString &catalogName);
+};
+
 /**
  * Access to the KDE global objects.
  * KGlobal provides you with pointers of many central
@@ -337,6 +342,14 @@ namespace KGlobal
      */
     KDECORE_EXPORT KSharedConfigPtr config();
 
+    /**
+     * Inserts the catalog in the main locale object if it exists.
+     * Otherwise the catalog name is stored and added once the main locale gets created
+     *
+     * @since 4.6
+     */
+    KDECORE_EXPORT void insertCatalog(const QString& catalog);
+
     /**
      * Returns the global locale object.
      * @return the global locale object
@@ -366,44 +379,6 @@ namespace KGlobal
      */
     KDECORE_EXPORT mode_t umask();
 
-    /**
-     * Creates a static QString.
-     *
-     * To be used inside functions(!) like:
-     * @code
-     * static const QString &myString = KGlobal::staticQString("myText");
-     * @endcode
-     *
-     * @attention Do @b NOT use code such as:
-     * @code
-     * static QString myString = KGlobal::staticQString("myText");
-     * @endcode
-     * This creates a static object (instead of a static reference)
-     * and as you know static objects are EVIL.
-     * @param str the string to create
-     * @return the static string
-     */
-    KDECORE_EXPORT const QString& staticQString(const char *str); //krazy:exclude=constref (doesn't make sense otherwise)
-
-    /**
-     * Creates a static QString.
-     *
-     * To be used inside functions(!) like:
-     * @code
-     * static const QString &myString = KGlobal::staticQString(i18n("My Text"));
-     * @endcode
-     *
-     * @attention Do @b NOT use code such as:
-     * @code
-     * static QString myString = KGlobal::staticQString(i18n("myText"));
-     * @endcode
-     * This creates a static object (instead of a static reference)
-     * and as you know static objects are EVIL.
-     * @param str the string to create
-     * @return the static string
-     */
-    KDECORE_EXPORT const QString& staticQString(const QString &str); //krazy:exclude=constref (doesn't make sense otherwise)
-
     /**
      * Tells KGlobal about one more operations that should be finished
      * before the application exits. The standard behavior is to exit on the
@@ -438,7 +413,7 @@ namespace KGlobal
      * will automatically be exited. Otherwise, the application will not exit automatically.
      *
      * This is used by KMainWindow to allow quitting after the first mainwindow is created,
-     * and is used by special applications like kfmclient, to allow quitting even though
+     * and is used by special applications like kioclient, to allow quitting even though
      * no mainwindow was created.
      *
      * However, don't try to call setAllowQuit(false) in applications, it doesn't make sense.
@@ -453,13 +428,13 @@ namespace KGlobal
     /**
      * The component currently active (useful in a multi-component
      * application, such as a KParts application).
-     * Don't use this - it's mainly for KAboutDialog and KBugReport.
+     * Don't use this - it's mainly for KAboutDialog
      * @internal
      */
     KDECORE_EXPORT KComponentData activeComponent();
 
     /**
-     * Set the active component for use by KAboutDialog and KBugReport.
+     * Set the active component for use by KAboutDialog.
      * To be used only by a multi-component (KParts) application.
      *
      * @see activeComponent()
@@ -470,7 +445,7 @@ namespace KGlobal
      * Returns a text for the window caption.
      *
      * This may be set by
-     * "-caption", otherwise it will be equivalent to the name of the
+     * "--caption", otherwise it will be equivalent to the name of the
      * executable.
      * @return the text for the window caption
      */
@@ -498,53 +473,5 @@ namespace KGlobal
     KDECORE_EXPORT void setLocale(KLocale *, CopyCatalogs copy = DoCopyCatalogs);
 }
 
-#ifdef KDE_SUPPORT
-/**
- * @relates KGlobal
- * A typesafe function to find the smaller of the two arguments.
- * @deprecated, used qMin instead
- */
-#define KMIN(a,b)	qMin(a,b)
-/**
- * @relates KGlobal
- * A typesafe function to find the larger of the two arguments.
- * @deprecated, used qMax instead
- */
-#define KMAX(a,b)	qMax(a,b)
-/**
- * \relates KGlobal
- * A typesafe function to determine the absolute value of the argument.
- * @deprecated, used qAbs instead
- */
-#define KABS(a)	qAbs(a)
-/**
- * @relates KGlobal
- * A typesafe function that returns x if it's between low and high values.
- * low if x is smaller than low and high if x is bigger than high.
- * @deprecated, used qBound instead. Warning, the argument order differs.
- */
-#define KCLAMP(x,low,high) qBound(low,x,high)
-
-#define kMin qMin
-#define kMax qMax
-#define kAbs qAbs
-
-/**
- * @relates KGlobal
- * A typesafe function that returns x if it's between low and high values.
- * low if x is smaller than low and high if x is bigger than high.
- * @deprecated, used qBound instead. Warning, the argument order differs.
- */
-
-template<class T>
-inline KDE_DEPRECATED T kClamp( const T& x, const T& low, const T& high )
-{
-    if ( x < low )       return low;
-    else if ( high < x ) return high;
-                         return x;
-}
-
-#endif
-
-#endif // _KGLOBAL_H
+#endif // KGLOBAL_H
 
