@@ -23,11 +23,9 @@
 #ifndef KSTANDARDDIRS_H
 #define KSTANDARDDIRS_H
 
-#include <QtCore/QStringList>
 #include <kglobal.h>
-#include <QtCore/QMap>
 
-class KConfig;
+#include <QStringList>
 
 /**
  * @short Site-independent access to standard KDE directories.
@@ -49,8 +47,8 @@ class KConfig;
  * install location, and one is <tt>$KDEHOME</tt>.
  * Under these toplevel prefixes there are several well-defined suffixes
  * where specific resource types can be found.
- * For example, for the resource type @c "html" the suffixes could be
- * @c share/doc/HTML and @c share/doc/kde/HTML.
+ * For example, for the resource type @c "services" the suffixes could be
+ * @c share/services and @c share/kde4/services.
  * The search algorithm tries to locate the file under each prefix-suffix
  * combination.
  *
@@ -62,20 +60,15 @@ class KConfig;
  *
  * <b>Standard resources that kdelibs allocates are:</b>
  *
- * @li @c apps - Applications menu (.desktop files).
  * @li @c autostart - Autostart directories (both XDG and kde-specific)
  * @li @c cache - Cached information (e.g. favicons, web-pages)
- * @li @c cgi - CGIs to run from kdehelp.
  * @li @c config - Configuration files.
  * @li @c data - Where applications store data.
- * @li @c emoticons - Emoticons themes
  * @li @c exe - Executables in $prefix/bin. findExe() for a function that takes $PATH into account.
- * @li @c html - HTML documentation.
  * @li @c icon - Icons, see KIconLoader.
  * @li @c kcfg - KConfigXT config files.
  * @li @c lib - Libraries.
  * @li @c locale - Translation files for KLocale.
- * @li @c mime - Mime types defined by KDE-specific .desktop files.
  * @li @c module - Module (dynamically loaded library).
  * @li @c qtplugins - Qt plugins (dynamically loaded objects for Qt)
  * @li @c services - Services.
@@ -83,8 +76,7 @@ class KConfig;
  * @li @c sound - Application sounds.
  * @li @c templates - Templates for the "Create new file" functionality.
  * @li @c wallpaper - Wallpapers.
- * @li @c tmp - Temporary files (specific for both current host and current user)
- * @li @c socket - UNIX Sockets (specific for both current host and current user)
+ * @li @c tmp - Temporary files (specific for current user)
  * @li @c xdgconf-menu - Freedesktop.org standard location for menu layout (.menu) files.
  * @li @c xdgdata-apps - Freedesktop.org standard location for application desktop files.
  * @li @c xdgdata-dirs - Freedesktop.org standard location for menu descriptions (.directory files).
@@ -112,10 +104,10 @@ class KConfig;
  *          specified.
  * @li @c KDEHOME - The directory where changes are saved to. This directory is
  *          used to search for resources first. If @c KDEHOME is not
- *          specified it defaults to @c "$HOME/.kde"
+ *          specified it defaults to @c "$HOME/.katana"
  * @li @c KDEROOTHOME - Like KDEHOME, but used for the root user.
- *          If @c KDEROOTHOME is not set it defaults to the <tt>.kde</tt> directory in the
- *          home directory of root, usually @c "/root/.kde".
+ *          If @c KDEROOTHOME is not set it defaults to the <tt>.katana</tt> directory in the
+ *          home directory of root, usually @c "/root/.katana".
  *          Note that the setting of @c $HOME is ignored in this case.
  *
  * @see KGlobalSettings
@@ -196,7 +188,7 @@ public:
     /**
      * KStandardDirs' destructor.
      */
-    virtual ~KStandardDirs();
+    ~KStandardDirs();
 
     /**
      * Adds another search dir to front of the @p fsstnd list.
@@ -232,35 +224,7 @@ public:
      *
      * You may add as many as you need, but it is advised that there
      * is exactly one to make writing definite.
-     * All basic types are added by addKDEDefaults(),
-     * but for those you can add more relative paths as well.
-     *
-     * The later a suffix is added, the higher its priority. Note, that the
-     * suffix should end with / but doesn't have to start with one (as prefixes
-     * should end with one). So adding a suffix for app_pics would look
-     * like KGlobal::dirs()->addResourceType("app_pics", "data" ,"app/pics");
-     *
-     * @param type Specifies a short descriptive string to access
-     * files of this type.
-     * @param relativename Specifies a directory relative to the root
-     * of the KFSSTND.
-     * @param priority if true, the directory is added before any other,
-     * otherwise after
-     * @return true if successful, false otherwise.
-     *
-     * @deprecated, use addResourceType(type, 0, relativename, priority)
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED bool addResourceType( const char *type,
-                                         const QString& relativename, bool priority = true );
-#endif
-
-    /**
-     * Adds suffixes for types.
-     *
-     * You may add as many as you need, but it is advised that there
-     * is exactly one to make writing definite.
-     * All basic types are added by addKDEDefaults(),
+     * All basic types are added by the constructor,
      * but for those you can add more relative paths as well.
      *
      * The later a suffix is added, the higher its priority. Note, that the
@@ -279,13 +243,6 @@ public:
     bool addResourceType( const char *type, const char *basetype,
                           const QString& relativename, bool priority = true );
 
-    /// @internal - just to avoid unwanted overload
-    bool addResourceType( const char *type, const char *basetype,
-                          const char* relativename, bool priority = true )
-    {
-        return addResourceType(type, basetype, QLatin1String(relativename), priority);
-    }
-
     /**
      * Adds absolute path at the beginning of the search path for
      * particular types (for example in case of icons where
@@ -336,23 +293,6 @@ public:
     QString findResource( const char *type,
                           const QString& filename ) const;
 
-    /**
-     * Checks whether a resource is restricted as part of the KIOSK
-     * framework. When a resource is restricted it means that user-
-     * specific files in the resource are ignored.
-     *
-     * E.g. by restricting the @c "wallpaper" resource, only system-wide
-     * installed wallpapers will be found by this class. Wallpapers
-     * installed under the @c $KDEHOME directory will be ignored.
-     *
-     * @param type The type of the resource to check
-     * @param relPath A relative path in the resource.
-     *
-     * @return True if the resource is restricted.
-     */
-    bool isRestrictedResource( const char *type,
-                               const QString& relPath=QString() ) const;
-
     /**
      * Returns a number that identifies this version of the resource.
      * When a change is made to the resource this number will change.
@@ -507,6 +447,30 @@ public:
                             const QString& pathstr = QString(),
                             SearchOptions options = NoSearchOptions );
 
+    /**
+     * Finds the executable in the system or root path.
+     *
+     * A valid executable must
+     * be a file and have its executable bit set.
+     *
+     * @param appname The name of the executable file for which to search.
+     *                if this contains a path separator, it will be resolved
+     *                according to the current working directory
+     *                (shell-like behaviour).
+     * @param pathstr The path which will be searched. If this is
+     *                null (default), the @c $PATH environment variable will
+     *                be searched and in addition some root-only system paths.
+     * @param options if the flags passed include IgnoreExecBit the path returned
+     *                may not have the executable bit set.
+     *
+     * @return The path of the executable. If it was not found,
+     *         it will return QString().
+     * @see findAllExe()
+     */
+    static QString findRootExe( const QString& appname,
+                                const QString& pathstr = QString(),
+                                SearchOptions options = NoSearchOptions );
+
     /**
      * Finds all occurrences of an executable in the system path.
      *
@@ -529,17 +493,6 @@ public:
                            const QString& pathstr=QString(),
                            SearchOptions options = NoSearchOptions );
 
-    /**
-     * Reads customized entries out of the given config object and add
-     * them via addResourceDirs().
-     *
-     * @param config The object the entries are read from. This should
-     *        contain global config files
-     * @return @c true if new config paths have been added
-     * from @p config.
-     **/
-    bool addCustomized(KConfig *config);
-
     /**
      * This function is used internally by almost all other function as
      * it serves and fills the directories cache.
@@ -597,7 +550,7 @@ public:
      * will find @p absPath. If no such relative path exists, @p absPath
      * will be returned unchanged.
      */
-    QString relativeLocation(const char *type, const QString &absPath);
+    QString relativeLocation(const char *type, const QString &absPath) const;
 
     /**
      * Recursively creates still-missing directories in the given path.
@@ -617,17 +570,13 @@ public:
      * of what this is all about.
      *
      * @li @c data - @c share/apps
-     * @li @c html - @c share/doc/HTML
      * @li @c icon - @c share/icon
      * @li @c config - @c share/config
      * @li @c pixmap - @c share/pixmaps
-     * @li @c apps - @c share/applnk
      * @li @c sound - @c share/sounds
      * @li @c locale - @c share/locale
      * @li @c services - @c share/kde4/services
      * @li @c servicetypes - @c share/kde4/servicetypes
-     * @li @c mime - @c share/mimelnk
-     * @li @c cgi - @c cgi-bin
      * @li @c wallpaper - @c share/wallpapers
      * @li @c templates - @c share/templates
      * @li @c exe - @c bin
@@ -635,7 +584,6 @@ public:
      * @li @c module - @c lib[suffix]/kde4
      * @li @c qtplugins - @c lib[suffix]/kde4/plugins
      * @li @c kcfg - @c share/config.kcfg
-     * @li @c emoticons - @c share/emoticons
      * @li @c xdgdata-apps - @c applications
      * @li @c xdgdata-icon - @c icons
      * @li @c xdgdata-pixmap - @c pixmaps
@@ -649,9 +597,6 @@ public:
      * @see locate()
      * @see locateLocal()
      */
-#ifndef KDE_NO_DEPRECATED
-    static KDE_DEPRECATED QString kde_default(const char *type);
-#endif
 
     /**
      * @internal (for use by sycoca only)
@@ -670,7 +615,7 @@ public:
 
     /**
      * Returns the toplevel directory in which KStandardDirs
-     * will store things. Most likely <tt>$HOME/.kde</tt>.
+     * will store things. Most likely <tt>$HOME/.katana</tt>.
      * Don't use this function if you can use locateLocal()
      * @return the toplevel directory
      */
@@ -696,7 +641,6 @@ public:
 
     /**
      * Checks for existence and accessability of a file or directory.
-     * Faster than creating a QFileInfo first.
      * @param fullPath the path to check. IMPORTANT: must end with a slash if expected to be a directory
      *                 (and no slash for a file, obviously).
      * @return @c true if the directory exists, @c false otherwise
@@ -787,22 +731,10 @@ public:
     static bool checkAccess(const QString& pathname, int mode);
 
 private:
-    // Disallow assignment and copy-construction
-    KStandardDirs( const KStandardDirs& );
-    KStandardDirs& operator= ( const KStandardDirs& );
+    Q_DISABLE_COPY(KStandardDirs)
 
     class KStandardDirsPrivate;
     KStandardDirsPrivate* const d;
-
-    // Like their public counter parts but with an extra priority argument
-    // If priority is true, the directory is added directly after
-    // $KDEHOME/$XDG_DATA_HOME/$XDG_CONFIG_HOME
-    void addPrefix( const QString& dir, bool priority );
-    void addXdgConfigPrefix( const QString& dir, bool priority );
-    void addXdgDataPrefix( const QString& dir, bool priority );
-    void addKDEDefaults();
-
-    void addResourcesFrom_krcdirs();
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KStandardDirs::SearchOptions)
