@@ -19,7 +19,6 @@
 */
 
 #include "ktoolinvocation.h"
-#include "klauncher_iface.h"
 #include "kdebug.h"
 #include "kglobal.h"
 #include "kstandarddirs.h"
@@ -27,16 +26,14 @@
 #include "kurl.h"
 #include "kmessage.h"
 #include "kservice.h"
-#include <klockfile.h>
-#include <klocale.h>
-
-#include <QMutex>
-#include <QMutexLocker>
-#include <QCoreApplication>
-#include <QThread>
-
-#include <errno.h>
+#include "klocale.h"
+#include "kglobalsettings.h"
 
+#include <QtCore/QThread>
+#include <QtCore/QProcess>
+#include <QtCore/QCoreApplication>
+#include <QtDBus/QDBusInterface>
+#include <QtDBus/QDBusConnectionInterface>
 
 KToolInvocation *KToolInvocation::self()
 {
@@ -44,25 +41,38 @@ KToolInvocation *KToolInvocation::self()
     return s_self;
 }
 
-KToolInvocation::KToolInvocation() : QObject(0), d(0)
+KToolInvocation::KToolInvocation()
+    : QObject(0),
+    klauncherIface(nullptr)
 {
+    klauncherIface = new org::kde::KLauncher(
+        QString::fromLatin1("org.kde.klauncher"),
+        QString::fromLatin1("/KLauncher"),
+        QDBusConnection::sessionBus()
+    );
 }
 
 KToolInvocation::~KToolInvocation()
 {
+    delete klauncherIface;
 }
 
-Q_GLOBAL_STATIC_WITH_ARGS(org::kde::KLauncher, klauncherIface,
-                          ("org.kde.klauncher", "/KLauncher", QDBusConnection::sessionBus()))
-
 org::kde::KLauncher *KToolInvocation::klauncher()
 {
-    if ( !QDBusConnection::sessionBus().interface()->isServiceRegistered( "org.kde.klauncher" ) )
-    {
+    if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(QString::fromLatin1("org.kde.klauncher"))) {
         kDebug(180) << "klauncher not running... launching kdeinit";
-        KToolInvocation::startKdeinit();
+        // Try to launch kdeinit.
+        QString srv = KStandardDirs::findExe(QLatin1String("kdeinit4"));
+        if (srv.isEmpty()) {
+            kError() << "kdeinit4 not available";
+            // NOTE: this will crash users not checking the pointer
+            return nullptr;
+        }
+        QStringList args;
+        args += QString::fromLatin1("--suicide");
+        QProcess::execute(srv, args);
     }
-    return ::klauncherIface();
+    return self()->klauncherIface;
 }
 
 static void printError(const QString& text, QString* error)
@@ -70,27 +80,16 @@ static void printError(const QString& text, QString* error)
     if (error)
         *error = text;
     else
-        kError() << text << endl;
-}
-
-bool KToolInvocation::isMainThreadActive(QString* error)
-{
-    if (QCoreApplication::instance() && QCoreApplication::instance()->thread() != QThread::currentThread())
-    {
-        printError(i18n("Function must be called from the main thread."), error);
-        return false;
-    }
-
-    return true;
+        kError() << text;
 }
 
 int KToolInvocation::startServiceInternal(const char *_function,
                                           const QString& _name, const QStringList &URLs,
-                                          QString *error, QString *serviceName, int *pid,
+                                          QString *error, QString *serviceName, qint64 *pid,
                                           const QByteArray& startup_id, bool noWait,
                                           const QString& workdir)
 {
-    QString function = QLatin1String(_function);
+    QString function = QString::fromLatin1(_function);
     org::kde::KLauncher *launcher = KToolInvocation::klauncher();
     QDBusMessage msg = QDBusMessage::createMethodCall(launcher->service(),
                                                 launcher->path(),
@@ -105,7 +104,7 @@ int KToolInvocation::startServiceInternal(const char *_function,
     QByteArray s = startup_id;
     emit kapplication_hook(envs, s);
     msg << envs;
-    msg << QString(s);
+    msg << QString::fromLatin1(s, s.size());
 #else
     msg << QStringList();
     msg << QString();
@@ -113,7 +112,7 @@ int KToolInvocation::startServiceInternal(const char *_function,
     if( !function.startsWith( QLatin1String("kdeinit_exec") ) )
         msg << noWait;
 
-    QDBusMessage reply = QDBusConnection::sessionBus().call(msg);
+    QDBusMessage reply = QDBusConnection::sessionBus().call(msg, QDBus::Block, INT_MAX);
     if ( reply.type() != QDBusMessage::ReplyMessage )
     {
         QDBusReply<QString> replyObj(reply);
@@ -136,45 +135,17 @@ int KToolInvocation::startServiceInternal(const char *_function,
     if (error)
         *error = reply.arguments().at(2).toString();
     if (pid)
-        *pid = reply.arguments().at(3).toInt();
+        *pid = reply.arguments().at(3).toLongLong();
     return reply.arguments().at(0).toInt();
 }
 
-int
-KToolInvocation::startServiceByName( const QString& _name, const QString &URL,
-                                     QString *error, QString *serviceName, int *pid,
-                                     const QByteArray& startup_id, bool noWait )
-{
-    if (!isMainThreadActive(error))
-        return EINVAL;
 
-    QStringList URLs;
-    if (!URL.isEmpty())
-        URLs.append(URL);
-    return self()->startServiceInternal("start_service_by_name",
-                                        _name, URLs, error, serviceName, pid, startup_id, noWait);
-}
-
-int
-KToolInvocation::startServiceByName( const QString& _name, const QStringList &URLs,
-                                     QString *error, QString *serviceName, int *pid,
-                                     const QByteArray& startup_id, bool noWait )
-{
-    if (!isMainThreadActive(error))
-        return EINVAL;
-
-    return self()->startServiceInternal("start_service_by_name",
-                                _name, URLs, error, serviceName, pid, startup_id, noWait);
-}
 
 int
 KToolInvocation::startServiceByDesktopPath( const QString& _name, const QString &URL,
                                             QString *error, QString *serviceName,
-                                            int *pid, const QByteArray& startup_id, bool noWait )
+                                            qint64 *pid, const QByteArray& startup_id, bool noWait )
 {
-    if (!isMainThreadActive(error))
-        return EINVAL;
-
     QStringList URLs;
     if (!URL.isEmpty())
         URLs.append(URL);
@@ -184,24 +155,18 @@ KToolInvocation::startServiceByDesktopPath( const QString& _name, const QString
 
 int
 KToolInvocation::startServiceByDesktopPath( const QString& _name, const QStringList &URLs,
-                                            QString *error, QString *serviceName, int *pid,
+                                            QString *error, QString *serviceName, qint64 *pid,
                                             const QByteArray& startup_id, bool noWait )
 {
-    if (!isMainThreadActive(error))
-        return EINVAL;
-
     return self()->startServiceInternal("start_service_by_desktop_path",
                                 _name, URLs, error, serviceName, pid, startup_id, noWait);
 }
 
 int
 KToolInvocation::startServiceByDesktopName( const QString& _name, const QString &URL,
-                                            QString *error, QString *serviceName, int *pid,
+                                            QString *error, QString *serviceName, qint64 *pid,
                                             const QByteArray& startup_id, bool noWait )
 {
-    if (!isMainThreadActive(error))
-        return EINVAL;
-
     QStringList URLs;
     if (!URL.isEmpty())
         URLs.append(URL);
@@ -211,23 +176,17 @@ KToolInvocation::startServiceByDesktopName( const QString& _name, const QString
 
 int
 KToolInvocation::startServiceByDesktopName( const QString& _name, const QStringList &URLs,
-                                            QString *error, QString *serviceName, int *pid,
+                                            QString *error, QString *serviceName, qint64 *pid,
                                             const QByteArray& startup_id, bool noWait )
 {
-    if (!isMainThreadActive(error))
-        return EINVAL;
-
     return self()->startServiceInternal("start_service_by_desktop_name",
                                 _name, URLs, error, serviceName, pid, startup_id, noWait);
 }
 
 int
 KToolInvocation::kdeinitExec( const QString& name, const QStringList &args,
-                              QString *error, int *pid, const QByteArray& startup_id )
+                              QString *error, qint64 *pid, const QByteArray& startup_id )
 {
-    if (!isMainThreadActive(error))
-        return EINVAL;
-
     return self()->startServiceInternal("kdeinit_exec",
                                 name, args, error, 0, pid, startup_id, false);
 }
@@ -235,11 +194,8 @@ KToolInvocation::kdeinitExec( const QString& name, const QStringList &args,
 
 int
 KToolInvocation::kdeinitExecWait( const QString& name, const QStringList &args,
-                                  QString *error, int *pid, const QByteArray& startup_id )
+                                  QString *error, qint64 *pid, const QByteArray& startup_id )
 {
-    if (!isMainThreadActive(error))
-        return EINVAL;
-
     return self()->startServiceInternal("kdeinit_exec_wait",
                                 name, args, error, 0, pid, startup_id, false);
 }
@@ -248,87 +204,47 @@ void KToolInvocation::invokeHelp( const QString& anchor,
                                   const QString& _appname,
                                   const QByteArray& startup_id )
 {
-    if (!isMainThreadActive())
-        return;
-
     KUrl url;
     QString appname;
     QString docPath;
     if (_appname.isEmpty()) {
         appname = QCoreApplication::instance()->applicationName();
-    } else
+    } else {
         appname = _appname;
-    
+    }
+
     KService::Ptr service(KService::serviceByDesktopName(appname));
     if (service) {
         docPath = service->docPath();
     }
-    
+
     if (!docPath.isEmpty()) {
-        url = KUrl(KUrl("help:/"), docPath);
+        url = KUrl(KUrl(QString::fromLatin1(KDE_HELP_URL)), docPath);
     } else {
-        url = QString("help:/%1/index.html").arg(appname);
+        url = QString::fromLatin1(KDE_HELP_URL);
     }
-    
+
     if (!anchor.isEmpty()) {
-        url.addQueryItem("anchor", anchor);
-    }
-    
-    // launch a browser for URIs not handled by khelpcenter
-    // (following KCMultiDialog::slotHelpClicked())
-    if (!(url.protocol() == "help" || url.protocol() == "man" || url.protocol() == "info")) {
-        invokeBrowser(url.url());
-        return;
+        url.addQueryItem(QString::fromLatin1("anchor"), anchor);
     }
 
-    QDBusInterface *iface = new QDBusInterface(QLatin1String("org.kde.khelpcenter"),
-                                               QLatin1String("/KHelpCenter"),
-                                               QLatin1String("org.kde.khelpcenter.khelpcenter"),
-                                               QDBusConnection::sessionBus());
-    if ( !iface->isValid() )
-    {
-        QString error;
-#ifdef Q_WS_WIN
-        // startServiceByDesktopName() does not work yet; KRun:processDesktopExec returned 'KRun: syntax error in command "khelpcenter %u" , service "KHelpCenter" '
-        if (kdeinitExec( "khelpcenter", QStringList() << url.url(), &error, 0, startup_id ))
-#else
-        if (startServiceByDesktopName("khelpcenter", url.url(), &error, 0, 0, startup_id, false))
-#endif
-        {
-            KMessage::message(KMessage::Error,
-                              i18n("Could not launch the KDE Help Center:\n\n%1", error),
-                              i18n("Could not Launch Help Center"));
-            delete iface;
-	    return;
-        }
-
-        delete iface;
-        iface = new QDBusInterface(QLatin1String("org.kde.khelpcenter"),
-                                   QLatin1String("/KHelpCenter"),
-                                   QLatin1String("org.kde.khelpcenter.khelpcenter"),
-                                   QDBusConnection::sessionBus());
-    }
-
-    iface->call("openUrl", url.url(), startup_id );
-    delete iface;
+    invokeBrowser(url.url());
 }
 
 void KToolInvocation::invokeMailer(const QString &address, const QString &subject, const QByteArray& startup_id)
 {
-    if (!isMainThreadActive())
-        return;
-
-    invokeMailer(address, QString(), QString(), subject, QString(), QString(),
-                 QStringList(), startup_id );
+    invokeMailer(address, QString(), subject, QString(), QStringList(), startup_id );
 }
 
 void KToolInvocation::invokeMailer(const KUrl &mailtoURL, const QByteArray& startup_id, bool allowAttachments )
 {
-    if (!isMainThreadActive())
-        return;
+    QString address = mailtoURL.path();
+    QString subject;
+    QString cc;
+    QString body;
 
-    QString address = KUrl::fromPercentEncoding(mailtoURL.path().toLatin1()), subject, cc, bcc, body;
-    const QStringList queries = mailtoURL.query().mid(1).split( '&');
+    const QStringList queries = mailtoURL.query().mid(1).split(QLatin1Char('&'));
+    const QChar comma = QChar::fromLatin1(',');
     QStringList attachURLs;
     for (QStringList::ConstIterator it = queries.begin(); it != queries.end(); ++it)
     {
@@ -337,51 +253,22 @@ void KToolInvocation::invokeMailer(const KUrl &mailtoURL, const QByteArray& star
             subject = KUrl::fromPercentEncoding((*it).mid(8).toLatin1());
         else
             if (q.startsWith(QLatin1String("cc=")))
-                cc = cc.isEmpty()? KUrl::fromPercentEncoding((*it).mid(3).toLatin1()): cc + ',' + KUrl::fromPercentEncoding((*it).mid(3).toLatin1());
+                cc = cc.isEmpty()? KUrl::fromPercentEncoding((*it).mid(3).toLatin1()): cc + comma + KUrl::fromPercentEncoding((*it).mid(3).toLatin1());
             else
-                if (q.startsWith(QLatin1String("bcc=")))
-                    bcc = bcc.isEmpty()? KUrl::fromPercentEncoding((*it).mid(4).toLatin1()): bcc + ',' + KUrl::fromPercentEncoding((*it).mid(4).toLatin1());
+                if (q.startsWith(QLatin1String("body=")))
+                    body = KUrl::fromPercentEncoding((*it).mid(5).toLatin1());
                 else
-                    if (q.startsWith(QLatin1String("body=")))
-                        body = KUrl::fromPercentEncoding((*it).mid(5).toLatin1());
+                    if (allowAttachments && q.startsWith(QLatin1String("attach=")))
+                        attachURLs.push_back(KUrl::fromPercentEncoding((*it).mid(7).toLatin1()));
                     else
-                        if (allowAttachments && q.startsWith(QLatin1String("attach=")))
-                            attachURLs.push_back(KUrl::fromPercentEncoding((*it).mid(7).toLatin1()));
+                        if (allowAttachments && q.startsWith(QLatin1String("attachment=")))
+                            attachURLs.push_back(KUrl::fromPercentEncoding((*it).mid(11).toLatin1()));
                         else
-                            if (allowAttachments && q.startsWith(QLatin1String("attachment=")))
-                                attachURLs.push_back(KUrl::fromPercentEncoding((*it).mid(11).toLatin1()));
-                            else
-                                if (q.startsWith(QLatin1String("to=")))
-                                    address = address.isEmpty()? KUrl::fromPercentEncoding((*it).mid(3).toLatin1()): address + ',' + KUrl::fromPercentEncoding((*it).mid(3).toLatin1());
+                            if (q.startsWith(QLatin1String("to=")))
+                                address = address.isEmpty()? KUrl::fromPercentEncoding((*it).mid(3).toLatin1()): address + comma + KUrl::fromPercentEncoding((*it).mid(3).toLatin1());
     }
 
-    invokeMailer( address, cc, bcc, subject, body, QString(), attachURLs, startup_id );
+    invokeMailer(address, cc, subject, body, attachURLs, startup_id);
 }
 
-void KToolInvocation::startKdeinit()
-{
-  KComponentData inst( "startkdeinitlock" );
-  KLockFile lock( KStandardDirs::locateLocal( "tmp", "startkdeinitlock", inst ));
-  if( lock.lock( KLockFile::NoBlockFlag ) != KLockFile::LockOK ) {
-     lock.lock();
-     if( QDBusConnection::sessionBus().interface()->isServiceRegistered( "org.kde.klauncher" ))
-         return; // whoever held the lock has already started it
-  }
-  // Try to launch kdeinit.
-  QString srv = KStandardDirs::findExe(QLatin1String("kdeinit4"));
-  if (srv.isEmpty())
-     return;
-//   this is disabled because we are in kdecore
-//  const bool gui = qApp && qApp->type() != QApplication::Tty;
-//  if ( gui )
-//    qApp->setOverrideCursor( Qt::WaitCursor );
-  QStringList args;
-#ifndef Q_WS_WIN
-  args += "--suicide";
-#endif
-  QProcess::execute(srv, args);
-//  if ( gui )
-//    qApp->restoreOverrideCursor();
-}
-
-#include "ktoolinvocation.moc"
+#include "moc_ktoolinvocation.cpp"
