@@ -21,24 +21,15 @@
 #ifndef KLOCALE_H
 #define KLOCALE_H
 
-#include <kdecore_export.h>
 #include <klocalizedstring.h>
 #include <ksharedconfig.h>
 
-#include <QtCore/QString>
-#include <QtCore/QList>
-
-class QStringList;
-class QTextCodec;
-class QDate;
-class QTime;
-class QDateTime;
+#include <QStringList>
+#include <QTextCodec>
+#include <QDateTime>
 
 class KDateTime;
 class KCalendarSystem;
-class KCurrencyCode;
-class KDayPeriod;
-
 class KLocalePrivate;
 
 /**
@@ -51,7 +42,7 @@ class KLocalePrivate;
   * the national language.
   *
   * KLocale supports translating, as well as specifying the format
-  * for numbers, currency, time, and date.
+  * for numbers, time, and date.
   *
   * Use KGlobal::locale() to get pointer to the global KLocale object,
   * containing the applications current locale settings.
@@ -127,19 +118,16 @@ public:
     /**
      * Destructor
      */
-    virtual ~KLocale();
+    ~KLocale();
 
     /**
      * @since 4.5
      *
-     * Raw translation from a message catalog.
-     * If catalog name is null or empty,
-     * all loaded catalogs are searched for the translation.
+     * Raw translation from all loaded catalogs.
      *
      * Never use this directly to get message translations. See the i18n and ki18n
      * family of calls related to KLocalizedString.
      *
-     * @param catname the catalog name. Must be UTF-8 encoded.
      * @param msg the message. Must not be null or empty. Must be UTF-8 encoded.
      * @param lang language in which the translation was found. If no translation
      *             was found, KLocale::defaultLanguage() is reported. If null,
@@ -150,27 +138,17 @@ public:
      *
      * @see KLocalizedString
      */
-    void translateRawFrom(const char* catname, const char* msg, QString *lang, QString *trans) const;
-
-    /**
-     * Like translateRawFrom, with implicit lookup through all loaded catalogs.
-     *
-     * @deprecated Use translateRawFrom with null or empty catalog name.
-     */
     void translateRaw(const char* msg, QString *lang, QString *trans) const;
 
     /**
      * @since 4.5
      *
-     * Raw translation from a message catalog, with given context.
+     * Raw translation from all loaded catalogs, with given context.
      * Context + message are used as the lookup key in the catalog.
-     * If catalog name is null or empty,
-     * all loaded catalogs are searched for the translation.
      *
      * Never use this directly to get message translations. See i18n* and ki18n*
      * calls related to KLocalizedString.
      *
-     * @param catname the catalog name. Must be UTF-8 encoded.
      * @param ctxt the context. Must not be null. Must be UTF-8 encoded.
      * @param msg the message. Must not be null or empty. Must be UTF-8 encoded.
      * @param lang language in which the translation was found. If no translation
@@ -182,27 +160,17 @@ public:
      *
      * @see KLocalizedString
      */
-    void translateRawFrom(const char *catname, const char *ctxt, const char *msg, QString *lang, QString *trans) const;
-
-    /**
-     * Like translateRawFrom, with implicit lookup through all loaded catalogs.
-     *
-     * @deprecated Use translateRawFrom with null or empty catalog name.
-     */
     void translateRaw(const char *ctxt, const char *msg, QString *lang, QString *trans) const;
 
     /**
      * @since 4.5
      *
-     * Raw translation from a message catalog, with given singular/plural form.
+     * Raw translation from all loaded catalogs, with given singular/plural form.
      * Singular form is used as the lookup key in the catalog.
-     * If catalog name is null or empty,
-     * all loaded catalogs are searched for the translation.
      *
      * Never use this directly to get message translations. See i18n* and ki18n*
      * calls related to KLocalizedString.
      *
-     * @param catname the catalog name. Must be UTF-8 encoded.
      * @param singular the singular form. Must not be null or empty. Must be UTF-8 encoded.
      * @param plural the plural form. Must not be null. Must be UTF-8 encoded.
      * @param n number on which the forms are decided.
@@ -216,30 +184,18 @@ public:
      *
      * @see KLocalizedString
      */
-    void translateRawFrom(const char *catname, const char *singular, const char *plural,  unsigned long n,
-                            QString *lang, QString *trans) const;
-
-    /**
-     * Like translateRawFrom, with implicit lookup through all loaded catalogs.
-     *
-     * @deprecated Use translateRawFrom with null or empty catalog name.
-     */
-    void translateRaw(const char *singular, const char *plural,  unsigned long n, QString *lang,
-                      QString *trans) const;
-
+    void translateRaw(const char *singular, const char *plural,  unsigned long n,
+                      QString *lang, QString *trans) const;
     /**
      * @since 4.5
      *
-     * Raw translation from a message catalog, with given context and
+     * Raw translation from all loaded catalogs, with given context and
      * singular/plural form.
      * Context + singular form is used as the lookup key in the catalog.
-     * If catalog name is null or empty,
-     * all loaded catalogs are searched for the translation.
      *
      * Never use this directly to get message translations. See i18n* and ki18n*
      * calls related to KLocalizedString.
      *
-     * @param catname the catalog name. Must be UTF-8 encoded.
      * @param ctxt the context. Must not be null. Must be UTF-8 encoded.
      * @param singular the singular form. Must not be null or empty. Must be UTF-8 encoded.
      * @param plural the plural form. Must not be null. Must be UTF-8 encoded.
@@ -254,16 +210,8 @@ public:
      *
      * @see KLocalizedString
      */
-    void translateRawFrom(const char *catname, const char *ctxt, const char *singular, const char *plural,
-                            unsigned long n, QString *lang, QString *trans) const;
-
-    /**
-     * Like translateRawFrom, with implicit lookup through all loaded catalogs.
-     *
-     * @deprecated Use translateRawFrom with null or empty catalog name.
-     */
-    void translateRaw(const char *ctxt, const char *singular, const char *plural, unsigned long n,
-                      QString *lang, QString *trans) const;
+    void translateRaw(const char *ctxt, const char *singular, const char *plural,
+                          unsigned long n, QString *lang, QString *trans) const;
 
     /**
      * Changes the current encoding.
@@ -274,33 +222,6 @@ public:
      */
     bool setEncoding(int mibEnum);
 
-    /**
-     * Various positions for where to place the positive or negative
-     * sign when they are related to a monetary value.
-     */
-    enum SignPosition {
-        /**
-         * Put parantheses around the quantity, e.g. "$ (217)"
-         */
-        ParensAround = 0,
-        /**
-         * Prefix the quantity with the sign, e.g. "$ -217"
-         */
-        BeforeQuantityMoney = 1,
-        /**
-         * Suffix the quanitity with the sign, e.g. "$ 217-"
-         */
-        AfterQuantityMoney = 2,
-        /**
-         * Prefix the currency symbol with the sign, e.g. "-$ 217"
-         */
-        BeforeMoney = 3,
-        /**
-         * Suffix the currency symbol with the sign, e.g. "$- 217"
-         */
-        AfterMoney = 4
-    };
-
     /**
      * @since 4.3
      *
@@ -401,50 +322,6 @@ public:
      */
     DigitSet digitSet() const;
 
-    /**
-     * @since 4.4
-     *
-     * Returns the ISO 4217 Currency Code for the current locale
-     *
-     * @return The default ISO Currency Code used by locale.
-    */
-    QString currencyCode() const;
-
-    /**
-     * @since 4.4
-     *
-     * Returns the Currency Code object for the current locale
-     *
-     * @return The default Currency Code object used by locale.
-    */
-    KCurrencyCode *currency() const;
-
-    /**
-     * Returns what the symbol denoting currency in the current locale
-     * as as defined by user settings should look like.
-     *
-     * @return The default currency symbol used by locale.
-     */
-    QString currencySymbol() const;
-
-    /**
-     * Returns what a decimal point should look like ("." or "," etc.)
-     * for monetary values, according to the current locale or user
-     * settings.
-     *
-     * @return The monetary decimal symbol used by locale.
-     */
-    QString monetaryDecimalSymbol() const;
-
-    /**
-     * Returns what a thousands separator for monetary values should
-     * look like ("," or " " etc.) according to the current locale or
-     * user settings.
-     *
-     * @return The monetary thousands separator used by locale.
-     */
-    QString monetaryThousandsSeparator() const;
-
     /**
      * Returns what a positive sign should look like ("+", " ", etc.)
      * according to the current locale or user settings.
@@ -461,15 +338,6 @@ public:
      */
     QString negativeSign() const;
 
-    /**
-     * @deprecated use decimalPlaces() or monetaryDecimalPlaces()
-     *
-     * The number of fractional digits to include in monetary values (usually 2).
-     *
-     * @return Default number of fractional digits used by locale.
-     */
-    KDE_DEPRECATED int fracDigits() const;
-
     /**
      * @since 4.4
      *
@@ -479,77 +347,6 @@ public:
      */
     int decimalPlaces() const;
 
-    /**
-     * @since 4.4
-     *
-     * The number of decimal places to include in monetary values (usually 2).
-     *
-     * @return Default number of monetary decimal places used by locale.
-     */
-    int monetaryDecimalPlaces() const;
-
-    /**
-     * If and only if the currency symbol precedes a positive value,
-     * this will be true.
-     *
-     * @return Where to print the currency symbol for positive numbers.
-     */
-    bool positivePrefixCurrencySymbol() const;
-
-    /**
-     * If and only if the currency symbol precedes a negative value,
-     * this will be true.
-     *
-     * @return True if the currency symbol precedes negative numbers.
-     */
-    bool negativePrefixCurrencySymbol() const;
-
-    /**
-     * Returns the position of a positive sign in relation to a
-     * monetary value.
-     *
-     * @return Where/how to print the positive sign.
-     * @see SignPosition
-     */
-    SignPosition positiveMonetarySignPosition() const;
-
-    /**
-     * Denotes where to place a negative sign in relation to a
-     * monetary value.
-     *
-     * @return Where/how to print the negative sign.
-     * @see SignPosition
-     */
-    SignPosition negativeMonetarySignPosition() const;
-
-    /**
-     * @since 4.3
-     *
-     * Retuns the digit set used to display monetary values.
-     *
-     * @return the digit set identifier
-     * @see DigitSet
-     * @see digitSetToName
-     */
-    DigitSet monetaryDigitSet() const;
-
-    /**
-     * Given a double, converts that to a numeric string containing
-     * the localized monetary equivalent.
-     *
-     * e.g. given 123456, return "$ 123,456.00".
-     *
-     * If precision isn't specified or is < 0, then the default monetaryDecimalPlaces() is used.
-     *
-     * @param num The number we want to format
-     * @param currency The currency symbol you want.
-     * @param precision Number of decimal places displayed
-     *
-     * @return The number of money as a localized string
-     * @see monetaryDecimalPlaces()
-     */
-    QString formatMoney(double num, const QString &currency = QString(), int precision = -1) const;
-
     /**
      * Given a double, converts that to a numeric string containing
      * the localized numeric equivalent.
@@ -766,7 +563,7 @@ public:
      *
      * @return If nouns are declined
      */
-    KDE_DEPRECATED bool nounDeclension() const;
+    KDECORE_DEPRECATED bool nounDeclension() const;
 
     //KDE5 move to KDateTime namespace
     /**
@@ -1126,7 +923,7 @@ public:
      * @see calendarSystem()
      * @return the name of the calendar system
      */
-    KDE_DEPRECATED QString calendarType() const;
+    KDECORE_DEPRECATED QString calendarType() const;
 
     /**
      * @since 4.6
@@ -1149,7 +946,7 @@ public:
      * @see setCalendarSystem()
      * @param calendarType the name of the calendar type
      */
-    KDE_DEPRECATED void setCalendar(const QString & calendarType);
+    KDECORE_DEPRECATED void setCalendar(const QString & calendarType);
 
     /**
      * @since 4.6
@@ -1173,18 +970,6 @@ public:
      */
     void setWeekNumberSystem(KLocale::WeekNumberSystem weekNumberSystem);
 
-    //KDE5 remove in favour of const version
-    /**
-     * @since 4.6
-     *
-     * Returns the type of Week Number System used in this Locale
-     *
-     * @see Klocale::WeekNumberSystem
-     * @see setWeekNumberSystem()
-     * @returns the Week Number System used
-     */
-    KLocale::WeekNumberSystem weekNumberSystem();
-
     /**
      * @since 4.7
      *
@@ -1196,17 +981,6 @@ public:
      */
     KLocale::WeekNumberSystem weekNumberSystem() const;
 
-    /**
-     * Converts a localized monetary string to a double.
-     *
-     * @param numStr the string we want to convert.
-     * @param ok the boolean that is set to false if it's not a number.
-     *           If @p ok is 0, it will be ignored
-     *
-     * @return The string converted to a double
-     */
-    double readMoney(const QString &numStr, bool * ok = 0) const;
-
     /**
      * Converts a localized numeric string to a double.
      *
@@ -1421,61 +1195,6 @@ public:
      */
     QStringList languageList() const;
 
-    /**
-     * @since 4.4
-     *
-     * Returns the ISO Currency Codes used in the locale, ordered by decreasing
-     * priority.
-     *
-     * Use KCurrency::currencyCodeToName(currencyCode) to get human readable,
-     * localized language name.
-     *
-     * @return list of ISO Currency Codes
-     *
-     * @see currencyCodeToName
-     */
-    QStringList currencyCodeList() const;
-
-    /**
-     * Returns the user's preferred encoding.
-     *
-     * @return The name of the preferred encoding
-     *
-     * @see codecForEncoding
-     * @see encodingMib
-     */
-    const QByteArray encoding() const;
-
-    /**
-     * Returns the user's preferred encoding.
-     *
-     * @return The Mib of the preferred encoding
-     *
-     * @see encoding
-     * @see codecForEncoding
-     */
-    int encodingMib() const;
-
-    /**
-     * Returns the user's preferred encoding. Should never be NULL.
-     *
-     * @return The codec for the preferred encoding
-     *
-     * @see encoding
-     * @see encodingMib
-     */
-    QTextCodec * codecForEncoding() const;
-
-    /**
-     * Returns the file encoding.
-     *
-     * @return The Mib of the file encoding
-     *
-     * @see QFile::encodeName
-     * @see QFile::decodeName
-     */
-    int fileEncodingMib() const;
-
     /**
      * Changes the current date format.
      *
@@ -1656,47 +1375,6 @@ public:
      */
     void setDigitSet(DigitSet digitSet);
 
-    /**
-     * Changes the sign position used for positive monetary values.
-     *
-     * @param signpos The new sign position
-     */
-    void setPositiveMonetarySignPosition(SignPosition signpos);
-
-    /**
-     * Changes the sign position used for negative monetary values.
-     *
-     * @param signpos The new sign position
-     */
-    void setNegativeMonetarySignPosition(SignPosition signpos);
-
-    /**
-     * Changes the position where the currency symbol should be printed for
-     * positive monetary values.
-     *
-     * @param prefix True if the currency symbol should be prefixed instead of
-     * postfixed
-     */
-    void setPositivePrefixCurrencySymbol(bool prefix);
-
-    /**
-     * Changes the position where the currency symbol should be printed for
-     * negative monetary values.
-     *
-     * @param prefix True if the currency symbol should be prefixed instead of
-     * postfixed
-     */
-    void setNegativePrefixCurrencySymbol(bool prefix);
-
-    /**
-     * @deprecated use setDecimalPlaces() or setMonetaryDecimalPlaces()
-     *
-     * Changes the number of digits used when formating numbers.
-     *
-     * @param digits The default number of digits to use.
-     */
-    KDE_DEPRECATED void setFracDigits(int digits);
-
     /**
      * @since 4.4
      *
@@ -1706,59 +1384,6 @@ public:
      */
     void setDecimalPlaces(int digits);
 
-    /**
-     * @since 4.4
-     *
-     * Changes the number of decimal places used when formating money.
-     *
-     * @param digits The default number of digits to use.
-     */
-    void setMonetaryDecimalPlaces(int digits);
-
-    /**
-     * Changes the separator used to group digits when formating monetary values.
-     *
-     * @param separator The new thousands separator.
-     */
-    void setMonetaryThousandsSeparator(const QString & separator);
-
-    /**
-     * Changes the symbol used to identify the decimal pointer for monetary
-     * values.
-     *
-     * @param symbol The new decimal symbol.
-     */
-    void setMonetaryDecimalSymbol(const QString & symbol);
-
-    /**
-     * @since 4.4
-     *
-     * Changes the current ISO Currency Code.
-     *
-     * @param newCurrencyCode The new Currency Code
-     */
-    void setCurrencyCode(const QString &newCurrencyCode);
-
-    /**
-     * Changes the current currency symbol.
-     *
-     * This symbol should be consistant with the selected Currency Code
-     *
-     * @param symbol The new currency symbol
-     * @see currencyCode, KCurrency::currencySymbols
-     */
-    void setCurrencySymbol(const QString & symbol);
-
-    /**
-     * @since 4.3
-     *
-     * Set digit characters used to display monetary values.
-     *
-     * @param digitSet the digit set identifier
-     * @see DigitSet
-     */
-    void setMonetaryDigitSet(DigitSet digitSet);
-
     /**
      * Returns the preferred page size for printing.
      *
@@ -1826,7 +1451,7 @@ public:
      * The parameters are similar to i18n(), but the result
      * value has other semantics (it can be QString())
      */
-    QString translateQt(const char *context, const char *sourceText, const char *comment) const;
+    QString translateQt(const char *context, const char *sourceText) const;
 
     /**
      * Provides list of all known language codes.
@@ -1924,24 +1549,6 @@ public:
      */
     static void setMainCatalog(const char *catalog);
 
-    /**
-     * @deprecated
-     *
-     * Finds localized resource in resourceDir( rtype ) + \<lang> + fname.
-     *
-     * Since KDE 4.1, this service is provided in a slightly different form,
-     * automatically by e.g. KStandardDirs::locate() and other KDE core classes
-     * dealing with paths. For manual use, it is replaced by localizedFilePath().
-     *
-     * @param fname relative path to find
-     * @param rtype resource type to use
-     *
-     * @return path to localized resource
-     *
-     * @see localizedFilePath
-     */
-    static QString langLookup(const QString &fname, const char *rtype = "html");
-
     /**
      * Returns the name of the internal language.
      *
@@ -1961,22 +1568,6 @@ public:
      */
     static QString defaultCountry();
 
-    /**
-     * @since 4.4
-     *
-     * Returns the ISO Code of the default currency.
-     *
-     * @return ISO Currency Code of the default currency
-     */
-    static QString defaultCurrencyCode();
-
-    /**
-     * Reports whether evaluation of translation scripts is enabled.
-     *
-     * @return true if script evaluation is enabled, false otherwise.
-     */
-    bool useTranscript() const;
-
     /**
      * Checks whether or not the active catalog is found for the given language.
      *
