@@ -21,10 +21,8 @@
 
 #include <kdecore_export.h>
 
-
-#include <QtCore/QChar>
-#include <QtCore/QLatin1Char>
-#include <QtCore/QStringList>
+#include <QtCore/qchar.h>
+#include <QtCore/qstringlist.h>
 
 class KLocale;
 struct KCatalogName;
@@ -66,10 +64,42 @@ class KLocalizedStringPrivate;
  * \endcode
  * \warning You need to call i18nc(context, stringVar) later on, not just
  * i18n(stringVar).
+ *
+ * @see I18N_NOOP2_NOSTRIP
  */
 #define I18N_NOOP2(comment,x) x
 #endif
 
+#ifndef I18N_NOOP2_NOSTRIP
+/**
+ * @since 4.3
+ *
+ * Similar to I18N_NOOP2, except that neither of the two arguments is omitted.
+ * This is typically used when contexts need to differ between static entries,
+ * and only some of the entries need context:
+ * \code
+ *   struct MyTextLabels
+ *   {
+ *     int labelId;
+ *     const char *context;
+ *     const char *text;
+ *   };
+ *   const MyTextLabels labels[] = {
+ *     { 10, I18N_NOOP2_NOSTRIP("new game", "New") },
+ *     { 20, 0, I18N_NOOP("End Turn") },
+ *     { 30, I18N_NOOP2_NOSTRIP("default move", "Default") },
+ *     { 40, 0, I18N_NOOP("Quit") },
+ *     ...
+ *   };
+ *   ...
+ *   QString itemLabel = i18nc(labels[item].context, labels[item].text);
+ * \endcode
+ * Note that i18nc() will not have any problems with context being null,
+ * it will simply behave as ordinary i18n().
+ */
+#define I18N_NOOP2_NOSTRIP(ctxt, text) ctxt, text
+#endif
+
 /**
  * @short Class for producing and handling localized messages
  *
@@ -185,7 +215,18 @@ class KLocalizedStringPrivate;
  * \code
  *   KLocale *myLocale;
  *   ...
- *   ki18n("Welcome").toString(myLocale);
+ *   QString msg = ki18n("Welcome").toString(myLocale);
+ * \endcode
+ *
+ * Normally all loaded catalogs are searched for translation,
+ * and the first found translation is returned.
+ * Sometimes this may lead to clashes, especially when dealing with
+ * specialized collection catalogs (country names, language names, etc.)
+ * in which messages are not equipped with contexts.
+ * In such situations, toString method can take the name of
+ * the specific catalog in which to look for translation:
+ * \code
+ *   QString trName = ki18n("Georgia").toString("countries");
  * \endcode
  *
  * Translators have a capability to script translations at runtime, which is
@@ -289,7 +330,7 @@ public:
 
     /**
      * Finalizes the translation, creates QString with placeholders
-     * substituted. Translations is obtained from default locale.
+     * substituted. Translation is obtained from default locale.
      *
      * If there was any mismatch between placeholders and arguments
      * returned string will contain error marks (in debug mode).
@@ -300,7 +341,7 @@ public:
 
     /**
      * Finalizes the translation, creates QString with placeholders
-     * substituted. Translations is obtained from given locale. If locale
+     * substituted. Translation is obtained from given locale. If locale
      * is NULL, original message is used instead of translated.
      *
      * If there was any mismatch between placeholders and arguments
@@ -530,23 +571,6 @@ extern KLocalizedString KDECORE_EXPORT ki18np (const char *singular, const char
 */
 extern KLocalizedString KDECORE_EXPORT ki18ncp (const char *ctxt, const char *singular, const char *plural);
 
-/**
- * Qt's uic generated translation calls go through numerous indirections
- * unnecessary in our case. So we use uic -tr tr2i18n to redirect them
- * to our i18n API.
-**/
-inline QString tr2i18n (const char *message, const char *comment = 0) {
-    if (comment && comment[0] && message && message[0]) {
-        return ki18nc(comment, message).toString();
-    }
-    else if (message && message[0]) {
-        return ki18n(message).toString();
-    }
-    else {
-        return QString();
-    }
-}
-
 #ifndef NDEBUG
 #define I18N_ERR_MSG String_literal_as_second_argument_to_i18n___Perhaps_you_need_i18nc_or_i18np
 template <typename T, int s> class I18nTypeCheck {public: static void I18N_ERR_MSG () {}};
