@@ -26,18 +26,13 @@
 #include <QRegExp>
 #include <QStack>
 #include <QXmlStreamReader>
-#include <QStringList>
-#include <QPair>
 #include <QDir>
 
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kcatalog_p.h>
-#include <kuitformats_p.h>
 #include <klocale.h>
 
-#define QL1S(x)   QLatin1String(x)
-
 // Truncates string, for output of long messages.
 // (But don't truncate too much otherwise it's impossible to determine
 // which message is faulty if many messages start with the same beginning).
@@ -82,8 +77,8 @@ namespace Kuit {
             None,
             TopLong, TopShort,
             Title, Subtitle, Para, List, Item, Note, Warning, Link,
-            Filename, Application, Command, Resource, Icode, Bcode, Shortcut,
-            Interface, Emphasis, Placeholder, Email, Numid, Envar, Message, Nl,
+            Filename, Application, Command, Resource,
+            Emphasis, Email, Numid, Envar, Message, Nl,
             NumIntg, NumReal // internal helpers for numbers, not part of DTD
         } Var;
     }
@@ -180,9 +175,8 @@ KuitSemanticsStaticData::KuitSemanticsStaticData ()
 
     #undef INLINES
     #define INLINES \
-        Filename << Link << Application << Command << Resource << Icode << \
-        Shortcut << Interface << Emphasis << Placeholder << Email << \
-        Numid << Envar << Nl
+        Filename << Link << Application << Command << Resource << \
+        Emphasis << Email << Numid << Envar << Nl
 
     SETUP_TAG(TopLong, "kuit", Ctx, Title << Subtitle << Para);
     SETUP_TAG(TopShort, "kuil", Ctx, INLINES << Note << Warning << Message);
@@ -196,17 +190,12 @@ KuitSemanticsStaticData::KuitSemanticsStaticData ()
 
     SETUP_TAG(Note, "note", Label, INLINES);
     SETUP_TAG(Warning, "warning", Label, INLINES);
-    SETUP_TAG(Filename, "filename", None, Envar << Placeholder);
+    SETUP_TAG(Filename, "filename", None, Envar);
     SETUP_TAG(Link, "link", Url, None);
     SETUP_TAG(Application, "application", None, None);
     SETUP_TAG(Command, "command", Section, None);
     SETUP_TAG(Resource, "resource", None, None);
-    SETUP_TAG(Icode, "icode", None, Envar << Placeholder);
-    SETUP_TAG(Bcode, "bcode", None, None);
-    SETUP_TAG(Shortcut, "shortcut", None, None);
-    SETUP_TAG(Interface, "interface", None, None);
     SETUP_TAG(Emphasis, "emphasis", Strong, None);
-    SETUP_TAG(Placeholder, "placeholder", None, None);
     SETUP_TAG(Email, "email", Address, None);
     SETUP_TAG(Envar, "envar", None, None);
     SETUP_TAG(Message, "message", None, None);
@@ -308,16 +297,34 @@ KuitSemanticsStaticData::KuitSemanticsStaticData ()
     SETUP_CUE(Shell, "shell");
 
     // Collect all Qt's rich text engine HTML tags, for some checks later.
-    qtHtmlTagNames << QL1S("a") << QL1S("address") << QL1S("b") << QL1S("big") << QL1S("blockquote")
-                   << QL1S("body") << QL1S("br") << QL1S("center") << QL1S("cita") << QL1S("code")
-                   << QL1S("dd") << QL1S("dfn") << QL1S("div") << QL1S("dl") << QL1S("dt") << QL1S("em")
-                   << QL1S("font") << QL1S("h1") << QL1S("h2") << QL1S("h3") << QL1S("h4") << QL1S("h5")
-                   << QL1S("h6") << QL1S("head") << QL1S("hr") << QL1S("html") << QL1S("i") << QL1S("img")
-                   << QL1S("kbd") << QL1S("meta") << QL1S("li") << QL1S("nobr") << QL1S("ol") << QL1S("p")
-                   << QL1S("pre") << QL1S("qt") << QL1S("s") << QL1S("samp") << QL1S("small") << QL1S("span")
-                   << QL1S("strong") << QL1S("sup") << QL1S("sub") << QL1S("table") << QL1S("tbody")
-                   << QL1S("td") << QL1S("tfoot") << QL1S("th") << QL1S("thead") << QL1S("title")
-                   << QL1S("tr") << QL1S("tt") << QL1S("u") << QL1S("ul") << QL1S("var");
+    qtHtmlTagNames << QLatin1String("a") << QLatin1String("address")
+                   << QLatin1String("b") << QLatin1String("big")
+                   << QLatin1String("blockquote") << QLatin1String("body")
+                   << QLatin1String("br") << QLatin1String("center")
+                   << QLatin1String("cita") << QLatin1String("code")
+                   << QLatin1String("dd") << QLatin1String("dfn")
+                   << QLatin1String("div") << QLatin1String("dl")
+                   << QLatin1String("dt") << QLatin1String("em")
+                   << QLatin1String("font") << QLatin1String("h1")
+                   << QLatin1String("h2") << QLatin1String("h3")
+                   << QLatin1String("h4") << QLatin1String("h5")
+                   << QLatin1String("h6") << QLatin1String("head")
+                   << QLatin1String("hr") << QLatin1String("html")
+                   << QLatin1String("i") << QLatin1String("img")
+                   << QLatin1String("kbd") << QLatin1String("meta")
+                   << QLatin1String("li") << QLatin1String("nobr")
+                   << QLatin1String("ol") << QLatin1String("p")
+                   << QLatin1String("pre") << QLatin1String("qt")
+                   << QLatin1String("s") << QLatin1String("samp")
+                   << QLatin1String("small") << QLatin1String("span")
+                   << QLatin1String("strong") << QLatin1String("sup")
+                   << QLatin1String("sub") << QLatin1String("table")
+                   << QLatin1String("tbody") << QLatin1String("td")
+                   << QLatin1String("tfoot") << QLatin1String("th")
+                   << QLatin1String("thead") << QLatin1String("title")
+                   << QLatin1String("tr") << QLatin1String("tt")
+                   << QLatin1String("u") << QLatin1String("ul")
+                   << QLatin1String("var");
 
     // Tags that format with number of leading newlines.
     #undef SETUP_TAG_NL
@@ -328,8 +335,6 @@ KuitSemanticsStaticData::KuitSemanticsStaticData ()
     SETUP_TAG_NL(Subtitle, 2);
     SETUP_TAG_NL(Para, 2);
     SETUP_TAG_NL(List, 1);
-    SETUP_TAG_NL(Bcode, 1);
-    SETUP_TAG_NL(Item, 1);
 
     // Default XML entities, direct and inverse mapping.
     xmlEntities[QString::fromLatin1("lt")] = QString(QLatin1Char('<'));
@@ -367,9 +372,6 @@ class KuitSemanticsPrivate
     // Set visual formatting patterns for text in semantic tags.
     void setFormattingPatterns ();
 
-    // Set data used in transformation of text within semantic tags.
-    void setTextTransformData ();
-
     // Compute integer hash key from the set of attributes.
     static int attSetKey (const QSet<Kuit::AttVar> &aset = QSet<Kuit::AttVar>());
 
@@ -441,11 +443,6 @@ class KuitSemanticsPrivate
           QHash<int, // attribute set key
                 QHash<Kuit::FmtVar, QString> > > m_patterns;
 
-    QHash<Kuit::FmtVar, QString> m_comboKeyDelim;
-    QHash<Kuit::FmtVar, QString> m_guiPathDelim;
-
-    QHash<QString, QString> m_keyNames;
-
     // For fetching metatranslations.
     KCatalog *m_metaCat;
 };
@@ -466,9 +463,6 @@ KuitSemanticsPrivate::KuitSemanticsPrivate (const QString &lang)
     // Get formatting patterns for all tag/att/fmt combinations.
     setFormattingPatterns();
 
-    // Get data for tag text transformations.
-    setTextTransformData();
-
     // Catalog not needed any more.
     delete m_metaCat;
     m_metaCat = NULL;
@@ -681,46 +675,6 @@ void KuitSemanticsPrivate::setFormattingPatterns ()
     // i18n: KUIT pattern, see the comment to the first of these entries above.
                            "“%1”"));
 
-    // -------> Icode
-    SET_PATTERN(Tag::Icode, Att::None, Fmt::Plain,
-                I18N_NOOP2("@icode/plain",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "“%1”"));
-    SET_PATTERN(Tag::Icode, Att::None, Fmt::Rich,
-                I18N_NOOP2("@icode/rich",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "<tt>%1</tt>"));
-
-    // -------> Bcode
-    SET_PATTERN(Tag::Bcode, Att::None, Fmt::Plain,
-                XXXX_NOOP2("@bcode/plain",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "\n%1\n"));
-    SET_PATTERN(Tag::Bcode, Att::None, Fmt::Rich,
-                XXXX_NOOP2("@bcode/rich",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "<pre>%1</pre>"));
-
-    // -------> Shortcut
-    SET_PATTERN(Tag::Shortcut, Att::None, Fmt::Plain,
-                I18N_NOOP2("@shortcut/plain",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "%1"));
-    SET_PATTERN(Tag::Shortcut, Att::None, Fmt::Rich,
-                I18N_NOOP2("@shortcut/rich",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "<b>%1</b>"));
-
-    // -------> Interface
-    SET_PATTERN(Tag::Interface, Att::None, Fmt::Plain,
-                I18N_NOOP2("@interface/plain",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "|%1|"));
-    SET_PATTERN(Tag::Interface, Att::None, Fmt::Rich,
-                I18N_NOOP2("@interface/rich",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "<i>%1</i>"));
-
     // -------> Emphasis
     SET_PATTERN(Tag::Emphasis, Att::None, Fmt::Plain,
                 I18N_NOOP2("@emphasis/plain",
@@ -739,16 +693,6 @@ void KuitSemanticsPrivate::setFormattingPatterns ()
     // i18n: KUIT pattern, see the comment to the first of these entries above.
                            "<b>%1</b>"));
 
-    // -------> Placeholder
-    SET_PATTERN(Tag::Placeholder, Att::None, Fmt::Plain,
-                I18N_NOOP2("@placeholder/plain",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "&lt;%1&gt;"));
-    SET_PATTERN(Tag::Placeholder, Att::None, Fmt::Rich,
-                I18N_NOOP2("@placeholder/rich",
-    // i18n: KUIT pattern, see the comment to the first of these entries above.
-                           "&lt;<i>%1</i>&gt;"));
-
     // -------> Email
     SET_PATTERN(Tag::Email, Att::None, Fmt::Plain,
                 I18N_NOOP2("@email/plain",
@@ -800,85 +744,6 @@ void KuitSemanticsPrivate::setFormattingPatterns ()
                            "%1<br/>"));
 }
 
-void KuitSemanticsPrivate::setTextTransformData ()
-{
-    // Mask metaTr with I18N_NOOP2 to have stuff extracted.
-    #undef I18N_NOOP2
-    #define I18N_NOOP2(ctxt, msg) metaTr(ctxt, msg)
-
-    // i18n: Decide which string is used to delimit keys in a keyboard
-    // shortcut (e.g. + in Ctrl+Alt+Tab) in plain text.
-    m_comboKeyDelim[Kuit::Fmt::Plain] = I18N_NOOP2("shortcut-key-delimiter/plain", "+");
-    m_comboKeyDelim[Kuit::Fmt::Term] = m_comboKeyDelim[Kuit::Fmt::Plain];
-    // i18n: Decide which string is used to delimit keys in a keyboard
-    // shortcut (e.g. + in Ctrl+Alt+Tab) in rich text.
-    m_comboKeyDelim[Kuit::Fmt::Rich] = I18N_NOOP2("shortcut-key-delimiter/rich", "+");
-
-    // i18n: Decide which string is used to delimit elements in a GUI path
-    // (e.g. -> in "Go to Settings->Advanced->Core tab.") in plain text.
-    m_guiPathDelim[Kuit::Fmt::Plain] = I18N_NOOP2("gui-path-delimiter/plain", "→");
-    m_guiPathDelim[Kuit::Fmt::Term] = m_guiPathDelim[Kuit::Fmt::Plain];
-    // i18n: Decide which string is used to delimit elements in a GUI path
-    // (e.g. -> in "Go to Settings->Advanced->Core tab.") in rich text.
-    m_guiPathDelim[Kuit::Fmt::Rich] = I18N_NOOP2("gui-path-delimiter/rich", "→");
-    // NOTE: The '→' glyph seems to be available in all widespread fonts.
-
-    // Collect keyboard key names.
-    #undef SET_KEYNAME
-    #define SET_KEYNAME(rawname) do { \
-        /* Normalize key, trim and all lower-case. */ \
-        QString normname = QString::fromLatin1(rawname).trimmed().toLower();  \
-        m_keyNames[normname] = metaTr("keyboard-key-name", rawname); \
-    } while (0)
-
-    // Now we need I18N_NOOP2 that does remove context.
-    #undef I18N_NOOP2
-    #define I18N_NOOP2(ctxt, msg) msg
-
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Alt"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "AltGr"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Backspace"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "CapsLock"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Control"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Ctrl"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Del"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Delete"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Down"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "End"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Enter"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Esc"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Escape"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Home"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Hyper"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Ins"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Insert"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Left"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Menu"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Meta"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "NumLock"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "PageDown"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "PageUp"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "PgDown"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "PgUp"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "PauseBreak"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "PrintScreen"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "PrtScr"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Return"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Right"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "ScrollLock"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Shift"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Space"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Super"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "SysReq"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Tab"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Up"));
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "Win"));
-    // TODO: Add rest of the key names?
-
-    // i18n: Pattern for the function keys.
-    SET_KEYNAME(I18N_NOOP2("keyboard-key-name", "F%1"));
-}
-
 QString KuitSemanticsPrivate::format (const QString &text,
                                       const QString &ctxt) const
 {
@@ -1300,7 +1165,7 @@ KuitSemanticsPrivate::parseOpenEl (const QXmlStreamReader &xml,
         oel.handling = OpenEl::Ignored;
         if (!s->qtHtmlTagNames.contains(oel.name)) {
             kDebug(173) << QString::fromLatin1("Tag '%1' is neither semantic nor HTML in "
-                                   "message {%3}.")
+                                   "message {%2}.")
                                   .arg(oel.name, shorten(text));
         }
     }
@@ -1421,24 +1286,14 @@ QString KuitSemanticsPrivate::modifyTagText (const QString &text,
                                              Kuit::FmtVar fmt) const
 {
     // numctx < 1 means that the number is not in numeric-id context.
-    if (   (tag == Kuit::Tag::NumIntg || tag == Kuit::Tag::NumReal) \
-        && numctx < 1)
-    {
+    if (   (tag == Kuit::Tag::NumIntg || tag == Kuit::Tag::NumReal) && numctx < 1) {
         int fieldWidth = avals.value(Kuit::Att::Width, QString(QLatin1Char('0'))).toInt();
         const QString fillStr = avals.value(Kuit::Att::Fill, QString(QLatin1Char(' ')));
         const QChar fillChar = !fillStr.isEmpty() ? fillStr[0] : QChar::fromLatin1(' ');
-        return QString::fromLatin1("%1").arg(KGlobal::locale()->formatNumber(text, false),
-                                 fieldWidth, fillChar);
-    }
-    else if (tag == Kuit::Tag::Filename) {
+        return QString::fromLatin1("%1").arg(KGlobal::locale()->formatNumber(text, false), fieldWidth, fillChar);
+    } else if (tag == Kuit::Tag::Filename) {
         return QDir::toNativeSeparators(text);
     }
-    else if (tag == Kuit::Tag::Shortcut) {
-        return KuitFormats::toKeyCombo(text, m_comboKeyDelim[fmt], m_keyNames);
-    }
-    else if (tag == Kuit::Tag::Interface) {
-        return KuitFormats::toInterfacePath(text, m_guiPathDelim[fmt]);
-    }
 
     // Fell through, no modification.
     return text;
@@ -1585,72 +1440,3 @@ QString KuitSemantics::format (const QString &text, const QString &ctxt) const
 {
     return d->format(text, ctxt);
 }
-
-bool KuitSemantics::mightBeRichText (const QString &text)
-{
-    KuitSemanticsStaticData *s = semanticsStaticData;
-
-    // Check by appearance of a valid XML entity at first ampersand.
-    int p1 = text.indexOf(QLatin1Char('&'));
-    if (p1 >= 0) {
-        p1 += 1;
-        int p2 = text.indexOf(QLatin1Char(';'), p1);
-        return (p2 > p1 && s->xmlEntities.contains(text.mid(p1, p2 - p1)));
-    }
-
-    // Check by appearance of a valid Qt rich-text tag at first less-than.
-    int tlen = text.length();
-    p1 = text.indexOf(QLatin1Char('<'));
-    if (p1 >= 0) {
-        p1 += 1;
-        // Also allow first tag to be closing tag,
-        // e.g. in case the text is pieced up with list.join("</foo><foo>")
-        bool closing = false;
-        while (p1 < tlen && (text[p1].isSpace() || text[p1] == QLatin1Char('/'))) {
-            if (text[p1] == QLatin1Char('/')) {
-                if (!closing) {
-                    closing = true;
-                } else {
-                    return false;
-                }
-            }
-            ++p1;
-        }
-        for (int p2 = p1; p2 < tlen; ++p2) {
-            QChar c = text[p2];
-            if (c == QLatin1Char('>') || (!closing && c == QLatin1Char('/')) || c.isSpace()) {
-                return s->qtHtmlTagNames.contains(text.mid(p1, p2 - p1));
-            } else if (!c.isLetter()) {
-                return false;
-            }
-        }
-        return false;
-    }
-
-    return false;
-}
-
-QString KuitSemantics::escape (const QString &text)
-{
-    int tlen = text.length();
-    QString ntext;
-    ntext.reserve(tlen);
-    for (int i = 0; i < tlen; ++i) {
-        QChar c = text[i];
-        if (c == QLatin1Char('&')) {
-            ntext += QLatin1String("&amp;");
-        } else if (c == QLatin1Char('<')) {
-            ntext += QLatin1String("&lt;");
-        } else if (c == QLatin1Char('>')) {
-            ntext += QLatin1String("&gt;");
-        } else if (c == QLatin1Char('\'')) {
-            ntext += QLatin1String("&apos;");
-        } else if (c == QLatin1Char('"')) {
-            ntext += QLatin1String("&quot;");
-        } else {
-            ntext += c;
-        }
-    }
-
-    return ntext;
-}
