@@ -17,6 +17,8 @@
  *  Boston, MA 02110-1301, USA.
  **/
 
+#include <kglobalsettings.h>
+
 #include "kmimetype.h"
 #include "kmimetype_p.h"
 #include "kmimetypefactory.h"
@@ -31,10 +33,13 @@
 #include <kstandarddirs.h>
 #include <kurl.h>
 
-#include <QtCore/QFile>
-#include <QtDBus/QtDBus>
-#include <QtCore/QHash>
-#include <QBuffer>
+#include <QtCore/qfile.h>
+#include <QtCore/qhash.h>
+#include <QtCore/qbuffer.h>
+#include <QtCore/qstack.h>
+#include <QXmlStreamReader>
+#include <QDBusInterface>
+#include <QDBusReply>
 
 extern int servicesDebugArea();
 
@@ -94,16 +99,6 @@ static KMimeType::Ptr findFromMode( const QString& path /*only used if is_local_
     }
 
     if ( S_ISDIR( mode ) ) {
-        // KDE4 TODO: use an overlay instead
-#if 0
-        // Special hack for local files. We want to see whether we
-        // are allowed to enter the directory
-        if ( is_local_file )
-        {
-            if ( KDE::access( path, R_OK ) == -1 )
-                return KMimeType::mimeType( "inode/directory-locked" );
-        }
-#endif
         return KMimeType::mimeType( QLatin1String("inode/directory") );
     }
     if ( S_ISCHR( mode ) )
@@ -114,32 +109,6 @@ static KMimeType::Ptr findFromMode( const QString& path /*only used if is_local_
         return KMimeType::mimeType( QLatin1String("inode/fifo") );
     if ( S_ISSOCK( mode ) )
         return KMimeType::mimeType( QLatin1String("inode/socket") );
-#ifdef Q_OS_WIN
-    // FIXME: distinguish between mounted & unmounted
-    int size = path.size();
-    if ( size == 2 || size == 3 ) {
-    //GetDriveTypeW is not defined in wince
-#ifndef _WIN32_WCE
-        unsigned int type = GetDriveTypeW( (LPCWSTR) path.utf16() );
-        switch( type ) {
-            case DRIVE_REMOVABLE:
-                return KMimeType::mimeType( QLatin1String("media/floppy_mounted") );
-            case DRIVE_FIXED:
-                return KMimeType::mimeType( QLatin1String("media/hdd_mounted") );
-            case DRIVE_REMOTE:
-                return KMimeType::mimeType( QLatin1String("media/smb_mounted") );
-            case DRIVE_CDROM:
-                return KMimeType::mimeType( QLatin1String("media/cdrom_mounted") );
-            case DRIVE_RAMDISK:
-                return KMimeType::mimeType( QLatin1String("media/hdd_mounted") );
-            default:
-                break;
-        };
-#else
-        return KMimeType::mimeType( QLatin1String("media/hdd_mounted") );
-#endif
-    }
-#endif
     // remote executable file? stop here (otherwise findFromContent can do that better for local files)
     if ( !is_local_file && S_ISREG( mode ) && ( mode & ( S_IXUSR | S_IXGRP | S_IXOTH ) ) )
         return KMimeType::mimeType( QLatin1String("application/x-executable") );
@@ -193,42 +162,47 @@ KMimeType::Ptr KMimeType::findByUrlHelper( const KUrl& _url, mode_t mode,
     if (mimeFromMode)
         return mimeFromMode;
 
-    // First try to find out by looking at the filename (if there's one)
-    const QString fileName( _url.fileName() );
-    QStringList mimeList;
-    if ( !fileName.isEmpty() && !path.endsWith( QLatin1Char('/') ) ) {
-        // and if we can trust it (e.g. don't trust *.pl over HTTP, could be anything)
-        if ( is_local_file || _url.hasSubUrl() || // Explicitly trust suburls
-             KProtocolInfo::determineMimetypeFromExtension( _url.protocol() ) ) {
-            mimeList = KMimeTypeRepository::self()->findFromFileName( fileName );
-            // Found one glob match exactly: OK, use that.
-            // We disambiguate multiple glob matches by sniffing, below.
-            if ( mimeList.count() == 1 ) {
-                const QString selectedMime = mimeList.at(0);
-                KMimeType::Ptr mime = mimeType(selectedMime);
-                if (!mime) {
-                    // #265188 - this can happen when an old globs file is lying around after
-                    // the packages xml file was removed.
-                    kWarning() << "Glob file refers to" << selectedMime << "but this mimetype does not exist!";
-                    mimeList.clear();
-                } else {
-                    return mime;
-                }
-            }
-        }
-    }
-
     if ( device && !device->isOpen() ) {
         if ( !device->open(QIODevice::ReadOnly) ) {
             device = 0;
         }
     }
 
+    QStringList mimeList;
+
+    // Try to find out by looking at the filename (if there's one)
+    const QString fileName( _url.fileName() );
+    if ( !fileName.isEmpty() && !path.endsWith( QLatin1Char('/') ) ) {
+        // and if we can trust it (e.g. don't trust *.pl over HTTP, could be anything)
+        if ( is_local_file || _url.hasSubUrl() || // Explicitly trust suburls
+             KProtocolInfo::determineMimetypeFromExtension( _url.protocol() ) ) {
+            mimeList = KMimeTypeRepository::self()->findFromFileName( fileName );
+        }
+    }
+
+    QStringList globMimeList = mimeList;
+    // Found one glob match exactly: OK, use that like the reference xdgmime
+    // implementation.
+    if ( mimeList.count() == 1 ) {
+        if (accuracy)
+            *accuracy = 50;
+        const QString selectedMime = mimeList.at(0);
+        KMimeType::Ptr mime = mimeType(selectedMime);
+        if (!mime) {
+            // #265188 - this can happen when an old globs file is lying around after
+            // the packages xml file was removed.
+            kWarning() << "Glob file refers to" << selectedMime << "but this mimetype does not exist!";
+            mimeList.clear();
+        } else {
+            return mime;
+        }
+    }
+
     // Try the magic matches (if we can read the data)
-    QByteArray beginning;
     if ( device ) {
+        QByteArray cache;
         int magicAccuracy;
-        KMimeType::Ptr mime = KMimeTypeRepository::self()->findFromContent(device, &magicAccuracy, beginning);
+        KMimeType::Ptr mime = KMimeTypeRepository::self()->findFromContent(device, &magicAccuracy, cache);
         // mime can't be 0, except in case of install problems.
         // However we get magicAccuracy==0 for octet-stream, i.e. no magic match found.
         //kDebug(servicesDebugArea()) << "findFromContent said" << (mime?mime->name():QString()) << "with accuracy" << magicAccuracy;
@@ -257,24 +231,6 @@ KMimeType::Ptr KMimeType::findByUrlHelper( const KUrl& _url, mode_t mode,
         }
     }
 
-    // Not a local file, or no magic allowed, or magic found nothing
-
-    // Maybe we had multiple matches from globs?
-    if (!mimeList.isEmpty()) {
-        if (accuracy)
-            *accuracy = 20;
-        // We have to pick one...
-        // At least make this deterministic
-        qSort(mimeList.begin(), mimeList.end());
-        Q_FOREACH(const QString& mimeName, mimeList) {
-            KMimeType::Ptr mime = mimeType(mimeName);
-            if (!mime)
-                kWarning() << "Glob file refers to" << mimeName << "but this mimetype does not exist!";
-            else
-                return mime;
-        }
-    }
-
     // Find a fallback from the protocol
     if (accuracy)
         *accuracy = 10;
@@ -308,6 +264,16 @@ KMimeType::Ptr KMimeType::findByUrlHelper( const KUrl& _url, mode_t mode,
         }
     }
 
+    if (globMimeList.count() > 0) {
+        // Glob with no magic (e.g. application/x-cd-image)
+        KMimeType::Ptr mime = mimeType( globMimeList.at(0) );
+        if (mime) {
+            if (accuracy)
+                *accuracy = 50;
+            return mime;
+        }
+    }
+
     if (accuracy)
         *accuracy = 0;
     return defaultMimeTypePtr();
@@ -436,7 +402,9 @@ void KMimeTypePrivate::save( QDataStream& _str )
 QVariant KMimeTypePrivate::property( const QString& _name ) const
 {
     if ( _name == QLatin1String("Patterns") )
-        return QVariant( m_lstPatterns );
+        return patterns();
+    if ( _name == QLatin1String("Comment") )
+        return comment();
     if ( _name == QLatin1String("Icon") )
         return QVariant( iconName(KUrl()) );
 
@@ -462,7 +430,7 @@ QString KMimeType::iconNameForUrl( const KUrl & _url, mode_t mode )
     if (!mt) {
         return QString();
     }
-    static const QString& unknown = KGlobal::staticQString("unknown");
+    static const QString unknown = QString::fromLatin1("unknown");
     const QString mimeTypeIcon = mt->iconName( _url );
     QString i = mimeTypeIcon;
 
@@ -485,39 +453,19 @@ QString KMimeType::iconNameForUrl( const KUrl & _url, mode_t mode )
 
 QString KMimeType::favIconForUrl( const KUrl& url )
 {
-    /* The kded module also caches favicons, for one week, without any way
-     * to clean up the cache meanwhile.
-     * On the other hand, this QHash will get cleaned up after 5000 request
-     * (a selection in konsole of 80 chars generates around 500 requests)
-     * or by simply restarting the application (or the whole desktop,
-     * more likely, for the case of konqueror or konsole).
-     */
-    static QHash<QUrl, QString> iconNameCache;
-    static int autoClearCache = 0;
-    const QString notFound = QLatin1String("NOTFOUND");
-
     if (url.isLocalFile()
         || !url.protocol().startsWith(QLatin1String("http"))
         || !KMimeTypeRepository::self()->useFavIcons())
         return QString();
 
-    QString iconNameFromCache = iconNameCache.value(url, notFound);
-    if ( iconNameFromCache != notFound ) {
-        if ( (++autoClearCache) < 5000 ) {
-            return iconNameFromCache;
-        }
-        else {
-            iconNameCache.clear();
-            autoClearCache = 0;
-        }
-    }
-
     QDBusInterface kded( QString::fromLatin1("org.kde.kded"),
                          QString::fromLatin1("/modules/favicons"),
                          QString::fromLatin1("org.kde.FavIcon") );
     QDBusReply<QString> result = kded.call( QString::fromLatin1("iconForUrl"), url.url() );
-    iconNameCache.insert(url, result.value());
-    return result;              // default is QString()
+    if (result.isValid()) {
+        return result.value();
+    }
+    return QString();
 }
 
 QString KMimeType::comment( const KUrl &url) const
@@ -526,15 +474,6 @@ QString KMimeType::comment( const KUrl &url) const
     return d->comment(url);
 }
 
-#ifndef KDE_NO_DEPRECATED
-QString KMimeType::parentMimeType() const
-{
-    const QStringList parents = parentMimeTypes();
-    if (!parents.isEmpty())
-        return parents.first();
-    return QString();
-}
-#endif
 
 bool KMimeTypePrivate::inherits(const QString& mime) const
 {
@@ -594,9 +533,7 @@ QStringList KMimeType::allParentMimeTypes() const
 
 QString KMimeType::defaultMimeType()
 {
-    static const QString & s_strDefaultMimeType =
-        KGlobal::staticQString( "application/octet-stream" );
-    return s_strDefaultMimeType;
+    return QString::fromLatin1("application/octet-stream");
 }
 
 QString KMimeType::iconName( const KUrl& url) const
@@ -608,8 +545,7 @@ QString KMimeType::iconName( const KUrl& url) const
 QStringList KMimeType::patterns() const
 {
     Q_D(const KMimeType);
-    d->ensureXmlDataLoaded();
-    return d->m_lstPatterns;
+    return d->patterns();
 }
 
 // loads comment, icon, mainPattern, m_lstPatterns
@@ -651,7 +587,7 @@ void KMimeTypePrivate::ensureXmlDataLoaded() const
             const QString name = xml.attributes().value(QLatin1String("type")).toString();
             if (name.isEmpty())
                 continue;
-            if (name != m_strName) {
+            if (name.toLower() != m_strName) {
                 kWarning() << "Got name" << name << "in file" << file << "expected" << m_strName;
             }
 
@@ -684,9 +620,13 @@ void KMimeTypePrivate::ensureXmlDataLoaded() const
                 }
                 xml.skipCurrentElement();
             }
+#warning FIXME: non-glibc crash workaround, investigate
+#ifdef __GLIBC__
             if (xml.name() != "mime-type") {
-                kFatal() << "Programming error in KMimeType XML loading, please create a bug report on http://bugs.kde.org and attach the file" << fullPath;
+                kFatal() << "Programming error in KMimeType XML loading, please create a bug report on"
+                    << KDE_BUG_REPORT_URL << "including the file" << fullPath;
             }
+#endif
         }
     }
 
@@ -714,16 +654,10 @@ void KMimeTypePrivate::ensureXmlDataLoaded() const
     }
     m_strComment = comment;
 
-    const bool globsInXml = (KMimeType::sharedMimeInfoVersion() >= KDE_MAKE_VERSION(0, 70, 0));
-    if (globsInXml) {
-        if (!mainPattern.isEmpty() && m_lstPatterns.first() != mainPattern) {
-            // ensure it's first in the list of patterns
-            m_lstPatterns.removeAll(mainPattern);
-            m_lstPatterns.prepend(mainPattern);
-        }
-    } else {
-        // Fallback: get the patterns from the globs file
-        m_lstPatterns = KMimeTypeRepository::self()->patternsForMimetype(m_strName);
+    if (!mainPattern.isEmpty() && m_lstPatterns.first() != mainPattern) {
+        // ensure it's first in the list of patterns
+        m_lstPatterns.removeAll(mainPattern);
+        m_lstPatterns.prepend(mainPattern);
     }
 }
 
@@ -743,22 +677,7 @@ QString KMimeType::mainExtension() const
 {
     Q_D(const KMimeType);
 
-#if 1 // HACK START - can be removed once shared-mime-info >= 0.70 is used/required.
-    // The idea was: first usable pattern from m_lstPatterns.
-    // But update-mime-database makes a mess of the order of the patterns,
-    // because it uses a hash internally.
-    static const struct { const char* mime; const char* extension; } s_hardcodedMimes[] = {
-        { "text/plain", ".txt" } };
-    if (d->m_lstPatterns.count() > 1) {
-        const QByteArray me = name().toLatin1();
-        for (uint i = 0; i < sizeof(s_hardcodedMimes)/sizeof(*s_hardcodedMimes); ++i) {
-            if (me == s_hardcodedMimes[i].mime)
-                return QString::fromLatin1(s_hardcodedMimes[i].extension);
-        }
-    }
-#endif // HACK END
-
-     Q_FOREACH(const QString& pattern, patterns()) {
+    Q_FOREACH(const QString& pattern, d->patterns()) {
         // Skip if if looks like: README or *. or *.*
         // or *.JP*G or *.JP?
         if (pattern.startsWith(QLatin1String("*.")) &&
