@@ -20,16 +20,9 @@
 #ifndef __kmimetype_h__
 #define __kmimetype_h__
 
-#include <QtCore/QStringList>
-#include <QtCore/QList>
-
 #include <kurl.h>
-#include <ksycocatype.h>
 #include <kservicetype.h>
 
-#include <sys/types.h>
-#include <sys/stat.h>
-
 class KMimeTypePrivate;
 
 /**
@@ -43,7 +36,7 @@ class KMimeTypePrivate;
  *
  * @see KServiceType
  */
-class KDECORE_EXPORT KMimeType : public KServiceType
+class KDECORE_EXPORT KMimeType : public KServiceType // TODO KDE5: drop kservicetype inheritance, inherit kshared
 {
     Q_DECLARE_PRIVATE( KMimeType )
 public:
@@ -56,10 +49,10 @@ public:
      * Return the filename of the icon associated with the mimetype.
      * Use KIconLoader::loadMimeTypeIcon to load the icon.
      *
-     * The url argument is unused, but is provided so that KMimeType-derived classes
-     * can use it (e.g. KFolderType uses the URL to return one out of 2 icons)
+     * @param url argument only used for directories, where the icon
+     * can be specified in the .directory file.
      *
-     * @return The path to the icon associated with this MIME type.
+     * @return The name of the icon associated with this MIME type.
      */
     QString iconName( const KUrl &url = KUrl()) const;
 
@@ -118,17 +111,22 @@ public:
      *         0 if not found
      * @see KServiceType::serviceType
      */
-    static Ptr mimeType( const QString& name, FindByNameOption options = DontResolveAlias );
+    static Ptr mimeType( const QString& name, FindByNameOption options = ResolveAliases );
 
     /**
      * Finds a KMimeType with the given @p url.
      * This function looks at mode_t first.
-     * If that does not help it
-     * looks at the extension.  This is fine for FTP, FILE, TAR and
-     * friends, but is not for HTTP ( cgi scripts! ). You should use
-     * KRun instead, but this function returns immediately while
-     * KRun is async. If no extension matches, then
-     * the file contents will be examined if the URL is a local file, or
+     * If that does not help it looks at the extension (and the contents, for local files).
+     * This method is fine for many protocols like ftp, file, fish, zip etc.,
+     * but is not for http (e.g. cgi scripts
+     * make extension-based checking unreliable).
+     * For HTTP you should use KRun instead (to open the URL, in an app
+     * or internally), or a KIO::mimetype() job (to find the mimetype without
+     * downloading), or a KIO::get() job (to find the mimetype and then download).
+     * In fact KRun is the most complete solution, but deriving from it just
+     * for this is a bit cumbersome.
+     *
+     * If no extension matches, then the file contents will be examined if the URL is a local file, or
      * "application/octet-stream" is returned otherwise.
      *
      * @param url Is the right most URL with a filesystem protocol. It
@@ -170,12 +168,11 @@ public:
      *
      * Equivalent to
      * \code
-     * KUrl u;
-     * u.setPath(path);
+     * KUrl u(path);
      * return findByUrl( u, mode, true, fast_mode );
      * \endcode
      *
-     * @param path the path to the file
+     * @param path the path to the file (a file name is enough, in fast mode)
      * @param mode the mode of the file (used, for example, to identify
      *              executables)
      * @param fast_mode If set to true no disk access is allowed to
@@ -195,8 +192,8 @@ public:
      * @param data the data to examine
      * @param accuracy If not a null pointer, *accuracy is set to the
      *          accuracy of the match (which is in the range 0..100)
-     * @return a pointer to the KMimeType. @c 0 if the
-     *         type can not be found this way.
+     * @return a pointer to the KMimeType. "application/octet-stream" is
+     *          returned if the type can not be found this way.
      */
     static Ptr findByContent( const QByteArray &data, int *accuracy=0 );
 
@@ -218,6 +215,40 @@ public:
     static Ptr findByNameAndContent( const QString& name, const QByteArray& data,
                                      mode_t mode = 0, int *accuracy=0 );
 
+    /**
+     * Tries to find out the MIME type of a data chunk by looking for
+     * certain magic numbers and characteristic strings in it.
+     *
+     * @param device the IO device providing the data to examine
+     * @param accuracy If not a null pointer, *accuracy is set to the
+     *          accuracy of the match (which is in the range 0..100)
+     * @return a pointer to the KMimeType. "application/octet-stream" is
+     *          returned if the type can not be found this way.
+     * @since 4.4
+     */
+    static Ptr findByContent( QIODevice* device, int* accuracy = 0 );
+
+    /**
+     * Tries to find out the MIME type of filename/url and a data chunk.
+     * Whether to trust the extension or the data depends on the results of both approaches,
+     * and is determined automatically.
+     *
+     * This method is useful for instance in the get() method of kioslaves, and anywhere else
+     * where a filename is associated with some data which is available immediately.
+     *
+     * @param name the filename or url representing this data.
+     * Only used for the extension, not used as a local filename.
+     * @param device the IO device providing the data to examine when the extension isn't conclusive in itself
+     * @param mode the mode of the file (used, for example, to identify executables)
+     * @param accuracy If not a null pointer, *accuracy is set to the
+     *          accuracy of the match (which is in the range 0..100)
+     * @return a pointer to the KMimeType. "application/octet-stream" is
+     *          returned if the type can not be found this way.
+     * @since 4.4
+     */
+    static Ptr findByNameAndContent( const QString& name, QIODevice* device,
+                                     mode_t mode = 0, int* accuracy = 0 );
+
     /**
      * Tries to find out the MIME type of a file by looking for
      * certain magic numbers and characteristic strings in it.
@@ -280,18 +311,6 @@ public:
     /// Return true if this mimetype is the default mimetype
     bool isDefault() const;
 
-    /**
-     * If this mimetype is a subclass of another mimetype,
-     * return the name of the parent.
-     *
-     * @return the parent mime type, or QString() if not set
-     *
-     * @deprecated this method does not support multiple inheritance,
-     * which is actually part of the shared-mime-info standard.
-     * Use is(), parentMimeTypes(), or allParentMimeTypes() instead of parentMimeType()
-     */
-    KDE_DEPRECATED QString parentMimeType() const;
-
     /**
      * If this mimetype is a subclass of one or more other mimetypes,
      * return the list of those mimetypes.
@@ -332,6 +351,26 @@ public:
      */
     bool is( const QString& mimeTypeName ) const;
 
+    /**
+     * Returns the user-specified icon for this mimetype. This is empty most of the time,
+     * you probably want to use iconName() instead. This method is for the mimetype editor.
+     * @since 4.3
+     */
+    QString userSpecifiedIconName() const;
+
+    /**
+     * Return the primary extension associated with this mimetype, if any.
+     * If patterns() returns (*.jpg, *.jpeg) then mainExtension will return ".jpg".
+     * Note that the dot is included.
+     *
+     * If none of the patterns is in *.foo format (for instance
+     *   <code>*.jp? or *.* or callgrind.out* </code>)
+     * then mainExtension() returns an empty string.
+     *
+     * @since 4.3
+     */
+    QString mainExtension() const;
+
     /**
      * Determines the extension from a filename (or full path) using the mimetype database.
      * This allows to extract "tar.bz2" for foo.tar.bz2
@@ -339,11 +378,27 @@ public:
      */
     static QString extractKnownExtension( const QString &fileName );
 
+    /**
+     * Returns true if the given filename matches the given pattern.
+     * @since 4.6.1
+     */
+    static bool matchFileName( const QString &filename, const QString &pattern );
+
+    /**
+     * Returns the version of the installed update-mime-database program
+     * (from freedesktop.org shared-mime-info). This is used by unit tests
+     * and by the code that writes out icon definitions.
+     * @since 4.3
+     * @return -1 on error, otherwise a version number to use like this:
+     * @code
+     * if (version >= KDE_MAKE_VERSION(0, 40, 0)) { ... }
+     * @endcode
+     */
+    static int sharedMimeInfoVersion();
+
 protected:
 
-    friend class KMimeTypeFactory; // for KMimeType(QDataStream&,int)
-    friend class KBuildMimeTypeFactory; // for KMimeType(QDataStream&,int)
-    friend class KMimeFileParser; // for addPattern and addMagicRule
+    friend class KMimeTypeRepository; // for KMimeType(QString,QString,QString)
 
     /**
      * @internal Construct a service from a stream.
@@ -378,17 +433,11 @@ protected:
      */
     KMimeType( KMimeTypePrivate &dd, const QString& name, const QString& comment );
 
-    /// @internal for kbuildsycoca. Don't ever use this, or else...
-    void setPatterns(const QStringList& patterns);
-    /// @internal for kbuildsycoca. Don't ever use this, or else...
-    void setParentMimeType(const QString& parent);
-    /// @internal for kbuildsycoca. Don't ever use this, or else...
-    void internalClearData();
-
 private:
+    // Forbidden nowadays in KMimeType
+    int offset() const;
+    void save(QDataStream &s);
 
-    void loadInternal( QDataStream& _str);
-    static void buildDefaultType();
     static void checkEssentialMimeTypes();
     static KMimeType::Ptr findByUrlHelper( const KUrl& url, mode_t mode,
                                            bool is_local_file, QIODevice* device, int* accuracy );
