@@ -17,21 +17,42 @@
  *  Boston, MA 02110-1301, USA.
  */
 
+#include "kmimetype.h"
+#include "kfoldermimetype.h"
 #include "kmimetyperepository_p.h"
 #include <kstandarddirs.h>
 #include <ksharedconfig.h>
 #include <kconfiggroup.h>
-#include "kmimetype.h"
 #include <kdeversion.h> // KDE_MAKE_VERSION
 #include <kmessage.h>
 #include <klocale.h>
-#include "kfoldermimetype.h"
+#include <kstandarddirs.h>
 #include <QFile>
 #include <QProcess>
-#include <QtEndian>
+#include <QtCore/qendian.h>
+
+#include "config-prefix.h"
 
 extern int servicesDebugArea();
 
+static int mimeDataBaseVersion()
+{
+    // shared-mime-info installs a "version" file since 0.91
+    const QStringList versionFiles = KGlobal::dirs()->findAllResources("xdgdata-mime", QLatin1String("version"));
+    if (!versionFiles.isEmpty()) {
+        QFile file(versionFiles.first()); // Look at the global file, not at a possibly old local one
+        if (file.open(QIODevice::ReadOnly)) {
+            const QByteArray line = file.readLine().simplified();
+            QRegExp versionRe(QString::fromLatin1("(\\d+)\\.(\\d+)(\\.(\\d+))?"));
+            if (versionRe.indexIn(QString::fromLocal8Bit(line)) > -1) {
+                return KDE_MAKE_VERSION(versionRe.cap(1).toInt(), versionRe.cap(2).toInt(), versionRe.cap(4).toInt());
+            }
+        }
+    }
+
+    return -1;
+}
+
 KMimeTypeRepository * KMimeTypeRepository::self()
 {
     K_GLOBAL_STATIC(KMimeTypeRepository, s_self)
@@ -43,12 +64,10 @@ KMimeTypeRepository::KMimeTypeRepository()
       m_magicFilesParsed(false),
       m_aliasFilesParsed(false),
       m_globsFilesParsed(false),
-      m_patternsMapCalculated(false),
       m_mimeTypesChecked(false),
       m_useFavIcons(true),
       m_useFavIconsChecked(false),
-      m_sharedMimeInfoVersion(0),
-      m_mutex(QReadWriteLock::Recursive)
+      m_sharedMimeInfoVersion(0)
 {
 }
 
@@ -63,7 +82,7 @@ KMimeType::Ptr KMimeTypeRepository::findMimeTypeByName(const QString &_name, KMi
         name = canonicalName(name);
     }
 
-    const QString filename = name + QLatin1String(".xml");
+    const QString filename = name.toLower() + QLatin1String(".xml");
 
     if (KStandardDirs::locate("xdgdata-mime", filename).isEmpty()) {
         return KMimeType::Ptr(); // Not found
@@ -191,36 +210,19 @@ void KMimeTypeRepository::findFromOtherPatternList(QStringList& matchingMimeType
 
 QStringList KMimeTypeRepository::findFromFileName(const QString &fileName, QString *pMatchingExtension)
 {
-    m_mutex.lockForWrite();
     parseGlobs();
-    m_mutex.unlock();
 
-    QReadLocker lock(&m_mutex);
-    // First try the high weight matches (>50), if any.
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
+    // First try the high weight matches (>=50), if any.
     QStringList matchingMimeTypes;
     QString foundExt;
     findFromOtherPatternList(matchingMimeTypes, fileName, foundExt, true);
-    if (matchingMimeTypes.isEmpty()) {
 
-        // Now use the "fast patterns" dict, for simple *.foo patterns with weight 50
-        // (which is most of them, so this optimization is definitely worth it)
-        const int lastDot = fileName.lastIndexOf(QLatin1Char('.'));
-        if (lastDot != -1) { // if no '.', skip the extension lookup
-            const int ext_len = fileName.length() - lastDot - 1;
-            const QString simpleExtension = fileName.right( ext_len ).toLower();
-            // (toLower because fast matterns are always case-insensitive and saved as lowercase)
-
-            matchingMimeTypes = m_globs.m_fastPatterns.value(simpleExtension);
-            if (!matchingMimeTypes.isEmpty()) {
-                foundExt = simpleExtension;
-                // Can't return yet; *.tar.bz2 has to win over *.bz2, so we need the low-weight mimetypes anyway,
-                // at least those with weight 50.
-            }
-        }
-
-        // Finally, try the low weight matches (<=50)
+    if (matchingMimeTypes.isEmpty() || foundExt.isEmpty()) {
+        // Try the low weight matches (<50)
         findFromOtherPatternList(matchingMimeTypes, fileName, foundExt, false);
     }
+
     if (pMatchingExtension)
         *pMatchingExtension = foundExt;
     return matchingMimeTypes;
@@ -244,16 +246,11 @@ KMimeType::Ptr KMimeTypeRepository::findFromContent(QIODevice* device, int* accu
         }
     }
 
-    m_mutex.lockForWrite();
-    if (!m_magicFilesParsed) {
-        parseMagic();
-        m_magicFilesParsed = true;
-    }
-    m_mutex.unlock();
+    parseMagic();
 
     // Apply magic rules
     {
-        QReadLocker lock(&m_mutex);
+        std::lock_guard<std::recursive_mutex> lock(m_mutex);
         Q_FOREACH ( const KMimeMagicRule& rule, m_magicRules ) {
             if (rule.match(device, deviceSize, beginning)) {
                 if (accuracy)
@@ -293,7 +290,7 @@ static QString fallbackParent(const QString& mimeTypeName)
 
 QStringList KMimeTypeRepository::parents(const QString& mime)
 {
-    QWriteLocker lock(&m_mutex);
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
     if (!m_parentsMapLoaded) {
         m_parentsMapLoaded = true;
         Q_ASSERT(m_parents.isEmpty());
@@ -305,24 +302,24 @@ QStringList KMimeTypeRepository::parents(const QString& mime)
             QFile qfile( fileName );
             //kDebug(7021) << "Now parsing" << fileName;
             if (qfile.open(QIODevice::ReadOnly)) {
-                QTextStream stream(&qfile);
-                stream.setCodec("ISO 8859-1");
-                while (!stream.atEnd()) {
-                    const QString line = stream.readLine();
-                    if (line.isEmpty() || line[0] == QLatin1Char('#'))
+                while (!qfile.atEnd()) {
+                    const QByteArray line = qfile.readLine().trimmed();
+                    if (line.isEmpty() || line[0] == '#')
                         continue;
-                    const int pos = line.indexOf(QLatin1Char(' '));
+                    const int pos = line.indexOf(' ');
                     if (pos == -1) // syntax error
                         continue;
-                    const QString derivedTypeName = line.left(pos);
-                    KMimeType::Ptr derivedType = findMimeTypeByName(derivedTypeName, KMimeType::ResolveAliases);
+                    const QByteArray derivedTypeName = line.left(pos);
+                    const QString derivedTypeNameStr = QString::fromLatin1(derivedTypeName.constData(), derivedTypeName.size());
+                    KMimeType::Ptr derivedType = findMimeTypeByName(derivedTypeNameStr, KMimeType::ResolveAliases);
                     if (!derivedType)
-                        kDebug() << fileName << " refers to unknown mimetype " << derivedTypeName;
+                        kWarning(7021) << fileName << " refers to unknown mimetype " << derivedTypeNameStr;
                     else {
-                        const QString parentTypeName = line.mid(pos+1);
+                        const QByteArray parentTypeName = line.mid(pos+1);
+                        const QString parentTypeNameStr = QString::fromLatin1(parentTypeName.constData(), parentTypeName.size());
                         Q_ASSERT(!parentTypeName.isEmpty());
-                        //derivedType->setParentMimeType(parentTypeName);
-                        m_parents[derivedTypeName].append(parentTypeName);
+                        //derivedType->setParentMimeType(parentTypeNameStr);
+                        m_parents[derivedTypeNameStr].append(parentTypeNameStr);
                     }
                 }
             }
@@ -339,18 +336,19 @@ QStringList KMimeTypeRepository::parents(const QString& mime)
     return parents;
 }
 
-#include <arpa/inet.h> // for ntohs
-#include <kstandarddirs.h>
-#include <QFile>
-
 // Sort them in descending order of priority
 static bool mimeMagicRuleCompare(const KMimeMagicRule& lhs, const KMimeMagicRule& rhs) {
     return lhs.priority() > rhs.priority();
 }
 
-// Caller must hold m_mutex
 void KMimeTypeRepository::parseMagic()
 {
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
+    if (m_magicFilesParsed) {
+        return;
+    }
+    m_magicFilesParsed = true;
+
     const QStringList magicFiles = KGlobal::dirs()->findAllResources("xdgdata-mime", QLatin1String("magic"));
     //kDebug() << magicFiles;
     QListIterator<QString> magicIter( magicFiles );
@@ -395,9 +393,12 @@ QList<KMimeMagicRule> KMimeTypeRepository::parseMagicFile(QIODevice* file, const
         return rules;
     }
     QList<KMimeMagicMatch> matches; // toplevel matches (indent==0)
-    int priority = 0; // to avoid warning
+    int priority = 50;
     QString mimeTypeName;
 
+    static const int sharedmimeinfover = mimeDataBaseVersion();
+    static const int sharedmimeinfo200 = KDE_MAKE_VERSION(2, 0, 0);
+
     Q_FOREVER {
         char ch = '\0';
         bool chOk = file->getChar(&ch);
@@ -405,7 +406,13 @@ QList<KMimeMagicRule> KMimeTypeRepository::parseMagicFile(QIODevice* file, const
         if (!chOk || ch == '[') {
             // Finish previous section
             if (!mimeTypeName.isEmpty()) {
-                rules.append(KMimeMagicRule(mimeTypeName, priority, matches));
+                // workaround for:
+                // https://gitlab.freedesktop.org/xdg/shared-mime-info/-/issues/144
+                if (sharedmimeinfover <= sharedmimeinfo200 && mimeTypeName == QLatin1String("audio/x-mod")) {
+                    kDebug(servicesDebugArea()) << "Ignoring audio/x-mod magic rules";
+                } else {
+                    rules.append(KMimeMagicRule(mimeTypeName, priority, matches));
+                }
                 matches.clear();
                 mimeTypeName.clear();
             }
@@ -417,14 +424,14 @@ QList<KMimeMagicRule> KMimeTypeRepository::parseMagicFile(QIODevice* file, const
             const int pos = line.indexOf(QLatin1Char(':'));
             if (pos == -1) { // syntax error
                 kWarning(servicesDebugArea()) << "Syntax error in " << mimeTypeName
-                               << " ':' not present in section name" << endl;
+                               << " ':' not present in section name";
                 break;
             }
             priority = line.left(pos).toInt();
             mimeTypeName = line.mid(pos+1);
             mimeTypeName = mimeTypeName.left(mimeTypeName.length()-2); // remove ']\n'
             //kDebug(servicesDebugArea()) << "New rule for " << mimeTypeName
-            //             << " with priority " << priority << endl;
+            //             << " with priority " << priority;
         } else {
             // Parse line in the section
             // [ indent ] ">" start-offset "=" value
@@ -452,7 +459,7 @@ QList<KMimeMagicRule> KMimeTypeRepository::parseMagicFile(QIODevice* file, const
                 break;
             const qint16 valueLength = qFromBigEndian(lengthBuffer);
             //kDebug() << "indent=" << indent << " rangeStart=" << match.m_rangeStart
-            //         << " valueLength=" << valueLength << endl;
+            //         << " valueLength=" << valueLength;
 
             match.m_data.resize(valueLength);
             if (file->read(match.m_data.data(), valueLength) != valueLength)
@@ -549,36 +556,37 @@ QList<KMimeMagicRule> KMimeTypeRepository::parseMagicFile(QIODevice* file, const
 
 const KMimeTypeRepository::AliasesMap& KMimeTypeRepository::aliases()
 {
-    QWriteLocker lock(&m_mutex);
-    if (!m_aliasFilesParsed) {
-        m_aliasFilesParsed = true;
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
+    if (m_aliasFilesParsed) {
+        return m_aliases;
+    }
+    m_aliasFilesParsed = true;
 
-        const QStringList aliasFiles = KGlobal::dirs()->findAllResources("xdgdata-mime", QLatin1String("aliases"));
-        Q_FOREACH(const QString& fileName, aliasFiles) {
-            QFile qfile(fileName);
-            //kDebug(7021) << "Now parsing" << fileName;
-            if (qfile.open(QIODevice::ReadOnly)) {
-                QTextStream stream(&qfile);
-                stream.setCodec("ISO 8859-1");
-                while (!stream.atEnd()) {
-                    const QString line = stream.readLine();
-                    if (line.isEmpty() || line[0] == QLatin1Char('#'))
-                        continue;
-                    const int pos = line.indexOf(QLatin1Char(' '));
-                    if (pos == -1) // syntax error
-                        continue;
-                    const QString aliasTypeName = line.left(pos);
-                    const QString parentTypeName = line.mid(pos+1);
-                    Q_ASSERT(!aliasTypeName.isEmpty());
-                    Q_ASSERT(!parentTypeName.isEmpty());
+    const QStringList aliasFiles = KGlobal::dirs()->findAllResources("xdgdata-mime", QLatin1String("aliases"));
+    Q_FOREACH(const QString& fileName, aliasFiles) {
+        QFile qfile(fileName);
+        //kDebug(7021) << "Now parsing" << fileName;
+        if (qfile.open(QIODevice::ReadOnly)) {
+            while (!qfile.atEnd()) {
+                const QByteArray line = qfile.readLine().trimmed();
+                if (line.isEmpty() || line[0] == '#')
+                    continue;
+                const int pos = line.indexOf(' ');
+                if (pos == -1) // syntax error
+                    continue;
+                const QByteArray aliasTypeName = line.left(pos);
+                const QByteArray parentTypeName = line.mid(pos+1);
+                Q_ASSERT(!aliasTypeName.isEmpty());
+                Q_ASSERT(!parentTypeName.isEmpty());
+                const QString aliasTypeNameStr = QString::fromLatin1(aliasTypeName.constData(), aliasTypeName.size());
+                const QString parentTypeNameStr = QString::fromLatin1(parentTypeName.constData(), parentTypeName.size());
 
-                    const KMimeType::Ptr realMimeType =
-                        findMimeTypeByName(aliasTypeName, KMimeType::DontResolveAlias);
-                    if (realMimeType) {
-                        //kDebug(servicesDebugArea()) << "Ignoring alias" << aliasTypeName << "because also defined as a real mimetype";
-                    } else {
-                        m_aliases.insert(aliasTypeName, parentTypeName);
-                    }
+                const KMimeType::Ptr realMimeType =
+                    findMimeTypeByName(aliasTypeNameStr, KMimeType::DontResolveAlias);
+                if (realMimeType) {
+                    //kDebug(servicesDebugArea()) << "Ignoring alias" << aliasTypeNameStr << "because also defined as a real mimetype";
+                } else {
+                    m_aliases.insert(aliasTypeNameStr, parentTypeNameStr);
                 }
             }
         }
@@ -586,25 +594,16 @@ const KMimeTypeRepository::AliasesMap& KMimeTypeRepository::aliases()
     return m_aliases;
 }
 
-// Caller must lock m_mutex for write
 void KMimeTypeRepository::parseGlobs()
 {
-    if (!m_globsFilesParsed) {
-        m_globsFilesParsed = true;
-        KMimeGlobsFileParser parser;
-        m_globs = parser.parseGlobs();
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
+    if (m_globsFilesParsed) {
+        return;
     }
-}
+    m_globsFilesParsed = true;
 
-QStringList KMimeTypeRepository::patternsForMimetype(const QString& mimeType)
-{
-    QWriteLocker lock(&m_mutex);
-    if (!m_patternsMapCalculated) {
-        m_patternsMapCalculated = true;
-        parseGlobs();
-        m_patterns = m_globs.patternsMap();
-    }
-    return m_patterns.value(mimeType);
+    KMimeGlobsFileParser parser;
+    m_globs = parser.parseGlobs();
 }
 
 static void errorMissingMimeTypes( const QStringList& _types )
@@ -615,10 +614,10 @@ static void errorMissingMimeTypes( const QStringList& _types )
 
 void KMimeTypeRepository::checkEssentialMimeTypes()
 {
-    QWriteLocker lock(&m_mutex);
-    if (m_mimeTypesChecked) // already done
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
+    if (m_mimeTypesChecked) { // already done
         return;
-
+    }
     m_mimeTypesChecked = true; // must be done before building mimetypes
 
     // No Mime-Types installed ?
@@ -636,9 +635,6 @@ void KMimeTypeRepository::checkEssentialMimeTypes()
 
     if (!KMimeType::mimeType(QLatin1String("inode/directory")))
         missingMimeTypes.append(QLatin1String("inode/directory"));
-#ifndef Q_OS_WIN
-    //if (!KMimeType::mimeType(QLatin1String("inode/directory-locked")))
-    //  missingMimeTypes.append(QLatin1String("inode/directory-locked"));
     if (!KMimeType::mimeType(QLatin1String("inode/blockdevice")))
         missingMimeTypes.append(QLatin1String("inode/blockdevice"));
     if (!KMimeType::mimeType(QLatin1String("inode/chardevice")))
@@ -647,7 +643,6 @@ void KMimeTypeRepository::checkEssentialMimeTypes()
         missingMimeTypes.append(QLatin1String("inode/socket"));
     if (!KMimeType::mimeType(QLatin1String("inode/fifo")))
         missingMimeTypes.append(QLatin1String("inode/fifo"));
-#endif
     if (!KMimeType::mimeType(QLatin1String("application/x-shellscript")))
         missingMimeTypes.append(QLatin1String("application/x-shellscript"));
     if (!KMimeType::mimeType(QLatin1String("application/x-executable")))
@@ -661,7 +656,7 @@ void KMimeTypeRepository::checkEssentialMimeTypes()
 
 KMimeType::Ptr KMimeTypeRepository::defaultMimeTypePtr()
 {
-    QWriteLocker lock(&m_mutex);
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
     if (!m_defaultMimeType) {
         // Try to find the default type
         KMimeType::Ptr mime = findMimeTypeByName(KMimeType::defaultMimeType());
@@ -682,109 +677,19 @@ bool KMimeTypeRepository::useFavIcons()
 {
     // this method will be called quite often, so better not read the config
     // again and again.
-    m_mutex.lockForWrite();
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
     if (!m_useFavIconsChecked) {
         m_useFavIconsChecked = true;
         KConfigGroup cg( KGlobal::config(), "HTML Settings" );
         m_useFavIcons = cg.readEntry("EnableFavicon", true);
     }
-    m_mutex.unlock();
     return m_useFavIcons;
 }
 
-static void addPlatformSpecificPkgConfigPath(QStringList& paths)
-{
-#if defined (Q_OS_FREEBSD)
-    paths << QLatin1String("/usr/local/libdata/pkgconfig"); // FreeBSD
-#elif defined(Q_OS_OPENBSD) || defined(Q_OS_NETBSD) || defined(Q_OS_SOLARIS)
-    paths << QLatin1String("/usr/local/lib/pkgconfig"); // {Net,Open}BSD/OpenSolaris
-#elif defined (Q_OS_UNIX)
-    paths << QLatin1String("/usr/share/pkgconfig"); // Linux and all other unix
-#endif
-}
-
-static int mimeDataBaseVersion()
-{
-    // shared-mime-info installs a "version" file since 0.91
-    const QStringList versionFiles = KGlobal::dirs()->findAllResources("xdgdata-mime", QLatin1String("version"));
-    if (!versionFiles.isEmpty()) {
-        QFile file(versionFiles.first()); // Look at the global file, not at a possibly old local one
-        if (file.open(QIODevice::ReadOnly)) {
-            const QByteArray line = file.readLine().simplified();
-            QRegExp versionRe(QString::fromLatin1("(\\d+)\\.(\\d+)(\\.(\\d+))?"));
-            if (versionRe.indexIn(QString::fromLocal8Bit(line)) > -1) {
-                return KDE_MAKE_VERSION(versionRe.cap(1).toInt(), versionRe.cap(2).toInt(), versionRe.cap(4).toInt());
-            }
-        }
-    }
-
-    // TODO: Remove the #idef'ed code below once the issue is fixed
-    // in QProcess or when we require s-m-i >= 0.91
-#ifdef Q_OS_UNIX
-    // Try to read the version number from the shared-mime-info.pc file
-    QStringList paths;
-    const QByteArray pkgConfigPath = qgetenv("PKG_CONFIG_PATH");
-    if (!pkgConfigPath.isEmpty()) {
-        paths << QFile::decodeName(pkgConfigPath).split(QLatin1Char(':'), QString::SkipEmptyParts);
-    }
-
-    // Add platform specific hard-coded default paths to the list...
-    addPlatformSpecificPkgConfigPath(paths);
-
-    Q_FOREACH(const QString& path, paths) {
-        const QString fileName = path + QLatin1String("/shared-mime-info.pc");
-        if (!QFile::exists(fileName)) {
-            continue;
-        }
-
-        QFile file (fileName);
-        if (!file.open(QIODevice::ReadOnly)) {
-            break;
-        }
-
-        while (!file.atEnd()) {
-            const QByteArray line = file.readLine().simplified();
-            if (!line.startsWith("Version")) { // krazy:exclude=strings
-                continue;
-            }
-            QRegExp versionRe(QString::fromLatin1("Version: (\\d+)\\.(\\d+)(\\.(\\d+))?"));
-            if (versionRe.indexIn(QString::fromLocal8Bit(line)) > -1) {
-                return KDE_MAKE_VERSION(versionRe.cap(1).toInt(), versionRe.cap(2).toInt(), versionRe.cap(4).toInt());
-            }
-        }
-    }
-#endif
-
-    // Execute "update-mime-database -v" to determine version number.
-    // NOTE: On *nix, the code below is known to cause freezes/hangs in apps
-    // that block signals. See https://bugs.kde.org/show_bug.cgi?id=260719.
-    const QString umd = KStandardDirs::findExe(QString::fromLatin1("update-mime-database"));
-    if (umd.isEmpty()) {
-        kWarning(servicesDebugArea()) << "update-mime-database not found!";
-        return -1;
-    }
-
-    QProcess smi;
-    smi.start(umd, QStringList() << QString::fromLatin1("-v"));
-    if (smi.waitForStarted() && smi.waitForFinished()) {
-        const QString out = QString::fromLocal8Bit(smi.readAllStandardError());
-        QRegExp versionRe(QString::fromLatin1("update-mime-database \\(shared-mime-info\\) (\\d+)\\.(\\d+)(\\.(\\d+))?"));
-        if (versionRe.indexIn(out) > -1) {
-            return KDE_MAKE_VERSION(versionRe.cap(1).toInt(), versionRe.cap(2).toInt(), versionRe.cap(4).toInt());
-        }
-        kWarning(servicesDebugArea()) << "Unexpected version scheme from update-mime-database -v: got" << out;
-    } else {
-        kWarning(servicesDebugArea()) << "Error running update-mime-database -v";
-    }
-
-    return -1;
-}
-
 int KMimeTypeRepository::sharedMimeInfoVersion()
 {
-    m_mutex.lockForWrite();
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
     if (m_sharedMimeInfoVersion == 0)
         m_sharedMimeInfoVersion = mimeDataBaseVersion();
-    m_mutex.unlock();
     return m_sharedMimeInfoVersion;
 }
