@@ -29,12 +29,11 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-#include <QtCore/QCharRef>
+#include <QtCore/qstring.h>
 #include <QtCore/QFile>
 #include <QtCore/QDir>
 #include <QtCore/QMap>
 
-#include <kauthorized.h>
 #include <kdebug.h>
 #include <kdesktopfile.h>
 #include <kglobal.h>
@@ -44,9 +43,9 @@
 #include "kservicefactory.h"
 #include "kservicetypefactory.h"
 
+// see kdebug.areas
 int servicesDebugArea() {
-    static int s_area = KDebug::registerArea("kdecore (services)");
-    return s_area;
+    return 183;
 }
 
 QDataStream &operator<<(QDataStream &s, const KService::ServiceTypeAndPreference &st)
@@ -66,7 +65,7 @@ void KServicePrivate::init( const KDesktopFile *config, KService* q )
     bool absPath = !QDir::isRelativePath(entryPath);
 
     // TODO: it makes sense to have a KConstConfigGroup I guess
-    const KConfigGroup desktopGroup = const_cast<KDesktopFile*>(config)->desktopGroup();
+    const KConfigGroup desktopGroup = config->desktopGroup();
     QMap<QString, QString> entryMap = desktopGroup.entryMap();
 
     entryMap.remove(QLatin1String("Encoding")); // reserved as part of Desktop Entry Standard
@@ -98,14 +97,15 @@ void KServicePrivate::init( const KDesktopFile *config, KService* q )
     {
         /*kWarning(servicesDebugArea()) << "The desktop entry file " << entryPath
           << " has no Type=... entry."
-          << " It should be \"Application\" or \"Service\"" << endl;
+          << " It should be \"Application\", \"Service\"" or \"FSDevice\";
           m_bValid = false;
           return;*/
         m_strType = QString::fromLatin1("Application");
-    } else if (m_strType != QLatin1String("Application") && m_strType != QLatin1String("Service")) {
+    } else if (m_strType != QLatin1String("Application") && m_strType != QLatin1String("Service")
+        && m_strType != QLatin1String("FSDevice")) {
         kWarning(servicesDebugArea()) << "The desktop entry file " << entryPath
                        << " has Type=" << m_strType
-                       << " instead of \"Application\" or \"Service\"" << endl;
+                       << " instead of \"Application\", \"Service\" or \"FSDevice\"";
         m_bValid = false;
         return;
     }
@@ -120,7 +120,7 @@ void KServicePrivate::init( const KDesktopFile *config, KService* q )
         if (m_strExec.isEmpty()) {
             kWarning(servicesDebugArea()) << "The desktop entry file " << entryPath
                            << " has Type=" << m_strType
-                           << " but no Exec line" << endl;
+                           << " but no Exec line";
             m_bValid = false;
             return;
         }
@@ -142,7 +142,7 @@ void KServicePrivate::init( const KDesktopFile *config, KService* q )
     {
         kWarning(servicesDebugArea()) << "The desktop entry file " << entryPath
                        << " has Type=" << m_strType << " but is located under \"" << resource
-                       << "\" instead of \"apps\"" << endl;
+                       << "\" instead of \"apps\"";
         m_bValid = false;
         return;
     }
@@ -179,9 +179,6 @@ void KServicePrivate::init( const KDesktopFile *config, KService* q )
     entryMap.remove(QLatin1String("Comment"));
     m_strGenName = config->readGenericName();
     entryMap.remove(QLatin1String("GenericName"));
-    QString _untranslatedGenericName = desktopGroup.readEntryUntranslated( "GenericName" );
-    if (!_untranslatedGenericName.isEmpty())
-        entryMap.insert(QLatin1String("UntranslatedGenericName"), _untranslatedGenericName);
 
     m_lstKeywords = desktopGroup.readXdgListEntry("Keywords", QStringList());
     entryMap.remove(QLatin1String("Keywords"));
@@ -227,44 +224,17 @@ void KServicePrivate::init( const KDesktopFile *config, KService* q )
                            << "has an empty mimetype!";
             continue;
         }
-
-        // The following searches through the list for duplicate, inherited mimetypes
-        // For example, if application/rtf and text/plain are both listed application/rtf is removed
-        // since it is inherited from text/plain
-        // This is a reworked fix for revision 871cccc8a88a600c8f850a020d44bfc5f5858caa
-        bool shouldAdd = true;
-        KMimeType::Ptr mimeType1 = KMimeTypeRepository::self()->findMimeTypeByName(st);
-        if (mimeType1) {
-            foreach(const QString mime2, lstServiceTypes) {
-                // Don't compare the mimetype with itself
-                if (st == mime2) {
-                    continue;
-                }
-
-                // is checks for inheritance and aliases, so this should suffice
-                if (mimeType1->is(mime2)) {
-                    shouldAdd = false;
-                    break;
-                }
+        int initialPreference = m_initialPreference;
+        if ( st_it.hasNext() ) {
+            // TODO better syntax - separate group with mimetype=number entries?
+            bool isNumber;
+            const int val = st_it.peekNext().toInt(&isNumber);
+            if (isNumber) {
+                initialPreference = val;
+                st_it.next();
             }
         }
-
-        // Only add unique mimetypes
-        if (shouldAdd) {
-            int initialPreference = m_initialPreference;
-            if (st_it.hasNext()) {
-                // TODO better syntax - separate group with mimetype=number entries?
-                bool isNumber;
-                const int val = st_it.peekNext().toInt(&isNumber);
-                if (isNumber) {
-                    initialPreference = val;
-                    st_it.next();
-                }
-            }
-            m_serviceTypes.push_back(KService::ServiceTypeAndPreference(initialPreference, st));
-        } else {
-            //kDebug(servicesDebugArea())<<"Not adding"<<st<<"from"<<entryPath;
-        }
+        m_serviceTypes.push_back(KService::ServiceTypeAndPreference(initialPreference, st));
     }
 
     if (entryMap.contains(QLatin1String("Actions"))) {
@@ -349,7 +319,6 @@ void KServicePrivate::load(QDataStream& s)
 {
     qint8 def, term;
     qint8 dst, initpref;
-    QStringList dummyList; // KDE4: you can reuse this for another QStringList. KDE5: remove
 
     // WARNING: THIS NEEDS TO REMAIN COMPATIBLE WITH PREVIOUS KDE 4.x VERSIONS!
     // !! This data structure should remain binary compatible at all times !!
@@ -357,7 +326,7 @@ void KServicePrivate::load(QDataStream& s)
     // number in ksycoca.h
     s >> m_strType >> m_strName >> m_strExec >> m_strIcon
       >> term >> m_strTerminalOptions
-      >> m_strPath >> m_strComment >> dummyList >> def >> m_mapProps
+      >> m_strPath >> m_strComment >> def >> m_mapProps
       >> m_strLibrary
       >> dst
       >> m_strDesktopEntryName
@@ -386,7 +355,7 @@ void KServicePrivate::save(QDataStream& s)
     // number in ksycoca.h
     s << m_strType << m_strName << m_strExec << m_strIcon
       << term << m_strTerminalOptions
-      << m_strPath << m_strComment << QStringList() << def << m_mapProps
+      << m_strPath << m_strComment << def << m_mapProps
       << m_strLibrary
       << dst
       << m_strDesktopEntryName
@@ -469,14 +438,6 @@ bool KService::hasServiceType( const QString& serviceType ) const
     return false;
 }
 
-#ifndef KDE_NO_DEPRECATED
-bool KService::hasMimeType( const KServiceType* ptr ) const
-{
-    if (!ptr) return false;
-
-    return hasMimeType(ptr->name());
-}
-#endif
 
 bool KService::hasMimeType(const QString& mimeType) const
 {
@@ -632,12 +593,6 @@ KService::List KService::allServices()
     return KServiceFactory::self()->allServices();
 }
 
-#ifndef KDE_NO_DEPRECATED
-KService::Ptr KService::serviceByName( const QString& _name )
-{
-    return KServiceFactory::self()->findServiceByName( _name );
-}
-#endif
 
 KService::Ptr KService::serviceByDesktopPath( const QString& _name )
 {
@@ -646,15 +601,8 @@ KService::Ptr KService::serviceByDesktopPath( const QString& _name )
 
 KService::Ptr KService::serviceByDesktopName( const QString& _name )
 {
-    // Prefer kde4-konsole over kde-konsole, if both are available
     QString name = _name.toLower();
-    KService::Ptr s;
-    if (!_name.startsWith(QLatin1String("kde4-")))
-        s = KServiceFactory::self()->findServiceByDesktopName(QString::fromLatin1("kde4-") + name);
-    if (!s)
-        s = KServiceFactory::self()->findServiceByDesktopName( name );
-
-    return s;
+    return KServiceFactory::self()->findServiceByDesktopName( name );
 }
 
 KService::Ptr KService::serviceByMenuId( const QString& _name )
@@ -681,9 +629,6 @@ KService::Ptr KService::serviceByStorageId( const QString& _storageId )
     if (tmp.endsWith(QLatin1String(".desktop")))
         tmp.truncate(tmp.length()-8);
 
-    if (tmp.endsWith(QLatin1String(".kdelnk")))
-        tmp.truncate(tmp.length()-7);
-
     service = KService::serviceByDesktopName(tmp);
 
     return service;
@@ -699,8 +644,6 @@ QString KService::username() const {
     QString user;
     QVariant v = property(QLatin1String("X-KDE-Username"), QVariant::String);
     user = v.isValid() ? v.toString() : QString();
-    if (user.isEmpty())
-        user = QString::fromLocal8Bit(qgetenv("ADMIN_ACCOUNT"));
     if (user.isEmpty())
         user = QString::fromLatin1("root");
     return user;
@@ -735,17 +678,9 @@ bool KService::noDisplay() const {
     if (!showInKDE())
         return true;
 
-    if (!KAuthorized::authorizeControlModule( storageId() ) )
-        return true;
-
     return false;
 }
 
-QString KService::untranslatedGenericName() const {
-    QVariant v = property(QString::fromLatin1("UntranslatedGenericName"), QVariant::String);
-    return v.isValid() ? v.toString() : QString();
-}
-
 QString KService::parentApp() const {
     Q_D(const KService);
     QMap<QString,QVariant>::ConstIterator it = d->m_mapProps.find(QLatin1String("X-KDE-ParentApp"));
@@ -773,10 +708,7 @@ QString KService::docPath() const
     Q_D(const KService);
     QMap<QString,QVariant>::ConstIterator it = d->m_mapProps.find(QLatin1String("X-DocPath"));
     if ((it == d->m_mapProps.end()) || (!it->isValid())) {
-        it = d->m_mapProps.find(QString::fromLatin1("DocPath"));
-        if ((it == d->m_mapProps.end()) || (!it->isValid())) {
-            return QString();
-        }
+        return QString();
     }
 
     return it->toString();
@@ -823,11 +755,9 @@ QString KService::locateLocal() const
     return KStandardDirs::locateLocal("xdgdata-apps", d->menuId);
 }
 
-QString KService::newServicePath(bool showInMenu, const QString &suggestedName,
+QString KService::newServicePath(const QString &suggestedName,
                                  QString *menuId, const QStringList *reservedMenuIds)
 {
-    Q_UNUSED(showInMenu); // TODO KDE5: remove argument
-
     QString base = suggestedName;
     QString result;
     for(int i = 1; true; i++)
@@ -862,13 +792,6 @@ bool KService::isApplication() const
     return d->m_strType == QLatin1String("Application");
 }
 
-#ifndef KDE_NO_DEPRECATED
-QString KService::type() const
-{
-    Q_D(const KService);
-    return d->m_strType;
-}
-#endif
 
 QString KService::exec() const
 {
@@ -876,7 +799,7 @@ QString KService::exec() const
     if (d->m_strType == QLatin1String("Application") && d->m_strExec.isEmpty())
     {
         kWarning(servicesDebugArea()) << "The desktop entry file " << entryPath()
-                       << " has Type=" << d->m_strType << " but has no Exec field." << endl;
+                       << " has Type=" << d->m_strType << " but has no Exec field.";
     }
     return d->m_strExec;
 }
@@ -905,14 +828,6 @@ bool KService::terminal() const
     return d->m_bTerminal;
 }
 
-// KDE5: remove and port code to entryPath?
-#ifndef KDE_NO_DEPRECATED
-QString KService::desktopEntryPath() const
-{
-    return entryPath();
-}
-#endif
-
 QString KService::desktopEntryName() const
 {
     Q_D(const KService);
@@ -952,10 +867,9 @@ QStringList KService::keywords() const
 QStringList KServicePrivate::serviceTypes() const
 {
     QStringList ret;
-    QVector<KService::ServiceTypeAndPreference>::const_iterator it = m_serviceTypes.begin();
-    for ( ; it < m_serviceTypes.end(); ++it ) {
-        Q_ASSERT(!(*it).serviceType.isEmpty());
-        ret.append((*it).serviceType);
+    foreach(const KService::ServiceTypeAndPreference it, m_serviceTypes) {
+        Q_ASSERT(!it.serviceType.isEmpty());
+        ret.append(it.serviceType);
     }
     return ret;
 }
@@ -970,9 +884,8 @@ QStringList KService::mimeTypes() const
 {
     Q_D(const KService);
     QStringList ret;
-    QVector<KService::ServiceTypeAndPreference>::const_iterator it = d->m_serviceTypes.begin();
-    for ( ; it < d->m_serviceTypes.end(); ++it ) {
-        const QString sv = (*it).serviceType;
+    foreach(const KService::ServiceTypeAndPreference it, d->m_serviceTypes) {
+        const QString sv = it.serviceType;
         if (KMimeType::mimeType(sv)) // keep only mimetypes, filter out servicetypes
             ret.append(sv);
     }
