@@ -22,20 +22,16 @@
 #define KSERVICE_H
 
 #include "kserviceaction.h"
-#include <QtCore/QStringList>
-#include <QtCore/QVariant>
-#ifndef KDE_NO_DEPRECATED
-#include <klibloader.h>
-#endif
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
 #include <ksycocaentry.h>
 #include <klocale.h>
 
+#include <QDataStream>
+#include <QWidget>
+
 class KServiceType;
-class QDataStream;
 class KDesktopFile;
-class QWidget;
 
 class KServicePrivate;
 
@@ -98,15 +94,6 @@ public:
      */
     bool isApplication() const;
 
-    /**
-     * Returns the type of the service.
-     * @return the type of the service ("Application" or "Service")
-     * @deprecated use isApplication()
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED QString type() const;
-#endif
-
     /**
      * Returns the executable.
      * @return the command that the service executes,
@@ -156,24 +143,6 @@ public:
      */
     QString username() const;
 
-    /**
-     * Returns the path to the location where the service desktop entry
-     * is stored.
-     *
-     * This is a relative path if the desktop entry was found in any
-     * of the locations pointed to by $KDEDIRS (e.g. "Internet/kppp.desktop")
-     * It is a full path if the desktop entry originates from another
-     * location.
-     *
-     * @deprecated use entryPath() instead
-     *
-     * @return the path of the service's desktop file,
-     *         or QString() if not set
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED QString desktopEntryPath() const;
-#endif
-
     /**
      * Returns the filename of the service desktop entry without any
      * extension. E.g. "kppp"
@@ -239,15 +208,6 @@ public:
      */
     QString genericName() const;
 
-    /**
-     * Returns the untranslated (US English) generic name
-     * for the service, if there is one
-     * (e.g. "Mail Client").
-     * @return the generic name,
-     *         or QString() if not set
-     */
-    QString untranslatedGenericName() const;
-
     /**
      * Returns a list of descriptive keywords the service, if there are any.
      * @return the list of keywords
@@ -287,29 +247,7 @@ public:
 
     /**
      * Checks whether the service supports this mime type
-     * @param mimeTypePtr The name of the mime type you are
-     *        interested in determining whether this service supports.
-     *
-     * Note that if you only have the name of the mime type, you have to look it up
-     * with KMimeType::mimeType( mimetype ) and use .data() on the result (this is
-     * because KService doesn't know KMimeType for dependency reasons)
-     *
-     * Warning this method will fail to return true if this KService isn't from ksycoca
-     * (i.e. it was created with a full path or a KDesktopFile) *and* the mimetype
-     * isn't explicited listed in the .desktop file but a parent mimetype is.
-     * For this reason you should generally get KServices with KMimeTypeTrader
-     * or one of the KService::serviceBy methods.
-     *
-     * @return true if the mime type you specified is supported, otherwise false.
-     * @deprecated, use hasMimeType(QString)
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED bool hasMimeType( const KServiceType* mimeTypePtr ) const;
-#endif
-
-    /**
-     * Checks whether the service supports this mime type
-     * @param mimeTypePtr The name of the mime type you are
+     * @param mimeType The name of the mime type you are
      *        interested in determining whether this service supports.
      * @since 4.6
      */
@@ -439,20 +377,6 @@ public:
      */
     void setExec(const QString& exec);
 
-    /**
-     * Find a service by name, i.e. the translated Name field. Don't use this.
-     * Use serviceByDesktopPath or serviceByStorageId instead.
-     *
-     * @param _name the name to search
-     * @return a pointer to the requested service or 0 if the service is
-     *         unknown.
-     * @em Very @em important: Don't store the result in a KService* !
-     * @deprecated there is never a good reason to use this method.
-     */
-#ifndef KDE_NO_DEPRECATED
-    static Ptr serviceByName( const QString& _name ); // KDE5: remove
-#endif
-
     /**
      * Find a service based on its path as returned by entryPath().
      * It's usually better to use serviceByStorageId() instead.
@@ -515,9 +439,6 @@ public:
     /**
      * Returns a path that can be used to create a new KService based
      * on @p suggestedName.
-     * @param showInMenu true, if the service should be shown in the KDE menu
-     *        false, if the service should be hidden from the menu
-     *        This argument isn't used anymore, use NoDisplay=true to hide the service.
      * @param suggestedName name to base the file on, if a service with such
      *        name already exists, a prefix will be added to make it unique.
      * @param menuId If provided, menuId will be set to the menu id to use for
@@ -527,7 +448,7 @@ public:
      *        of the reservedMenuIds
      * @return The path to use for the new KService.
      */
-    static QString newServicePath(bool showInMenu, const QString &suggestedName,
+    static QString newServicePath(const QString &suggestedName,
                                   QString *menuId = 0,
                                   const QStringList *reservedMenuIds = 0);
 
@@ -583,100 +504,6 @@ public:
         return 0;
     }
 
-    /**
-     * @deprecated Use the non-static service->createInstance<T>(parent, args, &error)
-     */
-#ifndef KDE_NO_DEPRECATED
-    template <class T>
-    static KDE_DEPRECATED T *createInstance(const KService::Ptr &service, QObject *parent = 0,
-            const QVariantList &args = QVariantList(), QString *error = 0)
-    {
-        return service->createInstance<T>(parent, args, error);
-    }
-#endif
-
-    /**
-     * @deprecated Use the non-static service->createInstance<T>(parent, args, &error)
-     * where args is a QVariantList rather than a QStringList
-     */
-#ifndef KDE_NO_DEPRECATED
-    template <class T>
-    static KDE_DEPRECATED T *createInstance( const KService::Ptr &service,
-                              QObject *parent,
-                              const QStringList &args,
-                              int *error = 0 )
-    {
-        const QString library = service->library();
-        if ( library.isEmpty() ) {
-            if ( error )
-                *error = KLibLoader::ErrServiceProvidesNoLibrary;
-            return 0;
-        }
-
-        return KLibLoader::createInstance<T>( library, parent, args, error );
-    }
-#endif
-
-    /**
-     * This template allows to create a component from a list of services,
-     * usually coming from a trader query. You probably want to use KServiceTypeTrader instead.
-     *
-     * @deprecated Use KServiceTypeTrader::createInstanceFromQuery instead
-     *
-     * @param begin The start iterator to the service describing the library to open
-     * @param end The end iterator to the service describing the library to open
-     * @param parent The parent object (see QObject constructor)
-     * @param args A list of string arguments, passed to the factory and possibly
-     *             to the component (see KLibFactory)
-     * @param error see KLibLoader
-     * @return A pointer to the newly created object or a null pointer if the
-     *         factory was unable to create an object of the given type.
-     */
-#ifndef KDE_NO_DEPRECATED
-    template <class T, class ServiceIterator>
-    static KDE_DEPRECATED T *createInstance(ServiceIterator begin, ServiceIterator end, QObject *parent = 0,
-            const QVariantList &args = QVariantList(), QString *error = 0)
-    {
-        for (; begin != end; ++begin) {
-            KService::Ptr service = *begin;
-            if (error) {
-                error->clear();
-            }
-
-            T *component = createInstance<T>(service, parent, args, error);
-            if (component) {
-                return component;
-            }
-        }
-        if (error) {
-            *error = KLibLoader::errorString(KLibLoader::ErrNoServiceFound);
-        }
-        return 0;
-    }
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-    template <class T, class ServiceIterator>
-    static KDE_DEPRECATED T *createInstance( ServiceIterator begin, ServiceIterator end,
-                              QObject *parent,
-                              const QStringList &args,
-                              int *error = 0 )
-    {
-        for (; begin != end; ++begin ) {
-            KService::Ptr service = *begin;
-            if ( error )
-                *error = 0;
-
-            T *component = createInstance<T>( service, parent, args, error );
-            if ( component )
-                return component;
-        }
-        if ( error )
-            *error = KLibLoader::ErrNoServiceFound;
-        return 0;
-    }
-#endif
-
 protected:
     friend class KMimeAssociations;
     friend class KBuildServiceFactory;
