@@ -19,8 +19,6 @@
 #ifndef KSERVICEGROUP_H
 #define KSERVICEGROUP_H
 
-#include <kdecore_export.h>
-#include <ksycocaentry.h>
 #include <kservice.h>
 
 class KBuildServiceGroupFactory;
@@ -211,7 +209,7 @@ public:
       SortByGenericName = 0x8 /*< sort by GenericName+Name instead of Name+GenericName */
     };
     Q_DECLARE_FLAGS(EntriesOptions, EntriesOption)
- 
+
     /**
      * subgroups for this service group
      */
@@ -240,17 +238,6 @@ public:
    */
   QString directoryEntryPath() const;
 
-  /**
-   * Returns the group for the given baseGroupName.
-   * Can return 0L if the directory (or the .directory file) was deleted.
-   * @return the base group with the given name, or 0 if not available.
-   *
-   * This mechanism was fragile and isn't used in kde4 anymore.
-   * @deprecated Use a servicetype and a proper trader query instead, for a better
-   * way of finding related services.
-   */
-  static KDE_DEPRECATED Ptr baseGroup( const QString &baseGroupName );
-
   /**
    * Returns the root service group.
    * @return the root service group
