@@ -23,8 +23,6 @@
 
 #include <ksycocaentry.h>
 
-#include <QtCore/QString>
-#include <QtCore/QStringList>
 #include <QtCore/QMap>
 #include <QtCore/QVariant>
 
@@ -72,9 +70,6 @@ public:
      * For instance inode/directory.desktop, or kpart.desktop
      * @return the path of the desktop file
      */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED QString desktopEntryPath() const;
-#endif
 
     /**
      * Checks whether this service type inherits another one.
@@ -183,7 +178,9 @@ private:
     Q_DECLARE_PRIVATE(KServiceType)
 };
 
+//QT_BEGIN_NAMESPACE
 //QDataStream& operator>>( QDataStream& _str, KServiceType& s );
 //QDataStream& operator<<( QDataStream& _str, KServiceType& s );
+//QT_END_NAMESPACE
 
 #endif
