@@ -19,18 +19,17 @@
 #include "kservicetypefactory.h"
 #include "ksycoca.h"
 #include "ksycocatype.h"
-#include "ksycocadict.h"
-#include "kservicetypeprofile.h"
+#include "ksycocadict_p.h"
 
 #include <kdebug.h>
 #include <assert.h>
 
-K_GLOBAL_STATIC(KSycocaFactorySingleton<KServiceTypeFactory>, kServiceTypeFactoryInstance)
+thread_local KServiceTypeFactory* kServiceTypeFactoryInstance = 0;
 
 KServiceTypeFactory::KServiceTypeFactory()
     : KSycocaFactory( KST_KServiceTypeFactory )
 {
-    kServiceTypeFactoryInstance->instanceCreated(this);
+    kServiceTypeFactoryInstance = this;
     if (!KSycoca::self()->isBuilding()) {
         QDataStream* str = stream();
         Q_ASSERT(str);
@@ -55,14 +54,16 @@ KServiceTypeFactory::KServiceTypeFactory()
 
 KServiceTypeFactory::~KServiceTypeFactory()
 {
-    KServiceTypeProfile::clearCache();
-    if (kServiceTypeFactoryInstance.exists())
-        kServiceTypeFactoryInstance->instanceDestroyed(this);
+    if (kServiceTypeFactoryInstance) {
+        kServiceTypeFactoryInstance = 0;
+    }
 }
 
 KServiceTypeFactory * KServiceTypeFactory::self()
 {
-    return kServiceTypeFactoryInstance->self();
+    if (!kServiceTypeFactoryInstance)
+        kServiceTypeFactoryInstance = new KServiceTypeFactory();
+    return kServiceTypeFactoryInstance;
 }
 
 KServiceType::Ptr KServiceTypeFactory::findServiceTypeByName(const QString &_name)
@@ -121,17 +122,15 @@ KServiceType * KServiceTypeFactory::createEntry(int offset) const
         newEntry = new KServiceType(*str, offset);
         break;
      default:
-        kError(7011) << QString("KServiceTypeFactory: unexpected object entry in KSycoca database (type = %1)").arg((int)type) << endl;
+         kError(7011) << "KServiceTypeFactory: unexpected object entry in KSycoca database (type=" << int(type) << ")";
         break;
    }
    if (newEntry && !newEntry->isValid())
    {
-      kError(7011) << "KServiceTypeFactory: corrupt object in KSycoca database!\n" << endl;
+      kError(7011) << "KServiceTypeFactory: corrupt object in KSycoca database!";
       delete newEntry;
       newEntry = 0;
    }
    return newEntry;
 }
 
-void KServiceTypeFactory::virtual_hook( int id, void* data )
-{ KSycocaFactory::virtual_hook( id, data ); }
