@@ -30,10 +30,11 @@
 #include <klocale.h>
 
 #include <QtCore/QMap>
-#include <QtCore/QMutableStringListIterator>
+#include <QtCore/qstringlist.h>
 
 namespace Sonnet
 {
+
 class Settings::Private
 {
 public:
@@ -51,11 +52,11 @@ public:
     int disablePercentage;
     int disableWordCount;
 
-    QMap<QString, bool> ignore;
+    QStringList ignore;
 };
 
 Settings::Settings(Loader *loader)
-	:d(new Private)
+    : d(new Private())
 {
     d->loader = loader;
 
@@ -162,23 +163,19 @@ void Settings::setCurrentIgnoreList(const QStringList &ignores)
 
 void Settings::setQuietIgnoreList(const QStringList &ignores)
 {
-    d->ignore = QMap<QString, bool>();//clear out
-    for (QStringList::const_iterator itr = ignores.begin();
-         itr != ignores.end(); ++itr) {
-        d->ignore.insert(*itr, true);
-    }
+    d->ignore = ignores;
 }
 
 QStringList Settings::currentIgnoreList() const
 {
-    return d->ignore.keys();
+    return d->ignore;
 }
 
 void Settings::addWordToIgnore(const QString &word)
 {
     if (!d->ignore.contains(word)) {
         d->modified = true;
-        d->ignore.insert( word, true );
+        d->ignore.append( word );
     }
 }
 
@@ -190,7 +187,7 @@ bool Settings::ignore( const QString& word )
 void Settings::readIgnoreList(KConfig *config)
 {
     const KConfigGroup conf(config, "Spelling");
-    const QString ignoreEntry = QString( "ignore_%1" ).arg(d->defaultLanguage);
+    const QString ignoreEntry = QString::fromLatin1( "ignore_%1" ).arg(d->defaultLanguage);
     const QStringList ignores = conf.readEntry(ignoreEntry, QStringList());
     setQuietIgnoreList(ignores);
 }
@@ -214,12 +211,11 @@ void Settings::save(KConfig *config)
     conf.writeEntry("skipRunTogether", d->skipRunTogether);
     conf.writeEntry("backgroundCheckerEnabled", d->backgroundCheckerEnabled);
     conf.writeEntry("checkerEnabledByDefault", d->checkerEnabledByDefault);
-    QString defaultLanguage = QString( "ignore_%1" ).arg(d->defaultLanguage);
+    QString defaultLanguage = QString::fromLatin1( "ignore_%1" ).arg(d->defaultLanguage);
     if(conf.hasKey(defaultLanguage) && d->ignore.isEmpty())
       conf.deleteEntry(defaultLanguage);
     else if(!d->ignore.isEmpty())
-      conf.writeEntry(QString( "ignore_%1" ).arg(d->defaultLanguage),
-                    d->ignore.keys() );
+        conf.writeEntry(defaultLanguage, d->ignore);
 
     conf.sync();
 }
