@@ -22,7 +22,8 @@
 
 #include "loader_p.h"
 #include "settings_p.h"
-#include "spellerplugin_p.h"
+#include "enchantclient_p.h"
+#include "enchantdict_p.h"
 
 #include <kconfig.h>
 #include <kglobal.h>
@@ -68,7 +69,7 @@ public:
         dict = Loader::openLoader()->createSpeller(language);
     }
 
-    SpellerPlugin *dict;
+    QSpellEnchantDict *dict;
     Settings      *settings;
 
     QString        language;
@@ -116,7 +117,7 @@ bool Speller::isMisspelled(const QString &word) const
 {
     if (!d->isValid())
         return false;
-    return d->dict->isMisspelled(word);
+    return !d->dict->isCorrect(word);
 }
 
 QStringList Speller::suggest(const QString &word) const
@@ -211,25 +212,21 @@ void Speller::setDefaultLanguage(const QString &lang)
     d->settings->setDefaultLanguage(lang);
 }
 
-
 QString Speller::defaultLanguage() const
 {
     return d->settings->defaultLanguage();
 }
 
-
 void Speller::setDefaultClient(const QString &client)
 {
     d->settings->setDefaultClient(client);
 }
 
-
 QString Speller::defaultClient() const
 {
     return d->settings->defaultClient();
 }
 
-
 void Speller::setAttribute(Attribute attr, bool b)
 {
     switch (attr) {
@@ -248,10 +245,8 @@ bool Speller::testAttribute(Attribute attr) const
     switch (attr) {
     case CheckUppercase:
         return d->settings->checkUppercase();
-        break;
     case SkipRunTogether:
         return d->settings->skipRunTogether();
-        break;
     }
     return false;
 }
@@ -270,20 +265,19 @@ void Speller::setLanguage(const QString &lang)
 QMap<QString, QString> Sonnet::Speller::availableDictionaries() const
 {
     Loader *l = Loader::openLoader();
-    const QStringList lst = l->languages();
     QMap<QString, QString> langs;
 
-    foreach(QString tag, lst) { // krazy:exclude=foreach (no const& because tag is modified below)
+    foreach (QString tag, l->languages()) { // no const& because tag is modified below
         tag = tag.mid(0, tag.indexOf(QLatin1Char('-')));
         int underscorePos = tag.indexOf(QLatin1Char('_'));
         QString cIsoName, lIsoName;
-	if (underscorePos != -1 && underscorePos <= 3) {
+        if (underscorePos != -1 && underscorePos <= 3) {
             cIsoName = tag.mid(underscorePos + 1, 2);
             lIsoName = tag.left(underscorePos);
-	}  else {
+        }  else {
             lIsoName = tag;
         }
-        QLocale loc(tag);
+        //QLocale loc(tag);
         QString description;
 
         if (!cIsoName.isEmpty())
