@@ -165,8 +165,8 @@ void SonnetCoreTest::testCore2()
     kDebug()<<"Elapsed time is "<<mtime.elapsed();
 
     kDebug()<<"Detecting language ...";
-    QString sentence = QString::fromLatin1("Die K Desktop Environment (KDE; auf Deutsch K-Arbeitsumgebung; frher: Kool Desktop Environment) ist eine frei verfgbare Arbeitsumgebung, das heit eine grafische Benutzeroberflche mit vielen Zusatzprogrammen fr den tglichen Gebrauch.");
+    QString sentence = QString::fromUtf8("Möchten Sie wirklich alle Werkzeugleisten dieser Anwendung auf ihre Voreinstellungen zurücksetzen? Die Änderung wird sofort wirksam.");
     kDebug()<<"\tlang is "<<Sonnet::detectLanguage(sentence);
 }
 
-#include "test_core.moc"
+#include "moc_test_core.cpp"
