@@ -18,8 +18,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
-#include "filter_p.h"
+
 #include "test_filter.h"
+#include "filter_p.h"
 
 #include <qtest_kde.h>
 #include <kdebug.h>
@@ -157,4 +158,4 @@ void SonnetFilterTest::testIndic()
     QCOMPARE( hitNumber, hits.count() );
 }
 
-#include "test_filter.moc"
+#include "moc_test_filter.cpp"
