@@ -24,11 +24,9 @@
 #include "ksycocafactory.h"
 #include "ktoolinvocation.h"
 #include "kglobal.h"
-#include "kmemfile.h"
 #include "kde_file.h"
 #include "kconfiggroup.h"
 #include "ksharedconfig.h"
-
 #include "kdebug.h"
 #include "kstandarddirs.h"
 
@@ -38,6 +36,7 @@
 #include <QtCore/QBuffer>
 #include <QProcess>
 #include <QtDBus/QtDBus>
+#include <QtCore/qthread.h>
 
 #include <config.h>
 
@@ -46,10 +45,6 @@
 
 #include "ksycocadevices_p.h"
 
-// TODO: remove mmap() from kdewin32 and use QFile::mmap() when needed
-#ifdef Q_WS_WIN
-#undef HAVE_MMAP
-#endif
 /**
  * Sycoca file version number.
  * If the existing file is outdated, it will not get read
@@ -62,14 +57,6 @@
  */
 #define KSYCOCA_FILENAME "ksycoca4"
 
-#if HAVE_MADVISE
-#include <sys/mman.h> // This #include was checked when looking for posix_madvise
-#endif
-
-#ifndef MAP_FAILED
-#define MAP_FAILED ((void *) -1)
-#endif
-
 static bool s_autoRebuild = true;
 
 // The following limitations are in place:
@@ -89,64 +76,20 @@ KSycocaPrivate::KSycocaPrivate()
       timeStamp( 0 ),
       m_databasePath(),
       updateSig( 0 ),
-      sycoca_size(0),
-      sycoca_mmap(0),
-      m_mmapFile(0),
       m_device(0)
 {
-#ifdef Q_OS_WIN
-    /*
-      on windows we use KMemFile (QSharedMemory) to avoid problems
-      with mmap (can't delete a mmap'd file)
-    */
-    m_sycocaStrategy = StrategyMemFile;
-#else
-    m_sycocaStrategy = StrategyMmap;
-#endif
+    m_sycocaStrategy = StrategyFile;
     KConfigGroup config(KGlobal::config(), "KSycoca");
     setStrategyFromString(config.readEntry("strategy"));
 }
 
 void KSycocaPrivate::setStrategyFromString(const QString& strategy) {
-    if (strategy == QLatin1String("mmap"))
-        m_sycocaStrategy = StrategyMmap;
-    else if (strategy == QLatin1String("file"))
+    if (strategy == QLatin1String("file"))
         m_sycocaStrategy = StrategyFile;
-    else if (strategy == QLatin1String("sharedmem"))
-        m_sycocaStrategy = StrategyMemFile;
     else if (!strategy.isEmpty())
         kWarning(7011) << "Unknown sycoca strategy:" << strategy;
 }
 
-bool KSycocaPrivate::tryMmap()
-{
-#ifdef HAVE_MMAP
-    Q_ASSERT(!m_databasePath.isEmpty());
-    m_mmapFile = new QFile(m_databasePath);
-    const bool canRead = m_mmapFile->open(QIODevice::ReadOnly);
-    Q_ASSERT(canRead);
-    Q_UNUSED(canRead); // no compiler warning in release builds.
-    fcntl(m_mmapFile->handle(), F_SETFD, FD_CLOEXEC);
-    sycoca_size = m_mmapFile->size();
-    sycoca_mmap = (const char *) mmap(0, sycoca_size,
-                                      PROT_READ, MAP_SHARED,
-                                      m_mmapFile->handle(), 0);
-    /* POSIX mandates only MAP_FAILED, but we are paranoid so check for
-       null pointer too.  */
-    if (sycoca_mmap == (const char*) MAP_FAILED || sycoca_mmap == 0) {
-        kDebug(7011) << "mmap failed. (length = " << sycoca_size << ")";
-        sycoca_mmap = 0;
-        return false;
-    } else {
-#ifdef HAVE_MADVISE
-        (void) posix_madvise((void*)sycoca_mmap, sycoca_size, POSIX_MADV_WILLNEED);
-#endif // HAVE_MADVISE
-        return true;
-    }
-#endif // HAVE_MMAP
-    return false;
-}
-
 int KSycoca::version()
 {
    return KSYCOCA_VERSION;
@@ -156,23 +99,30 @@ class KSycocaSingleton
 {
 public:
     KSycocaSingleton() { }
-    ~KSycocaSingleton() { }
+    ~KSycocaSingleton()
+    {
+        if (m_threadSycocas) {
+            delete m_threadSycocas;
+            m_threadSycocas = 0;
+        }
+    }
 
     bool hasSycoca() const {
-        return m_threadSycocas.hasLocalData();
+        return (m_threadSycocas != 0);
     }
     KSycoca* sycoca() {
-        if (!m_threadSycocas.hasLocalData())
-            m_threadSycocas.setLocalData(new KSycoca);
-        return m_threadSycocas.localData();
+        if (!m_threadSycocas)
+            m_threadSycocas = new KSycoca();
+        return m_threadSycocas;
     }
     void setSycoca(KSycoca* s) {
-        m_threadSycocas.setLocalData(s);
+        m_threadSycocas = s;
     }
 
 private:
-    QThreadStorage<KSycoca*> m_threadSycocas;
+    static thread_local KSycoca* m_threadSycocas;
 };
+thread_local KSycoca* KSycocaSingleton::m_threadSycocas = 0;
 
 K_GLOBAL_STATIC(KSycocaSingleton, ksycocaInstance)
 
@@ -238,23 +188,6 @@ KSycocaAbstractDevice* KSycocaPrivate::device()
         device = new KSycocaBufferDevice;
         device->device()->open(QIODevice::ReadOnly); // can't fail
     } else {
-#ifdef HAVE_MMAP
-        if (m_sycocaStrategy == StrategyMmap && tryMmap()) {
-            device = new KSycocaMmapDevice(sycoca_mmap,
-                                           sycoca_size);
-            if (!device->device()->open(QIODevice::ReadOnly)) {
-                delete device; device = 0;
-            }
-        }
-#endif
-#ifndef QT_NO_SHAREDMEMORY
-        if (!device && m_sycocaStrategy == StrategyMemFile) {
-            device = new KSycocaMemFileDevice(m_databasePath);
-            if (!device->device()->open(QIODevice::ReadOnly)) {
-                delete device; device = 0;
-            }
-        }
-#endif
         if (!device) {
             device = new KSycocaFileDevice(m_databasePath);
             if (!device->device()->open(QIODevice::ReadOnly)) {
@@ -322,17 +255,6 @@ void KSycocaPrivate::closeDatabase()
     // refcounted, and deleted when the last thread is done with them
     qDeleteAll(m_factories);
     m_factories.clear();
-#ifdef HAVE_MMAP
-    if (sycoca_mmap) {
-        //QBuffer *buf = static_cast<QBuffer*>(device);
-        //buf->buffer().clear();
-        // Solaris has munmap(char*, size_t) and everything else should
-        // be happy with a char* for munmap(void*, size_t)
-        munmap(const_cast<char*>(sycoca_mmap), sycoca_size);
-        sycoca_mmap = 0;
-    }
-    delete m_mmapFile; m_mmapFile = 0;
-#endif
 
     databaseStatus = DatabaseNotOpen;
     timeStamp = 0;
@@ -343,12 +265,6 @@ void KSycoca::addFactory( KSycocaFactory *factory )
     d->addFactory(factory);
 }
 
-#ifndef KDE_NO_DEPRECATED
-bool KSycoca::isChanged(const char *type)
-{
-    return self()->d->changeList.contains(QString::fromLatin1(type));
-}
-#endif
 
 void KSycoca::notifyDatabaseChanged(const QStringList &changeList)
 {
@@ -361,9 +277,6 @@ void KSycoca::notifyDatabaseChanged(const QStringList &changeList)
     d->closeDatabase();
 
     // Now notify applications
-#ifndef KDE_NO_DEPRECATED
-    emit databaseChanged();
-#endif
     emit databaseChanged(changeList);
 }
 
@@ -414,12 +327,8 @@ bool KSycocaPrivate::checkDatabase(BehaviorsIfNotFound ifNotFound)
 
     closeDatabase(); // close the dummy one
 
-    // We can only use the installed ksycoca file if kdeinit+klauncher+kded are running,
-    // since kded is what keeps the file uptodate.
-    const bool kdeinitRunning = QDBusConnection::sessionBus().interface()->isServiceRegistered(QString::fromLatin1("org.kde.klauncher"));
-
     // Check if new database already available
-    if (kdeinitRunning && openDatabase(ifNotFound & IfNotFoundOpenDummy)) {
+    if (openDatabase(ifNotFound & IfNotFoundOpenDummy)) {
         if (checkVersion()) {
             // Database exists, and version is ok.
             return true;
@@ -427,16 +336,10 @@ bool KSycocaPrivate::checkDatabase(BehaviorsIfNotFound ifNotFound)
     }
 
     if (ifNotFound & IfNotFoundRecreate) {
-        // Well, if kdeinit is not running we need to launch it,
-        // but otherwise we simply need to run kbuildsycoca to recreate the sycoca file.
-        if (!kdeinitRunning) {
-            kDebug(7011) << "We have no database.... launching kdeinit";
-            KToolInvocation::klauncher(); // this calls startKdeinit, and blocks until it returns
-            // and since kdeinit4 only returns after kbuildsycoca4 is done, we can proceed.
-        } else {
-            kDebug(7011) << QThread::currentThread() << "We have no database.... launching" << KBUILDSYCOCA_EXENAME;
-            if (QProcess::execute(KStandardDirs::findExe(QString::fromLatin1(KBUILDSYCOCA_EXENAME))) != 0)
-                qWarning("ERROR: Running KSycoca failed.");
+        // We simply need to run kbuildsycoca to recreate the sycoca file.
+        kDebug(7011) << QThread::currentThread() << "We have no database.... launching" << KBUILDSYCOCA_EXENAME;
+        if (QProcess::execute(KStandardDirs::findExe(QString::fromLatin1(KBUILDSYCOCA_EXENAME))) != 0) {
+            kWarning(7011) << "Running KSycoca failed.";
         }
 
         closeDatabase(); // close the dummy one
@@ -450,6 +353,16 @@ bool KSycocaPrivate::checkDatabase(BehaviorsIfNotFound ifNotFound)
             kDebug(7011) << "Still outdated...";
             return false; // Still outdated - uh oh
         }
+
+        // If kded is not running we need to launch it as it monitors for changes
+        static const QString kdedInterface = QString::fromLatin1("org.kde.kded");
+        QDBusConnectionInterface* sessionInterface = QDBusConnection::sessionBus().interface();
+        const bool kdedRunning = sessionInterface->isServiceRegistered(kdedInterface);
+        if (!kdedRunning) {
+            kDebug(7011) << "Launching kded";
+            sessionInterface->startService(kdedInterface);
+        }
+
         return true;
     }
 
@@ -535,11 +448,7 @@ QString KSycoca::absoluteFilePath(DatabaseType type)
         return path;
     }
 
-    const QByteArray ksycoca_env = qgetenv("KDESYCOCA");
-    if (ksycoca_env.isEmpty())
-        return KGlobal::dirs()->saveLocation("cache") + QString::fromLatin1(KSYCOCA_FILENAME);
-    else
-        return QFile::decodeName(ksycoca_env);
+    return KGlobal::dirs()->saveLocation("cache") + QString::fromLatin1(KSYCOCA_FILENAME);
 }
 
 QString KSycoca::language()
@@ -558,27 +467,22 @@ QStringList KSycoca::allResourceDirs()
 
 void KSycoca::flagError()
 {
-    kWarning(7011) << "ERROR: KSycoca database corruption!";
+    kWarning(7011) << "KSycoca database corruption!";
     KSycocaPrivate* d = ksycocaInstance->sycoca()->d;
     if (d->readError)
         return;
     d->readError = true;
     if (s_autoRebuild) {
         // Rebuild the damned thing.
-        if (QProcess::execute(KStandardDirs::findExe(QString::fromLatin1(KBUILDSYCOCA_EXENAME))) != 0)
-            qWarning("ERROR: Running %s failed", KBUILDSYCOCA_EXENAME);
+        if (QProcess::execute(KStandardDirs::findExe(QString::fromLatin1(KBUILDSYCOCA_EXENAME))) != 0) {
+            kWarning(7011) << "Running KSycoca failed.";
+        }
         // Old comment, maybe not true anymore:
         // Do not wait until the DBUS signal from kbuildsycoca here.
         // It deletes m_str which is a problem when flagError is called during the KSycocaFactory ctor...
     }
 }
 
-#ifndef KDE_NO_DEPRECATED
-bool KSycoca::readError() // KDE5: remove
-{
-    return false;
-}
-#endif
 
 bool KSycoca::isBuilding()
 {
@@ -601,4 +505,4 @@ void KSycoca::clearCaches()
         ksycocaInstance->sycoca()->d->closeDatabase();
 }
 
-#include "ksycoca.moc"
+#include "moc_ksycoca.cpp"
