@@ -14,6 +14,7 @@ main(int argc, char *argv[])
    KCmdLineOptions options;
    options.add("test", ki18n("do a short test only, note that\n"
                              "this is rather long comment"));
+   options.add("b");
    options.add("baud <baudrate>", ki18n("set baudrate"), "9600");
    options.add("+file(s)", ki18n("Files to load"));
 
@@ -44,6 +45,8 @@ main(int argc, char *argv[])
       printf("Option 'baud' is set.\n");
    }
 
+   kDebug() << "allArguments:" << KCmdLineArgs::allArguments();
+
    // Read the value of an option.
    QString baudrate = args->getOption("baud"); // 9600 is the default value.
 
@@ -74,18 +77,16 @@ main(int argc, char *argv[])
    assert(u.url() == "http://www.kde.org");
 
    QFile file("a:b");
-#ifndef Q_WS_WIN
    bool ok = file.open(QIODevice::WriteOnly);
    assert(ok);
-#endif
    u = KCmdLineArgs::makeURL("a:b");
    qDebug() << u.toLocalFile();
    assert(u.isLocalFile());
-   assert(u.toLocalFile().endsWith("a:b"));
+   assert(u.toLocalFile().endsWith(QLatin1String("a:b")));
 
    args->clear(); // Free up memory.
 
-
+   Q_UNUSED(ok);
 //   return app.exec();
    return 0;
 }
