@@ -23,13 +23,11 @@
 #include <ktempdir.h>
 #include <kdesktopfile.h>
 #include <kstandarddirs.h>
-#include "kconfigtest.moc"
-
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kconfiggroup.h>
 
-#include <QtNetwork/QHostInfo>
+#include <future>
 
 #ifdef Q_OS_UNIX
 #include <utime.h>
@@ -71,7 +69,8 @@ QTEST_KDEMAIN_CORE( KConfigTest )
 #define VARIANTLISTENTRY (QVariantList() << true << false << QString("joe") << 10023)
 #define VARIANTLISTENTRY2 (QVariantList() << POINTENTRY << SIZEENTRY)
 #define HOMEPATH QString(QDir::homePath()+"/foo")
-#define HOMEPATHESCAPE QString(QDir::homePath()+"/foo/$HOME")
+#define HOMEPATHENV QString(QDir::homePath()+"/foo/$HOME")
+#define HOMEPATHENVEXPANDED QString(QDir::homePath()+"/foo/"+QDir::homePath())
 #define DOLLARGROUP "$i"
 
 void KConfigTest::initTestCase()
@@ -151,7 +150,7 @@ void KConfigTest::initTestCase()
 
   cg = KConfigGroup(&sc, "Path Type" );
   cg.writePathEntry( "homepath", HOMEPATH );
-  cg.writePathEntry( "homepathescape", HOMEPATHESCAPE );
+  cg.writePathEntry( "homepathenv", HOMEPATHENV );
 
   cg = KConfigGroup(&sc, "Enum Types" );
   writeEntry( cg, "enum-10", Tens );
@@ -168,7 +167,9 @@ void KConfigTest::initTestCase()
   KConfigGroup cg3(&cg, "SubGroup/3");
   cg3.writeEntry( "sub3string", "somevalue" );
 
+  QVERIFY(sc.isDirty());
   sc.sync();
+  QVERIFY(!sc.isDirty());
 
   KConfig sc1("kdebugrc", KConfig::SimpleConfig);
   KConfigGroup sg0(&sc1, "0");
@@ -230,24 +231,26 @@ static QList<QByteArray> readLines(const char* fileName = "kconfigtest")
     return readLinesFrom(path);
 }
 
-// ### TODO: call this, and test the state of things afterwards
-void KConfigTest::revertEntries()
+// see also testDefaults, which tests reverting with a defaults (global) file available
+void KConfigTest::testDirtyAfterRevert()
 {
-//  qDebug("Reverting entries");
-  KConfig sc( "kconfigtest" );
+  KConfig sc( "kconfigtest_revert" );
 
   KConfigGroup cg(&sc, "Hello");
-  cg.revertToDefault( "boolEntry1" );
-  cg.revertToDefault( "boolEntry2" );
-
-  cg.revertToDefault( "Test" );
-  cg.revertToDefault( "emptyEntry" );
-  cg.revertToDefault( "stringEntry1" );
-  cg.revertToDefault( "stringEntry2" );
-  cg.revertToDefault( "stringEntry3" );
-  cg.revertToDefault( "stringEntry4" );
-  cg.revertToDefault( "stringEntry5" );
+  cg.revertToDefault( "does_not_exist" );
+  QVERIFY(!sc.isDirty());
+  cg.writeEntry("Test", "Correct");
+  QVERIFY(sc.isDirty());
   sc.sync();
+  QVERIFY(!sc.isDirty());
+
+  cg.revertToDefault("Test");
+  QVERIFY(sc.isDirty());
+  sc.sync();
+  QVERIFY(!sc.isDirty());
+
+  cg.revertToDefault("Test");
+  QVERIFY(!sc.isDirty());
 }
 
 void KConfigTest::testRevertAllEntries()
@@ -255,19 +258,19 @@ void KConfigTest::testRevertAllEntries()
     // this tests the case were we revert (delete) all entries in a file,
     // leaving a blank file
     {
-        KConfig sc( "konfigtest2" );
+        KConfig sc( "konfigtest2", KConfig::SimpleConfig );
         KConfigGroup cg( &sc, "Hello" );
         cg.writeEntry( "Test", "Correct" );
     }
 
     {
-        KConfig sc( "konfigtest2" );
+        KConfig sc( "konfigtest2", KConfig::SimpleConfig );
         KConfigGroup cg( &sc, "Hello" );
         QCOMPARE( cg.readEntry( "Test", "Default" ), QString("Correct") );
         cg.revertToDefault( "Test" );
     }
 
-    KConfig sc( "konfigtest2" );
+    KConfig sc( "konfigtest2", KConfig::SimpleConfig );
     KConfigGroup cg( &sc, "Hello" );
     QCOMPARE( cg.readEntry( "Test", "Default" ), QString("Default") );
 }
@@ -352,6 +355,18 @@ void KConfigTest::testDefaults()
     QCOMPARE(group.readEntry("entry1", QString()), Default);
     group.revertToDefault("entry2");
     QCOMPARE(group.readEntry("entry2", QString()), QString());
+
+    // TODO test reverting localized entries
+
+    Q_ASSERT(config.isDirty());
+    group.sync();
+
+    // Check that everything is OK on disk, too
+    KConfig reader("defaulttest", KConfig::NoGlobals);
+    reader.addConfigSources(QStringList() << KStandardDirs::locateLocal("config", defaultsFile));
+    KConfigGroup readerGroup = reader.group("any group");
+    QCOMPARE(readerGroup.readEntry("entry1", QString()), Default);
+    QCOMPARE(readerGroup.readEntry("entry2", QString()), QString());
 }
 
 void KConfigTest::testLocale()
@@ -437,7 +452,7 @@ void KConfigTest::testPath()
   KConfig sc2( "kconfigtest" );
   KConfigGroup sc3(&sc2, "Path Type");
   QCOMPARE( sc3.readPathEntry( "homepath", QString() ), HOMEPATH );
-  QCOMPARE( sc3.readPathEntry( "homepathescape", QString() ), HOMEPATHESCAPE );
+  QCOMPARE( sc3.readPathEntry( "homepathenv", QString() ), HOMEPATHENVEXPANDED );
   QCOMPARE( sc3.entryMap()["homepath"], HOMEPATH );
 
   {
@@ -463,12 +478,8 @@ void KConfigTest::testPath()
   QCOMPARE(group.readPathEntry("withBraces", QString()), QString("file://" + HOMEPATH) );
   QVERIFY(group.hasKey("URL"));
   QCOMPARE(group.readEntry("URL", QString()), QString("file://" + HOMEPATH) );
-#if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
-  // I don't know if this will work on windows
-  // This test hangs on OS X
   QVERIFY(group.hasKey("hostname"));
-  QCOMPARE(group.readEntry("hostname", QString()), QHostInfo::localHostName());
-#endif
+  QCOMPARE(group.readEntry("hostname", QString()), QString("$(hostname)"));
   QVERIFY(group.hasKey("noeol"));
   QCOMPARE(group.readEntry("noeol", QString()), QString("foo"));
 }
@@ -626,27 +637,12 @@ void KConfigTest::testChangeGroup()
     KConfigGroup sc3(&sc, "Hello");
     QCOMPARE(sc3.name(), QString("Hello"));
     KConfigGroup newGroup(sc3);
-#ifndef KDE_NO_DEPRECATED
-    newGroup.changeGroup("FooBar"); // deprecated!
-    QCOMPARE(newGroup.name(), QString("FooBar"));
-    QCOMPARE(sc3.name(), QString("Hello")); // unchanged
-
-    // Write into the "changed group" and check that it works
-    newGroup.writeEntry("InFooBar", "FB");
-    QCOMPARE(KConfigGroup(&sc, "FooBar").entryMap().value("InFooBar"), QString("FB"));
-    QCOMPARE(KConfigGroup(&sc, "Hello").entryMap().value("InFooBar"), QString());
-#endif
 
     KConfigGroup rootGroup(sc.group(""));
     QCOMPARE(rootGroup.name(), QString("<default>"));
     KConfigGroup sc32(rootGroup.group("Hello"));
     QCOMPARE(sc32.name(), QString("Hello"));
     KConfigGroup newGroup2(sc32);
-#ifndef KDE_NO_DEPRECATED
-    newGroup2.changeGroup("FooBar"); // deprecated!
-    QCOMPARE(newGroup2.name(), QString("FooBar"));
-    QCOMPARE(sc32.name(), QString("Hello")); // unchanged
-#endif
 }
 
 // Simple test for deleteEntry
@@ -825,6 +821,52 @@ void KConfigTest::testEmptyGroup()
     QVERIFY(lines.first() != QByteArray("TestKey=defaultGroup\n"));
 }
 
+void KConfigTest::testCascadingWithLocale()
+{
+    KTempDir middleDir;
+    KGlobal::dirs()->addPrefix(middleDir.name());
+    KTempDir globalDir;
+    KGlobal::dirs()->addPrefix(globalDir.name());
+
+    const QString globalConfigDir = globalDir.name() + "/share/config";
+    QVERIFY(QDir().mkpath(globalConfigDir));
+    QFile global(globalConfigDir + "/foo.desktop");
+    QVERIFY(global.open(QIODevice::WriteOnly|QIODevice::Text));
+    QTextStream globalOut(&global);
+    globalOut << "[Group]" << endl
+              << "FromGlobal=true" << endl
+              << "FromGlobal[fr]=vrai" << endl
+              << "Name=Testing" << endl
+              << "Name[fr]=FR" << endl
+              << "Other=Global" << endl
+              << "Other[fr]=Global_FR" << endl;
+    global.close();
+
+    const QString middleConfigDir = middleDir.name() + "/share/config";
+    QVERIFY(QDir().mkpath(middleConfigDir));
+    QFile local(middleConfigDir + "/foo.desktop");
+    QVERIFY(local.open(QIODevice::WriteOnly|QIODevice::Text));
+    QTextStream out(&local);
+    out << "[Group]" << endl
+        << "FromLocal=true" << endl
+        << "FromLocal[fr]=vrai" << endl
+        << "Name=Local Testing" << endl
+        << "Name[fr]=FR" << endl
+        << "Other=English Only" << endl;
+    local.close();
+
+    KConfig config("foo.desktop");
+    KConfigGroup group = config.group("Group");
+    QCOMPARE(group.readEntry("FromGlobal"), QString("true"));
+    QCOMPARE(group.readEntry("FromLocal"), QString("true"));
+    QCOMPARE(group.readEntry("Name"), QString("Local Testing"));
+    config.setLocale("fr");
+    QCOMPARE(group.readEntry("FromGlobal"), QString("vrai"));
+    QCOMPARE(group.readEntry("FromLocal"), QString("vrai"));
+    QCOMPARE(group.readEntry("Name"), QString("FR"));
+    QCOMPARE(group.readEntry("Other"), QString("English Only")); // Global_FR is locally overriden
+}
+
 void KConfigTest::testMerge()
 {
     KConfig config("mergetest", KConfig::SimpleConfig);
@@ -1526,43 +1568,45 @@ void KConfigTest::testNoKdeHome()
     const QString kdeHome = QDir::homePath() + "/.kde-unit-test-does-not-exist";
     setenv("KDEHOME", QFile::encodeName( kdeHome ), 1);
     KTempDir::removeDir(kdeHome);
-    QVERIFY(!QFile::exists(kdeHome));
+    QDir kdeDir(kdeHome);
+    QVERIFY(!kdeDir.exists());
 
     // Do what kde4-config does, and ensure kdehome doesn't get created (#233892)
     KComponentData componentData("KConfigTest");
-    QVERIFY(!QFile::exists(kdeHome));
+    QVERIFY(!kdeDir.exists());
     componentData.dirs();
-    QVERIFY(!QFile::exists(kdeHome));
+    QVERIFY(!kdeDir.exists());
     componentData.config();
-    QVERIFY(!QFile::exists(kdeHome));
+    QVERIFY(!kdeDir.exists());
 
     // Now try to actually save something, see if it works.
     KConfigGroup group(componentData.config(), "Group");
     group.writeEntry("Key", "Value");
     group.sync();
-    QVERIFY(QFile::exists(kdeHome));
+    QVERIFY(kdeDir.exists());
     QVERIFY(QFile::exists(kdeHome + "/share/config/KConfigTestrc"));
 
     // Cleanup
     KTempDir::removeDir(kdeHome);
 }
 
-#include <QThreadPool>
-#include <qtconcurrentrun.h>
-
 // To find multithreading bugs: valgrind --tool=helgrind --track-lockorders=no ./kconfigtest testThreads
 void KConfigTest::testThreads()
 {
-    QThreadPool::globalInstance()->setMaxThreadCount(6);
-    QList<QFuture<void> > futures;
     // Run in parallel some tests that work on different config files,
     // otherwise unexpected things might indeed happen.
-    futures << QtConcurrent::run(this, &KConfigTest::testAddConfigSources);
-    futures << QtConcurrent::run(this, &KConfigTest::testSimple);
-    futures << QtConcurrent::run(this, &KConfigTest::testDefaults);
-    // QEXPECT_FAIL triggers race conditions, it should be fixed to use QThreadStorage...
-    //futures << QtConcurrent::run(this, &KConfigTest::testDeleteWhenLocalized);
-    //futures << QtConcurrent::run(this, &KConfigTest::testEntryMap);
-    Q_FOREACH(QFuture<void> f, futures) // krazy:exclude=foreach
-        f.waitForFinished();
+    std::future<void> future1 = std::async(std::launch::async, &KConfigTest::testAddConfigSources, this);
+    std::future<void> future2 = std::async(std::launch::async, &KConfigTest::testSimple, this);
+    std::future<void> future3 = std::async(std::launch::async, &KConfigTest::testDefaults, this);
+    // QEXPECT_FAIL triggers race conditions...
+    // std::future<void> future4 = std::async(std::launch::async, &KConfigTest::testDeleteWhenLocalized, this);
+    // std::future<void> future5 = std::async(std::launch::async, &KConfigTest::testEntryMap, this);
+    kDebug() << "Joining all threads";
+    future1.wait();
+    future2.wait();
+    future3.wait();
+    // future4.wait();
+    // future5.wait();
 }
+
+#include "moc_kconfigtest.cpp"
