@@ -17,11 +17,12 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <qtest_kde.h>
 #include "kentrymaptest.h"
+
+#include <qtest_kde.h>
 #include "kconfigdata.h"
 
-#include "kentrymaptest.moc"
+#include "moc_kentrymaptest.cpp"
 
 const QByteArray group1("A Group");
 const QByteArray key1("A Key");
@@ -130,7 +131,8 @@ void KEntryMapTest::testDefault()
     // revert entry2, no default --> should be marked as deleted
     map.revertEntry(group1, key2);
     QCOMPARE(entry2->mValue, QByteArray());
-    QVERIFY(entry2->bDirty && entry2->bDeleted);
+    QVERIFY(entry2->bDirty);
+    QVERIFY(entry2->bReverted);
 }
 
 void KEntryMapTest::testDelete()
