@@ -21,9 +21,7 @@
 #include "kmimetypetest.h"
 
 #include <config.h>
-#include <kdefakes.h>
 #include <kde_file.h>
-#include <kprocess.h>
 #include <kmimetype.h>
 #include <ksycoca.h>
 #include <kglobal.h>
@@ -32,7 +30,6 @@
 #include <ktempdir.h>
 #include <kconfiggroup.h>
 #include <kdebug.h>
-
 #include <qtest_kde.h>
 #include <kprotocolinfo.h>
 #include <kmimetypetrader.h>
@@ -41,6 +38,11 @@
 #include <ktemporaryfile.h>
 #include <kdesktopfile.h>
 
+#include <QtCore/qbuffer.h>
+#include <QtCore/qprocess.h>
+
+#include <future>
+
 void KMimeTypeTest::initTestCase()
 {
     // Clean up local xdg dir in case of leftover mimetype definitions
@@ -128,7 +130,7 @@ void KMimeTypeTest::initTestCase()
 
     if ( mustUpdateKSycoca ) {
         // Update ksycoca in ~/.kde-unit-test after creating the above
-        QProcess::execute( KGlobal::dirs()->findExe(KBUILDSYCOCA_EXENAME) );
+        QProcess::execute( KStandardDirs::findExe(KBUILDSYCOCA_EXENAME) );
     }
 
     QVERIFY(KService::serviceByStorageId("fake_nonkde_application.desktop"));
@@ -151,11 +153,10 @@ void KMimeTypeTest::cleanupTestCase()
     QFile::remove(fakePlugin);
     QFile::remove(m_kdeApp);
     QFile::remove(m_nonKdeApp);
-    //QProcess::execute( KGlobal::dirs()->findExe(KBUILDSYCOCA_EXENAME) );
-    KProcess proc;
-    proc << KStandardDirs::findExe(KBUILDSYCOCA_EXENAME);
-    proc.setOutputChannelMode(KProcess::MergedChannels); // silence kbuildsycoca output
-    proc.execute();
+    QProcess proc;
+    proc.setProcessChannelMode(QProcess::MergedChannels); // silence kbuildsycoca output
+    proc.start(KStandardDirs::findExe(KBUILDSYCOCA_EXENAME));
+    proc.waitForFinished();
 }
 
 static void checkIcon( const KUrl& url, const QString& expectedIcon )
@@ -232,7 +233,6 @@ void KMimeTypeTest::testFindByPathUsingFileName_data()
     QTest::newRow("case-sensitive-only match") << "Core" << "application/octet-stream"; // #198477
 
     QTest::newRow("desktop file") << "foo.desktop" << "application/x-desktop";
-    QTest::newRow("old kdelnk file is x-desktop too") << "foo.kdelnk" << "application/x-desktop";
     QTest::newRow("double-extension file") << "foo.tar.bz2" << "application/x-bzip-compressed-tar";
     QTest::newRow("single-extension file") << "foo.bz2" << "application/x-bzip";
     QTest::newRow(".doc should assume msword") << "somefile.doc" << "application/msword"; // #204139
@@ -249,23 +249,23 @@ void KMimeTypeTest::testFindByPathUsingFileName_data()
     QTest::newRow("doesn't exist but has known extension") << "IDontExist.txt" << "text/plain";
 
     // Can't use KIconLoader since this is a "without GUI" test.
-    if (KStandardDirs::locate("icon", "oxygen/").isEmpty()) {
-        kWarning() << "oxygen not found";
+    if (KStandardDirs::locate("icon", "ariya/").isEmpty()) {
+        kWarning() << "ariya not found";
     } else {
-        QString fh = KStandardDirs::locate( "icon", "oxygen/22x22/places/folder.png" );
+        QString fh = KStandardDirs::locate( "icon", "ariya/22x22/places/folder.png" );
         QVERIFY( !fh.isEmpty() ); // if the file doesn't exist, please fix the above to point to an existing icon
         QTest::newRow("png image") << fh << "image/png";
     }
 
     QString exePath = KStandardDirs::findExe( "kioexec" );
-    if ( exePath.isEmpty() )
+    if ( exePath.isEmpty() ) {
         kWarning() << "kioexec not found";
-    else {
-#ifdef Q_WS_WIN
-        const QString executableType = QString::fromLatin1( "application/x-ms-dos-executable" );
-#else
-        const QString executableType = QString::fromLatin1( "application/x-executable" );
-#endif
+    } else {
+        QString executableType = QString::fromLatin1( "application/x-executable" );
+        // https://gitlab.freedesktop.org/xdg/shared-mime-info/-/issues/11
+        if (KMimeType::sharedMimeInfoVersion() <= KDE_MAKE_VERSION(2, 0, 0)) {
+            executableType = QString::fromLatin1( "application/x-sharedlib" );
+        }
         QTest::newRow("executable") << exePath << executableType;
     }
 }
@@ -372,21 +372,6 @@ void KMimeTypeTest::testFindByUrl()
 
     mime = KMimeType::findByUrl(KUrl("http://foo/s0/"));
     QCOMPARE( mime->name(), QString::fromLatin1( "application/octet-stream" ) ); // HTTP can't know before downloading
-
-    if ( !KProtocolInfo::isKnownProtocol(KUrl("man:/")) )
-        QSKIP( "man protocol not installed", SkipSingle );
-
-    mime = KMimeType::findByUrl( KUrl("man:/ls") );
-    QVERIFY( mime );
-    QCOMPARE( mime->name(), QString::fromLatin1("text/html") );
-
-    mime = KMimeType::findByUrl( KUrl("man:/ls/") );
-    QVERIFY( mime );
-    QCOMPARE( mime->name(), QString::fromLatin1("text/html") );
-
-    mime = KMimeType::findByUrl(KUrl("fish://host/test1")); // like fish does, to test for known extensions
-    QVERIFY(mime);
-    QCOMPARE(mime->name(), QString::fromLatin1("application/octet-stream"));
 }
 
 void KMimeTypeTest::testFindByNameAndContent()
@@ -404,12 +389,12 @@ void KMimeTypeTest::testFindByNameAndContent()
     QVERIFY( mime );
     QCOMPARE( mime->name(), QString::fromLatin1("text/plain") );
 
-    // textfile.doc -> text/plain. We added this to the mimetype database so that it can be handled.
+    // mswordfile.doc -> application/msword. Found by glob.
     mime = KMimeType::findByNameAndContent("textfile.doc", textData);
     QVERIFY( mime );
-    QCOMPARE( mime->name(), QString::fromLatin1("text/plain") );
+    QCOMPARE( mime->name(), QString::fromLatin1("application/msword") );
 
-    // mswordfile.doc -> application/msword. Found by contents, because of the above case.
+    // mswordfile.doc -> application/msword. Found by contents.
     // Note that it's application/msword, not application/vnd.ms-word, since it's the former that is registered to IANA.
     QByteArray mswordData = "\320\317\021\340\241\261\032\341";
     mime = KMimeType::findByNameAndContent("mswordfile.doc", mswordData);
@@ -766,12 +751,9 @@ void KMimeTypeTest::testPatterns_data()
     QTest::addColumn<QString>("mainExtension");
     QTest::newRow("mimetype with a single pattern") << "application/pdf" << "*.pdf" << ".pdf";
     QTest::newRow("mimetype with multiple patterns") << "application/x-kpresenter" << "*.kpr;*.kpt" << ".kpr";
-    if (KMimeType::sharedMimeInfoVersion() > KDE_MAKE_VERSION(0, 60, 0)) {
-        QTest::newRow("mimetype with many patterns") << "application/vnd.wordperfect" << "*.wp;*.wp4;*.wp5;*.wp6;*.wpd;*.wpp" << ".wp";
-    }
+    QTest::newRow("mimetype with many patterns") << "application/vnd.wordperfect" << "*.wp;*.wp4;*.wp5;*.wp6;*.wpd;*.wpp" << ".wp";
     QTest::newRow("oasis text mimetype") << "application/vnd.oasis.opendocument.text" << "*.odt" << ".odt";
     QTest::newRow("oasis presentation mimetype") << "application/vnd.oasis.opendocument.presentation" << "*.odp" << ".odp";
-    QTest::newRow("mimetype with multiple patterns, *.doc added by kde") << "text/plain" << "*.asc;*.txt;*.doc;*,v" << ".txt";
     QTest::newRow("mimetype with uncommon pattern") << "application/x-kcachegrind" << "callgrind.out*;cachegrind.out*" << QString();
     QTest::newRow("mimetype with no patterns") << "application/x-ole-storage" << QString() << QString();
 }
@@ -861,25 +843,25 @@ void KMimeTypeTest::testParseMagicFile_data()
     QTest::newRow("Second rule, two-level match") << "AB[C]" << "application/x-desktop";
     QTest::newRow("Second rule, failure at first level (mask)") << "AB[B]" << QString();
     QTest::newRow("Second rule, failure at second level") << "AB[CN" << QString();
-    QTest::newRow("Tnef magic, should pass") << "\x78\x9f\x3e\x22" << "application/vnd.ms-tnef";
-    QTest::newRow("Tnef magic, should fail") << "\x22\x3e\x9f\x78" << QString();
-    QTest::newRow("Powerpoint rule, for endianness check, should pass") << "\xd0\xcf\x11\xe0" << "application/vnd.ms-powerpoint";
-    QTest::newRow("Powerpoint rule, no swapping, should fail") << "\x11\xe0\xd0\xcf" << QString();
+    QTest::newRow("Tnef magic, should pass") << QString::fromLatin1("\x78\x9f\x3e\x22") << "application/vnd.ms-tnef";
+    QTest::newRow("Tnef magic, should fail") << QString::fromLatin1("\x22\x3e\x9f\x78") << QString();
+    QTest::newRow("Powerpoint rule, for endianness check, should pass") << QString::fromLatin1("\xd0\xcf\x11\xe0") << "application/vnd.ms-powerpoint";
+    QTest::newRow("Powerpoint rule, no swapping, should fail") << QString::fromLatin1("\x11\xe0\xd0\xcf") << QString();
 #if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
-    QTest::newRow("Test mime, host16, wrong endianness") << "\x12\x34" << QString();
-    QTest::newRow("Test mime, host16, little endian, ok") << "\x34\x12" << "text/x-test-mime-host16";
-    QTest::newRow("Test mime, host32, wrong endianness") << "\x12\x34\x56\x78" << QString();
-    QTest::newRow("Test mime, host32, little endian, ok") << "\x78\x56\x34\x12" << "text/x-test-mime-host32";
+    QTest::newRow("Test mime, host16, wrong endianness") << QString::fromLatin1("\x12\x34") << QString();
+    QTest::newRow("Test mime, host16, little endian, ok") << QString::fromLatin1("\x34\x12") << "text/x-test-mime-host16";
+    QTest::newRow("Test mime, host32, wrong endianness") << QString::fromLatin1("\x12\x34\x56\x78") << QString();
+    QTest::newRow("Test mime, host32, little endian, ok") << QString::fromLatin1("\x78\x56\x34\x12") << "text/x-test-mime-host32";
 #else
-    QTest::newRow("Test mime, host16, big endian, ok") << "\x12\x34" << "text/x-test-mime-host16";
-    QTest::newRow("Test mime, host16, wrong endianness") << "\x34\x12" << QString();
-    QTest::newRow("Test mime, host32, big endian, ok") << "\x12\x34\x56\x78" << "text/x-test-mime-host32";
-    QTest::newRow("Test mime, host32, wrong endianness") << "\x78\x56\x34\x12" << QString();
+    QTest::newRow("Test mime, host16, big endian, ok") << QString::fromLatin1("\x12\x34") << "text/x-test-mime-host16";
+    QTest::newRow("Test mime, host16, wrong endianness") << QString::fromLatin1("\x34\x12") << QString();
+    QTest::newRow("Test mime, host32, big endian, ok") << QString::fromLatin1("\x12\x34\x56\x78") << "text/x-test-mime-host32";
+    QTest::newRow("Test mime, host32, wrong endianness") << QString::fromLatin1("\x78\x56\x34\x12") << QString();
 #endif
-    QTest::newRow("Test mime, little16, little endian, ok") << "\x78\x55" << "text/x-test-mime-little16";
-    QTest::newRow("Test mime, little16, wrong endianness") << "\x55\x78" << QString();
-    QTest::newRow("Test mime, big16, little endian, ok") << "\x12\x78" << "text/x-test-mime-big16";
-    QTest::newRow("Test mime, big16, wrong endianness") << "\x78\x12" << QString();
+    QTest::newRow("Test mime, little16, little endian, ok") << QString::fromLatin1("\x78\x55") << "text/x-test-mime-little16";
+    QTest::newRow("Test mime, little16, wrong endianness") << QString::fromLatin1("\x55\x78") << QString();
+    QTest::newRow("Test mime, big16, little endian, ok") << QString::fromLatin1("\x12\x78") << "text/x-test-mime-big16";
+    QTest::newRow("Test mime, big16, wrong endianness") << QString::fromLatin1("\x78\x12") << QString();
 
     QByteArray magicData;
     magicData.resize(sizeof(s_magicData) - 1 /*trailing nul*/);
@@ -945,14 +927,14 @@ void KMimeTypeTest::testHelperProtocols()
     QVERIFY(!KProtocolInfo::isHelperProtocol("unknown"));
     QVERIFY(KProtocolInfo::isHelperProtocol("telnet"));
 
-    // "mailto" is associated with kmail2 when present, and with kmailservice otherwise.
-    KService::Ptr kmail2 = KService::serviceByStorageId("KMail2.desktop");
-    if (kmail2) {
-        //qDebug() << kmail2->entryPath();
-        QVERIFY2(KProtocolInfo::exec("mailto").contains(QLatin1String("kmail -caption ")), // comes from KMail2.desktop
+    // "mailto" is associated with kmail when present, and with kmailservice otherwise.
+    KService::Ptr kmail = KService::serviceByStorageId("kmail.desktop");
+    if (kmail) {
+        // qDebug() << kmail->entryPath();
+        QVERIFY2(KProtocolInfo::exec("mailto").contains(QLatin1String("kmail --icon ")), // comes from kmail.desktop
                  qPrintable(KProtocolInfo::exec("mailto")));
     } else {
-        QCOMPARE(KProtocolInfo::exec("mailto"), QLatin1String("kmailservice %u"));
+        QCOMPARE(KProtocolInfo::exec("mailto"), QLatin1String("kmailservice --icon '%i' --caption '%c' %u"));
     }
 
 
@@ -972,22 +954,38 @@ void KMimeTypeTest::testFromThread()
 
 void KMimeTypeTest::testThreads()
 {
-    QThreadPool::globalInstance()->setMaxThreadCount(20);
     // Note that data-based tests cannot be used here (QTest::fetchData asserts).
-    QList<QFuture<void> > futures;
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testFindByUrl);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testFindByFileContent);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testFindByNameAndContent);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testFindByPathWithContent);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testAllMimeTypes);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testAlias);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testMimeTypeParent);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testPreferredService);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testFromThread);
-    futures << QtConcurrent::run(this, &KMimeTypeTest::testHelperProtocols);
+    std::future<void> future1 = std::async(std::launch::async, &KMimeTypeTest::testFindByUrl, this);
+    std::future<void> future2 = std::async(std::launch::async, &KMimeTypeTest::testFindByFileContent, this);
+    std::future<void> future3 = std::async(std::launch::async, &KMimeTypeTest::testFindByNameAndContent, this);
+    std::future<void> future4 = std::async(std::launch::async, &KMimeTypeTest::testFindByPathWithContent, this);
+    std::future<void> future5 = std::async(std::launch::async, &KMimeTypeTest::testAllMimeTypes, this);
+    std::future<void> future6 = std::async(std::launch::async, &KMimeTypeTest::testAlias, this);
+    std::future<void> future7 = std::async(std::launch::async, &KMimeTypeTest::testMimeTypeParent, this);
+    std::future<void> future8 = std::async(std::launch::async, &KMimeTypeTest::testPreferredService, this);
+    std::future<void> future9 = std::async(std::launch::async, &KMimeTypeTest::testFromThread, this);
+    std::future<void> future10 = std::async(std::launch::async, &KMimeTypeTest::testHelperProtocols, this);
     kDebug() << "Joining all threads";
-    Q_FOREACH(QFuture<void> f, futures) // krazy:exclude=foreach
-        f.waitForFinished();
+    future1.wait();
+    future2.wait();
+    future3.wait();
+    future4.wait();
+    future5.wait();
+    future6.wait();
+    future7.wait();
+    future8.wait();
+    future9.wait();
+    future10.wait();
 }
 
-#include "kmimetypetest.moc"
+void KMimeTypeTest::testProperties()
+{
+    KMimeType::Ptr pngMimeType = KMimeType::mimeType("image/png");
+    QVariant comment = pngMimeType->property("Comment");
+    QVariant patterns = pngMimeType->property("Patterns");
+
+    QCOMPARE(comment.toString(), pngMimeType->comment());
+    QCOMPARE(patterns.toStringList(), pngMimeType->patterns());
+}
+
+#include "moc_kmimetypetest.cpp"
