@@ -18,7 +18,7 @@
 
 #include "kmountpointtest.h"
 #include <qtest_kde.h>
-#include "kmountpointtest.moc"
+#include "moc_kmountpointtest.cpp"
 
 #include "kmountpoint.h"
 #include <kdebug.h>
@@ -35,12 +35,15 @@ void KMountPointTest::initTestCase()
 void KMountPointTest::testCurrentMountPoints()
 {
     const KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::NeedRealDeviceName);
-    QVERIFY(!mountPoints.isEmpty());
+    if (mountPoints.isEmpty()) { // can happen in chroot jails. TODO: we could parse /proc/self/mountinfo instead....
+        QSKIP("mtab is empty", SkipAll);
+        return;
+    }
     KMountPoint::Ptr mountWithDevice;
     foreach(KMountPoint::Ptr mountPoint, mountPoints) {
         kDebug() << "Mount: " << mountPoint->mountedFrom()
           << " (" << mountPoint->realDeviceName() << ") "
-          << mountPoint->mountPoint() << " " << mountPoint->mountType() << endl;
+          << mountPoint->mountPoint() << " " << mountPoint->mountType();
         QVERIFY(!mountPoint->mountedFrom().isEmpty());
         QVERIFY(!mountPoint->mountPoint().isEmpty());
         QVERIFY(!mountPoint->mountType().isEmpty());
@@ -101,7 +104,7 @@ void KMountPointTest::testPossibleMountPoints()
         kDebug() << "Possible mount: " << mountPoint->mountedFrom()
           << " (" << mountPoint->realDeviceName() << ") "
           << mountPoint->mountPoint() << " " << mountPoint->mountType()
-                 << " options:" << mountPoint->mountOptions() << endl;
+                 << " options:" << mountPoint->mountOptions();
         QVERIFY(!mountPoint->mountedFrom().isEmpty());
         QVERIFY(!mountPoint->mountPoint().isEmpty());
         QVERIFY(!mountPoint->mountType().isEmpty());
