@@ -16,8 +16,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef ksavefiletest_h
-#define ksavefiletest_h
+#ifndef KSAVEFILETEST_H
+#define KSAVEFILETEST_H
 
 #include <QtCore/QObject>
 #include <QtCore/QStringList>
@@ -32,9 +32,7 @@ private Q_SLOTS:
     void transactionalWriteNoPermissionsOnDir_data();
     void transactionalWriteNoPermissionsOnDir();
 
-    void test_numberedBackupFile();
-    void test_rcsBackupFile();
-    void test_simpleBackupFile();
+    void test_backupFile();
     void cleanupTestCase();
     
 private:
