@@ -16,42 +16,29 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include <locale.h>
-
 #include "kservicetest.h"
-#include "kservicetest.moc"
 #include <qtest_kde.h>
-
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <kdesktopfile.h>
 #include <ksycoca.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
-
 #include <kprotocolinfo.h>
 #include <kdebug.h>
-#include <kprocess.h>
 #include <kservicegroup.h>
 #include <kservicetypetrader.h>
 #include <kservicetype.h>
-#include <kservicetypeprofile.h>
 
-#include <QtCore/Q_PID>
+#include <QtCore/qprocess.h>
+#include <QtCore/qthread.h>
+
+#include <locale.h>
+#include <future>
+#include <chrono>
 
 QTEST_KDEMAIN_CORE( KServiceTest )
 
-static void eraseProfiles()
-{
-    QString profilerc = KStandardDirs::locateLocal( "config", "profilerc" );
-    if ( !profilerc.isEmpty() )
-        QFile::remove( profilerc );
-
-    profilerc = KStandardDirs::locateLocal( "config", "servicetype_profilerc" );
-    if ( !profilerc.isEmpty() )
-        QFile::remove( profilerc );
-}
-
 void KServiceTest::initTestCase()
 {
     // A non-C locale is necessary for some tests.
@@ -65,7 +52,6 @@ void KServiceTest::initTestCase()
     }
 
     m_hasKde4Konsole = false;
-    eraseProfiles();
 
     // Create some fake services for the tests below, and ensure they are in ksycoca.
 
@@ -90,8 +76,8 @@ void KServiceTest::initTestCase()
 	group.writeEntry("Type", "Service");
 	group.writeEntry("X-KDE-Library", "fakepart");
 	group.writeEntry("X-KDE-Protocols", "http,ftp");
-	group.writeEntry("X-KDE-ServiceTypes", "KParts/ReadOnlyPart,Browser/View,KParts/ReadWritePart");
-	group.writeEntry("MimeType", "text/plain;");
+	group.writeEntry("X-KDE-ServiceTypes", "KParts/ReadOnlyPart,KParts/ReadWritePart");
+	group.writeEntry("MimeType", "text/plain;text/html;");
     }
 
     // faketextplugin: a ktexteditor plugin
@@ -112,7 +98,7 @@ void KServiceTest::initTestCase()
 
     if ( mustUpdateKSycoca ) {
         // Update ksycoca in ~/.kde-unit-test after creating the above
-        QProcess::execute( KGlobal::dirs()->findExe(KBUILDSYCOCA_EXENAME), QStringList() << "--noincremental" );
+        QProcess::execute( KStandardDirs::findExe(KBUILDSYCOCA_EXENAME), QStringList() << "--noincremental" );
         kDebug() << "waiting for signal";
         QVERIFY(QTest::kWaitForSignal(KSycoca::self(), SIGNAL(databaseChanged(QStringList)), 10000));
         kDebug() << "got signal";
@@ -128,11 +114,10 @@ void KServiceTest::cleanupTestCase()
         const QString fakeService = KStandardDirs::locateLocal("services", service);
         QFile::remove(fakeService);
     }
-    //QProcess::execute( KGlobal::dirs()->findExe(KBUILDSYCOCA_EXENAME) );
-    KProcess proc;
-    proc << KStandardDirs::findExe(KBUILDSYCOCA_EXENAME);
-    proc.setOutputChannelMode(KProcess::MergedChannels); // silence kbuildsycoca output
-    proc.execute();
+    QProcess proc;
+    proc.setProcessChannelMode(QProcess::MergedChannels); // silence kbuildsycoca output
+    proc.start(KStandardDirs::findExe(KBUILDSYCOCA_EXENAME));
+    proc.waitForFinished();
 }
 
 void KServiceTest::testByName()
@@ -144,30 +129,28 @@ void KServiceTest::testByName()
     QVERIFY( s0 );
     QCOMPARE( s0->name(), QString::fromLatin1("KParts/ReadOnlyPart") );
 
-    KService::Ptr khtml = KService::serviceByDesktopPath("khtml.desktop");
-    QCOMPARE( khtml->name(), QString::fromLatin1("KHTML"));
+    KService::Ptr kfilemodule = KService::serviceByDesktopPath("kfilemodule.desktop");
+    QVERIFY(kfilemodule);
+    QCOMPARE( kfilemodule->name(), QString::fromLatin1("KFileModule"));
 }
 
 void KServiceTest::testProperty()
 {
-    KService::Ptr kdedkcookiejar = KService::serviceByDesktopPath("kded/kcookiejar.desktop");
-    QVERIFY(kdedkcookiejar);
-    QCOMPARE(kdedkcookiejar->entryPath(), QString("kded/kcookiejar.desktop"));
+    KService::Ptr kdedkaudioplayer = KService::serviceByDesktopPath("kded/kaudioplayer.desktop");
+    QVERIFY(kdedkaudioplayer);
+    QCOMPARE(kdedkaudioplayer->entryPath(), QString("kded/kaudioplayer.desktop"));
 
-    QCOMPARE(kdedkcookiejar->property("ServiceTypes").toStringList().join(","), QString("KDEDModule"));
-    QCOMPARE(kdedkcookiejar->property("X-KDE-Kded-autoload").toBool(), false);
-    QCOMPARE(kdedkcookiejar->property("X-KDE-Kded-load-on-demand").toBool(), true);
-    QVERIFY(!kdedkcookiejar->property("Name").toString().isEmpty());
-    QVERIFY(!kdedkcookiejar->property("Name[fr]", QVariant::String).isValid());
-
-    KService::Ptr kjavaappletviewer = KService::serviceByDesktopPath("kjavaappletviewer.desktop");
-    QVERIFY(kjavaappletviewer);
-    QCOMPARE(kjavaappletviewer->property("X-KDE-BrowserView-PluginsInfo").toString(), QString("kjava/pluginsinfo"));
+    QCOMPARE(kdedkaudioplayer->property("ServiceTypes").toStringList().join(","), QString("KDEDModule"));
+    QCOMPARE(kdedkaudioplayer->property("X-KDE-Kded-autoload").toBool(), false);
+    QCOMPARE(kdedkaudioplayer->property("X-KDE-Kded-load-on-demand").toBool(), true);
+    QVERIFY(!kdedkaudioplayer->property("Name").toString().isEmpty());
+    QVERIFY(!kdedkaudioplayer->property("Name[fr]", QVariant::String).isValid());
 
     // Test property("X-KDE-Protocols"), which triggers the KServiceReadProperty code.
     KService::Ptr fakePart = KService::serviceByDesktopPath("fakepart.desktop");
     QVERIFY(fakePart); // see initTestCase; it should be found.
     QVERIFY(fakePart->propertyNames().contains("X-KDE-Protocols"));
+    QCOMPARE(fakePart->mimeTypes(), QStringList() << "text/plain" << "text/html"); // okular relies on subclasses being kept here
     const QStringList protocols = fakePart->property("X-KDE-Protocols").toStringList();
     QCOMPARE(protocols, QStringList() << "http" << "ftp");
 }
@@ -233,7 +216,7 @@ static bool offerListHasService( const KService::List& offers,
 {
     bool found = false;
     KService::List::const_iterator it = offers.begin();
-    for ( ; it != offers.end() ; it++ )
+    for ( ; it != offers.end() ; ++it )
     {
         if ( (*it)->entryPath() == entryPath ) {
             if( found ) { // should be there only once
@@ -257,7 +240,7 @@ void KServiceTest::testDBUSStartupType()
     QVERIFY(konsole);
     QCOMPARE(konsole->menuId(), QString("kde4-konsole.desktop"));
     //qDebug() << konsole->entryPath();
-    QCOMPARE((int)konsole->dbusStartupType(), (int)KService::DBusUnique);
+    QCOMPARE((int)konsole->dbusStartupType(), (int)KService::DBusMulti);
 }
 
 void KServiceTest::testByStorageId()
@@ -300,11 +283,6 @@ void KServiceTest::testServiceTypeTraderForReadOnlyPart()
     // Only test for parts provided by kdelibs, or better, by this unittest:
     QVERIFY( offerListHasService( offers, "fakepart.desktop" ) );
 
-    QVERIFY( offerListHasService( offers, "kmultipart.desktop" ) );
-    QVERIFY( offerListHasService( offers, "khtml.desktop" ) );
-    QVERIFY( offerListHasService( offers, "khtmlimage.desktop" ) );
-    QVERIFY( offerListHasService( offers, "kjavaappletviewer.desktop" ) );
-
     // Check ordering according to InitialPreference
     int lastPreference = -1;
     bool lastAllowedAsDefault = true;
@@ -356,7 +334,7 @@ void KServiceTest::testHasServiceType1() // with services constructed with a ful
     KService fakepart( fakepartPath );
     QVERIFY( fakepart.hasServiceType( "KParts/ReadOnlyPart" ) );
     QVERIFY( fakepart.hasServiceType( "KParts/ReadWritePart" ) );
-    QCOMPARE(fakepart.mimeTypes(), QStringList() << "text/plain");
+    QCOMPARE(fakepart.mimeTypes(), QStringList() << "text/plain" << "text/html");
 
     QString faketextPluginPath = KStandardDirs::locate( "services", "faketextplugin.desktop" );
     QVERIFY( !faketextPluginPath.isEmpty() );
@@ -371,7 +349,7 @@ void KServiceTest::testHasServiceType2() // with services coming from ksycoca
     QVERIFY( !fakepart.isNull() );
     QVERIFY( fakepart->hasServiceType( "KParts/ReadOnlyPart" ) );
     QVERIFY( fakepart->hasServiceType( "KParts/ReadWritePart" ) );
-    QCOMPARE(fakepart->mimeTypes(), QStringList() << "text/plain");
+    QCOMPARE(fakepart->mimeTypes(), QStringList() << "text/plain" << "text/html");
 
     KService::Ptr faketextPlugin = KService::serviceByDesktopPath( "faketextplugin.desktop" );
     QVERIFY( !faketextPlugin.isNull() );
@@ -379,91 +357,28 @@ void KServiceTest::testHasServiceType2() // with services coming from ksycoca
     QVERIFY( !faketextPlugin->hasServiceType( "KParts/ReadOnlyPart" ) );
 }
 
-void KServiceTest::testWriteServiceTypeProfile()
-{
-    const QString serviceType = "KParts/ReadOnlyPart";
-    KService::List services, disabledServices;
-    services.append(KService::serviceByDesktopPath("khtmlimage.desktop"));
-    services.append(KService::serviceByDesktopPath("fakepart.desktop"));
-    disabledServices.append(KService::serviceByDesktopPath("khtml.desktop"));
-
-    KService::List::ConstIterator servit = services.constBegin();
-    for( ; servit != services.constEnd(); ++servit) {
-        QVERIFY(!servit->isNull());
-    }
-
-
-    KServiceTypeProfile::writeServiceTypeProfile( serviceType, services, disabledServices );
-
-    // Check that the file got written
-    QString profilerc = KStandardDirs::locateLocal( "config", "servicetype_profilerc" );
-    QVERIFY(!profilerc.isEmpty());
-    QVERIFY(QFile::exists(profilerc));
-
-    KService::List offers = KServiceTypeTrader::self()->query( serviceType );
-    QVERIFY( offers.count() > 0 ); // not empty
-
-    //foreach( KService::Ptr service, offers )
-    //    qDebug( "%s %s", qPrintable( service->name() ), qPrintable( service->entryPath() ) );
-
-    QVERIFY( offers.count() >= 3 ); // at least 3, even
-    QCOMPARE( offers[0]->entryPath(), QString("khtmlimage.desktop") );
-    QCOMPARE( offers[1]->entryPath(), QString("fakepart.desktop") );
-    QVERIFY( offerListHasService( offers, "kmultipart.desktop" ) ); // should still be somewhere in there
-    QVERIFY( !offerListHasService( offers, "khtml.desktop" ) ); // it got disabled above
-}
-
-void KServiceTest::testDefaultOffers()
-{
-    // Now that we have a user-profile, let's see if defaultOffers indeed gives us the default ordering.
-    const QString serviceType = "KParts/ReadOnlyPart";
-    KService::List offers = KServiceTypeTrader::self()->defaultOffers( serviceType );
-    QVERIFY( offers.count() > 0 ); // not empty
-    QVERIFY( offerListHasService( offers, "khtml.desktop" ) ); // it's here even though it's disabled in the profile
-    if ( m_firstOffer.isEmpty() )
-        QSKIP( "testServiceTypeTraderForReadOnlyPart not run", SkipAll );
-    QCOMPARE( offers[0]->entryPath(), m_firstOffer );
-}
-
-void KServiceTest::testDeleteServiceTypeProfile()
-{
-    const QString serviceType = "KParts/ReadOnlyPart";
-    KServiceTypeProfile::deleteServiceTypeProfile( serviceType );
-
-    KService::List offers = KServiceTypeTrader::self()->query( serviceType );
-    QVERIFY( offers.count() > 0 ); // not empty
-    QVERIFY( offerListHasService( offers, "khtml.desktop" ) ); // it's back
-
-    if ( m_firstOffer.isEmpty() )
-        QSKIP( "testServiceTypeTraderForReadOnlyPart not run", SkipAll );
-    QCOMPARE( offers[0]->entryPath(), m_firstOffer );
-}
-
 void KServiceTest::testActionsAndDataStream()
 {
-    const QString servicePath = KStandardDirs::locate( "services", "ScreenSavers/krandom.desktop" );
+    const QString servicePath = KStandardDirs::locate( "services", "ServiceMenus/ark_servicemenu.desktop" );
     if (servicePath.isEmpty() )
-        QSKIP("kdebase not installed, krandom.desktop not found", SkipAll);
+        QSKIP("kde-extraapps not installed, ark_servicemenu.desktop not found", SkipAll);
     KService service( servicePath );
     QVERIFY(!service.property("Name[fr]", QVariant::String).isValid());
     const QList<KServiceAction> actions = service.actions();
     QCOMPARE(actions.count(), 3);
     const KServiceAction setupAction = actions[0];
-    QCOMPARE(setupAction.name(), QString("Setup"));
-    QCOMPARE(setupAction.exec(), QString("krandom.kss -setup"));
-    QVERIFY(!setupAction.icon().isEmpty());
+    QCOMPARE(setupAction.name(), QString("arkAutoExtractHere"));
+    QCOMPARE(setupAction.exec(), QString("ark --batch --autodestination --autosubfolder %F"));
+    QCOMPARE(setupAction.icon(), QString("ark"));
     QCOMPARE(setupAction.noDisplay(), false);
     QVERIFY(!setupAction.isSeparator());
-    const KServiceAction rootAction = actions[2];
-    QCOMPARE(rootAction.name(), QString("Root"));
+    const KServiceAction extractHereAction = actions[2];
+    QCOMPARE(extractHereAction.name(), QString("arkExtractHere"));
 
     QByteArray data;
     QDataStream stream(&data, QIODevice::WriteOnly);
     service.save(stream);
     QVERIFY(!data.isEmpty());
-    // The binary size of that KService in ksycoca was 3700 when storing all Name[...] translations!
-    // Now down to 755. This is on x86, so make the assert for 1500 in case x86_64 needs more.
-    QVERIFY(data.size() < 1500);
     QDataStream loadingStream(data);
     // loading must first get type, see KSycocaEntryPrivate::save
     // (the path that save writes out, is read by the KSycocaEntryPrivate ctor)
@@ -499,41 +414,36 @@ void KServiceTest::testServiceGroups()
 void KServiceTest::testKSycocaUpdate()
 {
     kWarning();
+    connect(KSycoca::self(), SIGNAL(databaseChanged(QStringList)), this, SLOT(slotDBUpdate(QStringList)));
     KService::Ptr fakeService = KService::serviceByDesktopPath("fakeservice.desktop");
     QVERIFY(fakeService); // see initTestCase; it should be found.
 
     // Test deleting a service
     const QString servPath = KStandardDirs::locateLocal("services", "fakeservice.desktop");
     QVERIFY(QFile::exists(servPath));
-    QSignalSpy spy(KSycoca::self(), SIGNAL(databaseChanged(QStringList)));
-    QVERIFY(spy.isValid());
+    m_resourcesUpdated.clear();
     QFile::remove(servPath);
     kDebug() << QThread::currentThread() << "executing kbuildsycoca";
-    QProcess::execute( KGlobal::dirs()->findExe(KBUILDSYCOCA_EXENAME) );
+    QProcess::execute( KStandardDirs::findExe(KBUILDSYCOCA_EXENAME) );
     kDebug() << QThread::currentThread() << "done";
-    while (spy.isEmpty())
-        QTest::qWait(50);
-    QVERIFY(!spy.isEmpty());
+    QVERIFY(QTest::kWaitForSignal(KSycoca::self(), SIGNAL(databaseChanged(QStringList)), 10000));
     QVERIFY(!KService::serviceByDesktopPath("fakeservice.desktop")); // not in ksycoca anymore
-    QVERIFY(spy[0][0].toStringList().contains("services"));
+    QVERIFY(m_resourcesUpdated.contains("services"));
     kDebug() << QThread::currentThread() << "got signal ok";
 
-    spy.clear();
     QVERIFY(fakeService); // the whole point of refcounting is that this KService instance is still valid.
     QVERIFY(!QFile::exists(servPath));
 
     // Recreate it, for future tests
+    m_resourcesUpdated.clear();
     createFakeService();
     QVERIFY(QFile::exists(servPath));
     kDebug() << QThread::currentThread() << "executing kbuildsycoca (2)";
-    QProcess::execute( KGlobal::dirs()->findExe(KBUILDSYCOCA_EXENAME) );
+    QProcess::execute( KStandardDirs::findExe(KBUILDSYCOCA_EXENAME) );
     kDebug() << QThread::currentThread() << "done (2)";
-    while (spy.isEmpty())
-        QTest::qWait(50);
+    QVERIFY(QTest::kWaitForSignal(KSycoca::self(), SIGNAL(databaseChanged(QStringList)), 10000));
     kDebug() << QThread::currentThread() << "got signal ok (2)";
-    QVERIFY(spy[0][0].toStringList().contains("services"));
-    if (QThread::currentThread() != QCoreApplication::instance()->thread())
-        m_sycocaUpdateDone.ref();
+    QVERIFY(m_resourcesUpdated.contains("services"));
 }
 
 void KServiceTest::createFakeService()
@@ -549,9 +459,6 @@ void KServiceTest::createFakeService()
     group.writeEntry("MimeType", "text/plain;");
 }
 
-#include <QThreadPool>
-#include <qtconcurrentrun.h>
-
 // Testing for concurrent access to ksycoca from multiple threads
 // It's especially interesting to run this test as ./kservicetest testThreads
 // so that even the ksycoca initialization is happening from N threads at the same time.
@@ -559,30 +466,42 @@ void KServiceTest::createFakeService()
 
 void KServiceTest::testReaderThreads()
 {
-    QThreadPool::globalInstance()->setMaxThreadCount(10);
-    QList<QFuture<void> > futures;
-    futures << QtConcurrent::run(this, &KServiceTest::testAllServices);
-    futures << QtConcurrent::run(this, &KServiceTest::testAllServices);
-    futures << QtConcurrent::run(this, &KServiceTest::testAllServices);
-    futures << QtConcurrent::run(this, &KServiceTest::testHasServiceType1);
-    futures << QtConcurrent::run(this, &KServiceTest::testAllServices);
-    futures << QtConcurrent::run(this, &KServiceTest::testAllServices);
-    Q_FOREACH(QFuture<void> f, futures) // krazy:exclude=foreach
-        f.waitForFinished();
-    QThreadPool::globalInstance()->setMaxThreadCount(1); // delete those threads
+    std::future<void> future1 = std::async(std::launch::async, &KServiceTest::testAllServices, this);
+    std::future<void> future2 = std::async(std::launch::async, &KServiceTest::testAllServices, this);
+    std::future<void> future3 = std::async(std::launch::async, &KServiceTest::testAllServices, this);
+    std::future<void> future4 = std::async(std::launch::async, &KServiceTest::testHasServiceType1, this);
+    std::future<void> future5 = std::async(std::launch::async, &KServiceTest::testAllServices, this);
+    std::future<void> future6 = std::async(std::launch::async, &KServiceTest::testAllServices, this);
+    kDebug() << "Joining all threads";
+    future1.wait();
+    future2.wait();
+    future3.wait();
+    future4.wait();
+    future5.wait();
+    future6.wait();
 }
 
 void KServiceTest::testThreads()
 {
-    QThreadPool::globalInstance()->setMaxThreadCount(10);
-    QList<QFuture<void> > futures;
-    futures << QtConcurrent::run(this, &KServiceTest::testAllServices);
-    futures << QtConcurrent::run(this, &KServiceTest::testHasServiceType1);
-    futures << QtConcurrent::run(this, &KServiceTest::testKSycocaUpdate);
-    futures << QtConcurrent::run(this, &KServiceTest::testTraderConstraints);
-    while (m_sycocaUpdateDone == 0) // not using a bool, just to silence helgrind
+    std::future<void> future1 = std::async(std::launch::async, &KServiceTest::testAllServices, this);
+    std::future<void> future2 = std::async(std::launch::async, &KServiceTest::testHasServiceType1, this);
+    std::future<void> future3 = std::async(std::launch::async, &KServiceTest::testKSycocaUpdate, this);
+    std::future<void> future4 = std::async(std::launch::async, &KServiceTest::testTraderConstraints, this);
+    while (future3.wait_for(std::chrono::milliseconds(100)) == std::future_status::timeout) {
         QTest::qWait(100); // process D-Bus events!
+        kDebug() << "Waiting";
+    }
     kDebug() << "Joining all threads";
-    Q_FOREACH(QFuture<void> f, futures) // krazy:exclude=foreach
-        f.waitForFinished();
+    future1.wait();
+    future2.wait();
+    future3.wait();
+    future4.wait();
 }
+
+void KServiceTest::slotDBUpdate(const QStringList &resources)
+{
+    // qDebug() << Q_FUNC_INFO << resources;
+    m_resourcesUpdated = resources;
+}
+
+#include "moc_kservicetest.cpp"
