@@ -32,13 +32,38 @@ class KShellTest : public QObject
     Q_OBJECT
 
   private Q_SLOTS:
+    void envExpand();
     void tildeExpand();
     void quoteArg();
     void joinArgs();
     void splitJoin();
+    void quoteSplit();
+    void quoteSplit_data();
     void abortOnMeta();
 };
 
+void
+KShellTest::envExpand()
+{
+    QString me(KUser().loginName());
+    QCOMPARE(KShell::envExpand("$HOME"), QDir::homePath());
+    QCOMPARE(KShell::envExpand("${HOME}"), QDir::homePath());
+    QCOMPARE(KShell::envExpand("\\$HOME"), QString("\\$HOME"));
+    QCOMPARE(KShell::envExpand("$HOME/dir"), QString(QDir::homePath()+"/dir"));
+    QCOMPARE(KShell::envExpand("${HOME}/dir"), QString(QDir::homePath()+"/dir"));
+    QCOMPARE(KShell::envExpand("\\${HOME}/dir"), QString("\\${HOME}/dir"));
+    QCOMPARE(KShell::envExpand("$LOGNAME"), me); 
+    QCOMPARE(KShell::envExpand("${LOGNAME}"), me);
+    QCOMPARE(KShell::envExpand("$HOME/$LOGNAME"), QString(QDir::homePath()+"/" + me));
+    QCOMPARE(KShell::envExpand("\\$HOME/$LOGNAME"), QString("\\$HOME/" + me));
+    QCOMPARE(KShell::envExpand("$HOME/\\$LOGNAME"), QString(QDir::homePath()+"/\\$LOGNAME"));
+    QCOMPARE(KShell::envExpand("${HOME}/${LOGNAME}"), QString(QDir::homePath()+"/" + me));
+    QCOMPARE(KShell::envExpand("\\${HOME}/${LOGNAME}"), QString("\\${HOME}/" + me));
+    QCOMPARE(KShell::envExpand("${HOME}/\\${LOGNAME}"), QString(QDir::homePath()+"/\\${LOGNAME}"));
+
+    QCOMPARE(KShell::envExpand("$(hostname)"), QString("$(hostname)"));
+}
+
 void
 KShellTest::tildeExpand()
 {
@@ -47,30 +72,13 @@ KShellTest::tildeExpand()
     QCOMPARE(KShell::tildeExpand("~/dir"), QString(QDir::homePath()+"/dir"));
     QCOMPARE(KShell::tildeExpand('~' + me), QDir::homePath());
     QCOMPARE(KShell::tildeExpand('~' + me + "/dir"), QString(QDir::homePath()+"/dir"));
-#ifdef Q_OS_WIN
-    QCOMPARE(KShell::tildeExpand("^~" + me), QString('~' + me));
-#else
     QCOMPARE(KShell::tildeExpand("\\~" + me), QString('~' + me));
-#endif
 }
 
 void
 KShellTest::quoteArg()
 {
-#ifdef Q_OS_WIN
-    QCOMPARE(KShell::quoteArg("a space"), QString("\"a space\""));
-    QCOMPARE(KShell::quoteArg("fds\\\""), QString("fds\\\\\\^\""));
-    QCOMPARE(KShell::quoteArg("\\\\foo"), QString("\\\\foo"));
-    QCOMPARE(KShell::quoteArg("\"asdf\""), QString("\\^\"asdf\\^\""));
-    QCOMPARE(KShell::quoteArg("with\\"), QString("\"with\\\\\""));
-    QCOMPARE(KShell::quoteArg("\\\\"), QString("\"\\\\\\\\\""));
-    QCOMPARE(KShell::quoteArg("\"a space\\\""), QString("\\^\"\"a space\"\\\\\\^\""));
-    QCOMPARE(KShell::quoteArg("as df\\"), QString("\"as df\\\\\""));
-    QCOMPARE(KShell::quoteArg("foo bar\"\\\"bla"), QString("\"foo bar\"\\^\"\\\\\\^\"\"bla\""));
-    QCOMPARE(KShell::quoteArg("a % space"), QString("\"a %PERCENT_SIGN% space\""));
-#else
     QCOMPARE(KShell::quoteArg("a space"), QString("'a space'"));
-#endif
 }
 
 void
@@ -91,39 +99,6 @@ KShellTest::splitJoin()
 {
     KShell::Errors err = KShell::NoError;
 
-#ifdef Q_OS_WIN
-    QCOMPARE(sj("\"(sulli)\" text", KShell::NoOptions, &err),
-             QString("\"(sulli)\" text"));
-    QVERIFY(err == KShell::NoError);
-
-    QCOMPARE(sj(" ha\\ lo ", KShell::NoOptions, &err),
-             QString("\"ha\\\\\" lo"));
-    QVERIFY(err == KShell::NoError);
-
-    QCOMPARE(sj("say \" error", KShell::NoOptions, &err),
-             QString());
-    QVERIFY(err == KShell::BadQuoting);
-
-    QCOMPARE(sj("no \" error\"", KShell::NoOptions, &err),
-             QString("no \" error\""));
-    QVERIFY(err == KShell::NoError);
-
-    QCOMPARE(sj("say \" still error", KShell::NoOptions, &err),
-             QString());
-    QVERIFY(err == KShell::BadQuoting);
-
-    QCOMPARE(sj("BLA;asdf sdfess d", KShell::NoOptions, &err),
-             QString("\"BLA;asdf\" sdfess d"));
-    QVERIFY(err == KShell::NoError);
-
-    QCOMPARE(sj("B\"L\"A&sdf FOO|bar sdf wer ", KShell::NoOptions, &err),
-             QString("\"BLA&sdf\" \"FOO|bar\" sdf wer"));
-    QVERIFY(err == KShell::NoError);
-
-    QCOMPARE(sj("\"\"\"just \"\" fine\"\"\"", KShell::NoOptions, &err),
-             QString("\\^\"\"just \"\\^\"\" fine\"\\^\""));
-    QVERIFY(err == KShell::NoError);
-#else
     QCOMPARE(sj("\"~qU4rK\" 'text' 'jo'\"jo\" $'crap' $'\\\\\\'\\e\\x21' ha\\ lo \\a", KShell::NoOptions, &err),
              QString("'~qU4rK' text jojo crap '\\'\\''\x1b!' 'ha lo' a"));
     QVERIFY(err == KShell::NoError);
@@ -151,7 +126,26 @@ KShellTest::splitJoin()
     QCOMPARE(sj("~qU4rK ~" + KUser().loginName(), KShell::TildeExpand, &err),
              QString("'~qU4rK' " + QDir::homePath()));
     QVERIFY(err == KShell::NoError);
-#endif
+}
+
+void
+KShellTest::quoteSplit_data()
+{
+    QTest::addColumn<QString>("string");
+
+    QTest::newRow("no space") << QString("hiho");
+    QTest::newRow("regular space") << QString("hi there");
+    QTest::newRow("special space") << QString::fromUtf8("如何定期清潔典型的電風扇　講義.pdf");
+}
+
+void
+KShellTest::quoteSplit()
+{
+    QFETCH(QString, string);
+
+    // Splitting a quote arg should always just return one argument
+    const QStringList args = KShell::splitArgs(KShell::quoteArg(string));
+    QCOMPARE(args.count(), 1);
 }
 
 void
@@ -163,33 +157,6 @@ KShellTest::abortOnMeta()
              QString("text"));
     QVERIFY(err1 == KShell::NoError);
 
-#ifdef Q_OS_WIN
-    QVERIFY(KShell::splitArgs("BLA & asdf sdfess d", KShell::AbortOnMeta, &err1).isEmpty());
-    QVERIFY(err1 == KShell::FoundMeta);
-
-    QVERIFY(KShell::splitArgs("foo %PATH% bar", KShell::AbortOnMeta, &err1).isEmpty());
-    QVERIFY(err1 == KShell::FoundMeta);
-
-    QCOMPARE(sj("foo %PERCENT_SIGN% bar", KShell::AbortOnMeta, &err1),
-             QString("foo %PERCENT_SIGN% bar"));
-    QVERIFY(err1 == KShell::NoError);
-
-    QCOMPARE(sj("@foo ^& bar", KShell::AbortOnMeta, &err1),
-             QString("foo \"&\" bar"));
-    QVERIFY(err1 == KShell::NoError);
-
-    QCOMPARE(sj("\"BLA|asdf\" sdfess d", KShell::AbortOnMeta, &err1),
-             QString("\"BLA|asdf\" sdfess d"));
-    QVERIFY(err1 == KShell::NoError);
-
-    QCOMPARE(sj("B\"L\"A\"|\"sdf \"FOO | bar\" sdf wer", KShell::AbortOnMeta, &err1),
-             QString("\"BLA|sdf\" \"FOO | bar\" sdf wer"));
-    QVERIFY(err1 == KShell::NoError);
-
-    QCOMPARE(sj("b-q me \\\\^|\\\\\\^\"", KShell::AbortOnMeta, &err1),
-             QString("b-q me \"\\\\|\"\\\\\\^\""));
-    QVERIFY(err1 == KShell::NoError);
-#else
     QCOMPARE(sj("say \" error", KShell::NoOptions, &err1),
              QString());
     QVERIFY(err1 != KShell::NoError);
@@ -209,7 +176,6 @@ KShellTest::abortOnMeta()
     QVERIFY(sj("B\"L\"A=say FOO=bar echo meta", KShell::NoOptions, &err1) ==
             sj("B\"L\"A=say FOO=bar echo meta", KShell::AbortOnMeta, &err2));
     QVERIFY(err1 == err2);
-#endif
 }
 
 QTEST_KDEMAIN_CORE(KShellTest)
