@@ -16,31 +16,25 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include <config.h>
+#include <config-prefix.h>
 #include "kstandarddirstest.h"
-
 #include "qtest_kde.h"
-#include "kstandarddirstest.moc"
-
-QTEST_KDEMAIN_CORE( KStandarddirsTest )
-
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <ktempdir.h>
-#include <config-prefix.h>
-#include <QtCore/QDebug>
 #include <kconfiggroup.h>
-#include <config.h>
+#include <QtCore/QDebug>
+
+#include <future>
 
 // we need case-insensitive comparison of file paths on windows
-#ifdef Q_OS_WIN
-#define QCOMPARE_PATHS(x,y) QCOMPARE(QString(x).toLower(), QString(y).toLower())
-#define PATH_SENSITIVITY Qt::CaseInsensitive
-#else
 #define QCOMPARE_PATHS(x,y) QCOMPARE(QString(x), QString(y))
 #define PATH_SENSITIVITY Qt::CaseSensitive
-#endif
+
+QTEST_KDEMAIN_CORE( KStandarddirsTest )
 
 void KStandarddirsTest::initTestCase()
 {
@@ -76,7 +70,7 @@ void KStandarddirsTest::testChangeSaveLocation()
     const QString newSaveLoc = m_kdehome + "/newconfigdir/";
     //cData.dirs()->addResourceDir("config", newSaveLoc); // can't be done, absolute paths have less priority than relative paths
     cData.dirs()->addResourceType("config", 0, "newconfigdir");
-    QCOMPARE_PATHS(KStandardDirs::realPath(cData.dirs()->saveLocation("config")), newSaveLoc);
+    QCOMPARE_PATHS(KGlobal::dirs()->realPath(cData.dirs()->saveLocation("config")), newSaveLoc);
 }
 
 static bool isKdelibsInstalled()
@@ -91,21 +85,16 @@ void KStandarddirsTest::testFindResource()
     if ( !isKdelibsInstalled() )
         QSKIP( "kdelibs not installed", SkipAll );
 
-#ifdef Q_WS_WIN
-#define EXT ".exe"
-#define KIOSLAVE "bin/kioslave.exe"
-#else
 #define EXT ""
-#define KIOSLAVE "kde4/libexec/kioslave"
-#endif
+#define KIOSLAVE "/kioslave"
     const QString bin = KGlobal::dirs()->findResource( "exe", "kioslave" EXT );
     QVERIFY( !bin.isEmpty() );
     QVERIFY( bin.endsWith( KIOSLAVE ) );
     QVERIFY( !QDir::isRelativePath(bin) );
 
-    const QString data = KGlobal::dirs()->findResource( "data", "cmake/modules/FindSoprano.cmake" );
+    const QString data = KGlobal::dirs()->findResource( "data", "cmake/modules/KDE4Macros.cmake" );
     QVERIFY( !data.isEmpty() );
-    QVERIFY( data.endsWith( QLatin1String("share/apps/cmake/modules/FindSoprano.cmake") ) );
+    QVERIFY( data.endsWith( QLatin1String("share/apps/cmake/modules/KDE4Macros.cmake") ) );
     QVERIFY( !QDir::isRelativePath(data) );
 }
 
@@ -125,7 +114,7 @@ void KStandarddirsTest::testFindAllResources()
 
     const QStringList cmakeModulesFiles = KGlobal::dirs()->findAllResources( "data", "cmake/modules/" );
     QVERIFY( !cmakeModulesFiles.isEmpty() );
-    QVERIFY( cmakeModulesFiles.count() > 80 ); // I have 150 here, installed by kdelibs.
+    QVERIFY( cmakeModulesFiles.count() > 40 ); // I have 79 here, installed by kdelibs.
 
     // Create a local config file, the file will be used as expected result
     const QString localConfigFile = m_kdehome + "/share/config/foorc";
@@ -168,18 +157,6 @@ void KStandarddirsTest::testFindAllResources()
     QVERIFY( !oneEndsWith( configFilesWithFilter, "share/config/accept-languages.codes" ) ); // didn't match the filter
     QCOMPARE(fileNames.count(), configFilesWithFilter.count());
     QVERIFY(fileNames.contains("kdebugrc"));
-
-#if 0
-    list = t.findAllResources("html", "en/*/index.html", false);
-    for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-        kDebug() << "docs " << (*it).toLatin1().constData();
-    }
-
-    list = t.findAllResources("html", "*/*/*.html", false);
-    for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-        kDebug() << "docs " << (*it).toLatin1().constData();
-    }
-#endif
 }
 
 void KStandarddirsTest::testFindAllResourcesNewDir()
@@ -205,8 +182,8 @@ void KStandarddirsTest::testFindDirs()
     if ( !isKdelibsInstalled() )
         QSKIP( "kdelibs not installed", SkipAll );
 
-    const QString t = KStandardDirs::locateLocal("data", "kconf_update/" );
-    const QStringList dirs = KGlobal::dirs()->findDirs( "data", "kconf_update" );
+    const QString t = KStandardDirs::locateLocal("data", "LICENSES/" );
+    const QStringList dirs = KGlobal::dirs()->findDirs( "data", "LICENSES" );
     QVERIFY( !dirs.isEmpty() );
     QVERIFY( dirs.count() >= 2 ); // at least local and global
     //qDebug() << dirs;
@@ -230,30 +207,21 @@ void KStandarddirsTest::testFindExe()
     // findExe with a result in bin
     const QString kdeinit = KGlobal::dirs()->findExe( "kdeinit4" );
     QVERIFY( !kdeinit.isEmpty() );
-#ifdef Q_OS_MAC
-    QVERIFY2(kdeinit.endsWith("kdeinit4", PATH_SENSITIVITY), qPrintable(kdeinit));
-#else
     QVERIFY2(kdeinit.endsWith("bin/kdeinit4" EXT, PATH_SENSITIVITY), qPrintable(kdeinit));
-#endif
 
+    // Check the "exe" resource too
+    QString kdeinitexe = KGlobal::dirs()->locate( "exe", "kdeinit4" );
+    QVERIFY2(kdeinitexe.endsWith("bin/kdeinit4" EXT, PATH_SENSITIVITY), qPrintable(kdeinit));
 
 #ifdef Q_OS_UNIX
     // findExe with a result in libexec
-    const QString lnusertemp = KGlobal::dirs()->findExe( "lnusertemp" );
-    QVERIFY( !lnusertemp.isEmpty() );
-    QVERIFY( lnusertemp.endsWith( "lib" KDELIBSUFF "/kde4/libexec/lnusertemp" EXT, PATH_SENSITIVITY ) );
-#endif
+    const QString klauncher = KGlobal::dirs()->findExe( "klauncher" );
+    QVERIFY( !klauncher.isEmpty() );
+    QVERIFY( klauncher.endsWith("/klauncher" EXT, PATH_SENSITIVITY ) );
 
-#ifndef Q_OS_MAC // kdeinit4 is a bundle on Mac, so the below doesn't work
-    // Check the "exe" resource too
-    QString kdeinitPath1 = KGlobal::dirs()->realFilePath(kdeinit);
-    QString kdeinitPath2 = KGlobal::dirs()->locate( "exe", "kdeinit4" );
-    QCOMPARE_PATHS( kdeinitPath1, kdeinitPath2 );
-#endif
-
-#ifdef Q_OS_UNIX
-    QCOMPARE_PATHS( KGlobal::dirs()->realFilePath(lnusertemp),
-              KGlobal::dirs()->locate( "exe", "lnusertemp" ) );
+    // locate("exe") with a result in libexec
+    const QString locateExeResult = KGlobal::dirs()->locate("exe", "klauncher");
+    QVERIFY(locateExeResult.endsWith("/klauncher" EXT, PATH_SENSITIVITY));
 
     // findExe with relative path
     const QString pwd = QDir::currentPath();
@@ -322,19 +290,19 @@ void KStandarddirsTest::testAddResourceType()
     QString ret = KStandardDirs::locate( "dtd", "customization/catalog.xml" );
     QCOMPARE(ret, QString()); // normal, there's no "dtd" resource in kstandarddirs by default
 
-    KGlobal::dirs()->addResourceType("dtd", "data", "ksgmltools2/");
-    ret = KStandardDirs::locate( "dtd", "customization/catalog.xml" );
+    KGlobal::dirs()->addResourceType("dtd", "data", "kdewidgets/");
+    ret = KStandardDirs::locate( "dtd", "pics/kpushbutton.png" );
     QVERIFY(!ret.isEmpty());
 
-    ret = KStandardDirs::locate("dtd", "customization/kde-chunk.xsl");
+    ret = KStandardDirs::locate("dtd", "pics/kruler.png");
     QVERIFY(!ret.isEmpty());
 
-    const QStringList files = KGlobal::dirs()->findAllResources("dtd", "customization/*", KStandardDirs::NoDuplicates);
-    QVERIFY(files.count() > 2);
+    const QStringList files = KGlobal::dirs()->findAllResources("dtd", "pics/*", KStandardDirs::NoDuplicates);
+    QVERIFY(files.count() >= 5);
 
     KGlobal::dirs()->addResourceType("xdgdata-ontology", 0, "ontology");
     const QStringList ontologyDirs = KGlobal::dirs()->resourceDirs("xdgdata-ontology");
-    QCOMPARE(ontologyDirs.first(), KStandardDirs::realPath(QString(qgetenv("XDG_DATA_HOME")) + "/ontology/"));
+    QCOMPARE(ontologyDirs.first(), KGlobal::dirs()->realPath(QString(qgetenv("XDG_DATA_HOME")) + "/ontology/"));
     if (QFile::exists("/usr/share/ontology") &&
         KGlobal::dirs()->kfsstnd_xdg_data_prefixes().contains("/usr/share")) {
         QVERIFY(ontologyDirs.contains("/usr/share/ontology/"));
@@ -350,14 +318,14 @@ void KStandarddirsTest::testAddResourceDir()
 
     KGlobal::dirs()->addResourceDir("here", dir);
     ret = KStandardDirs::locate( "here", file );
-    QCOMPARE_PATHS(ret, KStandardDirs::realPath(dir) + "Cairo");
+    QCOMPARE_PATHS(ret, KGlobal::dirs()->realPath(dir) + "Cairo");
 }
 
 void KStandarddirsTest::testSetXdgDataDirs()
 {
     // By default we should have KDEDIR/share/applications in `kde4-config --path xdgdata-apps`
     const QStringList dirs = KGlobal::dirs()->resourceDirs("xdgdata-apps");
-    const QString kdeDataApps = KStandardDirs::realPath(KDEDIR "/share/applications/");
+    const QString kdeDataApps = KGlobal::dirs()->realPath(KDEDIR "/share/applications/");
     if (!dirs.contains(kdeDataApps)) {
         kDebug() << "ERROR:" << kdeDataApps << "not in" << dirs;
         kDebug() << "XDG_DATA_DIRS=" << qgetenv("XDG_DATA_DIRS");
@@ -377,61 +345,8 @@ void KStandarddirsTest::testSetXdgDataDirs()
     QVERIFY(newDirs.contains(localApps, PATH_SENSITIVITY));
 }
 
-void KStandarddirsTest::testRestrictedResources()
-{
-    // Ensure we have a local xdgdata-apps dir
-    QFile localFile(KStandardDirs::locateLocal("xdgdata-apps", "foo.desktop"));
-    localFile.open(QIODevice::WriteOnly|QIODevice::Text);
-    localFile.write("foo");
-    localFile.close();
-    const QString localAppsDir = KStandardDirs::realPath(QFileInfo(localFile).absolutePath() + '/');
-    QVERIFY(!localAppsDir.contains("foo.desktop"));
-    // Ensure we have a local share/apps/qttest dir
-    const QString localDataDir = KStandardDirs::locateLocal("data", "qttest/");
-    QVERIFY(!localDataDir.isEmpty());
-    QVERIFY(QFile::exists(localDataDir));
-    const QString localOtherDataDir = KStandardDirs::locateLocal("data", "other/");
-    QVERIFY(!localOtherDataDir.isEmpty());
-
-    // Check unrestricted results first
-    const QStringList appsDirs = KGlobal::dirs()->resourceDirs("xdgdata-apps");
-    const QString kdeDataApps = KStandardDirs::realPath(KDEDIR "/share/applications/");
-    QCOMPARE_PATHS(appsDirs.first(), localAppsDir);
-    QVERIFY(appsDirs.contains(kdeDataApps, PATH_SENSITIVITY));
-    const QStringList dataDirs = KGlobal::dirs()->findDirs("data", "qttest");
-    QCOMPARE_PATHS(dataDirs.first(), localDataDir);
-    const QStringList otherDataDirs = KGlobal::dirs()->findDirs("data", "other");
-    QCOMPARE_PATHS(otherDataDirs.first(), localOtherDataDir);
-
-    // Initialize restrictions.
-    // Need a new componentdata to trigger restricted-resource initialization
-    // And we need to write the config _before_ creating the KComponentData.
-    KConfig foorc("foorc");
-    KConfigGroup restrictionsGroup(&foorc, "KDE Resource Restrictions");
-    restrictionsGroup.writeEntry("xdgdata-apps", false);
-    restrictionsGroup.writeEntry("data_qttest", false);
-    restrictionsGroup.sync();
-
-    // Check restrictions.
-    KComponentData cData("foo");
-    QVERIFY(cData.dirs()->isRestrictedResource("xdgdata-apps"));
-    QVERIFY(cData.dirs()->isRestrictedResource("data", "qttest"));
-
-    const QStringList newAppsDirs = cData.dirs()->resourceDirs("xdgdata-apps");
-    QVERIFY(newAppsDirs.contains(kdeDataApps, PATH_SENSITIVITY));
-    QVERIFY(!newAppsDirs.contains(localAppsDir, PATH_SENSITIVITY)); // restricted!
-    const QStringList newDataDirs = cData.dirs()->findDirs("data", "qttest");
-    QVERIFY(!newDataDirs.contains(localDataDir, PATH_SENSITIVITY)); // restricted!
-    const QStringList newOtherDataDirs = cData.dirs()->findDirs("data", "other");
-    QVERIFY(newOtherDataDirs.contains(localOtherDataDir, PATH_SENSITIVITY)); // not restricted!
-
-    restrictionsGroup.deleteGroup();
-    localFile.remove();
-}
-
 void KStandarddirsTest::testSymlinkResolution()
 {
-#ifndef Q_OS_WIN
     // This makes the save location for the david resource, "$HOME/.kde-unit-test/symlink/test/"
     // where symlink points to "real", and the subdir test will be created later
     // This used to confuse KStandardDirs and make it return unresolved paths,
@@ -452,7 +367,7 @@ void KStandarddirsTest::testSymlinkResolution()
     // The issue at this point is that saveLoc does not actually exist yet.
     QVERIFY(QDir(saveLoc).canonicalPath().isEmpty()); // this is why we can't use canonicalPath
     QVERIFY(!QFile::exists(saveLoc));
-    QCOMPARE(saveLoc, KStandardDirs::realPath(saveLoc)); // must be resolved
+    QCOMPARE(saveLoc, KGlobal::dirs()->realPath(saveLoc)); // must be resolved
     QCOMPARE(saveLoc, expected);
     QVERIFY(QDir(m_kdehome).mkpath("real/test")); // KConfig calls mkdir on its own, we simulate that here
     const QString sameSaveLoc = KGlobal::dirs()->resourceDirs("david").first();
@@ -460,28 +375,30 @@ void KStandarddirsTest::testSymlinkResolution()
     QCOMPARE(sameSaveLoc, KGlobal::dirs()->saveLocation("david"));
 
     // While we're here...
-    QCOMPARE(KStandardDirs::realPath(QString()), QString());
-    QCOMPARE(KStandardDirs::realPath(QString("/")), QString("/"));
+    QCOMPARE(KGlobal::dirs()->realPath(QString()), QString());
+    QCOMPARE(KGlobal::dirs()->realPath(QString("/")), QString("/"));
 
-    QCOMPARE(KStandardDirs::realPath(QString("/does_not_exist/")), QString("/does_not_exist/"));
-#endif
+    QCOMPARE(KGlobal::dirs()->realPath(QString("/does_not_exist/")), QString("/does_not_exist/"));
 }
 
-#include <QThreadPool>
-#include <qtconcurrentrun.h>
-
 // To find multithreading bugs: valgrind --tool=helgrind ./kstandarddirstest testThreads
 void KStandarddirsTest::testThreads()
 {
-    QThreadPool::globalInstance()->setMaxThreadCount(6);
-    QList<QFuture<void> > futures;
-    futures << QtConcurrent::run(this, &KStandarddirsTest::testLocateLocal);
-    futures << QtConcurrent::run(this, &KStandarddirsTest::testSaveLocation);
-    futures << QtConcurrent::run(this, &KStandarddirsTest::testAppData);
-    futures << QtConcurrent::run(this, &KStandarddirsTest::testFindResource);
-    futures << QtConcurrent::run(this, &KStandarddirsTest::testFindAllResources);
-    futures << QtConcurrent::run(this, &KStandarddirsTest::testLocate);
-    futures << QtConcurrent::run(this, &KStandarddirsTest::testRelativeLocation);
-    Q_FOREACH(QFuture<void> f, futures) // krazy:exclude=foreach
-        f.waitForFinished();
+    std::future<void> future1 = std::async(std::launch::async, &KStandarddirsTest::testLocateLocal, this);
+    std::future<void> future2 = std::async(std::launch::async, &KStandarddirsTest::testSaveLocation, this);
+    std::future<void> future3 = std::async(std::launch::async, &KStandarddirsTest::testAppData, this);
+    std::future<void> future4 = std::async(std::launch::async, &KStandarddirsTest::testFindResource, this);
+    std::future<void> future5 = std::async(std::launch::async, &KStandarddirsTest::testFindAllResources, this);
+    std::future<void> future6 = std::async(std::launch::async, &KStandarddirsTest::testLocate, this);
+    std::future<void> future7 = std::async(std::launch::async, &KStandarddirsTest::testRelativeLocation, this);
+    kDebug() << "Joining all threads";
+    future1.wait();
+    future2.wait();
+    future3.wait();
+    future4.wait();
+    future5.wait();
+    future6.wait();
+    future7.wait();
 }
+
+#include "moc_kstandarddirstest.cpp"
\ No newline at end of file
