@@ -12,7 +12,8 @@ private Q_SLOTS:
     void tagURLs();
     void perlSplit();
     void naturalCompare();
-    void obscure();
+    void preProcessWrap_data();
+    void preProcessWrap();
 
 private:
     static QString test;
