@@ -22,7 +22,7 @@
 #include "kurltest.h"
 
 #include "qtest_kde.h"
-#include "kurltest.moc"
+#include "moc_kurltest.cpp"
 
 QTEST_KDEMAIN_CORE( KUrlTest )
 
@@ -34,12 +34,14 @@ QTEST_KDEMAIN_CORE( KUrlTest )
 #include <kglobal.h>
 #include <kcharsets.h>
 #include <kuser.h>
-#include <QtCore/QTextCodec>
-#include <QtCore/QDataStream>
-#include <QtCore/QMap>
+#include <qtextcodec.h>
+#include <qdatastream.h>
+#include <qmimedata.h>
+#include <qmap.h>
+#include <qhostinfo.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h> // gethostname
+#include <ctype.h>
 
 //QCOMPARE cannot be used to strictly check for empty or null QString as it treats QString("") == QString()
 #define QSTREMPTY(_str) QVERIFY(!_str.isNull() && _str.isEmpty())
@@ -182,10 +184,6 @@ void KUrlTest::testQUrl()
 {
   QUrl url1( "file:///home/dfaure/my#%2f" );
   QCOMPARE( url1.toString(), QString( "file:///home/dfaure/my#%2f" ) );
-#ifdef Q_WS_WIN
-  QUrl url2( "file:///c:/home/dfaure/my#%2f" );
-  QCOMPARE( url2.toString(), QString( "file:///c:/home/dfaure/my#%2f" ) );
-#endif
 
   // Show how toString() is confusing
   QUrl url3 = QUrl::fromLocalFile( "/home/dfaure/hash#file" );
@@ -210,16 +208,8 @@ void KUrlTest::testIsLocalFile()
   QVERIFY( !local_file_2.isLocalFile() );
 
   // exactly like in kurl.cpp, getenv("HOSTNAME") can be different...
-  char hostname[ 256 ];
-  hostname[ 0 ] = '\0';
-  if (!gethostname( hostname, 255 ))
-     hostname[sizeof(hostname)-1] = '\0';
-
-  for(char *p = hostname; *p; p++)
-     *p = tolower(*p);
-
   KUrl local_file_3;
-  local_file_3.setHost(QString::fromLatin1(hostname));
+  local_file_3.setHost(QHostInfo::localHostName().toLower());
   local_file_3.setPath("/my/file");
   //qDebug("URL=%s\n", qPrintable( local_file_3.url() ));
   QVERIFY( local_file_3.isLocalFile() );
@@ -227,20 +217,11 @@ void KUrlTest::testIsLocalFile()
   KUrl local_file_4("file:///my/file");
   QVERIFY( local_file_4.isLocalFile() );
 
-#ifdef Q_WS_WIN
-  KUrl local_file_4a("file:///c:/my/file");
-  QVERIFY( local_file_4a.isLocalFile() );
-#endif
 
   KUrl local_file_5;
   local_file_5.setPath("/foo?bar");
   QCOMPARE( local_file_5.url(), QString("file:///foo%3Fbar") );
 
-#ifdef Q_WS_WIN
-  KUrl local_file_5a;
-  local_file_5a.setPath("c:/foo?bar");
-  QCOMPARE( local_file_5a.url(), QString("file:///c:/foo%3Fbar") );
-#endif
 
   KUrl scummos("inf://localhost/test.txt");
   QVERIFY(!scummos.isLocalFile());
@@ -313,12 +294,7 @@ void KUrlTest::testSimpleMethods() // to test parsing, mostly
 
   u1 = "file:///home/dfaure/my#%2f";
   url1 = u1;
-  // KDE3: was %2f, Qt-4.0 to 4.4: #/, bad. 4.5: %2f again, good
-#if QT_VERSION < 0x040500
-  QCOMPARE( url1.url(), QString("file:///home/dfaure/my#/") );
-#else
   QCOMPARE( url1.url(), QString("file:///home/dfaure/my#%2f") );
-#endif
   QVERIFY( url1.hasRef() );
   QVERIFY( url1.hasHTMLRef() );
   QVERIFY( !url1.hasSubUrl() );
@@ -417,13 +393,6 @@ void KUrlTest::testSimpleMethods() // to test parsing, mostly
   KUrl percentEncodedQuery( "http://mail.yandex.ru/message_part/%D0%9A%D1%80%D0%B8%D1%82%D0%B5%D1%80%D0%B8%D0%B8%20%D0%BE%D1%86%D0%B5%D0%BD%D0%B8%D0%B2%D0%B0%D0%BD%D0%B8%D1%8F%20%D0%BE%D1%80%D0%BB%D0%BE%D0%B2%D0%BE%D0%B9.rar?hid=1.1&mid=391.56424458.99241672611486679803334485488&name=%D0%9A%D1%80%D0%B8%D1%82%D0%B5%D1%80%D0%B8%D0%B8%20%D0%BE%D1%86%D0%B5%D0%BD%D0%B8%D0%B2%D0%B0%D0%BD%D0%B8%D1%8F%20%D0%BE%D1%80%D0%BB%D0%BE%D0%B2%D0%BE%D0%B9.rar" );
   QCOMPARE( percentEncodedQuery.prettyUrl(), QString::fromUtf8("http://mail.yandex.ru/message_part/Критерии оценивания орловой.rar?hid=1.1&mid=391.56424458.99241672611486679803334485488&name=%D0%9A%D1%80%D0%B8%D1%82%D0%B5%D1%80%D0%B8%D0%B8%20%D0%BE%D1%86%D0%B5%D0%BD%D0%B8%D0%B2%D0%B0%D0%BD%D0%B8%D1%8F%20%D0%BE%D1%80%D0%BB%D0%BE%D0%B2%D0%BE%D0%B9.rar"));
 
-#ifdef Q_WS_WIN
-#ifdef Q_CC_MSVC
-#pragma message ("port KUser")
-#else
-#warning port KUser
-#endif
-#else
   KUrl tilde;
   KUser currentUser;
   const QString userName = currentUser.loginName();
@@ -434,7 +403,6 @@ void KUrlTest::testSimpleMethods() // to test parsing, mostly
   tilde = KUrl("http://foo.bar/index.html");
   tilde.setPath( "~slajsjdlsjd/test.html" );
   QCOMPARE( tilde.url(), QString("http://foo.bar/~slajsjdlsjd/test.html"));
-#endif
 }
 
 void KUrlTest::testHostName()
@@ -739,14 +707,9 @@ void KUrlTest::testSetFileName() // and addPath
   QCOMPARE( singleFile.path(), QString("foo.txt") );
   QCOMPARE( singleFile.pathOrUrl(), QString("foo.txt") );
 
-  QString pre;
-#ifdef Q_OS_WIN
-  // On Windows we explicitly prepend a slash, see KUrl::setPath
-  pre = '/';
-#endif
   singleFile.setFileName( "bar.bin" );
-  QCOMPARE( singleFile.path(), QString(pre + "bar.bin") );
-  QCOMPARE( singleFile.pathOrUrl(), QString(pre + "bar.bin") );
+  QCOMPARE( singleFile.path(), QString("bar.bin") );
+  QCOMPARE( singleFile.pathOrUrl(), QString("bar.bin") );
 }
 
 void KUrlTest::testDirectory()
@@ -868,8 +831,6 @@ void KUrlTest::testIsRelative()
   // arguable, but necessary for KUrl( baseURL, "//www1.foo.bar" );
   QVERIFY( KUrl::isRelativeUrl("/path") );
   QVERIFY( KUrl::isRelativeUrl("something") );
-  // scheme = alpha *( alpha | digit | "+" | "-" | "." )
-  QVERIFY(!KUrl::isRelativeUrl(QString("abc.123+-xyz://foobar")));
 
   KUrl something("something");
   QCOMPARE(something.url(), QString("something"));
@@ -1001,11 +962,7 @@ void KUrlTest::testAdjustPath()
 
     {
     KUrl remote2("remote://");
-#if QT_VERSION < 0x040805
-    QCOMPARE( remote2.url(), QString("remote:") ); // QUrl bug, fixed in Qt 4.8.5 and Qt5
-#else
     QCOMPARE( remote2.url(), QString("remote://") );
-#endif
     QCOMPARE( remote2.url(KUrl::RemoveTrailingSlash ), QString("remote:") ); // QUrl bug, fixed in Qt5
     QCOMPARE( remote2.prettyUrl(), QString("remote://") );
     }
@@ -1276,8 +1233,6 @@ void KUrlTest::testBaseURL() // those are tests for the KUrl(base,relative) cons
   KUrl flashBase("http://www.youtube.com/?v=JvOSnRD5aNk");
   KUrl flashComposed(flashBase, flashRel);
   QCOMPARE(flashComposed.url(), QString("javascript:window.location+%22__flashplugin_unique__%22"));
-
-  QCOMPARE(KUrl(KUrl("data:text/plain, main"), "data:text/plain, subpage").url(), QString("data:text/plain,%20subpage"));
 }
 
 void KUrlTest::testSetEncodedFragment_data()
@@ -1295,11 +1250,6 @@ void KUrlTest::testSetEncodedFragment_data()
 
 void KUrlTest::testSetEncodedFragment()
 {
-    // Bug fixed in 4.5.1 by Thiago
-#if QT_VERSION < 0x040501
-    QSKIP("Bug in Qt-4.4/4.5-rc1: setEncodedFragment doesn't work if the initial url has no fragment", SkipAll);
-#endif
-
     QFETCH(QByteArray, base);
     QFETCH(QByteArray, fragment);
     QFETCH(QByteArray, expected);
@@ -1316,11 +1266,7 @@ void KUrlTest::testSubURL()
   QString u1 = "file:/home/dfaure/my%20tar%20file.tgz#gzip:/#tar:/#myref";
   KUrl url1(u1);
   // KDE3: was #,#,#, Qt-4.0 to 4.4: #,%23,%23 . 4.5: #,#,#, good
-#if QT_VERSION < 0x040500
-  QCOMPARE( url1.url(), QString("file:///home/dfaure/my%20tar%20file.tgz#gzip:/%23tar:/%23myref") );
-#else
   QCOMPARE( url1.url(), QString("file:///home/dfaure/my%20tar%20file.tgz#gzip:/#tar:/#myref") );
-#endif
   QVERIFY( url1.hasRef() );
   QVERIFY( !url1.isLocalFile() );  // Not strictly local!
   QVERIFY( url1.hasSubUrl() );
@@ -1334,9 +1280,6 @@ void KUrlTest::testSubURL()
   QCOMPARE( splitList[1].url(), QString("gzip:/#myref") );
   QCOMPARE( splitList[2].url(), QString("tar:/#myref") );
 
-#if QT_VERSION < 0x040500
-  QSKIP( "Multiple sub urls not supported with Qt < 4.5", SkipSingle );
-#endif
   KUrl rejoined = KUrl::join(splitList);
   QCOMPARE(rejoined.url(), url1.url());
 
@@ -1392,10 +1335,6 @@ void KUrlTest::testSubURL()
   QCOMPARE(url1Splitted[1].url(), QString("gzip:/"));
   QCOMPARE(url1Splitted[2].url(), QString("tar:/README"));
   const KUrl url1Rejoined = KUrl::join(url1Splitted);
-  // Bug fixed in 4.5.1 by Thiago
-#if QT_VERSION < 0x040501
-  QSKIP("Bug in Qt-4.4/4.5-rc1: setEncodedFragment doesn't work if the initial url has no fragment", SkipAll);
-#endif
   QCOMPARE(url1Rejoined.url(), url1.url());
   QCOMPARE(url1.upUrl().url(), QString("file:///home/dfaure/my%20tar%20file.tgz#gzip:/#tar:/"));
 
@@ -1444,10 +1383,6 @@ void KUrlTest::testComparisons()
 
   QString ucmp1 = "ftp://ftp.de.kde.org/dir";
   QString ucmp2 = "ftp://ftp.de.kde.org/dir/";
-#ifndef KDE_NO_DEPRECATED
-  QVERIFY(!urlcmp(ucmp1, ucmp2));
-  QVERIFY(urlcmp(ucmp1, ucmp2, KUrl::CompareWithoutTrailingSlash)); //only slash difference, ignore_trailing
-#endif
 
   {
       KUrl u1(ucmp1);
@@ -1461,11 +1396,6 @@ void KUrlTest::testComparisons()
   {
       QString str1 = QString::fromLatin1( "ftp://ftp.de.kde.org" );
       QString str2 = QString::fromLatin1( "ftp://ftp.de.kde.org/" );
-#ifndef KDE_NO_DEPRECATED
-      QVERIFY(!urlcmp(str1, str2));
-      QVERIFY(!urlcmp(str1, str2, KUrl::CompareWithoutTrailingSlash)); // empty path != '/'
-      QVERIFY(urlcmp(str1, str2, KUrl::CompareWithoutTrailingSlash|KUrl::AllowEmptyPath));
-#endif
       KUrl u1(str1);
       KUrl u2(str2);
       QVERIFY(!u1.equals(u2));
@@ -1474,17 +1404,6 @@ void KUrlTest::testComparisons()
   }
 
   QString ucmp3 = "ftp://ftp.de.kde.org/dir/#";
-#ifndef KDE_NO_DEPRECATED
-  QVERIFY( !urlcmp(ucmp2,ucmp3) ); // (only hash difference)
-  QVERIFY( urlcmp(ucmp2,ucmp3,KUrl::CompareWithoutFragment) ); // (only hash difference, ignore_ref)
-  QVERIFY( urlcmp(ucmp2,ucmp3,KUrl::CompareWithoutTrailingSlash | KUrl::CompareWithoutFragment) ); // (slash and hash difference, ignore_trailing, ignore_ref)
-  QVERIFY( urlcmp("","",KUrl::CompareWithoutFragment) ); // (empty, empty)
-  QVERIFY( urlcmp("","") ); // (empty, empty)
-  QVERIFY( !urlcmp("",ucmp1) ); // (empty, not empty)
-  QVERIFY( !urlcmp("",ucmp1,KUrl::CompareWithoutFragment) ); // (empty, not empty)
-  QVERIFY( !urlcmp("file",ucmp1) ); // (malformed, not empty)
-  QVERIFY( !urlcmp("file",ucmp1,KUrl::CompareWithoutFragment) ); // (malformed, not empty)
-#endif
 
   KUrl ftpUrl( "ftp://ftp.de.kde.org" );
   QCOMPARE( ftpUrl.path(), QString());
@@ -1717,9 +1636,6 @@ void KUrlTest::testMoreBrokenStuff()
 
   QUrl dxOffEagle3;
   dxOffEagle3.setEncodedUrl( "http://something/newpage.html?[{\"foo: bar\"}]", QUrl::TolerantMode);
-#if QT_VERSION < 0x040500
-  QEXPECT_FAIL("","Issue N183630, task ID 183874; works with setUrl so we do that in _setEncodedUrl now", Continue);
-#endif
   QVERIFY(dxOffEagle3.isValid());
   QCOMPARE(dxOffEagle.toEncoded(), dxOffEagle3.toEncoded());
 
@@ -1727,9 +1643,6 @@ void KUrlTest::testMoreBrokenStuff()
   javascript.setUrl("javascript:window.location+\"__flashplugin_unique__\"", QUrl::TolerantMode);
   QVERIFY(javascript.isValid());
   javascript.setEncodedUrl("javascript:window.location+\"__flashplugin_unique__\"", QUrl::TolerantMode);
-#if QT_VERSION < 0x040500
-  QEXPECT_FAIL("","Issue N183630, task ID 183874", Continue);
-#endif
   QVERIFY(javascript.isValid());
 }
 
@@ -1794,38 +1707,30 @@ void KUrlTest::testMailto()
   QCOMPARE(urlNoPath.prettyUrl(), QString("mailto:?to=test@example.com"));
 }
 
-void KUrlTest::testSmb()
+void KUrlTest::testSftp()
 {
-  KUrl smb("smb://domain;username:password@server/share");
-  QVERIFY( smb.isValid() );
-  QCOMPARE( smb.user(), QString("domain;username") );
-  smb = "smb:/";
-  QVERIFY( smb.isValid() );
-  QCOMPARE(smb.url(), QString::fromLatin1("smb:/"));
-  QCOMPARE(smb.prettyUrl(), QString::fromLatin1("smb:/"));
-  smb = "smb://"; // KDE3: kurl.cpp rev 1.106 made it invalid. Valid again with QUrl.
-  QVERIFY( smb.isValid() );
-#if QT_VERSION < 0x040805
-  QCOMPARE(smb.url(), QString::fromLatin1("smb:")); // QUrl bug, fixed in Qt 4.8.5 and Qt5
-#else
-  QCOMPARE(smb.url(), QString::fromLatin1("smb://"));
-#endif
-  QCOMPARE(smb.prettyUrl(), QString::fromLatin1("smb://"));
-  smb = "smb://host";
-  QVERIFY( smb.isValid() );
-  QCOMPARE(smb.url(), QString::fromLatin1("smb://host"));
-  QCOMPARE(smb.prettyUrl(), QString::fromLatin1("smb://host"));
-  smb = "smb:///";
-  QVERIFY( smb.isValid() );
-#if QT_VERSION < 0x040805
-  QCOMPARE(smb.url(), QString::fromLatin1("smb:/")); // QUrl bug, fixed in Qt 4.8.5 and Qt5
-#else
-  QCOMPARE(smb.url(), QString::fromLatin1("smb:///"));
-#endif
-  QCOMPARE(smb.prettyUrl(), QString::fromLatin1("smb:/"));
+  KUrl sftp("sftp://username:password@server/share");
+  QVERIFY( sftp.isValid() );
+  QCOMPARE( sftp.user(), QString("username") );
+  sftp = "sftp:/";
+  QVERIFY( sftp.isValid() );
+  QCOMPARE(sftp.url(), QString::fromLatin1("sftp:/"));
+  QCOMPARE(sftp.prettyUrl(), QString::fromLatin1("sftp:/"));
+  sftp = "sftp://"; // KDE3: kurl.cpp rev 1.106 made it invalid. Valid again with QUrl.
+  QVERIFY( sftp.isValid() );
+  QCOMPARE(sftp.url(), QString::fromLatin1("sftp://"));
+  QCOMPARE(sftp.prettyUrl(), QString::fromLatin1("sftp://"));
+  sftp = "sftp://host";
+  QVERIFY( sftp.isValid() );
+  QCOMPARE(sftp.url(), QString::fromLatin1("sftp://host"));
+  QCOMPARE(sftp.prettyUrl(), QString::fromLatin1("sftp://host"));
+  sftp = "sftp:///";
+  QVERIFY( sftp.isValid() );
+  QCOMPARE(sftp.url(), QString::fromLatin1("sftp:///"));
+  QCOMPARE(sftp.prettyUrl(), QString::fromLatin1("sftp:/"));
 
   KUrl implicitSmb("file://host/path");
-  QVERIFY(!implicitSmb.isLocalFile()); // -> kio_file will redirect to smb (by default)
+  QVERIFY(!implicitSmb.isLocalFile()); // -> kio_file will redirect to sftp (by default)
   QCOMPARE(implicitSmb.host(), QString("host"));
 
   KUrl noImplicitSmb("//path1/path2");
@@ -1858,11 +1763,6 @@ void KUrlTest::testOtherProtocols()
   QCOMPARE( testFrag.fragment(), QString("foo") );
 
   KUrl ptal( "ptal://mlc:usb@PC_970" ); // User=mlc, password=usb, host=PC_970
-#if QT_VERSION >= 0x040600 && QT_VERSION <= 0x040602 // Hostnames with underscores were invalid in 4.6.0 to 4.6.2, then allowed again in e301c82693c33c0f96c6a756d15fe35a9d877443
-  QCOMPARE(ptal.url(), QString("ptal://mlc:usb@")); // The host "PC_970" is invalid according to STD3 validation
-  KUrl ptalSimpler("ptal://mlc:usb@pc123");
-  QCOMPARE(ptalSimpler.url(), QString("ptal://mlc:usb@pc123"));
-#else
   QUrl ptal_qurl;
   ptal_qurl.setUrl("ptal://mlc:usb@PC_970", QUrl::TolerantMode);
   QVERIFY(ptal_qurl.isValid());
@@ -1873,7 +1773,6 @@ void KUrlTest::testOtherProtocols()
   QCOMPARE( ptal.host(), QString("pc_970") );
   QCOMPARE( ptal.user(), QString("mlc") );
   QCOMPARE( ptal.pass(), QString("usb") );
-#endif
 }
 
 void KUrlTest::testUtf8()
@@ -1958,19 +1857,11 @@ void KUrlTest::testPathOrURL()
   QVERIFY( uloc.isValid() ); // KDE3: was invalid; same as above
   uloc = KUrl( "" );
   QVERIFY( !uloc.isValid() );
-#ifdef Q_WS_WIN
-#ifdef Q_CC_MSVC
-#pragma message ("port KUser")
-#else
-#warning port KUser
-#endif
-#else
   KUser currentUser;
   const QString userName = currentUser.loginName();
   QVERIFY( !userName.isEmpty() );
   uloc = KUrl(QString::fromUtf8("~%1/konqtests/Matériel").arg(userName));
   QCOMPARE( uloc.path(), QString::fromUtf8("%1/konqtests/Matériel").arg(currentUser.homeDir()) );
-#endif
 
   // pathOrUrl tests
   uloc = KUrl( "/home/dfaure/konqtests/Mat%C3%A9riel" );
@@ -2016,13 +1907,6 @@ void KUrlTest::testAssignment()
   QVERIFY( uloc.isValid() );
   uloc = KUrl( "" );
   QVERIFY( !uloc.isValid() );
-#ifdef Q_WS_WIN
-#ifdef Q_CC_MSVC
-#pragma message ("port KUser")
-#else
-#warning port KUser
-#endif
-#else
   KUser currentUser;
   const QString userName = currentUser.loginName();
   QVERIFY( !userName.isEmpty() );
@@ -2037,7 +1921,6 @@ void KUrlTest::testAssignment()
   uloc = KUrl(qurl);
   QCOMPARE( qurl.toEncoded(), uloc.toEncoded() );
   QCOMPARE( uloc.path(), QString::fromUtf8("%1/konqtests/Matériel").arg(currentUser.homeDir()) );
-#endif
 }
 
 void KUrlTest::testQueryItem()
