@@ -16,8 +16,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef kurltest_h
-#define kurltest_h
+#ifndef KURLTEST_H
+#define KURLTEST_H
 
 #include <QtCore/QObject>
 
@@ -61,7 +61,7 @@ private Q_SLOTS:
     void testBrokenStuff();
     void testMoreBrokenStuff();
     void testMailto();
-    void testSmb();
+    void testSftp();
     void testOtherProtocols();
     void testOtherEncodings();
     void testPathOrURL();
