@@ -21,13 +21,11 @@
 
 #include "kstringhandler.h"
 
-#include <stdlib.h>		// random()
-
 #include <kglobal.h>
 
 #include <QtCore/QRegExp>            // for the word ranges
-#include <QtCore/QCharRef>
-#include <QtCore/QMutableStringListIterator>
+#include <QtCore/qstring.h>
+#include <QtCore/qstringlist.h>
 
 
 
@@ -41,11 +39,11 @@ QString KStringHandler::capwords( const QString &text )
     }
 
     const QString strippedText = text.trimmed();
-    const QStringList words = capwords( strippedText.split(' '));
-
+    const QString space = QString(QLatin1Char(' '));
+    const QStringList words = capwords(strippedText.split(space));
 
     QString result = text;
-    result.replace( strippedText, words.join( " " ) );
+    result.replace(strippedText, words.join(space));
     return result;
 }
 
@@ -63,7 +61,7 @@ QString KStringHandler::lsqueeze( const QString & str, int maxlen )
 {
   if (str.length() > maxlen) {
     int part = maxlen-3;
-    return QString("..." + str.right(part));
+    return QString::fromLatin1("...") + str.right(part);
   }
   else return str;
 }
@@ -71,8 +69,8 @@ QString KStringHandler::lsqueeze( const QString & str, int maxlen )
 QString KStringHandler::csqueeze( const QString & str, int maxlen )
 {
   if (str.length() > maxlen && maxlen > 3) {
-    int part = (maxlen-3)/2;
-    return QString(str.left(part) + "..." + str.right(part));
+    const int part = (maxlen-3)/2;
+    return str.left(part) + QLatin1String("...") + str.right(part);
   }
   else return str;
 }
@@ -81,7 +79,7 @@ QString KStringHandler::rsqueeze( const QString & str, int maxlen )
 {
   if (str.length() > maxlen) {
     int part = maxlen-3;
-    return QString(str.left(part) + "...");
+    return str.left(part) + QLatin1String("...");
   }
   else return str;
 }
@@ -164,7 +162,7 @@ QStringList KStringHandler::perlSplit(const QRegExp & sep, const QString & s, in
 
 QString KStringHandler::tagUrls( const QString& text )
 {
-    /*static*/ QRegExp urlEx("(www\\.(?!\\.)|(fish|(f|ht)tp(|s))://)[\\d\\w\\./,:_~\\?=&;#@\\-\\+\\%\\$]+[\\d\\w/]");
+    /*static*/ QRegExp urlEx(QLatin1String("(www\\.(?!\\.)|(fish|(f|ht)tp(|s))://)[\\d\\w\\./,:_~\\?=&;#@\\-\\+\\%\\$]+[\\d\\w/]"));
 
     QString richText( text );
     int urlPos = 0, urlLen;
@@ -178,7 +176,7 @@ QString KStringHandler::tagUrls( const QString& text )
             continue;
         }
         // Don't use QString::arg since %01, %20, etc could be in the string
-        QString anchor = "<a href=\"" + href + "\">" + href + "</a>";
+        QString anchor = QString::fromLatin1("<a href=\"") + href + QLatin1String("\">") + href + QLatin1String("</a>");
         richText.replace( urlPos, urlLen, anchor );
 
 
@@ -187,24 +185,10 @@ QString KStringHandler::tagUrls( const QString& text )
     return richText;
 }
 
-QString KStringHandler::obscure( const QString &str )
-{
-  QString result;
-  const QChar *unicode = str.unicode();
-  for ( int i = 0; i < str.length(); ++i )
-    // yes, no typo. can't encode ' ' or '!' because
-    // they're the unicode BOM. stupid scrambling. stupid.
-    result += ( unicode[ i ].unicode() <= 0x21 ) ? unicode[ i ] :
-        QChar( 0x1001F - unicode[ i ].unicode() );
-
-  return result;
-}
-
-
 bool KStringHandler::isUtf8( const char *buf )
 {
   int i, n;
-  register unsigned char c;
+  unsigned char c;
   bool gotone = false;
 
   if (!buf)
@@ -263,8 +247,9 @@ bool KStringHandler::isUtf8( const char *buf )
       following = 4;
     } else if ((c & 0x02) == 0) {      /* 1111110x */
       following = 5;
-    } else
+    } else {
       return false;
+    }
 
       for (n = 0; n < following; ++n) {
         i++;
@@ -288,15 +273,11 @@ done:
 
 QString KStringHandler::from8Bit( const char *str )
 {
-  if (!str)
+  if (!str || !*str)
     return QString();
-  if (!*str) {
-    static const QString &emptyString = KGlobal::staticQString("");
-    return emptyString;
-  }
-  return KStringHandler::isUtf8( str ) ?
-             QString::fromUtf8( str ) :
-             QString::fromLocal8Bit( str );
+  if (KStringHandler::isUtf8( str ))
+    return QString::fromUtf8( str );
+  return QString::fromLocal8Bit( str );
 }
 
 int KStringHandler::naturalCompare(const QString &_a, const QString &_b, Qt::CaseSensitivity caseSensitivity)
@@ -385,7 +366,7 @@ int KStringHandler::naturalCompare(const QString &_a, const QString &_b, Qt::Cas
         }
 
         // now some digits follow...
-        if ((*currA == '0') || (*currB == '0')) {
+        if ((*currA == QLatin1Char('0')) || (*currB == QLatin1Char('0'))) {
             // one digit-sequence starts with 0 -> assume we are in a fraction part
             // do left aligned comparison (numbers are considered left aligned)
             while (1) {
@@ -460,6 +441,7 @@ QString KStringHandler::preProcessWrap(const QString &text)
     for (int i = 0; i < text.length(); i++) {
         const QChar c = text[i];
         bool openingParens = (c == QLatin1Char('(') || c == QLatin1Char('{') || c == QLatin1Char('['));
+        bool singleQuote = (c == QLatin1Char('\'') );
         bool closingParens = (c == QLatin1Char(')') || c == QLatin1Char('}') || c == QLatin1Char(']'));
         bool breakAfter   = (closingParens || c.isPunct() || c.isSymbol());
         bool nextIsSpace  = (i == (text.length() - 1) || text[i + 1].isSpace());
@@ -468,10 +450,14 @@ QString KStringHandler::preProcessWrap(const QString &text)
         // Provide a breaking opportunity before opening parenthesis
         if (openingParens && !prevIsSpace)
             result += zwsp;
+        
+        // Provide a word joiner before the single quote
+        if (singleQuote && !prevIsSpace)
+            result += QChar(0x2060);
 
         result += c;
 
-        if (breakAfter && !openingParens && !nextIsSpace)
+        if (breakAfter && !openingParens && !nextIsSpace && !singleQuote) 
             result += zwsp;
     }
 
