@@ -49,7 +49,7 @@ KDEDModule::~KDEDModule()
 void KDEDModule::setModuleName( const QString& name )
 {
    d->moduleName = name;
-   QDBusObjectPath realPath( QString("/modules/") + d->moduleName);
+   QDBusObjectPath realPath( QString::fromLatin1("/modules/") + d->moduleName);
 
    if (realPath.path().isEmpty())
       {
@@ -98,4 +98,4 @@ QString KDEDModule::moduleName() const
    return d->moduleName;
 }
 
-#include "kdedmodule.moc"
+#include "moc_kdedmodule.cpp"
