@@ -28,8 +28,6 @@
 
 K_GLOBAL_STATIC(QObjectCleanupHandler, factorycleanup)
 
-extern int kLibraryDebugArea();
-
 KPluginFactory::KPluginFactory(const char *componentName, const char *catalogName, QObject *parent)
     : QObject(parent), d_ptr(new KPluginFactoryPrivate)
 {
@@ -42,17 +40,6 @@ KPluginFactory::KPluginFactory(const char *componentName, const char *catalogNam
     factorycleanup->add(this);
 }
 
-#ifndef KDE_NO_DEPRECATED
-KPluginFactory::KPluginFactory(const KAboutData *aboutData, QObject *parent)
-    : QObject(parent), d_ptr(new KPluginFactoryPrivate)
-{
-    Q_D(KPluginFactory);
-    d->q_ptr = this;
-    d->componentData = KComponentData(*aboutData);
-
-    factorycleanup->add(this);
-}
-#endif
 
 KPluginFactory::KPluginFactory(const KAboutData &aboutData, QObject *parent)
     : QObject(parent), d_ptr(new KPluginFactoryPrivate)
@@ -64,15 +51,6 @@ KPluginFactory::KPluginFactory(const KAboutData &aboutData, QObject *parent)
     factorycleanup->add(this);
 }
 
-#ifndef KDE_NO_DEPRECATED
-KPluginFactory::KPluginFactory(QObject *parent)
-    : QObject(parent), d_ptr(new KPluginFactoryPrivate())
-{
-    Q_D(KPluginFactory);
-    d->q_ptr = this;
-    factorycleanup->add(this);
-}
-#endif
 
 KPluginFactory::KPluginFactory(KPluginFactoryPrivate &d, QObject *parent)
     : QObject(parent), d_ptr(&d)
@@ -106,7 +84,7 @@ void KPluginFactory::registerPlugin(const QString &keyword, const QMetaObject *m
     // we allow different interfaces to be registered without keyword
     if (!keyword.isEmpty()) {
         if (d->createInstanceHash.contains(keyword)) {
-            kFatal(kLibraryDebugArea()) << "A plugin with the keyword" << keyword << "was already registered. A keyword must be unique!";
+            kFatal() << "A plugin with the keyword" << keyword << "was already registered. A keyword must be unique!";
         }
         d->createInstanceHash.insert(keyword, KPluginFactoryPrivate::Plugin(metaObject, instanceFunction));
     } else {
@@ -117,7 +95,7 @@ void KPluginFactory::registerPlugin(const QString &keyword, const QMetaObject *m
                 for (const QMetaObject *otherSuper = plugin.first->superClass(); otherSuper;
                         otherSuper = otherSuper->superClass()) {
                     if (superClass == otherSuper) {
-                        kFatal(kLibraryDebugArea()) << "Two plugins with the same interface(" << superClass->className() << ") were registered. Use keywords to identify the plugins.";
+                        kFatal() << "Two plugins with the same interface(" << superClass->className() << ") were registered. Use keywords to identify the plugins.";
                     }
                 }
             }
@@ -128,7 +106,7 @@ void KPluginFactory::registerPlugin(const QString &keyword, const QMetaObject *m
                 for (const QMetaObject *otherSuper = metaObject->superClass(); otherSuper;
                         otherSuper = otherSuper->superClass()) {
                     if (superClass == otherSuper) {
-                        kFatal(kLibraryDebugArea()) << "Two plugins with the same interface(" << superClass->className() << ") were registered. Use keywords to identify the plugins.";
+                        kFatal() << "Two plugins with the same interface(" << superClass->className() << ") were registered. Use keywords to identify the plugins.";
                     }
                 }
             }
@@ -137,26 +115,7 @@ void KPluginFactory::registerPlugin(const QString &keyword, const QMetaObject *m
     }
 }
 
-#ifndef KDE_NO_DEPRECATED
-QObject *KPluginFactory::createObject(QObject *parent, const char *className, const QStringList &args)
-{
-    Q_UNUSED(parent);
-    Q_UNUSED(className);
-    Q_UNUSED(args);
-    return 0;
-}
-#endif
 
-#ifndef KDE_NO_DEPRECATED
-KParts::Part *KPluginFactory::createPartObject(QWidget *parentWidget, QObject *parent, const char *classname, const QStringList &args)
-{
-    Q_UNUSED(parent);
-    Q_UNUSED(parentWidget);
-    Q_UNUSED(classname);
-    Q_UNUSED(args);
-    return 0;
-}
-#endif
 
 QObject *KPluginFactory::create(const char *iface, QWidget *parentWidget, QObject *parent, const QVariantList &args, const QString &keyword)
 {
@@ -169,27 +128,6 @@ QObject *KPluginFactory::create(const char *iface, QWidget *parentWidget, QObjec
         setupTranslations();
     }
 
-#ifndef KDE_NO_DEPRECATED
-    if (keyword.isEmpty()) {
-
-        // kde3-kparts compatibility, remove in kde5
-        const char* kpartsIface = iface;
-        if (args.contains(QVariant(QString::fromLatin1("Browser/View"))))
-            kpartsIface = "Browser/View";
-
-        const QStringList argsStringList = variantListToStringList(args);
-
-        if ((obj = reinterpret_cast<QObject *>(createPartObject(parentWidget, parent, kpartsIface, argsStringList)))) {
-            objectCreated(obj);
-            return obj;
-        }
-
-        if ((obj = createObject(parent, iface, argsStringList))) {
-            objectCreated(obj);
-            return obj;
-        }
-    }
-#endif
 
     const QList<KPluginFactoryPrivate::Plugin> candidates(d->createInstanceHash.values(keyword));
     // for !keyword.isEmpty() candidates.count() is 0 or 1
@@ -198,7 +136,7 @@ QObject *KPluginFactory::create(const char *iface, QWidget *parentWidget, QObjec
         for (const QMetaObject *current = plugin.first; current; current = current->superClass()) {
             if (0 == qstrcmp(iface, current->className())) {
                 if (obj) {
-                    kFatal(kLibraryDebugArea()) << "ambiguous interface requested from a DSO containing more than one plugin";
+                    kFatal() << "ambiguous interface requested from a DSO containing more than one plugin";
                 }
                 obj = plugin.second(parentWidget, parent, args);
                 break;
@@ -228,22 +166,4 @@ void KPluginFactory::setComponentData(const KComponentData &kcd)
     d->componentData = kcd;
 }
 
-// KDE5 TODO: should be static, and possibly public (for apps to use)
-QStringList KPluginFactory::variantListToStringList(const QVariantList &list)
-{
-    QStringList stringlist;
-    Q_FOREACH(const QVariant& var, list)
-        stringlist << var.toString();
-    return stringlist;
-}
-
-// KDE5 TODO: should be static, and possibly public (for apps to use)
-QVariantList KPluginFactory::stringListToVariantList(const QStringList &list)
-{
-    QVariantList variantlist;
-    Q_FOREACH(const QString& str, list)
-        variantlist << QVariant(str);
-    return variantlist;
-}
-
-#include "kpluginfactory.moc"
+#include "moc_kpluginfactory.cpp"
