@@ -20,10 +20,11 @@
 
 #include "kbuildsycoca.h"
 #include "ksycoca_p.h"
-#include "kresourcelist.h"
+#include "ksycocaresourcelist.h"
 #include "vfolder_menu.h"
 
 #include <config.h>
+#include <config-kded.h>
 
 #include <kservice.h>
 #include <kmimetype.h>
@@ -34,16 +35,13 @@
 #include "kbuildprotocolinfofactory.h"
 #include "kctimefactory.h"
 #include <ktemporaryfile.h>
-#include <QtCore/QDataStream>
 #include <QtCore/QDir>
-#include <QtCore/QEventLoop>
-#include <QtCore/QFile>
-#include <QtCore/QTimer>
-#include <QtDBus/QtDBus>
+#include <QtCore/QFileInfo>
+#include <QtCore/QCoreApplication>
+#include <QtDBus/QDBusConnectionInterface>
 #include <errno.h>
 
 #include <assert.h>
-#include <kapplication.h>
 #include <kglobal.h>
 #include <kdebug.h>
 #include <kdirwatch.h>
@@ -52,35 +50,33 @@
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
+#ifndef KBUILDSYCOCA_NO_KCRASH
 #include <kcrash.h>
-#include <kmemfile.h>
+#endif
 
 #include <stdlib.h>
 #include <unistd.h>
 #include <time.h>
-#include <memory> // auto_ptr
 
 typedef QHash<QString, KSycocaEntry::Ptr> KBSEntryDict;
 typedef QList<KSycocaEntry::List> KSycocaEntryListList;
 
 static quint32 newTimestamp = 0;
 
-static KBuildServiceFactory *g_bsf = 0;
-static KBuildServiceGroupFactory *g_bsgf = 0;
-static KSycocaFactory *g_factory = 0;
-static KCTimeInfo *g_ctimeInfo = 0;
-static QHash<QString, quint32> *g_ctimeDict = 0;
+static KBuildServiceFactory *g_serviceFactory = 0;
+static KBuildServiceGroupFactory *g_buildServiceGroupFactory = 0;
+static KSycocaFactory *g_currentFactory = 0;
+static KCTimeInfo *g_ctimeInfo = 0; // factory
+static KCTimeDict *g_ctimeDict = 0; // old timestamps
 static QByteArray g_resource = 0;
-static KBSEntryDict *g_entryDict = 0;
+static KBSEntryDict *g_currentEntryDict = 0;
 static KBSEntryDict *g_serviceGroupEntryDict = 0;
-static KSycocaEntryListList *g_allEntries = 0;
-static QStringList *g_changeList = 0;
+static KSycocaEntryListList *g_allEntries = 0; // entries from existing ksycoca
 static QStringList *g_allResourceDirs = 0;
 static bool g_changed = false;
 static KSycocaEntry::List g_tempStorage;
 static VFolderMenu *g_vfolder = 0;
-
-static const char *cSycocaPath = 0;
+static QByteArray g_sycocaPath = 0;
 
 static bool bGlobalDatabase = false;
 static bool bMenuTest = false;
@@ -89,8 +85,8 @@ void crashHandler(int)
 {
    // If we crash while reading sycoca, we delete the database
    // in an attempt to recover.
-   if (cSycocaPath)
-      unlink(cSycocaPath);
+   if (!g_sycocaPath.isEmpty())
+      unlink(g_sycocaPath.constData());
 }
 
 static QString sycocaPath()
@@ -110,7 +106,7 @@ KBuildSycoca::~KBuildSycoca()
 
 KSycocaEntry::Ptr KBuildSycoca::createEntry(const QString &file, bool addToFactory)
 {
-   quint32 timeStamp = g_ctimeInfo->ctime(file);
+   quint32 timeStamp = g_ctimeInfo->dict()->ctime(file, g_resource);
    if (!timeStamp)
    {
       timeStamp = KGlobal::dirs()->calcResourceHash( g_resource, file,
@@ -120,43 +116,46 @@ KSycocaEntry::Ptr KBuildSycoca::createEntry(const QString &file, bool addToFacto
    if (g_allEntries)
    {
       assert(g_ctimeDict);
-      quint32 oldTimestamp = g_ctimeDict->value( file, 0 );
+      quint32 oldTimestamp = g_ctimeDict->ctime(file, g_resource);
 
       if (timeStamp && (timeStamp == oldTimestamp))
       {
          // Re-use old entry
-         if (g_factory == g_bsgf) // Strip .directory from service-group entries
+         if (g_currentFactory == g_buildServiceGroupFactory) // Strip .directory from service-group entries
          {
-            entry = g_entryDict->value(file.left(file.length()-10));
+            entry = g_currentEntryDict->value(file.left(file.length()-10));
          } else {
-            entry = g_entryDict->value(file);
+            entry = g_currentEntryDict->value(file);
          }
          // remove from g_ctimeDict; if g_ctimeDict is not empty
          // after all files have been processed, it means
          // some files were removed since last time
-         g_ctimeDict->remove( file );
+         if (file.contains("fake"))
+            kDebug(7021) << g_resource << "reusing (and removing) old entry [\"fake\"] for:" << file;
+         g_ctimeDict->remove(file, g_resource);
       }
       else if (oldTimestamp)
       {
          g_changed = true;
-         kDebug(7021) << "modified:" << file;
+         g_ctimeDict->remove(file, g_resource);
+         kDebug(7021) << "modified:" << file << "in" << g_resource.constData();
       }
       else
       {
          g_changed = true;
-         kDebug(7021) << "new:" << file;
+         kDebug(7021) << "new:" << file << "in" << g_resource.constData();
       }
    }
-   g_ctimeInfo->addCTime(file, timeStamp );
+   g_ctimeInfo->dict()->addCTime(file, g_resource, timeStamp);
    if (!entry)
    {
       // Create a new entry
-      entry = g_factory->createEntry( file, g_resource );
+      entry = g_currentFactory->createEntry( file, g_resource );
    }
    if ( entry && entry->isValid() )
    {
       if (addToFactory)
-         g_factory->addEntry(entry);
+         g_currentFactory->addEntry(entry);
       else
          g_tempStorage.append(entry);
       return entry;
@@ -170,10 +169,10 @@ KService::Ptr KBuildSycoca::createService(const QString &path)
    return KService::Ptr::staticCast(entry);
 }
 
-// returns false if the database is up to date
+// returns false if the database is up to date, true if it needs to be saved
 bool KBuildSycoca::build()
 {
-  typedef QLinkedList<KBSEntryDict *> KBSEntryDictList;
+  typedef QList<KBSEntryDict *> KBSEntryDictList;
   KBSEntryDictList entryDictList;
   KBSEntryDict *serviceEntryDict = 0;
 
@@ -195,9 +194,9 @@ bool KBuildSycoca::build()
             entryDict->insert( (*it)->entryPath(), *it );
          }
      }
-     if ((*factory) == g_bsf)
+     if ((*factory) == g_serviceFactory)
         serviceEntryDict = entryDict;
-     else if ((*factory) == g_bsgf)
+     else if ((*factory) == g_buildServiceGroupFactory)
         g_serviceGroupEntryDict = entryDict;
      entryDictList.append(entryDict);
   }
@@ -225,12 +224,10 @@ bool KBuildSycoca::build()
   g_ctimeInfo = new KCTimeInfo(); // This is a build factory too, don't delete!!
   bool uptodate = true;
   // For all resources
-  for( QStringList::ConstIterator it1 = allResources.constBegin();
-       it1 != allResources.constEnd();
-       ++it1 )
+  foreach(const QString &it1, allResources)
   {
      g_changed = false;
-     g_resource = (*it1).toLatin1();
+     g_resource = it1.toLatin1();
 
      QStringList relFiles;
 
@@ -249,11 +246,11 @@ bool KBuildSycoca::build()
      const KSycocaFactoryList::const_iterator end = factories()->constEnd();
      for ( ; it != end; ++it, ++ed_it )
      {
-        g_factory = (*it);
+        g_currentFactory = (*it);
         // g_ctimeInfo gets created after the initial loop, so it has no entryDict.
-        g_entryDict = ed_it == ed_end ? 0 : *ed_it;
-	// For each resource the factory deals with
-        const KSycocaResourceList *list = g_factory->resourceList();
+        g_currentEntryDict = ed_it == ed_end ? 0 : *ed_it;
+        // For each resource the factory deals with
+        const KSycocaResourceList *list = g_currentFactory->resourceList();
         if (!list) continue;
 
         for( KSycocaResourceList::ConstIterator it2 = list->constBegin();
@@ -261,42 +258,52 @@ bool KBuildSycoca::build()
              ++it2 )
         {
            KSycocaResource res = (*it2);
-           if (res.resource != (*it1)) continue;
+           if (res.resource != it1) continue;
 
            // For each file in the resource
-           for( QStringList::ConstIterator it3 = relFiles.constBegin();
-                it3 != relFiles.constEnd();
-                ++it3 )
+           foreach(const QString &it3, relFiles)
            {
                // Check if file matches filter
-               if ((*it3).endsWith(res.extension))
-                   createEntry(*it3, true);
+               if (it3.endsWith(res.extension))
+                   createEntry(it3, true);
            }
         }
      }
      if (g_changed || !g_allEntries)
      {
         uptodate = false;
-        g_changeList->append(g_resource);
+        //kDebug() << "CHANGED:" << g_resource;
+        m_changedResources.append(g_resource);
      }
   }
 
   bool result = !uptodate || (g_ctimeDict && !g_ctimeDict->isEmpty());
+  if (g_ctimeDict && !g_ctimeDict->isEmpty()) {
+      //kDebug() << "Still in time dict:";
+      //g_ctimeDict->dump();
+      // ## It seems entries filtered out by vfolder are still in there,
+      // so we end up always saving ksycoca, i.e. this method never returns false
+
+      // Get the list of resources from which some files were deleted
+      const QStringList resources = g_ctimeDict->resourceList();
+      kDebug() << "Still in the time dict (i.e. deleted files)" << resources;
+      m_changedResources += resources;
+  }
 
   if (result || bMenuTest)
   {
-     g_resource = "apps";
-     g_factory = g_bsf;
-     g_entryDict = serviceEntryDict;
+     g_resource = "xdgdata-apps";
+     g_currentFactory = g_serviceFactory;
+     g_currentEntryDict = serviceEntryDict;
      g_changed = false;
 
-     g_vfolder = new VFolderMenu(g_bsf, this);
+     g_vfolder = new VFolderMenu(g_serviceFactory, this);
      if (!m_trackId.isEmpty())
         g_vfolder->setTrackId(m_trackId);
 
-     VFolderMenu::SubMenu *kdeMenu = g_vfolder->parseMenu("applications.menu", true);
+     VFolderMenu::SubMenu *kdeMenu = g_vfolder->parseMenu("applications.menu");
 
-     KServiceGroup::Ptr entry = g_bsgf->addNew("/", kdeMenu->directoryFile, KServiceGroup::Ptr(), false);
+     KServiceGroup::Ptr entry = g_buildServiceGroupFactory->addNew("/", kdeMenu->directoryFile, KServiceGroup::Ptr(), false);
      entry->setLayoutInfo(kdeMenu->layoutList);
      createMenu(QString(), QString(), kdeMenu);
 
@@ -306,7 +313,8 @@ bool KBuildSycoca::build()
      if (g_changed || !g_allEntries)
      {
         uptodate = false;
-        g_changeList->append(g_resource);
+        //kDebug() << "CHANGED:" << g_resource;
+        m_changedResources.append(g_resource);
      }
      if (bMenuTest) {
          result = false;
@@ -328,7 +336,7 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
      QString directoryFile = subMenu->directoryFile;
      if (directoryFile.isEmpty())
         directoryFile = subName+".directory";
-     quint32 timeStamp = g_ctimeInfo->ctime(directoryFile);
+     quint32 timeStamp = g_ctimeInfo->dict()->ctime(directoryFile, g_resource);
      if (!timeStamp) {
         timeStamp = KGlobal::dirs()->calcResourceHash( g_resource, directoryFile,
                                                        KStandardDirs::Recursive );
@@ -337,7 +345,7 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
      KServiceGroup::Ptr entry;
      if (g_allEntries)
      {
-        quint32 oldTimestamp = g_ctimeDict->value( directoryFile, 0 );
+        const quint32 oldTimestamp = g_ctimeDict->ctime(directoryFile, g_resource);
 
         if (timeStamp && (timeStamp == oldTimestamp))
         {
@@ -350,9 +358,9 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
             }
         }
      }
-     g_ctimeInfo->addCTime(directoryFile, timeStamp);
+     g_ctimeInfo->dict()->addCTime(directoryFile, g_resource, timeStamp);
 
-     entry = g_bsgf->addNew(subName, subMenu->directoryFile, entry, subMenu->isDeleted);
+     entry = g_buildServiceGroupFactory->addNew(subName, subMenu->directoryFile, entry, subMenu->isDeleted);
      entry->setLayoutInfo(subMenu->layoutList);
      if (! (bMenuTest && entry->noDisplay()) )
         createMenu(caption + entry->caption() + '/', subName, subMenu);
@@ -366,11 +374,11 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
      if (bMenuTest)
      {
         if (!menu->isDeleted && !p->noDisplay())
-           printf("%s\t%s\t%s\n", qPrintable( caption ), qPrintable( p->menuId() ), qPrintable( KStandardDirs::locate("apps", p->entryPath() ) ) );
+           printf("%s\t%s\t%s\n", qPrintable( caption ), qPrintable( p->menuId() ), qPrintable( KStandardDirs::locate("xdgdata-apps", p->entryPath() ) ) );
      }
      else
      {
-        g_bsgf->addNewEntryTo( name, p );
+        g_buildServiceGroupFactory->addNewEntryTo( name, p );
      }
   }
 }
@@ -396,16 +404,15 @@ bool KBuildSycoca::recreate()
   }
 
   QDataStream* str = new QDataStream(&database);
-  str->setVersion(QDataStream::Qt_3_1);
 
   kDebug(7021).nospace() << "Recreating ksycoca file (" << path << ", version " << KSycoca::version() << ")";
 
   // It is very important to build the servicetype one first
   // Both are registered in KSycoca, no need to keep the pointers
   KSycocaFactory *stf = new KBuildServiceTypeFactory;
-  KBuildMimeTypeFactory *mtf = new KBuildMimeTypeFactory;
-  g_bsgf = new KBuildServiceGroupFactory();
-  g_bsf = new KBuildServiceFactory(stf, mtf, g_bsgf);
+  KBuildMimeTypeFactory* mimeTypeFactory = new KBuildMimeTypeFactory;
+  g_buildServiceGroupFactory = new KBuildServiceGroupFactory();
+  g_serviceFactory = new KBuildServiceFactory(stf, mimeTypeFactory, g_buildServiceGroupFactory);
   (void) new KBuildProtocolInfoFactory();
 
   if( build()) // Parse dirs
@@ -439,14 +446,11 @@ bool KBuildSycoca::recreate()
     QFile ksycocastamp(stamppath);
     ksycocastamp.open( QIODevice::WriteOnly );
     QDataStream str( &ksycocastamp );
-    str.setVersion(QDataStream::Qt_3_1);
     str << newTimestamp;
     str << existingResourceDirs();
     if (g_vfolder)
         str << g_vfolder->allDirectories(); // Extra resource dirs
   }
-  if (d->m_sycocaStrategy == KSycocaPrivate::StrategyMemFile)
-     KMemFile::fileContentsChanged(path);
 
   return true;
 }
@@ -457,8 +461,6 @@ void KBuildSycoca::save(QDataStream* str)
    str->device()->seek(0);
 
    (*str) << (qint32) KSycoca::version();
-   KSycocaFactory * servicetypeFactory = 0;
-   KBuildMimeTypeFactory * mimeTypeFactory = 0;
    KBuildServiceFactory * serviceFactory = 0;
    for(KSycocaFactoryList::Iterator factory = factories()->begin();
        factory != factories()->end();
@@ -467,11 +469,7 @@ void KBuildSycoca::save(QDataStream* str)
       qint32 aId;
       qint32 aOffset;
       aId = (*factory)->factoryId();
-      if ( aId == KST_KServiceTypeFactory )
-         servicetypeFactory = *factory;
-      else if ( aId == KST_KMimeTypeFactory )
-         mimeTypeFactory = static_cast<KBuildMimeTypeFactory *>( *factory );
-      else if ( aId == KST_KServiceFactory )
+      if ( aId == KST_KServiceFactory )
          serviceFactory = static_cast<KBuildServiceFactory *>( *factory );
       aOffset = (*factory)->offset(); // not set yet, so always 0
       (*str) << aId;
@@ -487,7 +485,6 @@ void KBuildSycoca::save(QDataStream* str)
    (*str) << (*g_allResourceDirs);
 
    // Calculate per-servicetype/mimetype data
-   mimeTypeFactory->parseSubclasses();
    serviceFactory->postProcessServices();
 
    // Here so that it's the last debug message
@@ -545,7 +542,7 @@ bool KBuildSycoca::checkDirTimestamps( const QString& dirname, const QDateTime&
          continue;
       if( fi.lastModified() > stamp )
       {
-         kDebug( 7201 ) << "timestamp changed:" << fi.filePath();
+         kDebug( 7021 ) << "timestamp changed:" << fi.filePath();
          return false;
       }
       if( fi.isDir() && !checkDirTimestamps( fi.filePath(), stamp, false ))
@@ -560,18 +557,16 @@ bool KBuildSycoca::checkDirTimestamps( const QString& dirname, const QDateTime&
 // means that there's no need to rebuild ksycoca
 bool KBuildSycoca::checkTimestamps( quint32 timestamp, const QStringList &dirs )
 {
-   kDebug( 7021 ) << "checking file timestamps";
-   QDateTime stamp;
-   stamp.setTime_t( timestamp );
-   for( QStringList::ConstIterator it = dirs.begin();
-        it != dirs.end();
-        ++it )
-   {
-      if( !checkDirTimestamps( *it, stamp, true ))
+    kDebug( 7021 ) << "checking file timestamps";
+    QDateTime stamp;
+    stamp.setTime_t( timestamp );
+    foreach(const QString &it, dirs)
+    {
+        if( !checkDirTimestamps( it, stamp, true ))
             return false;
-   }
-   kDebug( 7021 ) << "timestamps check ok";
-   return true;
+    }
+    kDebug( 7021 ) << "timestamps check ok";
+    return true;
 }
 
 QStringList KBuildSycoca::existingResourceDirs()
@@ -613,7 +608,7 @@ static const char appFullName[] = "org.kde.kbuildsycoca";
 static const char appName[] = "kbuildsycoca4";
 static const char appVersion[] = "1.1";
 
-extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
+int main(int argc, char **argv)
 {
    KAboutData d(appName, "kdelibs4", ki18n("KBuildSycoca"), appVersion,
                 ki18n("Rebuilds the system configuration cache."),
@@ -645,9 +640,11 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
    QCoreApplication k(argc, argv);
    KComponentData mainComponent(d);
 
+#ifndef KBUILDSYCOCA_NO_KCRASH
    KCrash::setCrashHandler(KCrash::defaultCrashHandler);
    KCrash::setEmergencySaveFunction(crashHandler);
    KCrash::setApplicationName(QString(appName));
+#endif
 
    // force generating of KLocale object. if not, the database will get
    // be translated
@@ -697,21 +694,17 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
      }
    }
 
-   g_changeList = new QStringList;
-
    bool checkstamps = incremental && args->isSet("checkstamps") && checkfiles;
    quint32 filestamp = 0;
    QStringList oldresourcedirs;
    if( checkstamps && incremental )
    {
        QString path = sycocaPath()+"stamp";
-       QByteArray qPath = QFile::encodeName(path);
-       cSycocaPath = qPath.data(); // Delete timestamps on crash
+       g_sycocaPath = QFile::encodeName(path); // Delete timestamps on crash
        QFile ksycocastamp(path);
        if( ksycocastamp.open( QIODevice::ReadOnly ))
        {
            QDataStream str( &ksycocastamp );
-           str.setVersion(QDataStream::Qt_3_1);
 
            if (!str.atEnd())
                str >> filestamp;
@@ -736,15 +729,15 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
        {
            checkstamps = false;
        }
-       cSycocaPath = 0;
+       g_sycocaPath.clear();
    }
 
    newTimestamp = (quint32) time(0);
+   QStringList changedResources;
 
    if( checkfiles && ( !checkstamps || !KBuildSycoca::checkTimestamps( filestamp, oldresourcedirs )))
    {
-      QByteArray qSycocaPath = QFile::encodeName(sycocaPath());
-      cSycocaPath = qSycocaPath.data();
+      g_sycocaPath = QFile::encodeName(sycocaPath());
 
       g_allEntries = 0;
       g_ctimeDict = 0;
@@ -754,7 +747,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
          KSycoca::self();
          KSycocaFactoryList *factories = new KSycocaFactoryList;
          g_allEntries = new KSycocaEntryListList;
-         g_ctimeDict = new QHash<QString, quint32>;
+         g_ctimeDict = new KCTimeDict;
 
          // Must be in same order as in KBuildSycoca::recreate()!
          factories->append( new KServiceTypeFactory );
@@ -772,9 +765,9 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
          }
          delete factories; factories = 0;
          KCTimeInfo *ctimeInfo = new KCTimeInfo;
-         ctimeInfo->fillCTimeDict(*g_ctimeDict);
+         *g_ctimeDict = ctimeInfo->loadDict();
       }
-      cSycocaPath = 0;
+      g_sycocaPath.clear();
 
       KBuildSycoca *sycoca = new KBuildSycoca; // Build data base (deletes oldSycoca)
       if (args->isSet("track"))
@@ -782,13 +775,12 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
       if (!sycoca->recreate()) {
         return -1;
       }
+      changedResources = sycoca->changedResources();
 
       if (bGlobalDatabase)
       {
         // These directories may have been created with 0700 permission
         // better delete them if they are empty
-        QString applnkDir = KGlobal::dirs()->saveLocation("apps", QString(), false);
-        ::rmdir(QFile::encodeName(applnkDir));
         QString servicetypesDir = KGlobal::dirs()->saveLocation("servicetypes", QString(), false);
         ::rmdir(QFile::encodeName(servicetypesDir));
       }
@@ -797,11 +789,12 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
    if (args->isSet("signal"))
    {
      // Notify ALL applications that have a ksycoca object, using a signal
+     changedResources.removeDuplicates();
      QDBusMessage signal = QDBusMessage::createSignal("/", "org.kde.KSycoca", "notifyDatabaseChanged" );
-     signal << *g_changeList;
+     signal << changedResources;
 
      if (QDBusConnection::sessionBus().isConnected()) {
-        kDebug() << "Emitting notifyDatabaseChanged" << *g_changeList;
+       kDebug() << "Emitting notifyDatabaseChanged" << changedResources;
        QDBusConnection::sessionBus().send(signal);
        qApp->processEvents(); // make sure the dbus signal is sent before we quit.
      }
@@ -810,4 +803,4 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
    return 0;
 }
 
-#include "kbuildsycoca.moc"
+#include "moc_kbuildsycoca.cpp"
