@@ -25,23 +25,25 @@
 #include <QtCore/QTimer>
 #include <QtCore/QHash>
 #include <QtCore/QSet>
-
-#include <QtDBus/QtDBus>
+#include <QtDBus/QDBusMessage>
+#include <QtDBus/QDBusAbstractAdaptor>
+#include <QtDBus/QDBusServiceWatcher>
 
 #include <ksycoca.h>
 #include <ksycocatype.h>
 #include <kdedmodule.h>
 #include <kservice.h>
 
-class QDBusServiceWatcher;
+#include <QDBusServiceWatcher>
+
 class KDirWatch;
 
-// No need for this in libkio - apps only get readonly access
+// Apps get read-only access
 class Kded : public QObject
 {
   Q_OBJECT
 public:
-   Kded();
+   Kded(QObject *parent);
    virtual ~Kded();
 
    static Kded *self() { return _self;}
@@ -56,8 +58,6 @@ public:
    //bool isWindowRegistered(qlonglong windowId) const;
    /**
     * Applications can register/unregister their windows with kded modules.
-    * This allows kpasswdserver and kcookiejar to delete authentication
-    * and cookies that are local to a particular window when closing it.
     */
    //@{
    /**
@@ -69,8 +69,6 @@ public:
     */
    void unregisterWindowId(qlonglong windowId, const QString &sender);
    //@}
-   void recreate(const QDBusMessage&);
-   void recreate(bool initial);
    void loadSecondPhase();
 
    //@{
@@ -134,11 +132,6 @@ public Q_SLOTS:
     */
    void recreate();
 
-   /**
-    * Recreating finished
-    */
-   void recreateDone();
-
    /**
     * Collect all directories to watch
     */
@@ -159,30 +152,22 @@ public Q_SLOTS:
     */
    void slotKDEDModuleRemoved(KDEDModule *);
 
-protected Q_SLOTS:
+private Q_SLOTS:
 
    /**
     * @internal Triggers rebuilding
     */
-   void dirDeleted(const QString& path);
+   void update(const QString& dir);
 
    /**
-    * @internal Triggers rebuilding
+    * @internal Executes kdontchangethehostname when hostname changes
     */
-   void update (const QString& dir );
-
-   void runDelayedCheck();
-
-protected:
-   /**
-    * Scans dir for new files and new subdirectories.
-    */
-   void readDirectory(const QString& dir );
+   void checkHostname();
 
+private:
    /**
     * Pointer to the dirwatch class which tells us, when some directories
     * changed.
-    * Slower polling for remote file systems is now done in KDirWatch (JW).
     */
    KDirWatch* m_pDirWatch;
 
@@ -193,12 +178,17 @@ protected:
     */
    QTimer* m_pTimer;
 
-   QList<QDBusMessage> m_recreateRequests;
-   int m_recreateCount;
-   bool m_recreateBusy;
+   /**
+    * Timer for periodic hostname checking.
+    */
+   QTimer* m_hTimer;
+   /**
+    * The current hostname.
+    */
+   QByteArray m_hostname;
 
    QHash<QString,KDEDModule *> m_modules;
-    //QHash<QString,KLibrary *> m_libs;
+    //QHash<QString,QLibrary *> m_libs;
    QHash<QString,QObject *> m_dontLoad;
 
    //window id tracking, with a QDBusServiceWatcher to remove them as needed
@@ -207,7 +197,6 @@ protected:
    QSet<long> m_globalWindowIdList;
 
    QStringList m_allResourceDirs;
-   bool m_needDelayedCheck;
 
    static Kded *_self;
 };
@@ -220,53 +209,7 @@ public:
    KBuildsycocaAdaptor(QObject *parent);
 
 public Q_SLOTS:
-   Q_NOREPLY void recreate(const QDBusMessage&);
-};
-
-
-class KUpdateD : public QObject
-{
-   Q_OBJECT
-public:
-   KUpdateD();
-   ~KUpdateD();
-
-public Q_SLOTS:
-   void runKonfUpdate();
-   void slotNewUpdateFile();
-
-private:
-   /**
-    * Pointer to the dirwatch class which tells us, when some directories
-    * changed.
-    * Slower polling for remote file systems is now done in KDirWatch (JW).
-    */
-   KDirWatch* m_pDirWatch;
-
-   /**
-    * When a desktop file is updated, a timer is started (5 sec)
-    * before rebuilding the binary - so that multiple updates result
-    * in only one rebuilding.
-    */
-   QTimer* m_pTimer;
-};
-
-class KHostnameD : public QObject
-{
-   Q_OBJECT
-public:
-   KHostnameD(int pollInterval);
-   ~KHostnameD();
-
-public Q_SLOTS:
-   void checkHostname();
-
-private:
-   /**
-    * Timer for interval hostname checking.
-    */
-   QTimer m_Timer;
-   QByteArray m_hostname;
+   void recreate();
 };
 
 #endif
