@@ -18,7 +18,7 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <kprocess.h>
+#include <QProcess>
 #include <kconfiggroup.h>
 #include <kdesktopfile.h>
 #include <kmimetypetrader.h>
@@ -386,13 +386,13 @@ private Q_SLOTS:
     void testRemovedImplicitAssociation178560()
     {
         // #178560: Removing ark from interface/x-winamp-skin didn't work
-        // Using application/x-kns (another zip-derived mimetype) nowadays.
-        const QString mime = "application/x-kns";
+        // Using application/vnd.comicbook+zip (another zip-derived mimetype) nowadays.
+        const QString mime = "application/vnd.comicbook+zip";
         KService::List offers = KMimeTypeTrader::self()->query(mime);
         QVERIFY(offerListHasService(offers, fakeArkApplication, true));
 
         writeToMimeApps(QByteArray("[Removed Associations]\n"
-                                   "application/x-kns=fakearkapplication.desktop;\n"));
+                                   "application/vnd.comicbook+zip=fakearkapplication.desktop;\n"));
 
         offers = KMimeTypeTrader::self()->query(mime);
         QVERIFY(!offerListHasService(offers, fakeArkApplication, false));
@@ -432,12 +432,9 @@ private:
         // (The real KCM code simply does the refresh in a slot, asynchronously)
         QEventLoop loop;
         QObject::connect(KSycoca::self(), SIGNAL(databaseChanged(QStringList)), &loop, SLOT(quit()));
-        KProcess proc;
         const QString kbuildsycoca = KStandardDirs::findExe(KBUILDSYCOCA_EXENAME);
         QVERIFY(!kbuildsycoca.isEmpty());
-        proc << kbuildsycoca;
-        proc.setOutputChannelMode(KProcess::MergedChannels); // silence kbuildsycoca output
-        proc.execute();
+        QProcess::execute(kbuildsycoca);
         loop.exec();
     }
 
