@@ -55,11 +55,10 @@ static void foldNode(QDomElement &docElem, QDomElement &e, QMap<QString,QDomElem
 
 static void replaceNode(QDomElement &docElem, QDomNode &n, const QStringList &list, const QString &tag)
 {
-   for(QStringList::ConstIterator it = list.begin();
-       it != list.end(); ++it)
+   foreach(const QString it, list)
    {
       QDomElement e = docElem.ownerDocument().createElement(tag);
-      QDomText txt = docElem.ownerDocument().createTextNode(*it);
+      QDomText txt = docElem.ownerDocument().createTextNode(it);
       e.appendChild(txt);
       docElem.insertAfter(e, n);
    }
@@ -88,27 +87,11 @@ void VFolderMenu::registerDirectory(const QString &directory)
 QStringList VFolderMenu::allDirectories()
 {
    if (m_allDirectories.isEmpty())
-     return m_allDirectories;
+      return m_allDirectories;
+
+   m_allDirectories.removeDuplicates();
    m_allDirectories.sort();
 
-   QStringList::Iterator it = m_allDirectories.begin();
-   QString previous = *it++;
-   for(;it != m_allDirectories.end();)
-   {
-#ifndef Q_OS_WIN
-     if ((*it).startsWith(previous))
-#else
-     if ((*it).startsWith(previous, Qt::CaseInsensitive))
-#endif
-     {
-        it = m_allDirectories.erase(it);
-     }
-     else
-     {
-        previous = *it;
-        ++it;
-     }
-   }
    return m_allDirectories;
 }
 
@@ -130,19 +113,23 @@ VFolderMenu::includeItems(QHash<QString,KService::Ptr>& items1, const QHash<QStr
 void
 VFolderMenu::matchItems(QHash<QString,KService::Ptr>& items1, const QHash<QString,KService::Ptr>& items2)
 {
-   foreach (const KService::Ptr &p, items1)
-   {
-       QString id = p->menuId();
-       if (!items2.contains(id))
-          items1.remove(id);
-   }
+   QHash<QString,KService::Ptr>::iterator it = items1.begin();
+   while (it != items1.end()) {
+      QString id = (*it)->menuId();
+       if (!items2.contains(id)) {
+            it = items1.erase(it);
+        } else {
+           it++;
+        }
+    }
 }
 
 void
 VFolderMenu::excludeItems(QHash<QString,KService::Ptr>& items1, const QHash<QString,KService::Ptr>& items2)
 {
-   foreach (const KService::Ptr &p, items2)
+   foreach (const KService::Ptr &p, items2) {
        items1.remove(p->menuId());
+   }
 }
 
 VFolderMenu::SubMenu*
@@ -498,7 +485,6 @@ VFolderMenu::loadDoc()
    tagBaseDir(doc, "MergeDir", m_docInfo.baseDir);
    tagBaseDir(doc, "DirectoryDir", m_docInfo.baseDir);
    tagBaseDir(doc, "AppDir", m_docInfo.baseDir);
-   tagBaseDir(doc, "LegacyDir", m_docInfo.baseDir);
 
    return doc;
 }
@@ -542,7 +528,6 @@ VFolderMenu::mergeMenus(QDomElement &docElem, QString &name)
    QMap<QString,QDomElement> directoryNodes;
    QMap<QString,QDomElement> appDirNodes;
    QMap<QString,QDomElement> directoryDirNodes;
-   QMap<QString,QDomElement> legacyDirNodes;
    QDomElement defaultLayoutNode;
    QDomElement layoutNode;
 
@@ -575,10 +560,6 @@ VFolderMenu::mergeMenus(QDomElement &docElem, QString &name)
          // Filter out dupes
          foldNode(docElem, e, directoryDirNodes);
       }
-      else if( e.tagName() == "LegacyDir") {
-         // Filter out dupes
-         foldNode(docElem, e, legacyDirNodes);
-      }
       else if( e.tagName() == "Directory") {
          // Filter out dupes
          foldNode(docElem, e, directoryNodes);
@@ -641,10 +622,9 @@ VFolderMenu::mergeMenus(QDomElement &docElem, QString &name)
          QString dir = absoluteDir(e.text(), e.attribute("__BaseDir"), true);
 
          const QStringList dirs = KGlobal::dirs()->findDirs("xdgconf-menu", dir);
-         for(QStringList::ConstIterator it=dirs.begin();
-             it != dirs.end(); ++it)
+         foreach(const QString it, dirs)
          {
-            registerDirectory(*it);
+            registerDirectory(it);
          }
 
          QStringList fileList;
@@ -660,10 +640,9 @@ VFolderMenu::mergeMenus(QDomElement &docElem, QString &name)
                                                      KStandardDirs::NoDuplicates, fileList);
          }
 
-         for(QStringList::ConstIterator it=fileList.constBegin();
-             it != fileList.constEnd(); ++it)
+         foreach(const QString it, fileList)
          {
-            pushDocInfo(*it);
+            pushDocInfo(it);
             mergeFile(docElem, n);
             popDocInfo();
          }
@@ -766,7 +745,7 @@ VFolderMenu::locateMenuFile(const QString &fileName)
 {
    if (!QDir::isRelativePath(fileName))
    {
-      if (KStandardDirs::exists(fileName))
+      if (KGlobal::dirs()->exists(fileName))
          return fileName;
       return QString();
    }
@@ -804,18 +783,16 @@ VFolderMenu::locateDirectoryFile(const QString &fileName)
 
    if (!QDir::isRelativePath(fileName))
    {
-      if (KStandardDirs::exists(fileName))
+      if (KGlobal::dirs()->exists(fileName))
          return fileName;
       return QString();
    }
 
    // First location in the list wins
-   for(QStringList::ConstIterator it = m_directoryDirs.constBegin();
-       it != m_directoryDirs.constEnd();
-       ++it)
+   foreach(const QString it, m_directoryDirs)
    {
-      QString tmp = (*it)+fileName;
-      if (KStandardDirs::exists(tmp))
+      const QString tmp = it+fileName;
+      if (KGlobal::dirs()->exists(tmp))
          return tmp;
    }
 
@@ -831,7 +808,6 @@ VFolderMenu::initDirs()
 
    m_defaultAppDirs = KGlobal::dirs()->findDirs("xdgdata-apps", QString());
    m_defaultDirectoryDirs = KGlobal::dirs()->findDirs("xdgdata-dirs", QString());
-   m_defaultLegacyDirs = KGlobal::dirs()->resourceDirs("apps");
 }
 
 void
@@ -850,7 +826,7 @@ VFolderMenu::loadMenu(const QString &fileName)
    if (m_doc.isNull())
    {
       if (m_docInfo.path.isEmpty())
-         kError(7021) << fileName << " not found in " << m_allDirectories << endl;
+         kError(7021) << fileName << " not found in " << m_allDirectories;
       else
          kWarning(7021) << "Load error (" << m_docInfo.path << ")";
       return;
@@ -1002,115 +978,6 @@ VFolderMenu::loadApplications(const QString &dir, const QString &prefix)
    }
 }
 
-void
-VFolderMenu::processKDELegacyDirs()
-{
-    kDebug(7021);
-
-   QHash<QString,KService::Ptr> items;
-   QString prefix = "kde4-";
-
-   QStringList relFiles;
-
-   (void) KGlobal::dirs()->findAllResources( "apps",
-                                             QString(),
-                                             KStandardDirs::Recursive |
-                                             KStandardDirs::NoDuplicates,
-                                             relFiles);
-   for(QStringList::ConstIterator it = relFiles.constBegin();
-       it != relFiles.constEnd(); ++it)
-   {
-      if (!m_forcedLegacyLoad && (*it).endsWith(QLatin1String(".directory")))
-      {
-         QString name = *it;
-         if (!name.endsWith(QLatin1String("/.directory")))
-            continue; // Probably ".directory", skip it.
-
-         name = name.left(name.length()-11);
-
-         SubMenu *newMenu = new SubMenu;
-         newMenu->directoryFile = KStandardDirs::locate("apps", *it);
-
-         insertSubMenu(m_currentMenu, name, newMenu);
-         continue;
-      }
-
-      if ((*it).endsWith(QLatin1String(".desktop")))
-      {
-         QString name = *it;
-         KService::Ptr service = m_kbuildsycocaInterface->createService(name);
-
-         if (service && !m_forcedLegacyLoad)
-         {
-            QString id = name;
-            // Strip path from id
-            int i = id.lastIndexOf('/');
-            if (i >= 0)
-               id = id.mid(i+1);
-
-            id.prepend(prefix);
-
-            // TODO: add Legacy category
-            addApplication(id, service);
-            items.insert(service->menuId(), service);
-            if (service->categories().isEmpty())
-               insertService(m_currentMenu, name, service);
-
-         }
-      }
-   }
-   markUsedApplications(items);
-   m_legacyLoaded = true;
-}
-
-void
-VFolderMenu::processLegacyDir(const QString &dir, const QString &relDir, const QString &prefix)
-{
-   kDebug(7021).nospace() << "processLegacyDir(" << dir << ", " << relDir << ", " << prefix << ")";
-
-   QHash<QString,KService::Ptr> items;
-   QDirIterator it(dir);
-   while (it.hasNext()) {
-      it.next();
-      const QFileInfo fi = it.fileInfo();
-      const QString fn = fi.fileName();
-      if (fi.isDir()) {
-         if(fn == QLatin1String(".") || fn == QLatin1String(".."))
-            continue;
-         SubMenu *parentMenu = m_currentMenu;
-
-         m_currentMenu = new SubMenu;
-         m_currentMenu->name = fn;
-         m_currentMenu->directoryFile = fi.absoluteFilePath() + "/.directory";
-
-         parentMenu->subMenus.append(m_currentMenu);
-
-         processLegacyDir(fi.filePath(), relDir + fn + '/', prefix);
-         m_currentMenu = parentMenu;
-         continue;
-      }
-      if (fi.isFile() /*&& !fi.isSymLink() ?? */) {
-         if (!fn.endsWith(QLatin1String(".desktop")))
-            continue;
-         KService::Ptr service = m_kbuildsycocaInterface->createService(fi.absoluteFilePath());
-         if (service)
-         {
-            const QString id = prefix + fn;
-
-            // TODO: Add legacy category
-            addApplication(id, service);
-            items.insert(service->menuId(), service);
-
-            if (service->categories().isEmpty())
-               m_currentMenu->items.insert(id, service);
-         }
-      }
-   }
-   markUsedApplications(items);
-}
-
-
-
 void
 VFolderMenu::processMenu(QDomElement &docElem, int pass)
 {
@@ -1121,7 +988,6 @@ VFolderMenu::processMenu(QDomElement &docElem, int pass)
    QString directoryFile;
    bool onlyUnallocated = false;
    bool isDeleted = false;
-   bool kdeLegacyDirsDone = false;
    QDomElement defaultLayoutNode;
    QDomElement layoutNode;
 
@@ -1232,7 +1098,7 @@ VFolderMenu::processMenu(QDomElement &docElem, int pass)
       }
    }
 
-   // Process AppDir and LegacyDir
+   // Process AppDir
    if (pass == 0)
    {
       QDomElement query;
@@ -1248,63 +1114,6 @@ VFolderMenu::processMenu(QDomElement &docElem, int pass)
 
             loadApplications(dir, QString());
          }
-         else if (e.tagName() == "KDELegacyDirs")
-         {
-            createAppsInfo();
-            if (!kdeLegacyDirsDone)
-            {
-kDebug(7021) << "Processing KDE Legacy dirs for <KDE>";
-               SubMenu *oldMenu = m_currentMenu;
-               m_currentMenu = new SubMenu;
-
-               processKDELegacyDirs();
-
-               m_legacyNodes.insert("<KDE>", m_currentMenu);
-               m_currentMenu = oldMenu;
-
-               kdeLegacyDirsDone = true;
-            }
-         }
-         else if (e.tagName() == "LegacyDir")
-         {
-            createAppsInfo();
-            QString dir = absoluteDir(e.text(), e.attribute("__BaseDir"));
-
-            QString prefix = e.attributes().namedItem("prefix").toAttr().value();
-
-#ifndef Q_OS_WIN
-            if (m_defaultLegacyDirs.contains(dir))
-#else
-            if (m_defaultLegacyDirs.contains(dir, Qt::CaseInsensitive))
-#endif
-            {
-               if (!kdeLegacyDirsDone)
-               {
-kDebug(7021) << "Processing KDE Legacy dirs for" << dir;
-                  SubMenu *oldMenu = m_currentMenu;
-                  m_currentMenu = new SubMenu;
-
-                  processKDELegacyDirs();
-
-                  m_legacyNodes.insert("<KDE>", m_currentMenu);
-                  m_currentMenu = oldMenu;
-
-                  kdeLegacyDirsDone = true;
-               }
-            }
-            else
-            {
-               SubMenu *oldMenu = m_currentMenu;
-               m_currentMenu = new SubMenu;
-
-               registerDirectory(dir);
-
-               processLegacyDir(dir, QString(), prefix);
-
-               m_legacyNodes.insert(dir, m_currentMenu);
-               m_currentMenu = oldMenu;
-            }
-         }
          n = n.nextSibling();
       }
    }
@@ -1369,34 +1178,6 @@ kDebug(7021) << "Processing KDE Legacy dirs for" << dir;
       {
          processMenu(e, pass);
       }
-// We insert legacy dir in pass 0, this way the order in the .menu-file determines
-// which .directory file gets used, but the menu-entries of legacy-menus will always
-// have the lowest priority.
-//      else if (((pass == 1) && !onlyUnallocated) || ((pass == 2) && onlyUnallocated))
-      else if (pass == 0)
-      {
-         if (e.tagName() == "LegacyDir")
-         {
-            // Add legacy nodes to Menu structure
-            QString dir = absoluteDir(e.text(), e.attribute("__BaseDir"));
-            SubMenu *legacyMenu = m_legacyNodes[dir];
-            if (legacyMenu)
-            {
-               mergeMenu(m_currentMenu, legacyMenu);
-            }
-         }
-
-         else if (e.tagName() == "KDELegacyDirs")
-         {
-            // Add legacy nodes to Menu structure
-            QString dir = "<KDE>";
-            SubMenu *legacyMenu = m_legacyNodes[dir];
-            if (legacyMenu)
-            {
-               mergeMenu(m_currentMenu, legacyMenu);
-            }
-         }
-      }
       n = n.nextSibling();
    }
 
@@ -1533,7 +1314,7 @@ static QStringList parseLayoutNode(const QDomElement &docElem)
       }
       else if (e.tagName() == "Merge")
       {
-         QString type = e.attributeNode("type").value();
+         const QString type = e.attributeNode("type").value();
          if (type == "files")
             layout.append(":F");
          else if (type == "menus")
@@ -1587,17 +1368,13 @@ VFolderMenu::markUsedApplications(const QHash<QString,KService::Ptr>& items)
 }
 
 VFolderMenu::SubMenu *
-VFolderMenu::parseMenu(const QString &file, bool forceLegacyLoad)
+VFolderMenu::parseMenu(const QString &file)
 {
-   m_forcedLegacyLoad = false;
-   m_legacyLoaded = false;
    m_appsInfo = 0;
 
    const QStringList dirs = KGlobal::dirs()->resourceDirs("xdgconf-menu");
-   for(QStringList::ConstIterator it=dirs.begin();
-       it != dirs.end(); ++it)
-   {
-      registerDirectory(*it);
+   foreach(const QString it, dirs) {
+      registerDirectory(it);
    }
 
    loadMenu(file);
@@ -1638,12 +1415,6 @@ VFolderMenu::parseMenu(const QString &file, bool forceLegacyLoad)
       }
    }
 
-   if (!m_legacyLoaded && forceLegacyLoad)
-   {
-      m_forcedLegacyLoad = true;
-      processKDELegacyDirs();
-   }
-
    return m_rootMenu;
 }
 
@@ -1654,4 +1425,4 @@ VFolderMenu::setTrackId(const QString &id)
    m_trackId = id;
 }
 
-#include "vfolder_menu.moc"
+#include "moc_vfolder_menu.cpp"
