@@ -26,7 +26,6 @@
 
 #include "kactioncollection.h"
 #include "kactioncategory.h"
-#include <kauthorized.h>
 #include "kxmlguiclient.h"
 #include "kxmlguifactory.h"
 
@@ -35,7 +34,7 @@
 #include "kaction.h"
 #include "kaction_p.h"
 
-#include <QtXml/QDomDocument>
+#include <QtXml/qdom.h>
 #include <QtCore/QSet>
 #include <QtCore/QMap>
 #include <QtCore/QList>
@@ -267,13 +266,6 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
         return action;
     }
 
-    if (!KAuthorized::authorizeKAction(indexName)) {
-      // Disable this action
-      action->setEnabled(false);
-      action->setVisible(false);
-      action->blockSignals(true);
-    }
-
     // Check if we have another action under this name
     if (QAction *oldAction = d->actionByName.value(indexName)) {
       takeAction(oldAction);
@@ -299,7 +291,7 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
     connect(action, SIGNAL(destroyed(QObject*)), SLOT(_k_actionDestroyed(QObject*)));
 
     // only our private class is a friend of KAction
-    if (KAction *kaction = dynamic_cast<KAction *>(action)) {
+    if (KAction *kaction = qobject_cast<KAction *>(action)) {
       d->setComponentForAction(kaction);
     }
 
@@ -329,8 +321,6 @@ QAction* KActionCollection::takeAction(QAction *action)
   }
 
   action->disconnect(this);
-
-  emit removed( action ); //deprecated
   return action;
 }
 
@@ -640,16 +630,10 @@ void KActionCollection::slotActionTriggered( )
     emit actionTriggered(action);
 }
 
-void KActionCollection::slotActionHighlighted( )
-{
-	slotActionHovered();
-}
-
 void KActionCollection::slotActionHovered( )
 {
   QAction* action = qobject_cast<QAction*>(sender());
   if (action) {
-    emit actionHighlighted(action);
     emit actionHovered(action);
   }
 }
@@ -663,9 +647,6 @@ void KActionCollectionPrivate::_k_actionDestroyed( QObject *obj )
 
   if (!unlistAction(action))
       return;
-
-  //HACK the object we emit is partly destroyed
-  emit q->removed(action); //deprecated. remove in KDE5
 }
 
 void KActionCollection::connectNotify ( const char * signal )
@@ -673,8 +654,7 @@ void KActionCollection::connectNotify ( const char * signal )
   if (d->connectHovered && d->connectTriggered)
     return;
 
-  if (QMetaObject::normalizedSignature(SIGNAL(actionHighlighted(QAction*))) == signal ||
-      QMetaObject::normalizedSignature(SIGNAL(actionHovered(QAction*))) == signal) {
+  if (QMetaObject::normalizedSignature(SIGNAL(actionHovered(QAction*))) == signal) {
     if (!d->connectHovered) {
       d->connectHovered = true;
       foreach (QAction* action, actions())
@@ -780,4 +760,4 @@ void KActionCollectionPrivate::_k_associatedWidgetDestroyed(QObject *obj)
 /* vim: et sw=2 ts=2
  */
 
-#include "kactioncollection.moc"
+#include "moc_kactioncollection.cpp"
