@@ -19,9 +19,9 @@
 
 #include "kstandardaction.h"
 #include "kstandardaction_p.h"
-#include "kstandardaction_p.moc"
+#include "moc_kstandardaction_p.cpp"
 
-#include <QtCore/QMutableStringListIterator>
+#include <QtCore/qstringlist.h>
 #include <QtGui/QToolButton>
 
 #include <kaboutdata.h>
@@ -37,6 +37,7 @@
 #include <kmainwindow.h>
 #include <kicon.h>
 
+#include "kdualaction.h"
 #include "krecentfilesaction.h"
 #include "ktogglefullscreenaction.h"
 #include "kpastetextaction.h"
@@ -188,6 +189,9 @@ KAction *create(StandardAction id, const QObject *recvr, const char *slot, QObje
     }
 
     pAction->setText(sLabel);
+    if (pInfo->psToolTip) {
+        pAction->setToolTip(i18n(pInfo->psToolTip));
+    }
     pAction->setIcon(icon);
 
     KShortcut cut = KStandardShortcut::shortcut(pInfo->idAccel);
@@ -198,12 +202,15 @@ KAction *create(StandardAction id, const QObject *recvr, const char *slot, QObje
   }
 
   if (recvr && slot) {
-    if (id != OpenRecent)
-      QObject::connect(pAction, SIGNAL(triggered(bool)), recvr, slot);
-    else
-      // FIXME KAction port: probably a good idea to find a cleaner way to do this
-      // Open Recent is a special case - provide the selected URL
-      QObject::connect(pAction, SIGNAL(urlSelected(const KUrl &)), recvr, slot);
+      if (id == OpenRecent) {
+          // FIXME KAction port: probably a good idea to find a cleaner way to do this
+          // Open Recent is a special case - provide the selected URL
+          QObject::connect(pAction, SIGNAL(urlSelected(KUrl)), recvr, slot);
+      } else if (id == ConfigureToolbars) { // #200815
+          QObject::connect(pAction, SIGNAL(triggered(bool)), recvr, slot, Qt::QueuedConnection);
+      } else {
+          QObject::connect(pAction, SIGNAL(triggered(bool)), recvr, slot);
+      }
   }
 
   KActionCollection *collection = qobject_cast<KActionCollection *>(parent);
@@ -473,7 +480,9 @@ static KAction *buildAutomaticAction( QObject* parent, StandardAction id, const
       parent);
 
   action->setObjectName(p->psName);
-  action->setWhatsThis( i18n(p->psWhatsThis) );
+  if (p->psToolTip) {
+      action->setToolTip(i18n(p->psToolTip));
+  }
 
   KActionCollection *collection = qobject_cast<KActionCollection *>(parent);
   if (collection)
@@ -484,27 +493,27 @@ static KAction *buildAutomaticAction( QObject* parent, StandardAction id, const
 
 KAction *cut( QObject* parent )
 {
-  return buildAutomaticAction( parent, Cut, SLOT( cut() ) );
+  return buildAutomaticAction( parent, Cut, SLOT(cut()) );
 }
 
 KAction *copy( QObject* parent )
 {
-  return buildAutomaticAction( parent, Copy, SLOT( copy() ) );
+  return buildAutomaticAction( parent, Copy, SLOT(copy()) );
 }
 
 KAction *paste( QObject* parent )
 {
-  return buildAutomaticAction( parent, Paste, SLOT( paste() ) );
+  return buildAutomaticAction( parent, Paste, SLOT(paste()) );
 }
 
 KAction *clear( QObject* parent )
 {
-  return buildAutomaticAction( parent, Clear, SLOT( clear() ) );
+  return buildAutomaticAction( parent, Clear, SLOT(clear()) );
 }
 
 KAction *selectAll( QObject* parent )
 {
-  return buildAutomaticAction( parent, SelectAll, SLOT( selectAll() ) );
+  return buildAutomaticAction( parent, SelectAll, SLOT(selectAll()) );
 }
 
 KToggleAction *showMenubar(const QObject *recvr, const char *slot, QObject *parent)
@@ -521,7 +530,7 @@ KToggleAction *showMenubar(const QObject *recvr, const char *slot, QObject *pare
   ret->setChecked( true );
 
   if ( recvr && slot )
-    QObject::connect( ret, SIGNAL( triggered( bool ) ), recvr, slot );
+    QObject::connect( ret, SIGNAL(triggered(bool)), recvr, slot );
 
   KActionCollection *collection = qobject_cast<KActionCollection *>(parent);
   if (collection)
@@ -535,13 +544,13 @@ KToggleAction *showStatusbar(const QObject *recvr, const char *slot, QObject *pa
   KToggleAction *ret = new KToggleAction(i18n( "Show St&atusbar" ), parent);
   ret->setObjectName(name(ShowStatusbar));
 
-  ret->setWhatsThis( i18n( "Show Statusbar<br /><br />"
-                           "Shows the statusbar, which is the bar at the bottom of the window used for status information." ) );
+  ret->setWhatsThis( i18n( "Show Statusbar<p>"
+                           "Shows the statusbar, which is the bar at the bottom of the window used for status information.</p>" ) );
 
   ret->setChecked( true );
 
   if ( recvr && slot )
-    QObject::connect( ret, SIGNAL( triggered( bool ) ), recvr, slot );
+    QObject::connect( ret, SIGNAL(triggered(bool)), recvr, slot );
 
   KActionCollection *collection = qobject_cast<KActionCollection *>(parent);
   if (collection)
