@@ -23,9 +23,9 @@
 #include <kstandardshortcut.h>
 #include <QtCore/QList>
 
-class QObject;
-class QStringList;
-class QWidget;
+#include <QObject>
+#include <QStringList>
+#include <QWidget>
 class KAction;
 class KRecentFilesAction;
 class KDualAction;
@@ -188,11 +188,6 @@ namespace KStandardAction
    */
   KDEUI_EXPORT const char* name( StandardAction id );
 
-  /// @deprecated use name()
-#ifndef KDE_NO_DEPRECATED
-  inline KDE_DEPRECATED const char* stdName(StandardAction act_enum) { return name( act_enum ); }
-#endif
-
   /**
    * Returns a list of all standard names. Used by KAccelManager
    * to give those heigher weight.
@@ -584,13 +579,18 @@ namespace KStandardAction
    */
   KDEUI_EXPORT KAction *reportBug(const QObject *recvr, const char *slot, QObject *parent);
 
+  /**
+   * Open up the application Language switching dialog.
+   */
+  KDEUI_EXPORT KAction *switchApplicationLanguage(const QObject *recvr, const char *slot, QObject *parent);
+
   /**
    * Display the application's About box.
    */
   KDEUI_EXPORT KAction *aboutApp(const QObject *recvr, const char *slot, QObject *parent);
 
   /**
-   * Display the About KDE dialog.
+   * Display the About Katana dialog.
    */
   KDEUI_EXPORT KAction *aboutKDE(const QObject *recvr, const char *slot, QObject *parent);
 }
