@@ -30,8 +30,8 @@
 #include <QtGui/QStyle>
 #include <kglobalsettings.h>
 #include <kstandardshortcut.h>
-#include <QMouseEvent>
-#include <QStyleOptionButton>
+#include <QtGui/qevent.h>
+#include <QtGui/qstyleoption.h>
 #include "kcolordialog.h"
 #include "kcolorhelpers_p.h"
 #include "kcolormimedata.h"
@@ -263,8 +263,7 @@ void KColorButton::KColorButtonPrivate::_k_chooseColor()
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->setButtons(KDialog::Ok | KDialog::Cancel);
     connect(dialog, SIGNAL(applyClicked()), q, SLOT(_k_colorChosen()));
-    connect(dialog, SIGNAL(okClicked()), q, SLOT(_k_colorChosen()));
-    connect(dialog, SIGNAL(colorSelected(QColor)), q, SLOT(_k_colorChosen()));
+    connect(dialog, SIGNAL(accepted()), q, SLOT(_k_colorChosen()));
     dialogPtr = dialog;
     dialog->show();
 }
@@ -283,4 +282,4 @@ void KColorButton::KColorButtonPrivate::_k_colorChosen()
     }
 }
 
-#include "kcolorbutton.moc"
+#include "moc_kcolorbutton.cpp"
