@@ -36,13 +36,14 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <QtCore/QFile>
+#include <QtCore/QTimer>
+
 #include <QtGui/QButtonGroup>
 #include <QtGui/QCheckBox>
-#include <QtGui/QDesktopWidget>
 #include <QtGui/QRadioButton>
 #include <QtGui/qdrawutil.h>
-#include <QtGui/QActionEvent>
-#include <QtCore/QFile>
+#include <QtGui/qevent.h>
 #include <QtGui/QHeaderView>
 #include <QtGui/QImage>
 #include <QtGui/QStyledItemDelegate>
@@ -50,8 +51,9 @@
 #include <QtGui/QLayout>
 #include <QtGui/QPainter>
 #include <QtGui/QPushButton>
+#include <QtGui/QScrollArea>
+#include <QtGui/QDesktopWidget>
 #include <QtGui/QScrollBar>
-#include <QtCore/QTimer>
 
 #include <kapplication.h>
 #include <kcombobox.h>
@@ -85,7 +87,7 @@
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include <fixx11h.h>
 #endif
 
@@ -158,7 +160,6 @@ public:
                 //Draw the selection (radiobutton-like) circle
                 painter->save();
                 painter->setRenderHint(QPainter::Antialiasing, true);
-                painter->setRenderHint(QPainter::HighQualityAntialiasing, true);
                 painter->setPen(QPen(color, 1.2, Qt::SolidLine));
                 painter->setBrush(QBrush());
                 painter->drawEllipse(opt.rect.adjusted(2,2,-2,-2));
@@ -233,11 +234,21 @@ void KColorCells::setShading(bool _shade)
     d->shade = _shade;
 }
 
+bool KColorCells::shading() const
+{
+    return d->shade;
+}
+
 void KColorCells::setAcceptDrags(bool _acceptDrags)
 {
     this->setDragEnabled(_acceptDrags);
 }
 
+bool KColorCells::acceptDrags() const
+{
+    return this->dragEnabled();
+}
+
 void KColorCells::setSelected(int index)
 {
     Q_ASSERT(index >= 0 && index < count());
@@ -387,8 +398,7 @@ void KColorCells::dragEnterEvent(QDragEnterEvent *event)
 {
     kDebug() << "KColorCells::dragEnterEvent() acceptDrags="
     << this->dragEnabled()
-    << " canDecode=" << KColorMimeData::canDecode(event->mimeData())
-    << endl;
+    << " canDecode=" << KColorMimeData::canDecode(event->mimeData());
     event->setAccepted(this->dragEnabled() && KColorMimeData::canDecode(event->mimeData()));
 }
 
@@ -397,8 +407,7 @@ void KColorCells::dragMoveEvent(QDragMoveEvent *event)
 {
     kDebug() << "KColorCells::dragMoveEvent() acceptDrags="
     << this->dragEnabled()
-    << " canDecode=" << KColorMimeData::canDecode(event->mimeData())
-    << endl;
+    << " canDecode=" << KColorMimeData::canDecode(event->mimeData());
     event->setAccepted(this->dragEnabled() && KColorMimeData::canDecode(event->mimeData()));
 }
 
@@ -528,7 +537,6 @@ public:
     void slotColorCellDoubleClicked(int index , const QColor&);
     void slotColorTextSelected(const QString &colorText);
     void slotSetColors(const QString &_collectionName);
-    void slotShowNamedColorReadError(void);
 
     KColorTable *q;
     QString i18n_namedColors;
@@ -604,43 +612,6 @@ KColorTable::name() const
     return d->combo->currentText();
 }
 
-
-static const char * const *namedColorFilePath(void)
-{
-    //
-    // 2000-02-05 Espen Sand.
-    // Add missing filepaths here. Make sure the last entry is 0, 0!
-    //
-    // 2009-06-16 Pino Toscano
-    //
-    // You can specify either absolute paths or relative locations
-    // wrt KStandardDirs resources. In either way, there should be two
-    // "strings" for each path.
-    // - absolute path: specify it directly, then add 0 as second item
-    //   * example: "/usr/share/X11/rgb.txt", 0,
-    // - KStandardDirs location: specify the filename as first item,
-    //   then add the resource as second
-    //   * example: "kdeui/rgb.txt", "data",
-    //
-    static const char * const path[] = {
-#ifdef Q_WS_X11
-#ifdef X11_RGBFILE
-        X11_RGBFILE, 0,
-#endif
-        "/usr/share/X11/rgb.txt", 0,
-        "/usr/X11R6/lib/X11/rgb.txt", 0,
-        "/usr/openwin/lib/X11/rgb.txt", 0, // for Solaris.
-#else /* systems without X11 */
-        "kdeui/rgb.txt", "data",
-#endif
-        0, 0
-    };
-    return path;
-}
-
-
-
-
 void
 KColorTable::readNamedColor(void)
 {
@@ -648,105 +619,17 @@ KColorTable::readNamedColor(void)
         return; // Strings already present
     }
 
-    KGlobal::locale()->insertCatalog("kdelibs_colors4");
-
-    //
-    // Code somewhat inspired by KColorCollection.
-    //
-
-    const char * const *path = namedColorFilePath();
-    for (int i = 0; path[i]; i += 2) {
-        QString file;
-        if (path[i + 1]) {
-            file = KStandardDirs::locate(path[i + 1], QString::fromLatin1(path[i]));
-            if (file.isEmpty()) {
-                continue;
-            }
-        } else {
-            file = QString::fromLatin1(path[i]);
-        }
-
-        QFile paletteFile(file);
-        if (!paletteFile.open(QIODevice::ReadOnly)) {
-            continue;
-        }
-
-        QByteArray line;
-        QStringList list;
-        while (!paletteFile.atEnd()) {
-            line = paletteFile.readLine();
-
-            int red, green, blue;
-            int pos = 0;
-
-            if (sscanf(line, "%d %d %d%n", &red, &green, &blue, &pos) == 3) {
-                //
-                // Remove duplicates. Every name with a space and every name
-                // that start with "gray".
-                //
-                QString name = line.mid(pos).trimmed();
-                QByteArray s1 = line.mid(pos);
-                if (name.isNull() || name.indexOf(' ') != -1 ||
-                        name.indexOf("gray") != -1 ||  name.indexOf("grey") != -1) {
-                    continue;
-                }
-
-                const QColor color(red, green, blue);
-                if (color.isValid()) {
-                    const QString colorName(i18nc("color", name.toLatin1().data()));
-                    list.append(colorName);
-                    d->m_namedColorMap[ colorName ] = color;
-                }
-            }
-        }
-
-        list.sort();
-        d->mNamedColorList->addItems(list);
-        break;
+    QStringList list;
+    foreach (const QString &colorName, QColor::colorNames()) {
+        const QColor color(colorName);
+        list.append(colorName);
+        d->m_namedColorMap[ colorName ] = color;
     }
 
-    if (d->mNamedColorList->count() == 0) {
-        //
-        // Give the error dialog box a chance to center above the
-        // widget (or dialog). If we had displayed it now we could get a
-        // situation where the (modal) error dialog box pops up first
-        // preventing the real dialog to become visible until the
-        // error dialog box is removed (== bad UI).
-        //
-        QTimer::singleShot(10, this, SLOT(slotShowNamedColorReadError()));
-    }
+    list.sort();
+    d->mNamedColorList->addItems(list);
 }
 
-
-void
-KColorTable::KColorTablePrivate::slotShowNamedColorReadError(void)
-{
-    if (mNamedColorList->count() == 0) {
-        QString pathMsg;
-        int pathCount = 0;
-
-        const char * const *path = namedColorFilePath();
-        for (int i = 0; path[i]; i += 2, ++pathCount) {
-            if (path[i + 1]) {
-                pathMsg += QLatin1String(path[i + 1]) + ", " + QString::fromLatin1(path[i]);
-            } else {
-                pathMsg += QLatin1String(path[i]);
-            }
-            pathMsg += '\n';
-        }
-
-        QString finalMsg  = i18ncp("%1 is the number of paths, %2 is the list of paths (with newlines between them)",
-                                   "Unable to read X11 RGB color strings. The following "
-                                   "file location was examined:\n%2",
-                                   "Unable to read X11 RGB color strings. The following "
-                                   "file locations were examined:\n%2",
-                                   pathCount, pathMsg );
-
-        KMessageBox::sorry(q, finalMsg);
-    }
-}
-
-
 //
 // 2000-02-12 Espen Sand
 // Set the color in two steps. The setColors() slot will not emit a signal
@@ -1320,7 +1203,6 @@ KColorDialog::eventFilter(QObject *obj, QEvent *ev)
         case QEvent::DragMove:
         case QEvent::DragLeave:
         case QEvent::Drop:
-        case QEvent::DragResponse:
             qApp->sendEvent(d->patch, ev);
             return true;
         default:
@@ -1826,5 +1708,5 @@ void KColorDialog::KColorDialogPrivate::setHsvEdit(const QColor &col)
     vedit->setValue(v);
 }
 
-#include "kcolordialog.moc"
-#include "kcolordialog_p.moc"
+#include "moc_kcolordialog.cpp"
+#include "moc_kcolordialog_p.cpp"
