@@ -21,6 +21,11 @@
 #ifndef KDEUI_COLORS_KCOLORHELPERS_P_H
 #define KDEUI_COLORS_KCOLORHELPERS_P_H
 
+#include <QColor>
+#include <QPainter>
+#include <QRect>
+#include <QBrush>
+
 // normalize: like qBound(a, 0.0, 1.0) but without needing the args and with
 // "safer" behavior on NaN (isnan(a) -> return 0.0)
 static inline qreal normalize(qreal a)
@@ -28,4 +33,11 @@ static inline qreal normalize(qreal a)
     return (a < 1.0 ? (a > 0.0 ? a : 0.0) : 1.0);
 }
 
+namespace KDEPrivate {
+
+//  fill a rectangle with a brush over chessboard pattern
+void fillOpaqueRect(QPainter *painter, const QRect &rect, const QBrush &brush);
+
+} // namespace KDEPrivate
+
 #endif // KDEUI_COLORS_KCOLORHELPERS_P_H
