@@ -74,25 +74,28 @@ StateEffects::StateEffects(QPalette::ColorGroup state, const KSharedConfigPtr &c
         group = "ColorEffects:Disabled";
     else if(state == QPalette::Inactive)
         group = "ColorEffects:Inactive";
-    else {
-        _effects[0] = 0;
-        _effects[1] = 0;
-        _effects[2] = 0;
-    }
+
+    _effects[0] = 0;
+    _effects[1] = 0;
+    _effects[2] = 0;
 
     // NOTE: keep this in sync with kdebase/workspace/kcontrol/colors/colorscm.cpp
     if(! group.isEmpty()) {
         KConfigGroup cfg(config, group);
-        _effects[Intensity] = cfg.readEntry( "IntensityEffect",
-                (int)(state == QPalette::Disabled ?  IntensityDarken : IntensityNoEffect));
-        _effects[Color]     = cfg.readEntry(     "ColorEffect", (int)ColorNoEffect );
-        _effects[Contrast]  = cfg.readEntry(  "ContrastEffect",
-                (int)(state == QPalette::Disabled ?  ContrastFade : ContrastNoEffect));
-        _amount[Intensity]  = cfg.readEntry( "IntensityAmount", state == QPalette::Disabled ? 0.10 : 0.0 );
-        _amount[Color]      = cfg.readEntry(     "ColorAmount", 0.0 );
-        _amount[Contrast]   = cfg.readEntry(  "ContrastAmount", state == QPalette::Disabled ? 0.65 : 0.0 );
-        if (_effects[Color] > ColorNoEffect)
-            _color = cfg.readEntry( "Color", QColor(112, 111, 110) );
+        const bool enabledByDefault = (state == QPalette::Disabled);
+        if (cfg.readEntry("Enable", enabledByDefault)) {
+            _effects[Intensity] = cfg.readEntry( "IntensityEffect",
+                                                 (int)(state == QPalette::Disabled ?  IntensityDarken : IntensityNoEffect));
+            _effects[Color]     = cfg.readEntry(     "ColorEffect",
+                                                     (int)(state == QPalette::Disabled ?  ColorNoEffect : ColorDesaturate));
+            _effects[Contrast]  = cfg.readEntry(  "ContrastEffect",
+                                                  (int)(state == QPalette::Disabled ?  ContrastFade : ContrastTint));
+            _amount[Intensity]  = cfg.readEntry( "IntensityAmount", state == QPalette::Disabled ? 0.10 :  0.0 );
+            _amount[Color]      = cfg.readEntry(     "ColorAmount", state == QPalette::Disabled ?  0.0 : -0.9 );
+            _amount[Contrast]   = cfg.readEntry(  "ContrastAmount", state == QPalette::Disabled ? 0.65 :  0.25 );
+            if (_effects[Color] > ColorNoEffect)
+                _color = cfg.readEntry( "Color", state == QPalette::Disabled ?  QColor(56, 56, 56) : QColor(112, 111, 110));
+        }
     }
 }
 
@@ -164,48 +167,51 @@ struct DecoDefaultColors {
 SetDefaultColors defaultViewColors = {
     { 255, 255, 255 }, // Background
     { 248, 247, 246 }, // Alternate
-    {  20,  19,  18 }, // Normal
-    { 136, 135, 134 }, // Inactive
-    { 255, 128, 224 }, // Active
+    {  31,  28,  27 }, // Normal
+    { 137, 136, 135 }, // Inactive
+    { 146,  76, 157 }, // Active
     {   0,  87, 174 }, // Link
-    {  69,  40, 134 }, // Visited
+    { 100,  74, 155 }, // Visited
     { 191,   3,   3 }, // Negative
     { 176, 128,   0 }, // Neutral
     {   0, 110,  40 }  // Positive
 };
 
+
 SetDefaultColors defaultWindowColors = {
-    { 224, 223, 222 }, // Background
+    { 214, 210, 208 }, // Background
     { 218, 217, 216 }, // Alternate
-    {  20,  19,  18 }, // Normal
-    { 136, 135, 134 }, // Inactive
-    { 255, 128, 224 }, // Active
+    {  34,  31,  30 }, // Normal
+    { 137, 136, 135 }, // Inactive
+    { 146,  76, 157 }, // Active
     {   0,  87, 174 }, // Link
-    {  69,  40, 134 }, // Visited
+    { 100,  74, 155 }, // Visited
     { 191,   3,   3 }, // Negative
     { 176, 128,   0 }, // Neutral
-    {   0, 110,  40 }  // Positive
+    { 0,   110,  40 }  // Positive
 };
 
+
 SetDefaultColors defaultButtonColors = {
-    { 232, 231, 230 }, // Background
+    { 223, 220, 217 }, // Background
     { 224, 223, 222 }, // Alternate
-    {  20,  19,  18 }, // Normal
-    { 136, 135, 134 }, // Inactive
-    { 255, 128, 224 }, // Active
+    {  34,  31,  30 }, // Normal
+    { 137, 136, 135 }, // Inactive
+    { 146,  76, 157 }, // Active
     {   0,  87, 174 }, // Link
-    {  69,  40, 134 }, // Visited
+    { 100,  74, 155 }, // Visited
     { 191,   3,   3 }, // Negative
     { 176, 128,   0 }, // Neutral
     {   0, 110,  40 }  // Positive
 };
 
+
 SetDefaultColors defaultSelectionColors = {
-    {  65, 139, 212 }, // Background
+    {  67, 172, 232 }, // Background
     {  62, 138, 204 }, // Alternate
     { 255, 255, 255 }, // Normal
-    { 165, 193, 228 }, // Inactive
-    { 255, 128, 224 }, // Active
+    { 199, 226, 248 }, // Inactive
+    { 108,  36, 119 }, // Active
     {   0,  49, 110 }, // Link
     {  69,  40, 134 }, // Visited
     { 156,  14,  14 }, // Negative
@@ -213,23 +219,23 @@ SetDefaultColors defaultSelectionColors = {
     { 128, 255, 128 }  // Positive
 };
 
+
 SetDefaultColors defaultTooltipColors = {
-    { 192, 218, 255 }, // Background
+    {  24,  21,  19 }, // Background
     { 196, 224, 255 }, // Alternate
-    {  20,  19,  18 }, // Normal
-    {  96, 112, 128 }, // Inactive
+    { 231, 253, 255 }, // Normal
+    { 137, 136, 135 }, // Inactive
     { 255, 128, 224 }, // Active
-    {   0,  87, 174 }, // Link
-    {  69,  40, 134 }, // Visited
+    {  88, 172, 255 }, // Link
+    { 150, 111, 232 }, // Visited
     { 191,   3,   3 }, // Negative
     { 176, 128,   0 }, // Neutral
     {   0, 110,  40 }  // Positive
 };
 
-
 DecoDefaultColors defaultDecorationColors = {
-    { 119, 183, 255 }, // Hover
-    {  43, 116, 199 }, // Focus
+    { 110, 214, 255 }, // Hover
+    {  58, 167, 221 }, // Focus
 };
 //END default colors
 
@@ -255,7 +261,7 @@ private:
 };
 
 #define DEFAULT(c) QColor( c[0], c[1], c[2] )
-#define  SET_DEFAULT(a) DEFAULT( defaults.a )
+#define SET_DEFAULT(a) DEFAULT( defaults.a )
 #define DECO_DEFAULT(a) DEFAULT( defaultDecorationColors.a )
 
 KColorSchemePrivate::KColorSchemePrivate(const KSharedConfigPtr &config,
@@ -426,7 +432,7 @@ KColorScheme::KColorScheme(QPalette::ColorGroup state, ColorSet set, KSharedConf
         case Selection: {
             KConfigGroup group(config, "ColorEffects:Inactive");
             // NOTE: keep this in sync with kdebase/workspace/kcontrol/colors/colorscm.cpp
-            bool inactiveSelectionEffect = group.readEntry("ChangeSelectionColor", group.readEntry("Enable", false));
+            bool inactiveSelectionEffect = group.readEntry("ChangeSelectionColor", group.readEntry("Enable", true));
             // if enabled, inactiver/disabled uses Window colors instead, ala gtk
             // ...except tinted with the Selection:NormalBackground color so it looks more like selection
             if (state == QPalette::Active || (state == QPalette::Inactive && !inactiveSelectionEffect))
