@@ -25,7 +25,7 @@
 #include <QGroupBox>
 #include <QLabel>
 #include <QMetaObject>
-#include <QMetaProperty>
+#include <QtCore/qmetaobject.h>
 #include <QTimer>
 #include <QRadioButton>
 //#include <QButtonGroup>
@@ -48,12 +48,13 @@ public:
 public:
   KConfigDialogManager *q;
 
-  static int debugArea() { static int s_area = KDebug::registerArea("kdeui (KConfigDialogManager)"); return s_area; }
+  // see kdebug.areas
+  static int debugArea() { return 300; }
 
   /**
   * KConfigSkeleton object used to store settings
    */
-  KConfigSkeleton *m_conf;
+  KCoreConfigSkeleton *m_conf;
 
   /**
   * Dialog being managed
@@ -66,6 +67,14 @@ public:
   bool trackChanges : 1;
 };
 
+KConfigDialogManager::KConfigDialogManager(QWidget *parent, KCoreConfigSkeleton *conf)
+ : QObject(parent), d(new Private(this))
+{
+  d->m_conf = conf;
+  d->m_dialog = parent;
+  init(true);
+}
+
 KConfigDialogManager::KConfigDialogManager(QWidget *parent, KConfigSkeleton *conf)
  : QObject(parent), d(new Private(this))
 {
@@ -99,46 +108,47 @@ void KConfigDialogManager::initMaps()
     // a ButtonGroup that is checkable.
 //    s_changedMap->insert("QButtonGroup", SIGNAL(buttonClicked(int)));
     s_changedMap->insert("QGroupBox", SIGNAL(toggled(bool)));
-    s_changedMap->insert("QComboBox", SIGNAL(activated (int)));
+    s_changedMap->insert("QComboBox", SIGNAL(activated(int)));
     //qsqlproperty map doesn't store the text, but the value!
-    //s_changedMap->insert("QComboBox", SIGNAL(textChanged(const QString &)));
-    s_changedMap->insert("QDateEdit", SIGNAL(dateChanged(const QDate &)));
-    s_changedMap->insert("QTimeEdit", SIGNAL(timeChanged(const QTime &)));
-    s_changedMap->insert("QDateTimeEdit", SIGNAL(dateTimeChanged(const QDateTime &)));
-    s_changedMap->insert("QDial", SIGNAL(valueChanged (int)));
+    //s_changedMap->insert("QComboBox", SIGNAL(textChanged(QString)));
+    s_changedMap->insert("QDateEdit", SIGNAL(dateChanged(QDate)));
+    s_changedMap->insert("QDateTimeEdit", SIGNAL(timeChanged(QTime)));
+    s_changedMap->insert("QDateTimeEdit", SIGNAL(dateTimeChanged(QDateTime)));
+    s_changedMap->insert("QDial", SIGNAL(valueChanged(int)));
     s_changedMap->insert("QDoubleSpinBox", SIGNAL(valueChanged(double)));
-    s_changedMap->insert("QLineEdit", SIGNAL(textChanged(const QString &)));
+    s_changedMap->insert("QLineEdit", SIGNAL(textChanged(QString)));
     s_changedMap->insert("QSlider", SIGNAL(valueChanged(int)));
     s_changedMap->insert("QSpinBox", SIGNAL(valueChanged(int)));
     s_changedMap->insert("QTextEdit", SIGNAL(textChanged()));
-    s_changedMap->insert("QTextBrowser", SIGNAL(sourceChanged(const QString &)));
+    s_changedMap->insert("QTextBrowser", SIGNAL(sourceChanged(QString)));
+    s_changedMap->insert("QPlainTextEdit", SIGNAL(textChanged()));
     s_changedMap->insert("QTabWidget", SIGNAL(currentChanged(int)));
 
     // KDE
-    s_changedMap->insert( "KComboBox", SIGNAL(activated (int)));
-    s_changedMap->insert( "KFontCombo", SIGNAL(activated (int)));
-    s_changedMap->insert( "KFontRequester", SIGNAL(fontSelected(const QFont &)));
-    s_changedMap->insert( "KFontChooser",  SIGNAL(fontSelected(const QFont &)));
-    s_changedMap->insert( "KHistoryCombo", SIGNAL(activated (int)));
-    s_changedMap->insert( "KColorCombo", SIGNAL(activated (const QColor &)));
+    s_changedMap->insert( "KComboBox", SIGNAL(activated(int)));
+    s_changedMap->insert( "KFontComboBox", SIGNAL(activated(int)));
+    s_changedMap->insert( "KFontRequester", SIGNAL(fontSelected(QFont)));
+    s_changedMap->insert( "KFontChooser",  SIGNAL(fontSelected(QFont)));
+    s_changedMap->insert( "KHistoryCombo", SIGNAL(activated(int)));
+    s_changedMap->insert( "KColorCombo", SIGNAL(activated(QColor)));
 
-    s_changedMap->insert( "KColorButton", SIGNAL(changed(const QColor &)));
-    s_changedMap->insert( "KDatePicker", SIGNAL(dateSelected (QDate)));
-    s_changedMap->insert( "KDateWidget", SIGNAL(changed (QDate)));
-    s_changedMap->insert( "KDateTimeWidget", SIGNAL(valueChanged (const QDateTime &)));
+    s_changedMap->insert( "KColorButton", SIGNAL(changed(QColor)));
+    s_changedMap->insert( "KDatePicker", SIGNAL(dateSelected(QDate)));
+    s_changedMap->insert( "KDateWidget", SIGNAL(changed(QDate)));
+    s_changedMap->insert( "KDateTimeWidget", SIGNAL(valueChanged(QDateTime)));
     s_changedMap->insert( "KEditListBox", SIGNAL(changed()));
+    s_changedMap->insert( "KEditListWidget", SIGNAL(changed()));
     s_changedMap->insert( "KListWidget", SIGNAL(itemSelectionChanged()));
-    s_changedMap->insert( "KLineEdit", SIGNAL(textChanged(const QString &)));
-    s_changedMap->insert( "KPasswordEdit", SIGNAL(textChanged(const QString &)));
-    s_changedMap->insert( "KRestrictedLine", SIGNAL(textChanged(const QString &)));
-    s_changedMap->insert( "KTextBrowser", SIGNAL(sourceChanged(const QString &)));
+    s_changedMap->insert( "KLineEdit", SIGNAL(textChanged(QString)));
+    s_changedMap->insert( "KPasswordEdit", SIGNAL(textChanged(QString)));
+    s_changedMap->insert( "KRestrictedLine", SIGNAL(textChanged(QString)));
     s_changedMap->insert( "KTextEdit", SIGNAL(textChanged()));
-    s_changedMap->insert( "KUrlRequester",  SIGNAL(textChanged (const QString& )));
-    s_changedMap->insert( "KUrlComboRequester",  SIGNAL(textChanged (const QString& )));
-    s_changedMap->insert( "KUrlComboBox",  SIGNAL(urlActivated (const KUrl& )));
-    s_changedMap->insert( "KIntNumInput", SIGNAL(valueChanged (int)));
-    s_changedMap->insert( "KIntSpinBox", SIGNAL(valueChanged (int)));
-    s_changedMap->insert( "KDoubleNumInput", SIGNAL(valueChanged (double)));
+    s_changedMap->insert( "KUrlRequester",  SIGNAL(textChanged(QString)));
+    s_changedMap->insert( "KUrlComboRequester",  SIGNAL(textChanged(QString)));
+    s_changedMap->insert( "KUrlComboBox",  SIGNAL(urlActivated(KUrl)));
+    s_changedMap->insert( "KIntNumInput", SIGNAL(valueChanged(int)));
+    s_changedMap->insert( "KIntSpinBox", SIGNAL(valueChanged(int)));
+    s_changedMap->insert( "KDoubleNumInput", SIGNAL(valueChanged(double)));
     s_changedMap->insert( "KButtonGroup", SIGNAL(changed(int)));
   }
 }
@@ -253,7 +263,7 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
             if ( childWidget->metaObject()->superClass() )
               changedIt = s_changedMap->constFind(childWidget->metaObject()->superClass()->className());
             else
-              changedIt = s_changedMap->constFind(0);
+              changedIt = s_changedMap->constFind(QString());
           }
 
           if (changedIt == s_changedMap->constEnd())
@@ -267,7 +277,7 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
 
             QComboBox *cb = qobject_cast<QComboBox *>(childWidget);
             if (cb && cb->isEditable())
-              connect(cb, SIGNAL(editTextChanged(const QString &)),
+              connect(cb, SIGNAL(editTextChanged(QString)),
                     this, SIGNAL(widgetModified()));
 	  }
         }
@@ -279,7 +289,7 @@ bool KConfigDialogManager::parseChildren(const QWidget *widget, bool trackChange
       }
       else
       {
-        kFatal(d->debugArea()) << "A widget named '" << widgetName << "' was found but there is no setting named '" << configId << "'";
+        kWarning(d->debugArea()) << "A widget named '" << widgetName << "' was found but there is no setting named '" << configId << "'";
       }
     }
     else if (QLabel *label = qobject_cast<QLabel*>(childWidget))
@@ -402,12 +412,24 @@ QByteArray KConfigDialogManager::getUserProperty(const QWidget *widget) const
     if ( user.isValid() ) {
         s_propertyMap->insert( widget->metaObject()->className(), user.name() );
         //kDebug(d->debugArea()) << "class name: '" << widget->metaObject()->className()
-        //<< " 's USER property: " << metaProperty.name() << endl;
+        //<< " 's USER property: " << metaProperty.name();
     }
     else {
         return QByteArray(); //no USER property
     }
   }
+  const QComboBox *cb = qobject_cast<const QComboBox *>(widget);
+  if (cb) {
+    const char *qcomboUserPropertyName = cb->QComboBox::metaObject()->userProperty().name();
+    const int qcomboUserPropertyIndex = qcomboUserPropertyName ? cb->QComboBox::metaObject()->indexOfProperty(qcomboUserPropertyName) : -1;
+    const char *widgetUserPropertyName = widget->metaObject()->userProperty().name();
+    const int widgetUserPropertyIndex = widgetUserPropertyName ? cb->metaObject()->indexOfProperty(widgetUserPropertyName) : -1;
+
+    if (qcomboUserPropertyIndex == widgetUserPropertyIndex) {
+        return QByteArray(); // use the q/kcombobox special code
+    }
+  }
+
   return s_propertyMap->value( widget->metaObject()->className() );
 }
 
@@ -455,9 +477,12 @@ void KConfigDialogManager::setProperty(QWidget *w, const QVariant &v)
             }
             return;
         }
+    }
+    if (userproperty.isEmpty()) {
         kWarning(d->debugArea()) << w->metaObject()->className() << " widget not handled!";
         return;
     }
+
     w->setProperty(userproperty, v);
 }
 
@@ -480,6 +505,8 @@ QVariant KConfigDialogManager::property(QWidget *w) const
                 return QVariant(cb->currentIndex());
             }
         }
+    }
+    if (userproperty.isEmpty()) {
         kWarning(d->debugArea()) << w->metaObject()->className() << " widget not handled!";
         return QVariant();
     }
@@ -517,5 +544,5 @@ bool KConfigDialogManager::isDefault() const
   return result;
 }
 
-#include "kconfigdialogmanager.moc"
+#include "moc_kconfigdialogmanager.cpp"
 
