@@ -31,7 +31,7 @@
 #include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
-#include <QHideEvent>
+#include <QtGui/qevent.h>
 #include <QPointer>
 #include <QStyle>
 #include <QTimer>
@@ -50,6 +50,8 @@
 #include <netwm.h>
 #endif
 
+static bool sAllowEmbeddingInGraphicsView = false;
+
 void KDialogPrivate::setupLayout()
 {
     Q_Q(KDialog);
@@ -108,6 +110,8 @@ void KDialogPrivate::queuedLayoutUpdate()
 
 void KDialogPrivate::appendButton(KDialog::ButtonCode key, const KGuiItem &item)
 {
+    Q_Q(KDialog);
+
   QDialogButtonBox::ButtonRole role = QDialogButtonBox::InvalidRole;
   switch ( key ) {
     case KDialog::Help:
@@ -155,7 +159,12 @@ void KDialogPrivate::appendButton(KDialog::ButtonCode key, const KGuiItem &item)
   mButtonSignalMapper.setMapping( button, key );
 
     QObject::connect(button, SIGNAL(clicked()),
-           &mButtonSignalMapper, SLOT( map() ) );
+           &mButtonSignalMapper, SLOT(map()) );
+
+    if (key == mDefaultButton) {
+        // Now that it exists, set it as default
+        q->setDefaultButton(mDefaultButton);
+    }
 }
 
 void KDialogPrivate::init(KDialog *q)
@@ -169,7 +178,7 @@ void KDialogPrivate::init(KDialog *q)
 
     q->connect(&mButtonSignalMapper, SIGNAL(mapped(int)), q, SLOT(slotButtonClicked(int)));
 
-    q->setPlainCaption(KGlobal::caption()); // set appropriate initial window title for case it gets not set later
+    q->setWindowTitle(KGlobal::caption()); // set appropriate initial window title for case it gets not set later
 }
 
 void KDialogPrivate::helpLinkClicked()
@@ -177,14 +186,14 @@ void KDialogPrivate::helpLinkClicked()
     q_ptr->slotButtonClicked(KDialog::Help);
 }
 
-KDialog::KDialog( QWidget *parent, Qt::WFlags flags )
-  : QDialog(parent, flags), d_ptr(new KDialogPrivate)
+KDialog::KDialog( QWidget *parent, Qt::WindowFlags flags )
+  : QDialog(parent, sAllowEmbeddingInGraphicsView ? flags : flags | Qt::BypassGraphicsProxyWidget ), d_ptr(new KDialogPrivate)
 {
     d_ptr->init(this);
 }
 
-KDialog::KDialog(KDialogPrivate &dd, QWidget *parent, Qt::WFlags flags)
-    : QDialog(parent, flags), d_ptr(&dd)
+KDialog::KDialog(KDialogPrivate &dd, QWidget *parent, Qt::WindowFlags flags)
+    : QDialog(parent, sAllowEmbeddingInGraphicsView ? flags : flags | Qt::BypassGraphicsProxyWidget), d_ptr(&dd)
 {
     d_ptr->init(this);
 }
@@ -277,6 +286,8 @@ void KDialog::setEscapeButton( ButtonCode id )
 
 void KDialog::setDefaultButton( ButtonCode newDefaultButton )
 {
+    Q_D(KDialog);
+
     if (newDefaultButton == None)
         newDefaultButton = NoDefault; // #148969
 
@@ -306,6 +317,7 @@ void KDialog::setDefaultButton( ButtonCode newDefaultButton )
             }
         }
     }
+    d->mDefaultButton = newDefaultButton;
     Q_ASSERT(defaultButton() == newDefaultButton);
 }
 
@@ -320,7 +332,7 @@ KDialog::ButtonCode KDialog::defaultButton() const
     }
   }
 
-  return NoDefault;
+    return d->mDefaultButton;
 }
 
 void KDialog::setMainWidget( QWidget *widget )
@@ -457,7 +469,7 @@ QString KDialog::makeStandardCaption( const QString &userCaption,
 void KDialog::setCaption( const QString &_caption )
 {
   const QString caption = makeStandardCaption( _caption, this );
-  setPlainCaption( caption );
+  setWindowTitle( caption );
 }
 
 void KDialog::setCaption( const QString &caption, bool modified )
@@ -469,19 +481,7 @@ void KDialog::setCaption( const QString &caption, bool modified )
         flags |= ModifiedCaption;
     }
 
-    setPlainCaption( makeStandardCaption(caption, this, flags) );
-}
-
-
-void KDialog::setPlainCaption( const QString &caption )
-{
-    if (QWidget *win = window()) {
-        win->setWindowTitle( caption );
-#ifdef Q_WS_X11
-        NETWinInfo info( QX11Info::display(), win->winId(), QX11Info::appRootWindow(), 0 );
-        info.setName( caption.toUtf8().constData() );
-#endif
-    }
+    setWindowTitle( makeStandardCaption(caption, this, flags) );
 }
 
 void KDialog::resizeLayout( QWidget *widget, int margin, int spacing ) //static
@@ -525,7 +525,7 @@ static QRect screenRect( QWidget *widget, int screen )
        cg.readEntry( "XineramaEnabled", true ) &&
        cg.readEntry( "XineramaPlacementEnabled", true ) ) {
 
-    if ( screen < 0 || screen >= desktop->numScreens() ) {
+    if ( screen < 0 || screen >= desktop->screenCount() ) {
       if ( screen == -1 )
         screen = desktop->primaryScreen();
       else if ( screen == -3 )
@@ -843,10 +843,11 @@ void KDialog::setDetailsWidgetVisible( bool visible )
     if ( d->mDetailsWidget )
       d->mDetailsWidget->hide();
 
-    if ( layout() )
+    if ( layout() ) {
       layout()->activate();
+      adjustSize();
+    }
 
-    adjustSize();
   }
 
   d->mSettingDetails = false;
@@ -863,7 +864,7 @@ void KDialog::delayedDestruct()
 
 void KDialog::slotButtonClicked( int button )
 {
-    Q_D(KDialog);
+  Q_D(KDialog);
   emit buttonClicked( static_cast<KDialog::ButtonCode>(button) );
 
   switch( button ) {
@@ -872,7 +873,7 @@ void KDialog::slotButtonClicked( int button )
       accept();
       break;
     case Apply:
-        emit applyClicked();
+      emit applyClicked();
       break;
     case Try:
       emit tryClicked();
@@ -881,17 +882,17 @@ void KDialog::slotButtonClicked( int button )
       emit user3Clicked();
       break;
     case User2:
-        emit user2Clicked();
+      emit user2Clicked();
       break;
     case User1:
-        emit user1Clicked();
-        break;
+      emit user1Clicked();
+      break;
     case Yes:
       emit yesClicked();
       done( Yes );
       break;
     case No:
-        emit noClicked();
+      emit noClicked();
       done( No );
       break;
     case Cancel:
@@ -1028,6 +1029,11 @@ void KDialog::saveDialogSize( KConfigGroup& config, KConfigGroup::WriteConfigFla
    config.writeEntry( QString::fromLatin1("Height %1").arg( desk.height() ), sizeToSave.height(), options );
 }
 
+void KDialog::setAllowEmbeddingInGraphicsView( bool allowEmbedding )
+{
+  sAllowEmbeddingInGraphicsView = allowEmbedding;
+}
+
 
 class KDialogQueue::Private
 {
@@ -1065,7 +1071,7 @@ void KDialogQueue::queueDialog( QDialog *dialog )
   KDialogQueue *_this = self();
   _this->d->queue.append( dialog );
 
-  QTimer::singleShot( 0, _this, SLOT( slotShowQueuedDialog() ) );
+  QTimer::singleShot( 0, _this, SLOT(slotShowQueuedDialog()) );
 }
 
 void KDialogQueue::Private::slotShowQueuedDialog()
@@ -1087,8 +1093,8 @@ void KDialogQueue::Private::slotShowQueuedDialog()
   delete dialog;
 
   if ( !queue.isEmpty() )
-    QTimer::singleShot( 20, q, SLOT( slotShowQueuedDialog() ) );
+    QTimer::singleShot( 20, q, SLOT(slotShowQueuedDialog()) );
 }
 
-#include "kdialog.moc"
-#include "kdialogqueue_p.moc"
+#include "moc_kdialog.cpp"
+#include "moc_kdialogqueue_p.cpp"
