@@ -25,13 +25,13 @@
 #define KDIALOG_H
 
 class KPushButton;
-class QMenu;
 class KDialogPrivate;
 
 #include <kdeui_export.h>
 #include <kconfiggroup.h>
 #include <kguiitem.h>
 
+#include <QtGui/QMenu>
 #include <QtGui/QDialog>
 
 /**
@@ -169,7 +169,7 @@ class KDEUI_EXPORT KDialog : public QDialog //krazy:exclude=qclasses
      * @param parent The parent of the dialog.
      * @param flags  The widget flags passed to the QDialog constructor
      */
-    explicit KDialog( QWidget *parent = 0, Qt::WFlags flags = 0 );
+    explicit KDialog( QWidget *parent = 0, Qt::WindowFlags flags = 0 );
 
     /**
      * Destroys the dialog.
@@ -232,7 +232,7 @@ class KDEUI_EXPORT KDialog : public QDialog //krazy:exclude=qclasses
     ButtonCode defaultButton() const;
 
     /**
-     * Hide or display the a separator line drawn between the action
+     * Hide or display the separator line drawn between the action
      * buttons an the main widget.
      */
     void showButtonSeparator( bool state );
@@ -541,6 +541,13 @@ class KDEUI_EXPORT KDialog : public QDialog //krazy:exclude=qclasses
      * Reimplemented from QDialog.
      */
     virtual QSize minimumSizeHint() const;
+	
+	/**
+	 * Allow embedding the dialogs based on KDialog into a graphics view. By default embedding is not allowed, dialogs
+	 * will appear as separate windows.
+	 * @since 4.6
+	*/
+	static void setAllowEmbeddingInGraphicsView( bool allowEmbedding );
 
   public Q_SLOTS:
     /**
@@ -563,14 +570,6 @@ class KDEUI_EXPORT KDialog : public QDialog //krazy:exclude=qclasses
      */
     virtual void setCaption( const QString &caption, bool modified );
 
-    /**
-     * Make a plain caption without any modifications.
-     *
-     * @param caption Your caption. This is the string that will be
-     * displayed in the window title.
-     */
-    virtual void setPlainCaption( const QString &caption );
-
     /**
      * Enable or disable (gray out) a general action button.
      *
@@ -844,7 +843,7 @@ class KDEUI_EXPORT KDialog : public QDialog //krazy:exclude=qclasses
     void updateGeometry();
 
     protected:
-        KDialog(KDialogPrivate &dd, QWidget *parent, Qt::WFlags flags = 0);
+        KDialog(KDialogPrivate &dd, QWidget *parent, Qt::WindowFlags flags = 0);
         KDialogPrivate *const d_ptr;
 
     private:
