@@ -19,20 +19,21 @@
 */
 #include <kedittoolbar.h>
 #include <kedittoolbar_p.h>
-#include <QShowEvent>
+#include <QtGui/qevent.h>
 
 
-#include <QtXml/QDomDocument>
-#include <QtGui/QLayout>
+#include <QtXml/qdom.h>
 #include <QtCore/QDir>
 #include <QtCore/QFile>
-#include <QHeaderView>
+#include <QtCore/QProcess>
+#include <QtCore/QMimeData>
+#include <QtGui/QHeaderView>
 #include <QtGui/QToolButton>
 #include <QtGui/QLabel>
 #include <QtGui/QApplication>
 #include <QtGui/QGridLayout>
 #include <QtGui/QCheckBox>
-#include <QMimeData>
+#include <QtGui/QLayout>
 
 #include <kstandarddirs.h>
 #include <klistwidgetsearchline.h>
@@ -46,7 +47,6 @@
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kpushbutton.h>
-#include <kprocess.h>
 #include <ktoolbar.h>
 #include <kdeversion.h>
 #include <kcombobox.h>
@@ -70,9 +70,9 @@ namespace KDEPrivate {
  */
 static ToolBarList findToolBars(const QDomElement& start)
 {
-    static const QString &tagToolBar = KGlobal::staticQString( "ToolBar" );
-    static const QString &tagMenuBar = KGlobal::staticQString( "MenuBar" );
-    static const QString &attrNoEdit = KGlobal::staticQString( "noEdit" );
+    static const QString tagToolBar = QString::fromLatin1( "ToolBar" );
+    static const QString tagMenuBar = QString::fromLatin1( "MenuBar" );
+    static const QString attrNoEdit = QString::fromLatin1( "noEdit" );
     ToolBarList list;
 
     for( QDomElement elem = start; !elem.isNull(); elem = elem.nextSiblingElement() ) {
@@ -116,7 +116,7 @@ public:
     KActionCollection* actionCollection() const { return m_actionCollection; }
     void setDomDocument(const QDomDocument& domDoc)
     {
-        m_document = domDoc;
+        m_document = domDoc.cloneNode().toDocument();
         m_barList = findToolBars(m_document.documentElement());
     }
     // Return reference, for e.g. actionPropertiesElement() to modify the document
@@ -143,9 +143,9 @@ private:
 
 QString XmlData::toolBarText( const QDomElement& it ) const
 {
-    static const QString &tagText = KGlobal::staticQString( "text" );
-    static const QString &tagText2 = KGlobal::staticQString( "Text" );
-    static const QString &attrName = KGlobal::staticQString( "name" );
+    static const QString tagText = QString::fromLatin1( "text" );
+    static const QString tagText2 = QString::fromLatin1( "Text" );
+    static const QString attrName = QString::fromLatin1( "name" );
 
     QString name;
     QByteArray txt( it.namedItem( tagText ).toElement().text().toUtf8() );
@@ -424,7 +424,7 @@ public:
      */
     QDomElement findElementForToolBarItem( const ToolBarItem* item ) const
     {
-        static const QString &attrName    = KGlobal::staticQString( "name" );
+        static const QString attrName    = QString::fromLatin1( "name" );
         //kDebug(240) << "looking for name=" << item->internalName() << "and tag=" << item->internalTag();
         for(QDomNode n = m_currentToolBarElem.firstChild(); !n.isNull(); n = n.nextSibling())
         {
@@ -486,7 +486,7 @@ public:
     QLabel * m_helpArea;
     KPushButton* m_changeIcon;
     KPushButton* m_changeIconText;
-    KProcess* m_kdialogProcess;
+    QProcess* m_kdialogProcess;
     bool m_isPart : 1;
     bool m_hasKDialog : 1;
     bool m_loadedOnce : 1;
@@ -652,7 +652,6 @@ void KEditToolBarPrivate::_k_slotDefault()
     q->enableButtonApply(false);
 
     emit q->newToolBarConfig();
-    emit q->newToolbarConfig(); // compat
 }
 
 void KEditToolBarPrivate::_k_slotOk()
@@ -672,7 +671,6 @@ void KEditToolBarPrivate::_k_slotOk()
     // button was already pressed and no further changes were made.
     if (q->isButtonEnabled(KDialog::Apply)) {
         emit q->newToolBarConfig();
-        emit q->newToolbarConfig(); // compat
     }
     q->accept();
   }
@@ -683,7 +681,6 @@ void KEditToolBarPrivate::_k_slotApply()
     (void)m_widget->save();
     q->enableButtonApply(false);
     emit q->newToolBarConfig();
-    emit q->newToolbarConfig(); // compat
 }
 
 void KEditToolBar::setGlobalDefaultToolBar(const char *toolbarName)
@@ -825,7 +822,12 @@ bool KEditToolBarWidget::save()
 
     // Add noMerge="1" to all the menus since we are saving the merged data
     QDomNodeList menuNodes = (*it).domDocument().elementsByTagName( "Menu" );
+    // the lenght() method had a TODO which is done in Katie
+#ifdef QT_KATIE
+    for (int i = 0; i < menuNodes.length(); ++i)
+#else
     for (uint i = 0; i < menuNodes.length(); ++i)
+#endif
     {
         QDomNode menuNode = menuNodes.item(i);
         QDomElement menuElement = menuNode.toElement();
@@ -1320,9 +1322,6 @@ void KEditToolBarWidgetPrivate::slotRemoveButton()
 {
   removeActive( m_activeList->currentItem() );
 
-  // we're modified, so let this change
-  emit m_widget->enableOk(true);
-
   slotToolBarSelected( m_toolbarCombo->currentIndex() );
 }
 
@@ -1331,10 +1330,10 @@ void KEditToolBarWidgetPrivate::insertActive(ToolBarItem *item, ToolBarItem *bef
   if (!item)
     return;
 
-  static const QString &tagAction    = KGlobal::staticQString( "Action" );
-  static const QString &tagSeparator = KGlobal::staticQString( "Separator" );
-  static const QString &attrName     = KGlobal::staticQString( "name" );
-  static const QString &attrNoMerge  = KGlobal::staticQString( "noMerge" );
+  static const QString tagAction    = QString::fromLatin1( "Action" );
+  static const QString tagSeparator = QString::fromLatin1( "Separator" );
+  static const QString attrName     = QString::fromLatin1( "name" );
+  static const QString attrNoMerge  = QString::fromLatin1( "noMerge" );
 
   QDomElement new_item;
   // let's handle the separator specially
@@ -1376,7 +1375,7 @@ void KEditToolBarWidgetPrivate::removeActive(ToolBarItem *item)
   if (!item)
     return;
 
-  static const QString &attrNoMerge = KGlobal::staticQString( "noMerge" );
+  static const QString attrNoMerge = QString::fromLatin1( "noMerge" );
 
   // we're modified, so let this change
   emit m_widget->enableOk(true);
@@ -1441,7 +1440,7 @@ void KEditToolBarWidgetPrivate::moveActive( ToolBarItem* item, ToolBarItem* befo
     m_currentToolBarElem.insertAfter(e, findElementForToolBarItem( (ToolBarItem*)before ));
 
   // and set this container as a noMerge
-  static const QString &attrNoMerge = KGlobal::staticQString( "noMerge" );
+  static const QString attrNoMerge = QString::fromLatin1( "noMerge" );
   m_currentToolBarElem.setAttribute( attrNoMerge, "1");
 
   // update the local doc
@@ -1472,7 +1471,7 @@ void KEditToolBarWidgetPrivate::slotDownButton()
 
 void KEditToolBarWidgetPrivate::updateLocal(QDomElement& elem)
 {
-  static const QString &attrName = KGlobal::staticQString( "name" );
+  static const QString attrName = QString::fromLatin1( "name" );
 
   XmlDataList::Iterator xit = m_xmlFiles.begin();
   for ( ; xit != m_xmlFiles.end(); ++xit)
@@ -1516,9 +1515,8 @@ void KEditToolBarWidgetPrivate::updateLocal(QDomElement& elem)
 
 void KEditToolBarWidgetPrivate::slotChangeIcon()
 {
-  // We can't use KIconChooser here, since it's in libkio
-  // ##### KDE4: reconsider this, e.g. move KEditToolBar to libkio,
-  // ##### or better, dlopen libkfile from here like kio does.
+  // We can't use KIconDialog here, since it's in libkio
+  // ##### KDE4: reconsider this, e.g. move KEditToolBar to libkio
 
   //if the process is already running (e.g. when somebody clicked the change button twice (see #127149)) - do nothing...
   //otherwise m_kdialogProcess will be overwritten and set to zero in slotProcessExited()...crash!
@@ -1528,21 +1526,20 @@ void KEditToolBarWidgetPrivate::slotChangeIcon()
   m_currentXmlData->dump();
   Q_ASSERT( m_currentXmlData->type() != XmlData::Merged );
 
-  m_kdialogProcess = new KProcess;
+  m_kdialogProcess = new QProcess();
   QString kdialogExe = KStandardDirs::findExe(QLatin1String("kdialog"));
-  (*m_kdialogProcess) << kdialogExe;
-  (*m_kdialogProcess) << "--caption";
-  (*m_kdialogProcess) << i18n( "Change Icon" );
-  (*m_kdialogProcess) << "--embed";
-  (*m_kdialogProcess) << QString::number( (quintptr)m_widget->window()->winId() );
-  (*m_kdialogProcess) << "--geticon";
-  (*m_kdialogProcess) << "Toolbar";
-  (*m_kdialogProcess) << "Actions";
-  m_kdialogProcess->setOutputChannelMode(KProcess::OnlyStdoutChannel);
-  m_kdialogProcess->setNextOpenMode( QIODevice::ReadOnly | QIODevice::Text );
-  m_kdialogProcess->start();
+  QStringList kdialogArgs;
+  kdialogArgs << "--caption";
+  kdialogArgs << i18n( "Change Icon" );
+  kdialogArgs << "--embed";
+  kdialogArgs << QString::number( (quintptr)m_widget->window()->winId() );
+  kdialogArgs << "--geticon";
+  kdialogArgs << "Toolbar";
+  kdialogArgs << "Actions";
+  m_kdialogProcess->setReadChannel(QProcess::StandardOutput);
+  m_kdialogProcess->start(kdialogExe, kdialogArgs, QIODevice::ReadOnly | QIODevice::Text);
   if ( !m_kdialogProcess->waitForStarted() ) {
-    kError(240) << "Can't run " << kdialogExe << endl;
+    kError(240) << "Can't run " << kdialogExe;
     delete m_kdialogProcess;
     m_kdialogProcess = 0;
     return;
@@ -1608,7 +1605,7 @@ void KEditToolBarWidgetPrivate::slotProcessExited()
   QString icon;
 
   if (!m_kdialogProcess) {
-         kError(240) << "Something is wrong here! m_kdialogProcess is zero!" << endl;
+         kError(240) << "Something is wrong here! m_kdialogProcess is zero!";
          return;
   }
 
@@ -1699,5 +1696,5 @@ void KEditToolBar::hideEvent(QHideEvent* event)
   KDialog::hideEvent(event);
 }
 
-#include "kedittoolbar.moc"
-#include "kedittoolbar_p.moc"
+#include "moc_kedittoolbar.cpp"
+#include "moc_kedittoolbar_p.cpp"
