@@ -137,10 +137,18 @@ static void sendNotification( QString message, //krazy:exclude=passbyvalue
     }
 
     if ( !message.isEmpty() ) {
-        KNotification::event( messageType, message , QPixmap() , QWidget::find( parent_id ) );
+        KNotification::event( messageType, message, QPixmap(), QWidget::find( parent_id ),
+                              KNotification::DefaultEvent | KNotification::CloseOnTimeout );
     }
 }
 
+static void applyOptions( KDialog* dialog, KMessageBox::Options options )
+{
+    if ( options & KMessageBox::WindowModal ) {
+        dialog->setWindowModality( Qt::WindowModal );
+    }
+    dialog->setModal( true );
+}
 
 int KMessageBox::createKMessageBox(KDialog *dialog, QMessageBox::Icon icon,
                              const QString &text, const QStringList &strlist,
@@ -159,18 +167,20 @@ int KMessageBox::createKMessageBox(KDialog *dialog, const QIcon &icon,
 {
     QWidget *mainWidget = new QWidget(dialog);
     QVBoxLayout *mainLayout = new QVBoxLayout(mainWidget);
-    mainLayout->setSpacing(KDialog::spacingHint() * 2);
+    mainLayout->setSpacing(KDialog::spacingHint() * 2); // provide extra spacing
     mainLayout->setMargin(0);
 
     QHBoxLayout *hLayout = new QHBoxLayout();
     hLayout->setMargin(0);
-    hLayout->setSpacing(KDialog::spacingHint());
+    hLayout->setSpacing(-1); // use default spacing
     mainLayout->addLayout(hLayout,5);
 
     QLabel *iconLabel = new QLabel(mainWidget);
 
     if (!icon.isNull()) {
-       iconLabel->setPixmap(icon.pixmap(KIconLoader::SizeHuge));
+        QStyleOption option;
+        option.initFrom(mainWidget);
+        iconLabel->setPixmap(icon.pixmap(mainWidget->style()->pixelMetric(QStyle::PM_MessageBoxIconSize, &option, mainWidget)));
     }
 
     QVBoxLayout *iconLayout = new QVBoxLayout();
@@ -182,24 +192,29 @@ int KMessageBox::createKMessageBox(KDialog *dialog, const QIcon &icon,
     hLayout->addSpacing(KDialog::spacingHint());
 
     QLabel *messageLabel = new QLabel(text, mainWidget);
+    messageLabel->setOpenExternalLinks(options & KMessageBox::AllowLink);
+    Qt::TextInteractionFlags flags = Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard;
+    if (options & KMessageBox::AllowLink) {
+        flags |= Qt::LinksAccessibleByMouse | Qt::LinksAccessibleByKeyboard;
+    }
+    messageLabel->setTextInteractionFlags(flags);
+
     QRect desktop = KGlobalSettings::desktopGeometry(dialog);
-    bool usingSqueezedTextLabel=false;
-    if (desktop.width() / 2 < messageLabel->sizeHint().width()) {
-        // do only enable automatic wrapping of messages which are longer than one third of the current screen
+    bool usingSqueezedTextLabel = false;
+    if (messageLabel->sizeHint().width() > desktop.width() * 0.5) {
+        // enable automatic wrapping of messages which are longer than 50% of screen width
         messageLabel->setWordWrap(true);
-        usingSqueezedTextLabel=desktop.width() / 2 < messageLabel->sizeHint().width();
+        // display a text widget with scrollbar if still too wide
+        usingSqueezedTextLabel = messageLabel->sizeHint().width() > desktop.width() * 0.85;
         if (usingSqueezedTextLabel)
         {
             delete messageLabel;
             messageLabel = new KSqueezedTextLabel(text, mainWidget);
+            messageLabel->setOpenExternalLinks(options & KMessageBox::AllowLink);
+            messageLabel->setTextInteractionFlags(flags);
         }
     }
 
-    messageLabel->setOpenExternalLinks(options & KMessageBox::AllowLink );
-    Qt::TextInteractionFlags flags = Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard;
-    if ( options & KMessageBox::AllowLink )
-        flags |= Qt::LinksAccessibleByMouse | Qt::LinksAccessibleByKeyboard;;
-    messageLabel->setTextInteractionFlags(flags);
     QPalette messagePal(messageLabel->palette());
     messagePal.setColor(QPalette::Window, Qt::transparent);
     messageLabel->setPalette(messagePal);
@@ -237,8 +252,8 @@ int KMessageBox::createKMessageBox(KDialog *dialog, const QIcon &icon,
         }
         const int borderWidth = listWidget->width() - listWidget->viewport()->width() + listWidget->verticalScrollBar()->height();
         w += borderWidth;
-        if (qRound(desktop.width() / 2) < w) { // do not allow the listWidget to be bigger than half width of the current screen
-            w = qRound(desktop.width() / 2);
+        if (w > desktop.width() * 0.85) { // limit listWidget size to 85% of screen width
+            w = qRound(desktop.width() * 0.85);
         }
         listWidget->setMinimumWidth(w);
 
@@ -283,7 +298,6 @@ int KMessageBox::createKMessageBox(KDialog *dialog, const QIcon &icon,
     }
 
     dialog->setMainWidget(mainWidget);
-    dialog->showButtonSeparator(true);
     if (!usingListWidget && !usingScrollArea && !usingSqueezedTextLabel && details.isEmpty())
         dialog->setFixedSize(dialog->sizeHint() + QSize( 10, 10 ));
     else if (!details.isEmpty() && dialog->minimumHeight()<iconLabel->sizeHint().height()*2)//strange bug...
@@ -307,11 +321,9 @@ int KMessageBox::createKMessageBox(KDialog *dialog, const QIcon &icon,
         dialog->setButtonFocus(defaultCode);
     }
 
-#ifndef Q_WS_WIN // FIXME problems with KNotify on Windows
     if ((options & KMessageBox::Notify)) {
-        sendNotification(text, strlist, notifyType, dialog->topLevelWidget()->winId());
+        sendNotification(text, strlist, notifyType, dialog->window()->winId());
     }
-#endif
 
     if (KMessageBox_queue) {
         KDialogQueue::queueDialog(dialog);
@@ -454,14 +466,13 @@ int KMessageBox::questionYesNoListWId(WId parent_id, const QString &text,
     dialog->setCaption( caption.isEmpty() ? i18n("Question") : caption );
     dialog->setButtons( KDialog::Yes | KDialog::No );
     dialog->setObjectName( "questionYesNo" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
     dialog->setButtonGuiItem( KDialog::Yes, buttonYes );
     dialog->setButtonGuiItem( KDialog::No, buttonNo );
     dialog->setDefaultButton( KDialog::Yes );
     dialog->setEscapeButton( KDialog::No );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -516,14 +527,13 @@ int KMessageBox::questionYesNoCancelWId(WId parent_id,
     dialog->setCaption( caption.isEmpty() ? i18n("Question") : caption );
     dialog->setButtons( KDialog::Yes | KDialog::No | KDialog::Cancel );
     dialog->setObjectName( "questionYesNoCancel" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
     dialog->setButtonGuiItem( KDialog::Yes, buttonYes );
     dialog->setButtonGuiItem( KDialog::No, buttonNo );
     dialog->setButtonGuiItem( KDialog::Cancel, buttonCancel );
     dialog->setDefaultButton( KDialog::Yes );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -605,14 +615,13 @@ int KMessageBox::warningYesNoListWId(WId parent_id, const QString &text,
     dialog->setCaption( caption.isEmpty() ? i18n("Warning") : caption );
     dialog->setButtons( KDialog::Yes | KDialog::No );
     dialog->setObjectName( "warningYesNoList" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
     dialog->setButtonGuiItem( KDialog::Yes, buttonYes );
     dialog->setButtonGuiItem( KDialog::No, buttonNo );
     dialog->setDefaultButton( KDialog::No );
     dialog->setEscapeButton( KDialog::No );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -686,14 +695,13 @@ int KMessageBox::warningContinueCancelListWId(WId parent_id, const QString &text
     dialog->setCaption( caption.isEmpty() ? i18n("Warning") : caption );
     dialog->setButtons( KDialog::Yes | KDialog::No );
     dialog->setObjectName( "warningYesNo" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
     dialog->setButtonGuiItem( KDialog::Yes, buttonContinue );
     dialog->setButtonGuiItem( KDialog::No, buttonCancel );
     dialog->setDefaultButton( KDialog::Yes );
     dialog->setEscapeButton( KDialog::No );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -774,14 +782,13 @@ int KMessageBox::warningYesNoCancelListWId(WId parent_id, const QString &text,
     dialog->setCaption( caption.isEmpty() ? i18n("Warning") : caption );
     dialog->setButtons( KDialog::Yes | KDialog::No | KDialog::Cancel );
     dialog->setObjectName( "warningYesNoCancel" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
     dialog->setButtonGuiItem( KDialog::Yes, buttonYes );
     dialog->setButtonGuiItem( KDialog::No, buttonNo );
     dialog->setButtonGuiItem( KDialog::Cancel, buttonCancel );
     dialog->setDefaultButton( KDialog::Yes );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -830,16 +837,13 @@ void KMessageBox::errorListWId(WId parent_id,  const QString &text, const QStrin
     QWidget* parent = QWidget::find( parent_id );
     KDialog *dialog = new KDialog(parent, Qt::Dialog);
     dialog->setCaption( caption.isEmpty() ? i18n("Error") : caption );
-    dialog->setButtons( KDialog::Yes );
+    dialog->setButtons( KDialog::Ok );
     dialog->setObjectName( "error" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
-    dialog->setButtonText( KDialog::Yes, KStandardGuiItem::ok().text() );
-    dialog->setButtonToolTip( KDialog::Yes, QString() );
-    dialog->setDefaultButton( KDialog::Yes );
-    dialog->setEscapeButton( KDialog::Yes );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    dialog->setDefaultButton( KDialog::Ok );
+    dialog->setEscapeButton( KDialog::Ok );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -863,15 +867,13 @@ void KMessageBox::detailedErrorWId(WId parent_id,  const QString &text,
     QWidget* parent = QWidget::find( parent_id );
     KDialog *dialog = new KDialog(parent, Qt::Dialog);
     dialog->setCaption( caption.isEmpty() ? i18n("Error") : caption );
-    dialog->setButtons( KDialog::Yes | KDialog::Details );
+    dialog->setButtons( KDialog::Ok | KDialog::Details );
     dialog->setObjectName( "error" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
-    dialog->setButtonText( KDialog::Yes, KStandardGuiItem::ok().text() );
-    dialog->setDefaultButton( KDialog::Yes );
-    dialog->setEscapeButton( KDialog::Yes );
-    if( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    dialog->setDefaultButton( KDialog::Ok );
+    dialog->setEscapeButton( KDialog::Ok );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -909,15 +911,13 @@ void KMessageBox::sorryWId(WId parent_id, const QString &text,
     QWidget* parent = QWidget::find( parent_id );
     KDialog *dialog = new KDialog(parent, Qt::Dialog);
     dialog->setCaption( caption.isEmpty() ? i18n("Sorry") : caption );
-    dialog->setButtons( KDialog::Yes );
+    dialog->setButtons( KDialog::Ok );
     dialog->setObjectName( "sorry" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
-    dialog->setButtonText( KDialog::Yes, KStandardGuiItem::ok().text() );
-    dialog->setDefaultButton( KDialog::Yes );
-    dialog->setEscapeButton( KDialog::Yes );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    dialog->setDefaultButton( KDialog::Ok );
+    dialog->setEscapeButton( KDialog::Ok );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -940,15 +940,13 @@ void KMessageBox::detailedSorryWId(WId parent_id, const QString &text,
     QWidget* parent = QWidget::find( parent_id );
     KDialog *dialog = new KDialog(parent, Qt::Dialog);
     dialog->setCaption( caption.isEmpty() ? i18n("Sorry") : caption );
-    dialog->setButtons( KDialog::Yes | KDialog::Details );
+    dialog->setButtons( KDialog::Ok | KDialog::Details );
     dialog->setObjectName( "sorry" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
-    dialog->setButtonText( KDialog::Yes, KStandardGuiItem::ok().text() );
-    dialog->setDefaultButton( KDialog::Yes );
-    dialog->setEscapeButton( KDialog::Yes );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    dialog->setDefaultButton( KDialog::Ok );
+    dialog->setEscapeButton( KDialog::Ok );
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -986,15 +984,13 @@ void KMessageBox::informationListWId(WId parent_id,const QString &text, const QS
     QWidget* parent = QWidget::find( parent_id );
     KDialog *dialog = new KDialog(parent, Qt::Dialog);
     dialog->setCaption( caption.isEmpty() ? i18n("Information") : caption );
-    dialog->setButtons( KDialog::Yes );
+    dialog->setButtons( KDialog::Ok );
     dialog->setObjectName( "information" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
-    dialog->setButtonText( KDialog::Yes, KStandardGuiItem::ok().text() );
-    dialog->setDefaultButton( KDialog::Yes );
-    dialog->setEscapeButton( KDialog::Yes );
-    if ( options & PlainCaption ) {
-        dialog->setPlainCaption( caption );
+    dialog->setDefaultButton( KDialog::Ok );
+    dialog->setEscapeButton( KDialog::Ok);
+    applyOptions( dialog, options );
+    if ( options & KMessageBox::PlainCaption ) {
+        dialog->setWindowTitle( caption );
     }
     if ( parent == NULL && parent_id ) {
         KWindowSystem::setMainWindow( dialog, parent_id );
@@ -1053,20 +1049,17 @@ void KMessageBox::about(QWidget *parent, const QString &text,
 
     KDialog *dialog = new KDialog(parent, Qt::Dialog);
     dialog->setCaption( caption );
-    dialog->setButtons( KDialog::Yes );
+    dialog->setButtons( KDialog::Ok );
     dialog->setObjectName( "about" );
-    dialog->setModal( true );
-    dialog->showButtonSeparator( true );
-    dialog->setButtonText( KDialog::Yes, KStandardGuiItem::ok().text() );
-    dialog->setDefaultButton( KDialog::Yes );
-    dialog->setEscapeButton( KDialog::Yes );
+    applyOptions( dialog, options );
+    dialog->setDefaultButton( KDialog::Ok );
+    dialog->setEscapeButton( KDialog::Ok );
     if (qApp->windowIcon().isNull()) {
         QPixmap ret = QMessageBox::standardIcon(QMessageBox::Information);
         dialog->setWindowIcon(ret);
     }
 
     createKMessageBox(dialog, qApp->windowIcon(), text, QStringList(), QString(), 0, options);
-    return;
 }
 
 int KMessageBox::messageBox( QWidget *parent, DialogType type, const QString &text,
