@@ -23,7 +23,7 @@
 #include <QMenu>
 #include <QFile>
 #include <QTextStream>
-#include <QtXml/QDomDocument>
+#include <QtXml/qdom.h>
 #include <QFileDialog>
 
 #include <kcombobox.h>
@@ -33,6 +33,7 @@
 #include <kmessagebox.h>
 #include <kxmlguiclient.h>
 #include <kinputdialog.h>
+#include <klocale.h>
 
 #include "kshortcutsdialog.h"
 #include "kshortcutschemeshelper_p.h"
@@ -176,11 +177,8 @@ void KShortcutSchemesEditor::exportShortcutsScheme()
     {
         const KXMLGUIClient *client = collection->parentGUIClient();
         if (!client) continue;
-        QString fileDir = QLatin1String("shortcuts/share/apps/")
-                        + client->componentData().componentName() + '/';
-        schemeRoot.mkpath(fileDir);
         KShortcutSchemesHelper::exportActionCollection(collection,
-            currentScheme(), exportTo + '/' + fileDir);
+            currentScheme(), exportTo + '/');
     }
 }
 
