@@ -35,7 +35,7 @@
 #include <QTextDocument>
 #include <QTextTable>
 #include <QTextCursor>
-#include <QTextTableFormat>
+#include <QtGui/qtextformat.h>
 #include <QPrinter>
 #include <QPrintDialog>
 
@@ -48,6 +48,7 @@
 #include "kmessagebox.h"
 #include "kshortcut.h"
 #include "kaboutdata.h"
+#include "kconfiggroup.h"
 
 //---------------------------------------------------------------------
 // KShortcutsEditor
@@ -173,12 +174,6 @@ void KShortcutsEditor::clearConfiguration()
 }
 
 
-#ifndef KDE_NO_DEPRECATED
-void KShortcutsEditor::importConfiguration( KConfig *config)
-{
-    d->importConfiguration(config);
-}
-#endif
 
 
 void KShortcutsEditor::importConfiguration( KConfigBase *config)
@@ -187,12 +182,6 @@ void KShortcutsEditor::importConfiguration( KConfigBase *config)
 }
 
 
-#ifndef KDE_NO_DEPRECATED
-void KShortcutsEditor::exportConfiguration( KConfig *config) const
-{
-    exportConfiguration(static_cast<KConfigBase*>(config));
-}
-#endif
 
 
 void KShortcutsEditor::exportConfiguration( KConfigBase *config) const
@@ -300,8 +289,6 @@ void KShortcutsEditorPrivate::initGUI( KShortcutsEditor::ActionTypes types, KSho
     ui.searchFilter->searchLine()->setTreeWidget(ui.list); // Plug into search line
     ui.list->header()->setResizeMode(QHeaderView::ResizeToContents);
     ui.list->header()->hideSection(GlobalAlternate);  //not expected to be very useful
-    ui.list->header()->hideSection(ShapeGesture);  //mouse gestures didn't make it in time...
-    ui.list->header()->hideSection(RockerGesture);
     if (!(actionTypes & KShortcutsEditor::GlobalAction)) {
         ui.list->header()->hideSection(GlobalPrimary);
     } else if (!(actionTypes & ~KShortcutsEditor::GlobalAction)) {
@@ -373,12 +360,6 @@ void KShortcutsEditorPrivate::allDefault()
             changeKeyShortcut(item, GlobalPrimary, act->globalShortcut(KAction::DefaultShortcut).primary());
             changeKeyShortcut(item, GlobalAlternate, act->globalShortcut(KAction::DefaultShortcut).alternate());
         }
-
-        if (act->shapeGesture() != act->shapeGesture(KAction::DefaultShortcut))
-            changeShapeGesture(item, act->shapeGesture(KAction::DefaultShortcut));
-
-        if (act->rockerGesture() != act->rockerGesture(KAction::DefaultShortcut))
-            changeRockerGesture(item, act->rockerGesture(KAction::DefaultShortcut));
     }
 }
 
@@ -421,10 +402,6 @@ void KShortcutsEditorPrivate::capturedShortcut(const QVariant &newShortcut, cons
 
     if (column >= LocalPrimary && column <= GlobalAlternate)
         changeKeyShortcut(item, column, newShortcut.value<QKeySequence>());
-    else if (column == ShapeGesture)
-        changeShapeGesture(item, newShortcut.value<KShapeGesture>());
-    else if (column == RockerGesture)
-        changeRockerGesture(item, newShortcut.value<KRockerGesture>());
 }
 
 
@@ -442,69 +419,6 @@ void KShortcutsEditorPrivate::changeKeyShortcut(KShortcutsEditorItem *item, uint
 }
 
 
-void KShortcutsEditorPrivate::changeShapeGesture(KShortcutsEditorItem *item, const KShapeGesture &capture)
-{
-    if (capture == item->m_action->shapeGesture())
-        return;
-
-    if (capture.isValid()) {
-        bool conflict = false;
-        KShortcutsEditorItem *otherItem;
-
-        //search for conflicts
-        for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
-            if (!(*it)->parent() || (*it == item))
-                continue;
-
-            otherItem = static_cast<KShortcutsEditorItem *>(*it);
-
-            //comparisons are possibly expensive
-            if (!otherItem->m_action->shapeGesture().isValid())
-                continue;
-
-            if (capture == otherItem->m_action->shapeGesture()) {
-                conflict = true;
-                break;
-            }
-        }
-
-        if (conflict && !stealShapeGesture(otherItem, capture))
-            return;
-    }
-
-    item->setShapeGesture(capture);
-}
-
-
-void KShortcutsEditorPrivate::changeRockerGesture(KShortcutsEditorItem *item, const KRockerGesture &capture)
-{
-    if (capture == item->m_action->rockerGesture())
-        return;
-
-    if (capture.isValid()) {
-        bool conflict = false;
-        KShortcutsEditorItem *otherItem;
-
-        for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
-            if (!(*it)->parent() || (*it == item))
-                continue;
-
-            otherItem = static_cast<KShortcutsEditorItem *>(*it);
-
-            if (capture == otherItem->m_action->rockerGesture()) {
-                conflict = true;
-                break;
-            }
-        }
-
-        if (conflict && !stealRockerGesture(otherItem, capture))
-            return;
-    }
-
-    item->setRockerGesture(capture);
-}
-
-
 void KShortcutsEditorPrivate::clearConfiguration()
 {
     for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
@@ -518,9 +432,6 @@ void KShortcutsEditorPrivate::clearConfiguration()
 
         changeKeyShortcut(item, GlobalPrimary,   QKeySequence());
         changeKeyShortcut(item, GlobalAlternate, QKeySequence());
-
-        changeShapeGesture(item, KShapeGesture() );
-
     }
 }
 
@@ -564,39 +475,6 @@ void KShortcutsEditorPrivate::importConfiguration(KConfigBase *config)
     }
 }
 
-
-bool KShortcutsEditorPrivate::stealShapeGesture(KShortcutsEditorItem *item, const KShapeGesture &gst)
-{
-    QString title = i18n("Key Conflict");
-    QString message = i18n("The '%1' shape gesture has already been allocated to the \"%2\" action.\n"
-                           "Do you want to reassign it from that action to the current one?",
-                           gst.shapeName(), item->m_action->text());
-
-    if (KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18n("Reassign")))
-        != KMessageBox::Continue)
-        return false;
-
-    item->setShapeGesture(KShapeGesture());
-    return true;
-}
-
-
-bool KShortcutsEditorPrivate::stealRockerGesture(KShortcutsEditorItem *item, const KRockerGesture &gst)
-{
-    QString title = i18n("Key Conflict");
-    QString message = i18n("The '%1' rocker gesture has already been allocated to the \"%2\" action.\n"
-                           "Do you want to reassign it from that action to the current one?",
-                           gst.rockerName(), item->m_action->text());
-
-    if (KMessageBox::warningContinueCancel(q, message, title, KGuiItem(i18n("Reassign")))
-        != KMessageBox::Continue)
-        return false;
-
-    item->setRockerGesture(KRockerGesture());
-    return true;
-}
-
-
 /*TODO for the printShortcuts function
 Nice to have features (which I'm not sure I can do before may due to
 more important things):
@@ -618,7 +496,6 @@ more important things):
 void KShortcutsEditorPrivate::printShortcuts() const
 {
 // One cant print on wince
-#ifndef _WIN32_WCE
     QTreeWidgetItem* root = ui.list->invisibleRootItem();
     QTextDocument doc;
     doc.setDefaultFont(KGlobalSettings::generalFont());
@@ -722,7 +599,6 @@ void KShortcutsEditorPrivate::printShortcuts() const
         doc.print(&printer);
     }
     delete dlg;
-#endif
 }
 
-#include "kshortcutseditor.moc"
+#include "moc_kshortcutseditor.cpp"
