@@ -28,9 +28,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <QtCore/QFile>
 #include <QtGui/QCheckBox>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QLabel>
 #include <QtGui/QLayout>
+#include <QtGui/QTextBrowser>
 
 #include <kaboutdata.h>
 #include <kconfig.h>
@@ -42,7 +43,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <krandom.h>
 #include <kseparator.h>
 #include <kstandarddirs.h>
-#include <ktextbrowser.h>
 
 class KTipDatabase::Private
 {
@@ -123,7 +123,7 @@ KTipDatabase::KTipDatabase( const QString &_tipFile )
   d->loadTips( tipFile );
 
   if ( !d->tips.isEmpty() )
-    d->currentTip = KRandom::random() % d->tips.count();
+    d->currentTip = KRandom::randomMax(d->tips.count());
 }
 
 KTipDatabase::KTipDatabase( const QStringList& tipsFiles )
@@ -137,7 +137,7 @@ KTipDatabase::KTipDatabase( const QStringList& tipsFiles )
   }
 
   if ( !d->tips.isEmpty() )
-    d->currentTip = KRandom::random() % d->tips.count();
+    d->currentTip = KRandom::randomMax(d->tips.count());
 }
 
 KTipDatabase::~KTipDatabase()
@@ -195,7 +195,7 @@ class KTipDialog::Private
     KTipDialog *parent;
     KTipDatabase *database;
     QCheckBox *tipOnStart;
-    KTextBrowser *tipText;
+    QTextBrowser *tipText;
 
     static KTipDialog *mInstance;
 };
@@ -255,7 +255,7 @@ KTipDialog::KTipDialog( KTipDatabase *database, QWidget *parent )
   QHBoxLayout *browserLayout = new QHBoxLayout();
   mainLayout->addLayout( browserLayout );
 
-  d->tipText = new KTextBrowser( this );
+  d->tipText = new QTextBrowser( this );
 
   d->tipText->setOpenExternalLinks( true );
 
@@ -366,7 +366,7 @@ void KTipDialog::showMultiTip( QWidget *parent, const QStringList &tipFiles, boo
       QDateTime lastShown = configGroup.readEntry( "TipLastShown", QDateTime() );
 
       // Show tip roughly once a week
-      if ( lastShown.secsTo( QDateTime::currentDateTime() ) < (oneDay + (KRandom::random() % (10 * oneDay))) )
+      if ( lastShown.secsTo( QDateTime::currentDateTime() ) < (oneDay + (KRandom::randomMax(10 * oneDay))) )
         return;
     }
 
@@ -402,9 +402,9 @@ bool KTipDialog::eventFilter( QObject *object, QEvent *event )
 
   /**
    * If the user presses Return or Space, we close the dialog as if the
-   * default button was pressed even if the KTextBrowser has the keyboard
+   * default button was pressed even if the QTextBrowser has the keyboard
    * focus. This could have the bad side-effect that the user cannot use the
-   * keyboard to open urls in the KTextBrowser, so we just let it handle
+   * keyboard to open urls in the QTextBrowser, so we just let it handle
    * the key event _additionally_. (Antonio)
    */
 
@@ -412,4 +412,4 @@ bool KTipDialog::eventFilter( QObject *object, QEvent *event )
 }
 
 
-#include "ktip.moc"
+#include "moc_ktip.cpp"
