@@ -84,12 +84,10 @@ void KFindDialog::KFindDialogPrivate::init(bool forReplace, const QStringList &_
     q->setMainWidget(page);
 
     topLayout = new QVBoxLayout(page);
-    topLayout->setSpacing( KDialog::spacingHint() );
     topLayout->setMargin( 0 );
 
     findGrp = new QGroupBox(i18nc("@title:group", "Find"), page);
     findLayout = new QGridLayout(findGrp);
-    findLayout->setSpacing( KDialog::spacingHint() );
 
     QLabel *findLabel = new QLabel(i18n("&Text to find:"), findGrp);
     find = new KHistoryComboBox(findGrp);
@@ -107,7 +105,6 @@ void KFindDialog::KFindDialogPrivate::init(bool forReplace, const QStringList &_
 
     replaceGrp = new QGroupBox( i18n("Replace With"), page);
     replaceLayout = new QGridLayout(replaceGrp);
-    replaceLayout->setSpacing( KDialog::spacingHint() );
 
     QLabel *replaceLabel = new QLabel(i18n("Replace&ment text:"), replaceGrp);
     replace = new KHistoryComboBox(replaceGrp);
@@ -125,7 +122,6 @@ void KFindDialog::KFindDialogPrivate::init(bool forReplace, const QStringList &_
 
     QGroupBox *optionGrp = new QGroupBox(i18n("Options"), page);
     optionsLayout = new QGridLayout(optionGrp);
-    optionsLayout->setSpacing( KDialog::spacingHint() );
 
     caseSensitive = new QCheckBox(i18n("C&ase sensitive"), optionGrp);
     wholeWordsOnly = new QCheckBox(i18n("&Whole words only"), optionGrp);
@@ -160,7 +156,7 @@ void KFindDialog::KFindDialogPrivate::init(bool forReplace, const QStringList &_
     q->connect(regExpItem, SIGNAL(clicked()), q, SLOT(_k_showPatterns()));
     q->connect(backRefItem, SIGNAL(clicked()), q, SLOT(_k_showPlaceholders()));
 
-    q->connect(find, SIGNAL(editTextChanged(const QString &)), q, SLOT(_k_textSearchChanged(const QString &)));
+    q->connect(find, SIGNAL(editTextChanged(QString)), q, SLOT(_k_textSearchChanged(QString)));
 
     q->connect(regExp, SIGNAL(toggled(bool)), q, SIGNAL(optionsChanged()));
     q->connect(backRef, SIGNAL(toggled(bool)), q, SIGNAL(optionsChanged()));
@@ -174,7 +170,7 @@ void KFindDialog::KFindDialogPrivate::init(bool forReplace, const QStringList &_
     // tab order
     q->setTabOrder(find, regExp);
     q->setTabOrder(regExp, regExpItem);
-    q->setTabOrder(regExpItem, replace);
+    q->setTabOrder(regExpItem, replace); //findExtension widgets are inserted in showEvent()
     q->setTabOrder(replace, backRef);
     q->setTabOrder(backRef, backRefItem);
     q->setTabOrder(backRefItem, caseSensitive);
@@ -269,6 +265,15 @@ void KFindDialog::showEvent( QShowEvent *e )
             d->find->lineEdit()->selectAll();
             d->pattern.clear();
         }
+        //maintain a user-friendly tab order
+        if (d->findExtension) {
+            QWidget* prev=d->regExpItem;
+            foreach(QWidget* child, d->findExtension->findChildren<QWidget*>()) {
+                setTabOrder(prev, child);
+                prev=child;
+            }
+            setTabOrder(prev, d->replace);
+        }
     }
     KDialog::showEvent(e);
 }
@@ -537,7 +542,7 @@ void KFindDialog::KFindDialogPrivate::_k_slotPlaceholdersAboutToShow()
     placeholders->addAction( new PlaceHolderAction(placeholders, i18n("Complete Match"), 0));
 
     QRegExp r( q->pattern() );
-    uint n = r.numCaptures();
+    uint n = r.captureCount();
     for ( uint i=0; i < n; i++ )
         placeholders->addAction( new PlaceHolderAction(placeholders, i18n("Captured Text (%1)",  i+1 ), i+1 ) );
 }
@@ -567,4 +572,4 @@ void KFindDialog::KFindDialogPrivate::_k_slotOk()
         q->accept();
 }
 // kate: space-indent on; indent-width 4; replace-tabs on;
-#include "kfinddialog.moc"
+#include "moc_kfinddialog.cpp"
