@@ -35,7 +35,6 @@ Boston, MA 02110-1301, USA.
 #include <kdialog.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
-#include <klineedit.h>
 #include <klistwidget.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
@@ -74,7 +73,7 @@ static int minimumListHeight( const QListWidget *list, int numVisibleEntry )
     return ( w * numVisibleEntry + 2 * list->frameWidth() );
 }
 
-static QString formatFontSize(qreal size)
+static QString formatFontSize(const qreal size)
 {
     return KGlobal::locale()->formatNumber(size, (size == floor(size)) ? 0 : 1);
 }
@@ -92,10 +91,6 @@ public:
         customSizeRow = -1;
     }
 
-    // pointer to an optinally supplied list of fonts to
-    // inserted into the fontdialog font-family combo-box
-//    QStringList  fontList;
-
     void setFamilyBoxItems(const QStringList &fonts);
     void fillFamilyListBox(bool onlyFixedFonts = false);
     int nearestSizeRow(qreal val, bool customize);
@@ -110,7 +105,6 @@ public:
     void _k_size_chosen_slot(const QString&);
     void _k_style_chosen_slot(const QString&);
     void _k_displaySample(const QFont &font);
-    void _k_showXLFDArea(bool);
     void _k_size_value_slot(double);
 
     KFontChooser *q;
@@ -123,7 +117,6 @@ public:
     KDoubleNumInput *sizeOfFont;
 
     SampleEdit   *sampleEdit;
-    KLineEdit    *xlfdEdit;
 
     QLabel       *familyLabel;
     QLabel       *styleLabel;
@@ -165,7 +158,7 @@ KFontChooser::KFontChooser( QWidget *parent,
     setWhatsThis(i18nc("@info:whatsthis", "Here you can choose the font to be used." ));
 
     // The top layout is divided vertically into a splitter with font
-    // attribute widgets and preview on the top, and XLFD data at the bottom.
+    // attribute widgets and preview on the top, and fonts at the bottom.
     QVBoxLayout *topLayout = new QVBoxLayout( this );
     topLayout->setMargin( 0 );
     int checkBoxGap = KDialog::spacingHint() / 2;
@@ -295,7 +288,7 @@ KFontChooser::KFontChooser( QWidget *parent,
     }
     // Populate usual styles, to determine minimum list width;
     // will be replaced later with correct styles.
-    d->styleListBox->addItem(i18nc("@item font","Regular"));
+    d->styleListBox->addItem(I18NC_NOX("QFontDatabase", "Normal"));
     d->styleListBox->addItem(i18nc("@item font","Italic"));
     d->styleListBox->addItem(i18nc("@item font","Oblique"));
     d->styleListBox->addItem(i18nc("@item font","Bold"));
@@ -401,31 +394,6 @@ KFontChooser::KFontChooser( QWidget *parent,
     //
     // Finished setting up the splitter.
 
-    // Add XLFD data below the font attributes/preview splitter.
-    //
-    QVBoxLayout *vbox;
-    if( flags & DisplayFrame )
-    {
-        page = new QGroupBox( i18n("Actual Font"), this );
-        topLayout->addWidget(page);
-        vbox = new QVBoxLayout( page );
-        vbox->addSpacing( fontMetrics().lineSpacing() );
-    }
-    else
-    {
-        page = new QWidget( this );
-        topLayout->addWidget(page);
-        vbox = new QVBoxLayout( page );
-        vbox->setMargin( 0 );
-        QLabel *label = new QLabel( i18n("Actual Font"), page );
-        vbox->addWidget( label );
-    }
-
-    d->xlfdEdit = new KLineEdit( page );
-    vbox->addWidget( d->xlfdEdit );
-    //
-    // Finished setting up the chooser layout.
-
     // lets initialize the display if possible
     setFont( d->usingFixed ? KGlobalSettings::fixedFont() : KGlobalSettings::generalFont(), d->usingFixed );
 
@@ -433,9 +401,6 @@ KFontChooser::KFontChooser( QWidget *parent,
     if( sizeIsRelativeState && d->sizeIsRelativeCheckBox )
         setSizeIsRelative( *sizeIsRelativeState );
 
-    KConfigGroup cg(KGlobal::config(), QLatin1String("General"));
-    d->_k_showXLFDArea(cg.readEntry(QLatin1String("fontSelectorShowXLFD"), false));
-
     // Set focus to the size list as this is the most commonly changed property
     d->sizeListBox->setFocus();
 }
@@ -612,28 +577,24 @@ void KFontChooser::Private::_k_family_chosen_slot(const QString& family)
     QStringList filteredStyles;
     qtStyles.clear();
     styleIDs.clear();
-    foreach (const QString &style, styles) {
+    QMutableListIterator<QString> stylesit(styles);
+    while (stylesit.hasNext()) {
+        const QString style = stylesit.next();
         // Sometimes the font database will report an invalid style,
         // that falls back back to another when set.
         // Remove such styles, by checking set/get round-trip.
         QFont testFont = dbase.font(currentFamily, style, 10);
         if (dbase.styleString(testFont) != style) {
-            styles.removeAll(style);
+            stylesit.remove();
             continue;
         }
 
-        // We don't like Qt's name for some styles.
-        // FIXME: Actually "Normal" is better, remove this in KF5.
-        QString styleMod = style;
-        if (style == I18NC_NOX("QFontDatabase", "Normal"))
-            styleMod = i18nc("@item font", "Regular");
-
         // i18n: Filtering message, so that translators can script the
         // style string according to the font family name (e.g. may need
         // noun-adjective congruence wrt. gender of the family name).
         // The message provides the dynamic context 'family', which is
         // the family name to which the style string corresponds.
-        QString fstyle = ki18nc("@item Font style", "%1").subs(styleMod).inContext("family", pureFamily).toString();
+        QString fstyle = ki18nc("@item Font style", "%1").subs(style).inContext("family", pureFamily).toString();
         if (!filteredStyles.contains(fstyle)) {
             filteredStyles.append(fstyle);
             qtStyles.insert(fstyle, style);
@@ -644,7 +605,7 @@ void KFontChooser::Private::_k_family_chosen_slot(const QString& family)
     styleListBox->addItems(filteredStyles);
 
     // Try to set the current style in the listbox to that previous.
-    int listPos = filteredStyles.indexOf(selectedStyle.isEmpty() ?  i18nc("@item font", "Regular") : selectedStyle);
+    int listPos = filteredStyles.indexOf(selectedStyle.isEmpty() ?  I18NC_NOX("QFontDatabase", "Normal") : selectedStyle);
     if (listPos < 0) {
         // Make extra effort to have Italic selected when Oblique was chosen,
         // and vice versa, as that is what the user would probably want.
@@ -662,18 +623,20 @@ void KFontChooser::Private::_k_family_chosen_slot(const QString& family)
         }
     }
     styleListBox->setCurrentRow(listPos >= 0 ? listPos : 0);
-    QString currentStyle = qtStyles[styleListBox->currentItem()->text()];
+    QListWidgetItem* currentitem = styleListBox->currentItem();
+    if (currentitem) {
+        QString currentStyle = qtStyles[currentitem->text()];
 
-    // Recompute the size listbox for this family/style.
-    qreal currentSize = setupSizeListBox(currentFamily, currentStyle);
-    sizeOfFont->setValue(currentSize);
+        // Recompute the size listbox for this family/style.
+        qreal currentSize = setupSizeListBox(currentFamily, currentStyle);
+        sizeOfFont->setValue(currentSize);
 
-    selFont = dbase.font(currentFamily, currentStyle, int(currentSize));
-    if (dbase.isSmoothlyScalable(currentFamily, currentStyle) && selFont.pointSize() == floor(currentSize)) {
-        selFont.setPointSizeF(currentSize);
+        selFont = dbase.font(currentFamily, currentStyle, int(currentSize));
+        if (dbase.isScalable(currentFamily, currentStyle) && selFont.pointSize() == floor(currentSize)) {
+            selFont.setPointSizeF(currentSize);
+        }
+        emit q->fontSelected(selFont);
     }
-    emit q->fontSelected(selFont);
-
     signalsAllowed = true;
 }
 
@@ -698,7 +661,7 @@ void KFontChooser::Private::_k_style_chosen_slot(const QString& style)
     sizeOfFont->setValue(currentSize);
 
     selFont = dbase.font(currentFamily, currentStyle, int(currentSize));
-    if (dbase.isSmoothlyScalable(currentFamily, currentStyle) && selFont.pointSize() == floor(currentSize)) {
+    if (dbase.isScalable(currentFamily, currentStyle) && selFont.pointSize() == floor(currentSize)) {
         selFont.setPointSizeF(currentSize);
     }
     emit q->fontSelected(selFont);
@@ -762,32 +725,7 @@ void KFontChooser::Private::_k_size_value_slot(double dval)
         customSizeRow = -1;
     }
 
-    bool canCustomize = true;
-
-    // For Qt-bad-sizes workaround: skip this block unconditionally
-    if (!dbase.isSmoothlyScalable(family, style)) {
-        // Bitmap font, allow only discrete sizes.
-        // Determine the nearest in the direction of change.
-        canCustomize = false;
-        int nrows = sizeListBox->count();
-        int row = sizeListBox->currentRow();
-        int nrow;
-        if (val - selFont.pointSizeF() > 0) {
-            for (nrow = row + 1; nrow < nrows; ++nrow)
-                if (KGlobal::locale()->readNumber(sizeListBox->item(nrow)->text()) >= val)
-                    break;
-        }
-        else {
-            for (nrow = row - 1; nrow >= 0; --nrow)
-                if (KGlobal::locale()->readNumber(sizeListBox->item(nrow)->text()) <= val)
-                    break;
-        }
-        // Make sure the new row is not out of bounds.
-        nrow = nrow < 0 ? 0 : nrow >= nrows ? nrows - 1 : nrow;
-        // Get the size from the new row and set the spinbox to that size.
-        val = KGlobal::locale()->readNumber(sizeListBox->item(nrow)->text());
-        sizeOfFont->setValue(val);
-    }
+    bool canCustomize = dbase.isScalable(family, style);
 
     // Set the current size in the size listbox.
     int row = nearestSizeRow(val, canCustomize);
@@ -803,14 +741,10 @@ void KFontChooser::Private::_k_size_value_slot(double dval)
 void KFontChooser::Private::_k_displaySample( const QFont& font )
 {
     sampleEdit->setFont(font);
-    //sampleEdit->setCursorPosition(0);
+    // sampleEdit->setCursorPosition(0);
 
-    xlfdEdit->setText(font.rawName());
-    xlfdEdit->setCursorPosition(0);
-
-    //QFontInfo a = QFontInfo(font);
-    //kDebug() << "font: " << a.family () << ", " << a.pointSize ();
-    //kDebug() << "      (" << font.toString() << ")\n";
+    // QFontInfo a = QFontInfo(font);
+    // kDebug() << "font:" << font.toString();
 }
 
 int KFontChooser::Private::nearestSizeRow (qreal val, bool customize)
@@ -863,7 +797,7 @@ qreal KFontChooser::Private::fillSizeList (const QList<qreal> &sizes_)
     // Insert sizes into the listbox.
     sizeListBox->clear();
     qSort(sizes);
-    foreach (qreal size, sizes) {
+    foreach (const qreal size, sizes) {
         sizeListBox->addItem(formatFontSize(size));
     }
 
@@ -881,16 +815,15 @@ qreal KFontChooser::Private::setupSizeListBox (const QString& family, const QStr
 {
     QFontDatabase dbase;
     QList<qreal> sizes;
-    if (dbase.isSmoothlyScalable(family, style)) {
+    if (dbase.isScalable(family, style)) {
         // A vector font.
         //>sampleEdit->setPaletteBackgroundPixmap( VectorPixmap ); // TODO
-    }
-    else {
+    } else {
         // A bitmap font.
         //sampleEdit->setPaletteBackgroundPixmap( BitmapPixmap ); // TODO
-        QList<int> smoothSizes = dbase.smoothSizes(family, style);
-        foreach (int size, smoothSizes) {
-            sizes.append(size);
+        QList<int> pointSizes = dbase.pointSizes(family, style);
+        foreach (const int size, pointSizes) {
+            sizes.append(qreal(size));
         }
     }
 
@@ -995,7 +928,7 @@ void KFontChooser::Private::setupDisplay()
     // otherwise just select the nearest available size.
     QString currentFamily = qtFamilies[familyListBox->currentItem()->text()];
     QString currentStyle = qtStyles[styleListBox->currentItem()->text()];
-    bool canCustomize = dbase.isSmoothlyScalable(currentFamily, currentStyle);
+    bool canCustomize = dbase.isScalable(currentFamily, currentStyle);
     sizeListBox->setCurrentRow(nearestSizeRow(size, canCustomize));
 
     // Set current size in the spinbox.
@@ -1015,9 +948,7 @@ void KFontChooser::getFontList( QStringList &list, uint fontListCriteria)
         for (QStringList::const_iterator it = lstSys.constBegin(); it != lstSys.constEnd(); ++it)
         {
             if ((fontListCriteria & FixedWidthFonts) > 0 && !dbase.isFixedPitch(*it)) continue;
-            if (((fontListCriteria & (SmoothScalableFonts | ScalableFonts)) == ScalableFonts) &&
-                !dbase.isBitmapScalable(*it)) continue;
-            if ((fontListCriteria & SmoothScalableFonts) > 0 && !dbase.isSmoothlyScalable(*it)) continue;
+            if ((fontListCriteria & SmoothScalableFonts) > 0 && !dbase.isScalable(*it)) continue;
             lstFonts.append(*it);
         }
 
@@ -1054,18 +985,6 @@ void KFontChooser::Private::fillFamilyListBox(bool onlyFixedFonts)
     setFamilyBoxItems(fontList);
 }
 
-void KFontChooser::Private::_k_showXLFDArea(bool show)
-{
-    if( show )
-    {
-        xlfdEdit->parentWidget()->show();
-    }
-    else
-    {
-        xlfdEdit->parentWidget()->hide();
-    }
-}
-
 // Human-readable style identifiers returned by QFontDatabase::styleString()
 // do not always survive round trip of QFont serialization/deserialization,
 // causing wrong style in the style box to be highlighted when
@@ -1080,5 +999,5 @@ QString KFontChooser::Private::styleIdentifier(const QFont &font)
            + QString::number(font.stretch());
 }
 
-#include "kfontchooser.moc"
-#include "sampleedit_p.moc"
+#include "moc_kfontchooser.cpp"
+#include "moc_sampleedit_p.cpp"
