@@ -27,8 +27,8 @@
 #include <kdeui_export.h>
 #include <QtGui/QWidget>
 
-class QFont;
-class QStringList;
+#include <QFont>
+#include <QStringList>
 
 /**
  * @short A font selection widget.
@@ -100,10 +100,8 @@ public:
    *
    * @param parent The parent widget.
    * @param flags Defines how the font chooser is displayed. @see DisplayFlags
-   * @param fontList A list of fonts to display, in XLFD format.  If
-   *        no list is formatted, the internal KDE font list is used.
-   *        If that has not been created, X is queried, and all fonts
-   *        available on the system are displayed.
+   * @param fontList A list of fonts families to display.  If the list is
+   *        empty, all fonts available on the system are displayed.
    * @param visibleListSize The minimum number of visible entries in the
    *        fontlists.
    * @param sizeIsRelativeState If not zero the widget will show a
@@ -222,14 +220,11 @@ public:
    * The selection criteria for the font families shown in the dialog.
    *  @li @p FixedWidthFont when included only fixed-width fonts are returned.
    *        The fonts where the width of every character is equal.
-   *  @li @p ScalableFont when included only scalable fonts are returned;
-   *        certain configurations allow bitmap fonts to remain unscaled and
-   *        thus these fonts have limited number of sizes.
    *  @li @p SmoothScalableFont when included only return smooth scalable fonts.
    *        this will return only non-bitmap fonts which are scalable to any size requested.
    *        Setting this option to true will mean the "scalable" flag is irrelavant.
    */
-  enum FontListCriteria { FixedWidthFonts=0x01, ScalableFonts=0x02, SmoothScalableFonts=0x04 };
+  enum FontListCriteria { FixedWidthFonts=0x01, SmoothScalableFonts=0x02 };
 
   /**
    * Creates a list of font strings.
@@ -262,7 +257,6 @@ private:
     Q_PRIVATE_SLOT(d, void _k_size_chosen_slot(const QString&))
     Q_PRIVATE_SLOT(d, void _k_style_chosen_slot(const QString&))
     Q_PRIVATE_SLOT(d, void _k_displaySample(const QFont &font))
-    Q_PRIVATE_SLOT(d, void _k_showXLFDArea(bool))
     Q_PRIVATE_SLOT(d, void _k_size_value_slot(double))
 };
 
