@@ -27,6 +27,7 @@
 #include "kglobalsettings.h"
 #include "kfontchooser.h"
 #include "kcompletion.h"
+#include "kiconloader.h"
 
 #include <QEvent>
 #include <QListView>
@@ -35,6 +36,7 @@
 #include <QAbstractItemDelegate>
 #include <QStringListModel>
 #include <QPainter>
+#include <QPen>
 #include <QList>
 #include <QHash>
 #include <QScrollBar>
@@ -68,13 +70,14 @@ public:
     double sizeFactSample;
 
     QHash<QString, QString> fontFamilyTrMap;
+    QFontDatabase fontdb;
 };
 
 KFontFamilyDelegate::KFontFamilyDelegate (QObject *parent)
-: QAbstractItemDelegate(parent)
+    : QAbstractItemDelegate(parent)
 {
-    truetype = QIcon(QLatin1String(":/trolltech/styles/commonstyle/images/fonttruetype-16.png"));
-    bitmap = QIcon(QLatin1String(":/trolltech/styles/commonstyle/images/fontbitmap-16.png"));
+    truetype = SmallIcon(QString::fromLatin1("application-x-font-ttf"));
+    bitmap = SmallIcon(QString::fromLatin1("application-x-font-bdf"));
 
     // Font size factors for family name and text sample in font previes,
     // multiplies normal font size.
@@ -102,37 +105,9 @@ void KFontFamilyDelegate::paint (QPainter *painter,
     QString trFontFamily = index.data(Qt::DisplayRole).toString();
     QString fontFamily = fontFamilyTrMap[trFontFamily];
 
-    // Writing systems provided by the font.
-    QList<QFontDatabase::WritingSystem> availableSystems = QFontDatabase().writingSystems(fontFamily);
-
-    // Intersect font's writing systems with that specified for
-    // the language's sample text, to see if the sample can be shown.
-    // If the font reports no writing systems, assume it can show the sample.
-    bool canShowLanguageSample = true;
-    if (availableSystems.count() > 0) {
-        canShowLanguageSample = false;
-        QString scriptsSpec = i18nc("Numeric IDs of scripts for font previews",
-        // i18n: Integer which indicates the script you used in the sample text
-        // for font previews in your language. For the possible values, see
-        // http://doc.trolltech.com/qfontdatabase.html#WritingSystem-enum
-        // If the sample text contains several scripts, their IDs can be given
-        // as a comma-separated list (e.g. for Japanese it is "1,27").
-                                    "1");
-        QStringList scriptStrIds = scriptsSpec.split(',');
-        foreach (const QString &scriptStrId, scriptStrIds) {
-            bool convOk;
-            int ws = scriptStrId.toInt(&convOk);
-            if (   convOk && ws > 0 && ws < QFontDatabase::WritingSystemsCount
-                && availableSystems.contains(static_cast<QFontDatabase::WritingSystem>(ws))) {
-                canShowLanguageSample = true;
-                break;
-            }
-        }
-    }
-
     // Choose and paint an icon according to the font type, scalable or bitmat.
     const QIcon *icon = &bitmap;
-    if (QFontDatabase().isSmoothlyScalable(fontFamily)) {
+    if (fontdb.isScalable(fontFamily)) {
         icon = &truetype;
     }
     QRect r = option.rect;
@@ -160,18 +135,7 @@ void KFontFamilyDelegate::paint (QPainter *painter,
     // Show text sample in user's language if the writing system is supported,
     // otherwise show a collage of generic script samples provided by Qt.
     // If the font does not report what it supports, assume all.
-    QString sample;
-    if (canShowLanguageSample) {
-        sample = alphabetSample();
-    } else {
-        foreach (const QFontDatabase::WritingSystem &ws, availableSystems) {
-            sample += QFontDatabase::writingSystemSample(ws) + "  ";
-            if (sample.length() > 40) { // do not let the sample be too long
-                break;
-            }
-        }
-        sample = sample.trimmed();
-    }
+    QString sample = alphabetSample();
     QFont sampleFont;
     sampleFont.setFamily(fontFamily);
     sampleFont.setPointSizeF(sampleFont.pointSizeF() * sizeFactSample);
@@ -229,11 +193,11 @@ public:
 };
 
 KFontComboBoxPrivate::KFontComboBoxPrivate (KFontComboBox *parent)
+    : k(parent),
+      currentFont(KGlobalSettings::generalFont()),
+      onlyFixed(false),
+      signalsAllowed(true)
 {
-    k = parent;
-    currentFont = KGlobalSettings::generalFont();
-    onlyFixed = false;
-    signalsAllowed = true;
 }
 
 void KFontComboBoxPrivate::updateDatabase ()
