@@ -26,13 +26,14 @@
 #include <config.h>
 #include <unistd.h>
 #include <math.h>
+#include <string.h>
 
-#include <QtCore/QSysInfo>
+#include <QtCore/QDebug>
 #include <QtGui/QApplication>
 #include <QtGui/QPaintEngine>
 #include <QtGui/QDesktopWidget>
-#include <QtCore/QCharRef>
-#include <QtCore/QMutableStringListIterator>
+#include <QtCore/qstring.h>
+#include <QtCore/qstringlist.h>
 #include <QtGui/QBitmap>
 #include <QtGui/QPixmap>
 #include <QtGui/QImage>
@@ -77,6 +78,8 @@ void KIconEffect::init()
     KSharedConfig::Ptr config = KGlobal::config();
 
     int i, j, effect=-1;
+    //FIXME: this really should be using KIconLoader::metaObject() to guarantee synchronization
+    // performance wise it's also practically guaranteed to be faster
     QStringList groups;
     groups += "Desktop";
     groups += "Toolbar";
@@ -149,12 +152,21 @@ void KIconEffect::init()
 
 bool KIconEffect::hasEffect(int group, int state) const
 {
+    if (group < 0 || group >= KIconLoader::LastGroup ||
+        state < 0 || state >= KIconLoader::LastState) {
+        return false;
+    }
+
     return d->effect[group][state] != NoEffect;
 }
 
 QString KIconEffect::fingerprint(int group, int state) const
 {
-    if ( group >= KIconLoader::LastGroup ) return "";
+    if (group < 0 || group >= KIconLoader::LastGroup ||
+        state < 0 || state >= KIconLoader::LastState) {
+        return QString();
+    }
+
     QString cached = d->key[group][state];
     if (cached.isEmpty())
     {
@@ -317,7 +329,7 @@ struct KIEImgEdit
 	}
 	else
 	{
-	    pixels = img.numColors();
+	    pixels = img.colorCount();
 	    colors = img.colorTable();
 	    data   = (unsigned int*)colors.data();
 	}
@@ -325,21 +337,15 @@ struct KIEImgEdit
 
     ~KIEImgEdit()
     {
-	if (img.depth() <= 8)
+	if (img.depth() == 1)
 	    img.setColorTable(colors);
     }
 };
 
 static bool painterSupportsAntialiasing()
 {
-#ifdef Q_WS_WIN
-   // apparently QApplication::desktop()->paintEngine() is null on windows
-   // but we can assume the paint engine supports antialiasing there, right?
-   return true;
-#else
    QPaintEngine* const pe = QApplication::desktop()->paintEngine();
    return pe && pe->hasFeature(QPaintEngine::Antialiasing);
-#endif
 }
 
 // Taken from KImageEffect. We don't want to link kdecore to kdeui! As long
@@ -520,23 +526,24 @@ void KIconEffect::semiTransparent(QImage &img)
         if(img.format() == QImage::Format_ARGB32_Premultiplied)
             img = img.convertToFormat(QImage::Format_ARGB32);
         int width  = img.width();
-	int height = img.height();
+        int height = img.height();
 
         if(painterSupportsAntialiasing()){
             unsigned char *line;
-            for(y=0; y<height; y++){
-                if(QSysInfo::ByteOrder == QSysInfo::BigEndian)
-                    line = img.scanLine(y);
-                else
-                    line = img.scanLine(y) + 3;
-                for(x=0; x<width; x++){
+            for(y=0; y<height; ++y){
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
+                line = img.scanLine(y);
+#else
+                line = img.scanLine(y) + 3;
+#endif
+                for(x=0; x<width; ++x){
                     *line >>= 1;
                     line += 4;
                 }
             }
         }
         else{
-            for(y=0; y<height; y++){
+            for(y=0; y<height; ++y){
                 QRgb* line = (QRgb*)img.scanLine(y);
                 for(x=(y%2); x<width; x+=2)
                     line[x] &= 0x00ffffff;
@@ -544,22 +551,11 @@ void KIconEffect::semiTransparent(QImage &img)
         }
     }
     else{
-        if (img.depth() == 8) {
-            if (painterSupportsAntialiasing()) {
-                // not running on 8 bit, we can safely install a new colorTable
-                QVector<QRgb> colorTable = img.colorTable();
-                for (int i = 0; i < colorTable.size(); ++i) {
-                    colorTable[i] = (colorTable[i] & 0x00ffffff) | ((colorTable[i] & 0xfe000000) >> 1);
-                }
-                img.setColorTable(colorTable);
-                return;
-            }
-        }
         // Insert transparent pixel into the clut.
         int transColor = -1;
 
         // search for a color that is already transparent
-        for(x=0; x<img.numColors(); x++){
+        for(x=0; x<img.colorCount(); ++x){
             // try to find already transparent pixel
             if(qAlpha(img.color(x)) < 127){
                 transColor = x;
@@ -568,40 +564,30 @@ void KIconEffect::semiTransparent(QImage &img)
         }
 
         // FIXME: image must have transparency
-        if(transColor < 0 || transColor >= img.numColors())
+        if(transColor < 0 || transColor >= img.colorCount())
             return;
 
-	img.setColor(transColor, 0);
+        img.setColor(transColor, 0);
         unsigned char *line;
-        if(img.depth() == 8){
-            for(y=0; y<img.height(); y++){
+        bool setOn = (transColor != 0);
+        if (img.format() == QImage::Format_MonoLSB){
+            for(y=0; y<img.height(); ++y){
                 line = img.scanLine(y);
-                for(x=(y%2); x<img.width(); x+=2)
-                    line[x] = transColor;
-            }
-	}
-        else{
-            bool setOn = (transColor != 0);
-            if(img.format() == QImage::Format_MonoLSB){
-                for(y=0; y<img.height(); y++){
-                    line = img.scanLine(y);
-                    for(x=(y%2); x<img.width(); x+=2){
-                        if(!setOn)
-                            *(line + (x >> 3)) &= ~(1 << (x & 7));
-                        else
-                            *(line + (x >> 3)) |= (1 << (x & 7));
-                    }
+                for(x=(y%2); x<img.width(); x+=2){
+                    if(!setOn)
+                        *(line + (x >> 3)) &= ~(1 << (x & 7));
+                    else
+                        *(line + (x >> 3)) |= (1 << (x & 7));
                 }
             }
-            else{
-                for(y=0; y<img.height(); y++){
-                    line = img.scanLine(y);
-                    for(x=(y%2); x<img.width(); x+=2){
-                        if(!setOn)
-                            *(line + (x >> 3)) &= ~(1 << (7-(x & 7)));
-                        else
-                            *(line + (x >> 3)) |= (1 << (7-(x & 7)));
-                    }
+        } else {
+            for(y=0; y<img.height(); ++y){
+                line = img.scanLine(y);
+                for(x=(y%2); x<img.width(); x+=2){
+                    if(!setOn)
+                        *(line + (x >> 3)) &= ~(1 << (7-(x & 7)));
+                    else
+                        *(line + (x >> 3)) |= (1 << (7-(x & 7)));
                 }
             }
         }
@@ -633,9 +619,7 @@ void KIconEffect::semiTransparent(QPixmap &pix)
         for (int x=0; x<(img.width()+31)/32; x++)
             line[x] &= pattern;
     }
-    QBitmap mask;
-    mask = QBitmap::fromImage(img);
-    pix.setMask(mask);
+    pix.setMask(QBitmap::fromImage(img));
 }
 
 QImage KIconEffect::doublePixels(const QImage &src) const
@@ -655,11 +639,11 @@ QImage KIconEffect::doublePixels(const QImage &src) const
     if (src.depth() == 32)
     {
 	QRgb* l1, *l2;
-	for (y=0; y<h; y++)
+	for (y=0; y<h; ++y)
 	{
 	    l1 = (QRgb*)src.scanLine(y);
 	    l2 = (QRgb*)dst.scanLine(y*2);
-	    for (x=0; x<w; x++)
+	    for (x=0; x<w; ++x)
 	    {
 		l2[x*2] = l2[x*2+1] = l1[x];
 	    }
@@ -667,16 +651,16 @@ QImage KIconEffect::doublePixels(const QImage &src) const
 	}
     } else
     {
-	for (x=0; x<src.numColors(); x++)
+	for (x=0; x<src.colorCount(); ++x)
 	    dst.setColor(x, src.color(x));
 
 	const unsigned char *l1;
 	unsigned char *l2;
-	for (y=0; y<h; y++)
+	for (y=0; y<h; ++y)
 	{
 	    l1 = src.scanLine(y);
 	    l2 = dst.scanLine(y*2);
-	    for (x=0; x<w; x++)
+	    for (x=0; x<w; ++x)
 	    {
 		l2[x*2] = l1[x];
 		l2[x*2+1] = l1[x];
@@ -720,54 +704,6 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
 	return;
     }
 
-    // Overlay at 8 bpp doesn't use alpha blending
-
-    if (src.depth() == 8)
-    {
-	if (src.numColors() + overlay.numColors() > 255)
-	{
-	    kDebug(265) << "Too many colors in src + overlay!\n";
-	    return;
-	}
-
-	// Find transparent pixel in overlay
-	int trans;
-	for (trans=0; trans<overlay.numColors(); trans++)
-	{
-	    if (qAlpha(overlay.color(trans)) == 0)
-	    {
-		kDebug(265) << "transparent pixel found at " << trans << "\n";
-		break;
-	    }
-	}
-	if (trans == overlay.numColors())
-	{
-	    kDebug(265) << "transparent pixel not found!\n";
-	    return;
-	}
-
-	// Merge color tables
-	int nc = src.numColors();
-	src.setNumColors(nc + overlay.numColors());
-	for (i=0; i<overlay.numColors(); i++)
-	{
-	    src.setColor(nc+i, overlay.color(i));
-	}
-
-	// Overwrite nontransparent pixels.
-	unsigned char *oline, *sline;
-	for (i=0; i<src.height(); i++)
-	{
-	    oline = overlay.scanLine(i);
-	    sline = src.scanLine(i);
-	    for (j=0; j<src.width(); j++)
-	    {
-		if (oline[j] != trans)
-		    sline[j] = oline[j]+nc;
-	    }
-	}
-    }
-
     // Overlay at 32 bpp does use alpha blending
 
     if (src.depth() == 32)
@@ -776,12 +712,12 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
 	int r1, g1, b1, a1;
 	int r2, g2, b2, a2;
 
-	for (i=0; i<src.height(); i++)
+	for (i=0; i<src.height(); ++i)
 	{
 	    oline = (QRgb*)overlay.scanLine(i);
 	    sline = (QRgb*)src.scanLine(i);
 
-	    for (j=0; j<src.width(); j++)
+	    for (j=0; j<src.width(); ++j)
 	    {
 		r1 = qRed(oline[j]);
 		g1 = qGreen(oline[j]);
@@ -806,3 +742,223 @@ void KIconEffect::overlay(QImage &src, QImage &overlay)
     return;
 }
 
+
+static const quint32 stack_blur8_mul[255] =
+{
+    512,512,456,512,328,456,335,512,405,328,271,456,388,335,292,512,
+    454,405,364,328,298,271,496,456,420,388,360,335,312,292,273,512,
+    482,454,428,405,383,364,345,328,312,298,284,271,259,496,475,456,
+    437,420,404,388,374,360,347,335,323,312,302,292,282,273,265,512,
+    497,482,468,454,441,428,417,405,394,383,373,364,354,345,337,328,
+    320,312,305,298,291,284,278,271,265,259,507,496,485,475,465,456,
+    446,437,428,420,412,404,396,388,381,374,367,360,354,347,341,335,
+    329,323,318,312,307,302,297,292,287,282,278,273,269,265,261,512,
+    505,497,489,482,475,468,461,454,447,441,435,428,422,417,411,405,
+    399,394,389,383,378,373,368,364,359,354,350,345,341,337,332,328,
+    324,320,316,312,309,305,301,298,294,291,287,284,281,278,274,271,
+    268,265,262,259,257,507,501,496,491,485,480,475,470,465,460,456,
+    451,446,442,437,433,428,424,420,416,412,408,404,400,396,392,388,
+    385,381,377,374,370,367,363,360,357,354,350,347,344,341,338,335,
+    332,329,326,323,320,318,315,312,310,307,304,302,299,297,294,292,
+    289,287,285,282,280,278,275,273,271,269,267,265,263,261,259
+};
+
+static const quint32 stack_blur8_shr[255] =
+{
+    9, 11, 12, 13, 13, 14, 14, 15, 15, 15, 15, 16, 16, 16, 16, 17,
+    17, 17, 17, 17, 17, 17, 18, 18, 18, 18, 18, 18, 18, 18, 18, 19,
+    19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 20, 20, 20,
+    20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 21,
+    21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21,
+    21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 22, 22, 22, 22, 22, 22,
+    22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22,
+    22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 22, 23,
+    23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23,
+    23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23,
+    23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23,
+    23, 23, 23, 23, 23, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24,
+    24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24,
+    24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24,
+    24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24,
+    24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24
+};
+
+inline static void blurHorizontal(QImage &image, unsigned int *stack, int div, int radius)
+{
+    int stackindex;
+    int stackstart;
+
+    quint32 * const pixels = reinterpret_cast<quint32 *>(image.bits());
+    quint32 pixel;
+
+    int w = image.width();
+    int h = image.height();
+    int wm = w - 1;
+
+    unsigned int mul_sum = stack_blur8_mul[radius];
+    unsigned int shr_sum = stack_blur8_shr[radius];
+
+    unsigned int sum, sum_in, sum_out;
+
+    for (int y = 0; y < h; y++)
+    {
+        sum     = 0;
+        sum_in  = 0;
+        sum_out = 0;
+
+        const int yw = y * w;
+        pixel = pixels[yw];
+        for (int i = 0; i <= radius; i++)
+        {
+            stack[i] = qAlpha(pixel);
+
+            sum += stack[i] * (i + 1);
+            sum_out += stack[i];
+        }
+
+        for (int i = 1; i <= radius; i++)
+        {
+            pixel = pixels[yw + qMin(i, wm)];
+
+            unsigned int *stackpix = &stack[i + radius];
+            *stackpix = qAlpha(pixel);
+
+            sum    += *stackpix * (radius + 1 - i);
+            sum_in += *stackpix;
+        }
+
+        stackindex = radius;
+        for (int x = 0, i = yw; x < w; x++)
+        {
+            pixels[i++] = (((sum * mul_sum) >> shr_sum) << 24) & 0xff000000;
+
+            sum -= sum_out;
+
+            stackstart = stackindex + div - radius;
+            if (stackstart >= div)
+                stackstart -= div;
+
+            unsigned int *stackpix = &stack[stackstart];
+
+            sum_out -= *stackpix;
+
+            pixel = pixels[yw + qMin(x + radius + 1, wm)];
+
+            *stackpix = qAlpha(pixel);
+
+            sum_in += *stackpix;
+            sum    += sum_in;
+
+            if (++stackindex >= div)
+                stackindex = 0;
+
+            stackpix = &stack[stackindex];
+
+            sum_out += *stackpix;
+            sum_in  -= *stackpix;
+        } // for (x = 0, ...)
+    } // for (y = 0, ...)
+}
+
+inline static void blurVertical(QImage &image, unsigned int *stack, int div, int radius)
+{
+    int stackindex;
+    int stackstart;
+
+    quint32 * const pixels = reinterpret_cast<quint32 *>(image.bits());
+    quint32 pixel;
+
+    int w = image.width();
+    int h = image.height();
+    int hm = h - 1;
+
+    int mul_sum = stack_blur8_mul[radius];
+    int shr_sum = stack_blur8_shr[radius];
+
+    unsigned int sum, sum_in, sum_out;
+
+    for (int x = 0; x < w; x++)
+    {
+        sum     = 0;
+        sum_in  = 0;
+        sum_out = 0;
+
+        pixel = pixels[x];
+        for (int i = 0; i <= radius; i++)
+        {
+            stack[i] = qAlpha(pixel);
+
+            sum += stack[i] * (i + 1);
+            sum_out += stack[i];
+        }
+
+        for (int i = 1; i <= radius; i++)
+        {
+            pixel = pixels[qMin(i, hm) * w + x];
+
+            unsigned int *stackpix = &stack[i + radius];
+            *stackpix = qAlpha(pixel);
+
+            sum    += *stackpix * (radius + 1 - i);
+            sum_in += *stackpix;
+        }
+
+        stackindex = radius;
+        for (int y = 0, i = x; y < h; y++, i += w)
+        {
+            pixels[i] = (((sum * mul_sum) >> shr_sum) << 24) & 0xff000000;
+
+            sum -= sum_out;
+
+            stackstart = stackindex + div - radius;
+            if (stackstart >= div)
+                stackstart -= div;
+
+            unsigned int *stackpix = &stack[stackstart];
+
+            sum_out -= *stackpix;
+
+            pixel = pixels[qMin(y + radius + 1, hm) * w + x];
+
+            *stackpix = qAlpha(pixel);
+
+            sum_in += *stackpix;
+            sum    += sum_in;
+
+            if (++stackindex >= div)
+                stackindex = 0;
+
+            stackpix = &stack[stackindex];
+
+            sum_out += *stackpix;
+            sum_in  -= *stackpix;
+        } // for (y = 0, ...)
+    } // for (x = 0, ...)
+}
+
+static void stackBlur(QImage &image, float radius)
+{
+    radius = qRound(radius);
+
+    int div = int(radius * 2) + 1;
+    unsigned int *stack  = new unsigned int[div];
+
+    blurHorizontal(image, stack, div, radius);
+    blurVertical(image, stack, div, radius);
+
+    delete [] stack;
+}
+
+void KIconEffect::shadowBlur(QImage &image, float radius, const QColor &color)
+{
+    if (radius < 0)
+        return;
+
+    if (radius > 0)
+        stackBlur(image, radius);
+
+    // Correct the color and opacity of the shadow
+    QPainter p(&image);
+    p.setCompositionMode(QPainter::CompositionMode_SourceIn);
+    p.fillRect(image.rect(), color);
+}
