@@ -44,16 +44,16 @@ static inline int qIconModeToKIconState( QIcon::Mode mode )
 {
     int kstate;
     switch (mode) {
-    default:
-    case QIcon::Normal:
-        kstate = KIconLoader::DefaultState;
-        break;
     case QIcon::Active:
         kstate = KIconLoader::ActiveState;
         break;
     case QIcon::Disabled:
         kstate = KIconLoader::DisabledState;
         break;
+    case QIcon::Normal:
+    default:
+        kstate = KIconLoader::DefaultState;
+        break;
     }
     return kstate;
 }
@@ -138,16 +138,3 @@ bool KIconEngine::write(QDataStream &out) const
     return true;
 }
 
-void KIconEngine::virtual_hook(int id, void *data)
-{
-    switch (id) {
-    case IconNameHook: {
-        QString *name = reinterpret_cast<QString*>(data);
-        *name = mIconName;
-        break;
-    }
-    default:
-        QIconEngineV2::virtual_hook(id, data);
-        break;
-    }
-}
