@@ -33,19 +33,12 @@
 #include <QtCore/QCache>
 #include <QtCore/QFileInfo>
 #include <QtCore/QDir>
-#include <QtCore/QBuffer>
-#include <QtCore/QDataStream>
-#include <QtCore/QByteArray>
-#include <QtCore/QStringBuilder> // % operator for QString
 #include <QtGui/QIcon>
 #include <QtGui/QImage>
-#include <QtGui/QMovie>
 #include <QtGui/QPainter>
 #include <QtGui/QPixmap>
 #include <QtGui/QPixmapCache>
-#ifndef _WIN32_WCE
-#include <QtSvg/QSvgRenderer>
-#endif
+#include <QtGui/QX11Info>
 
 // kdecore
 #include <kconfig.h>
@@ -56,7 +49,6 @@
 #include <kglobalsettings.h>
 #include <kcomponentdata.h>
 #include <kde_file.h>
-#include <kshareddatacache.h>
 
 // kdeui
 #include "kicontheme.h"
@@ -66,13 +58,6 @@
 // Used to make cache keys for icons with no group. Result type is QString*
 K_GLOBAL_STATIC_WITH_ARGS(QString, NULL_EFFECT_FINGERPRINT, (QString::fromLatin1("noeffect")))
 
-// Qt implements Tiny SVG specification. This specification does not cover important elements
-// that are pretty globally used on our icons, like blurring (and other filters). TT seems to have
-// no interest in supporting the full SVG specification (it would be slower, even with JS, CSS
-// support...). So, we have no chance for now. Let's disable svg rendering unconditionally.
-// (ereslibre)
-#undef KDE_QT_SVG_RENDERER_FIXED
-
 /**
  * Checks for relative paths quickly on UNIX-alikes, slowly on everything else.
  */
@@ -167,7 +152,6 @@ public:
     KIconLoaderPrivate(KIconLoader *q)
         : q(q)
         , mpGroups(0)
-        , mIconCache(0)
     {
     }
 
@@ -177,7 +161,6 @@ public:
         deleted when the elements of d->links are deleted */
         qDeleteAll(links);
         delete[] mpGroups;
-        delete mIconCache;
     }
 
     /**
@@ -263,9 +246,7 @@ public:
 
     /**
      * @internal
-     * Creates the QImage for @p path, using SVG rendering as appropriate.
-     * @p size is only used for scalable images, but if non-zero non-scalable
-     * images will be resized anyways.
+     * Creates the QImage for @p path. If @p size is not zero image will be scaled.
      */
     QImage createIconImage(const QString &path, int size = 0);
 
@@ -282,6 +263,12 @@ public:
      */
     bool findCachedPixmapWithPath(const QString &key, QPixmap &data, QString &path);
 
+    /**
+     * @internal
+     * Returns size suitable for overlay image based on the width and height of @p size.
+     */
+    int overlaySize(const QSize &size) const;
+
     KIconLoader *const q;
 
     QStringList mThemesInTree;
@@ -291,16 +278,13 @@ public:
     KIconEffect mpEffect;
     QList<KIconThemeNode *> links;
 
-    // This shares the icons across all processes
-    KSharedDataCache* mIconCache;
-
     // This caches rendered QPixmaps in just this process.
     QCache<QString, PixmapWithPath> mPixmapCache;
 
-    bool extraDesktopIconsLoaded :1;
+    bool extraDesktopIconsLoaded;
     // lazy loading: initIconThemes() is only needed when the "links" list is needed
     // mIconThemeInited is used inside initIconThemes() to init only once
-    bool mIconThemeInited :1;
+    bool mIconThemeInited;
     QString appname;
 
     void drawOverlays(const KIconLoader *loader, KIconLoader::Group group, int state, QPixmap& pix, const QStringList& overlays);
@@ -330,24 +314,24 @@ void KIconLoaderGlobalData::parseGenericIconsFiles(const QString& fileName)
 {
     QFile file(fileName);
     if (file.open(QIODevice::ReadOnly)) {
-        QTextStream stream(&file);
-        stream.setCodec("ISO 8859-1");
-        while (!stream.atEnd()) {
-            const QString line = stream.readLine();
+        while (!file.atEnd()) {
+            const QByteArray line = file.readLine().trimmed();
             if (line.isEmpty() || line[0] == '#')
                 continue;
             const int pos = line.indexOf(':');
             if (pos == -1) // syntax error
                 continue;
-            QString mimeIcon = line.left(pos);
-            const int slashindex = mimeIcon.indexOf(QLatin1Char('/'));
+            QByteArray mimeIcon = line.left(pos);
+            const int slashindex = mimeIcon.indexOf('/');
             if (slashindex != -1) {
-                mimeIcon[slashindex] = QLatin1Char('-');
+                mimeIcon[slashindex] = '-';
             }
+            const QString mimeIconStr = QString::fromLatin1(mimeIcon.constData(), mimeIcon.size());
 
-            const QString genericIcon = line.mid(pos+1);
-            m_genericIcons.insert(mimeIcon, genericIcon);
-            //kDebug(264) << mimeIcon << "->" << genericIcon;
+            const QByteArray genericIcon = line.mid(pos+1);
+            const QString genericIconStr = QString::fromLatin1(genericIcon.constData(), genericIcon.size());
+            m_genericIcons.insert(mimeIconStr, genericIconStr);
+            //kDebug(264) << mimeIconStr << "->" << genericIconStr;
         }
     }
 }
@@ -360,22 +344,8 @@ void KIconLoaderPrivate::drawOverlays(const KIconLoader *iconLoader, KIconLoader
         return;
     }
 
-    const int width = pix.size().width();
-    const int height = pix.size().height();
-    const int iconSize = qMin(width, height);
-    int overlaySize;
-
-    if (iconSize < 32) {
-        overlaySize = 8;
-    } else if (iconSize <= 48) {
-        overlaySize = 16;
-    } else if (iconSize <= 96) {
-        overlaySize = 22;
-    } else if (iconSize < 256) {
-        overlaySize = 32;
-    } else {
-        overlaySize = 64;
-    }
+    const QSize pixSize = pix.size();
+    const int iconSize = overlaySize(pixSize);
 
     QPainter painter(&pix);
 
@@ -389,10 +359,10 @@ void KIconLoaderPrivate::drawOverlays(const KIconLoader *iconLoader, KIconLoader
             continue;
         }
 
-        //TODO: should we pass in the kstate? it results in a slower
+        //TODO: should we pass in the state? it results in a slower
         //      path, and perhaps emblems should remain in the default state
         //      anyways?
-        const QPixmap pixmap = iconLoader->loadIcon(overlay, group, overlaySize, state, QStringList(), 0, true);
+        const QPixmap pixmap = iconLoader->loadIcon(overlay, group, iconSize, state, QStringList(), 0, true);
 
         if (pixmap.isNull()) {
             continue;
@@ -402,16 +372,16 @@ void KIconLoaderPrivate::drawOverlays(const KIconLoader *iconLoader, KIconLoader
         switch (count) {
         case 0:
             // bottom left corner
-            startPoint = QPoint(2, height - overlaySize - 2);
+            startPoint = QPoint(2, pixSize.height() - iconSize - 2);
             break;
         case 1:
             // bottom right corner
-            startPoint = QPoint(width - overlaySize - 2,
-                                height - overlaySize - 2);
+            startPoint = QPoint(pixSize.width() - iconSize - 2,
+                                pixSize.height() - iconSize - 2);
             break;
         case 2:
             // top right corner
-            startPoint = QPoint(width - overlaySize - 2, 2);
+            startPoint = QPoint(pixSize.width() - iconSize - 2, 2);
             break;
         case 3:
             // top left corner
@@ -452,7 +422,6 @@ KIconLoader::KIconLoader(const KComponentData &componentData, QObject* parent)
 
 void KIconLoader::reconfigure( const QString& _appname, KStandardDirs *_dirs )
 {
-    d->mIconCache->clear();
     delete d;
     d = new KIconLoaderPrivate(this);
     d->init( _appname, _dirs );
@@ -474,10 +443,8 @@ void KIconLoaderPrivate::init( const QString& _appname, KStandardDirs *_dirs )
         appname = KGlobal::mainComponent().componentName();
 
     // Initialize icon cache
-    mIconCache = new KSharedDataCache("icon-cache", 10 * 1024 * 1024);
-    // Cost here is number of pixels, not size. So this is actually a bit
-    // smaller.
-    mPixmapCache.setMaxCost(10 * 1024 * 1024);
+    mPixmapCache.setMaxCost(10240);
+    mPixmapCache.clear();
 
     // These have to match the order in kicontheme.h
     static const char * const groups[] = { "Desktop", "Toolbar", "MainToolbar", "Small", "Panel", "Dialog", 0L };
@@ -494,7 +461,7 @@ void KIconLoaderPrivate::init( const QString& _appname, KStandardDirs *_dirs )
 
         KConfigGroup cg(config, QLatin1String(groups[i]) + "Icons");
         mpGroups[i].size = cg.readEntry("Size", 0);
-        if (QPixmap::defaultDepth() > 8) {
+        if (QX11Info::appDepth() > 8) {
             mpGroups[i].alphaBlending = cg.readEntry("AlphaBlending", true);
         } else {
             mpGroups[i].alphaBlending = false;
@@ -525,7 +492,7 @@ bool KIconLoaderPrivate::initIconThemes()
         def = new KIconTheme(KIconTheme::defaultThemeName(), appname);
         if (!def->isValid())
         {
-            kError(264) << "Error: standard icon theme" << KIconTheme::defaultThemeName() << "not found!" << endl;
+            kError(264) << "Error: standard icon theme" << KIconTheme::defaultThemeName() << "not found!";
             delete def;
             return false;
         }
@@ -544,12 +511,12 @@ bool KIconLoaderPrivate::initIconThemes()
     QStringList dirs;
     dirs += mpDirs->resourceDirs("icon");
     dirs += mpDirs->resourceDirs("pixmap");
+    dirs += mpDirs->resourceDirs("pixmaps");
     dirs += mpDirs->resourceDirs("xdgdata-icon");
-    dirs += "/usr/share/pixmaps";
     // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
     dirs += mpDirs->resourceDirs("xdgdata-pixmap");
-    for (QStringList::ConstIterator it = dirs.constBegin(); it != dirs.constEnd(); ++it)
-        mpDirs->addResourceDir("appicon", *it);
+    foreach (const QString it, dirs)
+        mpDirs->addResourceDir("appicon", it);
 
 #ifndef NDEBUG
     QString dbgString = "Theme tree: ";
@@ -619,16 +586,14 @@ void KIconLoaderPrivate::addBaseThemes(KIconThemeNode *node, const QString &appn
 
 void KIconLoaderPrivate::addInheritedThemes(KIconThemeNode *node, const QString &appname)
 {
-    const QStringList lst = node->theme->inherits();
-
-    for (QStringList::ConstIterator it = lst.begin(); it != lst.end(); ++it) {
-        if ((*it) == "hicolor") {
+    foreach (const QString it, node->theme->inherits()) {
+        if (it == "hicolor") {
           // The icon theme spec says that "hicolor" must be the very last
           // of all inherited themes, so don't add it here but at the very end
           // of addBaseThemes().
           continue;
         }
-        addThemeByName(*it, appname);
+        addThemeByName(it, appname);
     }
 }
 
@@ -668,8 +633,7 @@ void KIconLoader::addExtraDesktopThemes()
         QStringList::ConstIterator it2;
         for (it2=lst.begin(); it2!=lst.end(); ++it2)
         {
-            if (!KStandardDirs::exists(*it + *it2 + "/index.desktop")
-                && !KStandardDirs::exists(*it + *it2 + "/index.theme"))
+            if (!KGlobal::dirs()->exists(*it + *it2 + "/index.theme"))
                 continue;
             r=readlink( QFile::encodeName(*it + *it2) , buf, sizeof(buf)-1);
             if ( r>0 )
@@ -760,49 +724,26 @@ void KIconLoaderPrivate::normalizeIconMetadata(KIconLoader::Group &group, int &s
 QString KIconLoaderPrivate::makeCacheKey(const QString &name, KIconLoader::Group group,
                                          const QStringList &overlays, int size, int state) const
 {
-    // The KSharedDataCache is shared so add some namespacing. The following code
-    // uses QStringBuilder (new in Qt 4.6)
+    // The icon cache is shared so add some namespacing.
 
     return (group == KIconLoader::User
-                  ? QLatin1Literal("$kicou_")
-                  : QLatin1Literal("$kico_"))
-           % name
-           % QLatin1Char('_')
-           % QString::number(size)
-           % QLatin1Char('_')
-           % overlays.join("_")
-           % ( group >= 0 ? mpEffect.fingerprint(group, state)
+                  ? QLatin1String("$kicou_")
+                  : QLatin1String("$kico_"))
+           + name
+           + QLatin1Char('_')
+           + QString::number(size)
+           + QLatin1Char('_')
+           + overlays.join("_")
+           + ( group >= 0 ? mpEffect.fingerprint(group, state)
                           : *NULL_EFFECT_FINGERPRINT);
 }
 
 QImage KIconLoaderPrivate::createIconImage(const QString &path, int size)
 {
-    // Use the extension as the format. Works for XPM and PNG, but not for SVG. The
-    // "VGZ" is the last 3 characters of "SVGZ"
-    QString ext = path.right(3).toUpper();
-    QImage img;
+    QImage img(path);
 
-    if (ext != "SVG" && ext != "VGZ")
-    {
-        // Not a SVG or SVGZ
-        img = QImage(path, ext.toLatin1());
-
-        if (size != 0 && !img.isNull()) {
-            img = img.scaled(size, size, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-        }
-    }
-    else
-    {
-#ifndef _WIN32_WCE
-        QSvgRenderer renderer(path, q);
-
-        if (renderer.isValid()) {
-            img = QImage(size, size, QImage::Format_ARGB32_Premultiplied);
-            img.fill(0);
-            QPainter p(&img);
-            renderer.render(&p);
-        }
-#endif
+    if (size != 0 && !img.isNull()) {
+        img = img.scaled(size, size, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
     }
 
     return img;
@@ -813,33 +754,28 @@ void KIconLoaderPrivate::insertCachedPixmapWithPath(
     const QPixmap &data,
     const QString &path = QString())
 {
+    // reject anything bigger than 1024x1024, it is questionable what limit should be because
+    // in some projects the icon loader is abused with pixmaps bigger than that
+    if (data.width() > 1024 || data.height() > 1024) {
+        kWarning(264) << "trying to insert pixmap bigger than 1024x1024 with path:" << path;
+        return;
+    }
+
+    PixmapWithPath *pixmapPath = mPixmapCache.object(key);
+    if (pixmapPath
+        && pixmapPath->pixmap.cacheKey() == data.cacheKey()
+        && pixmapPath->path == path) {
+        return;
+    }
+
     // Even if the pixmap is null, we add it to the caches so that we record
     // the fact that whatever icon led to us getting a null pixmap doesn't
     // exist.
-
-    QBuffer output;
-    output.open(QIODevice::WriteOnly);
-
-    QDataStream outputStream(&output);
-    outputStream.setVersion(QDataStream::Qt_4_6);
-
-    outputStream << path;
-
-    // Convert the QPixmap to PNG. This is actually done by Qt's own operator.
-    outputStream << data;
-
-    output.close();
-
-    // The byte array contained in the QBuffer is what we want in the cache.
-    mIconCache->insert(key, output.buffer());
-
-    // Also insert the object into our process-local cache for even more
-    // speed.
-    PixmapWithPath *pixmapPath = new PixmapWithPath;
+    pixmapPath = new PixmapWithPath;
     pixmapPath->pixmap = data;
     pixmapPath->path = path;
 
-    mPixmapCache.insert(key, pixmapPath, data.width() * data.height() + 1);
+    mPixmapCache.insert(key, pixmapPath);
 }
 
 bool KIconLoaderPrivate::findCachedPixmapWithPath(const QString &key, QPixmap &data, QString &path)
@@ -854,46 +790,24 @@ bool KIconLoaderPrivate::findCachedPixmapWithPath(const QString &key, QPixmap &d
         return true;
     }
 
-    // Otherwise try to find it in our shared memory cache since that will
-    // be quicker than the disk, especially for SVGs.
-    QByteArray result;
-
-    if (!mIconCache->find(key, &result) || result.isEmpty()) {
-        return false;
-    }
-
-    QBuffer buffer;
-    buffer.setBuffer(&result);
-    buffer.open(QIODevice::ReadOnly);
-
-    QDataStream inputStream(&buffer);
-    inputStream.setVersion(QDataStream::Qt_4_6);
-
-    QString tempPath;
-    inputStream >> tempPath;
-
-    if (inputStream.status() == QDataStream::Ok) {
-        QPixmap tempPixmap;
-        inputStream >> tempPixmap;
-
-        if (inputStream.status() == QDataStream::Ok) {
-            data = tempPixmap;
-            path = tempPath;
-
-            // Since we're here we didn't have a QPixmap cache entry, add one now.
-            PixmapWithPath *newPixmapWithPath = new PixmapWithPath;
-            newPixmapWithPath->pixmap = data;
-            newPixmapWithPath->path = path;
-
-            mPixmapCache.insert(key, newPixmapWithPath, data.width() * data.height() + 1);
-
-            return true;
-        }
-    }
-
     return false;
 }
 
+int KIconLoaderPrivate::overlaySize(const QSize &size) const
+{
+    const int minSize = qMin(size.width(), size.height());
+    if (minSize < 32) {
+        return 8;
+    } else if (minSize <= 48) {
+        return  16;
+    } else if (minSize <= 96) {
+        return  22;
+    } else if (minSize < 256) {
+        return  32;
+    }
+    return 64;
+}
+
 K3Icon KIconLoaderPrivate::findMatchingIconWithGenericFallbacks(const QString& name, int size) const
 {
     K3Icon icon = findMatchingIcon(name, size);
@@ -913,130 +827,61 @@ K3Icon KIconLoaderPrivate::findMatchingIcon(const QString& name, int size) const
 
     K3Icon icon;
 
-// The following code has been commented out because the Qt SVG renderer needs
-// to be improved. If you are going to change/remove some code from this part,
-// please contact me before (ereslibre@kde.org), or kde-core-devel@kde.org. (ereslibre)
-#ifdef KDE_QT_SVG_RENDERER_FIXED
-    const char * ext1[4] = { ".png", ".svgz", ".svg", ".xpm" };
-    const char * ext2[4] = { ".svgz", ".svg", ".png", ".xpm" };
-    const char ** ext;
-
-    if (size == KIconLoader::SizeSmall ||
-        size == KIconLoader::SizeSmallMedium ||
-        size == KIconLoader::SizeMedium ||
-        size == KIconLoader::SizeLarge ||
-        size == KIconLoader::SizeHuge ||
-        size == KIconLoader::SizeEnormous)
-    {
-        ext = ext1; // size is standard, give preference to PNG over SVG when searching
-    }
-    else
-    {
-        ext = ext2; // size is non-standard, give preference to SVG over PNG when searching
-    }
-
-    /* If size parameter is a standard one, that means:
-
-           - KIconLoader::SizeSmall
-           - KIconLoader::SizeSmallMedium
-           - KIconLoader::SizeMedium
-           - KIconLoader::SizeLarge
-           - KIconLoader::SizeHuge
-           - KIconLoader::SizeEnormous
-
-       To follow the XDG icon theme and icon naming specifications,
-       the order in which we look for an icon is:
-
-       png, svgz, svg, xpm exact match
-       png, svgz, svg, xpm best match
-       less specific fallback in this theme: png, svgz, svg, xpm exact match
-                                             png, svgz, svg, xpm best match
-       even less specific fallback in this theme: [same order]
-       (...)
-
-       next theme in inheritance tree: png, svgz, svg, xpm exact match
-                                       png, svgz, svg, xpm best match
-       less specific fallbacks in this next theme
-       (...)
-
-       next theme in inheritance tree: png, svgz, svg, xpm exact match
-                                       png, svgz, svg, xpm best match
-       less specific fallbacks in this next theme
-       (...)
-
-       and so on.
-
-       If size parameter is a non-standard one, then we give more preference to
-       SVG format since drawing SVG's gives better quality and despite being
-       slower than resizing a PNG image, the cases where non-standard sizes are
-       asked are very rare. For non-standard sizes what we have is:
-
-       svgz, svg, png, xpm exact match
-       svgz, svg, png, xpm best match
-       less specific fallback in this theme: svgz, svg, png, xpm exact match
-                                             svgz, svg, png, xpm best match
-       even less specific fallback in this theme: [same order]
-       (...)
-
-       next theme in inheritance tree: svgz, svg, png, xpm exact match
-                                       svgz, svg, png, xpm best match
-       less specific fallbacks in this next theme
-       (...)
-
-       next theme in inheritance tree: svgz, svg, png, xpm exact match
-                                       svgz, svg, png, xpm best match
-       less specific fallbacks in this next theme
-       (...)
-
-       and so on.
-       */
-#else
     const char * const ext[4] = { ".png", ".svgz", ".svg", ".xpm" };
-#endif
-
     bool genericFallback = name.endsWith(QLatin1String("-x-generic"));
 
-    foreach(KIconThemeNode *themeNode, links)
-    {
+    // Do two passes through themeNodes.
+    //
+    // The first pass looks for an exact match in each themeNode one after the other.
+    // If one is found and it is an app icon then return that icon.
+    //
+    // In the next pass (assuming the first pass failed), it looks for exact matches
+    // and then generic fallbacks in each themeNode one after the other
+    //
+    // The reasoning is that application icons should always match exactly, all other
+    // icons may fallback. Since we do not know what the context is here when we start
+    // looking for it, we can only go by the path found.
+    foreach (KIconThemeNode *themeNode, links) {
+        for (int i = 0 ; i < 4 ; i++) {
+            icon = themeNode->theme->iconPath(name + ext[i], size, KIconLoader::MatchExact);
+            if (icon.isValid()) {
+                break;
+            }
+
+            icon = themeNode->theme->iconPath(name + ext[i], size, KIconLoader::MatchBest);
+            if (icon.isValid()) {
+                break;
+            }
+        }
+
+        if (icon.isValid() && icon.path.contains("/apps/")) {
+            return icon;
+        }
+    }
+
+    foreach (KIconThemeNode *themeNode, links) {
         QString currentName = name;
 
-        while (!currentName.isEmpty())
-        {
-
+        while (!currentName.isEmpty()) {
             //kDebug(264) << "Looking up" << currentName;
 
-// The following code has been commented out because the Qt SVG renderer needs
-// to be improved. If you are going to change/remove some code from this part,
-// please contact me before (ereslibre@kde.org), or kde-core-devel@kde.org. (ereslibre)
-#ifdef KDE_QT_SVG_RENDERER_FIXED
-            for (int i = 0 ; i < 4 ; i++)
-            {
+            for (int i = 0 ; i < 4 ; i++) {
                 icon = themeNode->theme->iconPath(currentName + ext[i], size, KIconLoader::MatchExact);
-                if (icon.isValid())
-                    return icon;
-            }
-
-            for (int i = 0 ; i < 4 ; i++)
-            {
-                icon = themeNode->theme->iconPath(currentName + ext[i], size, KIconLoader::MatchBest);
-                if (icon.isValid())
-                    return icon;
-            }
-#else
-            for (int i = 0 ; i < 4 ; i++)
-            {
-                icon = themeNode->theme->iconPath(currentName + ext[i], size, KIconLoader::MatchExact);
-                if (icon.isValid())
+                if (icon.isValid()) {
                     return icon;
+                }
 
                 icon = themeNode->theme->iconPath(currentName + ext[i], size, KIconLoader::MatchBest);
-                if (icon.isValid())
+                if (icon.isValid()) {
                     return icon;
+                }
             }
-#endif
-            if (genericFallback)
+            //kDebug(264) << "Looking up" << currentName;
+
+            if (genericFallback) {
                 // we already tested the base name
                 break;
+            }
 
             int rindex = currentName.lastIndexOf('-');
             if (rindex > 1) { // > 1 so that we don't split x-content or x-epoc
@@ -1068,13 +913,13 @@ K3Icon KIconLoaderPrivate::findMatchingIcon(const QString& name, int size) const
 
 inline QString KIconLoaderPrivate::unknownIconPath( int size ) const
 {
-    static const QString &str_unknown = KGlobal::staticQString("unknown");
+    static const QString str_unknown = QString::fromLatin1("unknown");
 
     K3Icon icon = findMatchingIcon(str_unknown, size);
     if (!icon.isValid())
     {
         kDebug(264) << "Warning: could not find \"Unknown\" icon for size = "
-                     << size << endl;
+                     << size;
         return QString();
     }
     return icon.path;
@@ -1100,18 +945,13 @@ QString KIconLoader::iconPath(const QString& _name, int group_or_size,
     QString path;
     if (group_or_size == KIconLoader::User)
     {
-        static const QString &png_ext = KGlobal::staticQString(".png");
-        static const QString &xpm_ext = KGlobal::staticQString(".xpm");
-        path = d->mpDirs->findResource("appicon", name + png_ext);
-
-        static const QString &svgz_ext = KGlobal::staticQString(".svgz");
-        static const QString &svg_ext = KGlobal::staticQString(".svg");
+        path = d->mpDirs->findResource("appicon", name + QLatin1String(".png"));
         if (path.isEmpty())
-            path = d->mpDirs->findResource("appicon", name + svgz_ext);
+            path = d->mpDirs->findResource("appicon", name + QLatin1String(".svgz"));
         if (path.isEmpty())
-            path = d->mpDirs->findResource("appicon", name + svg_ext);
+            path = d->mpDirs->findResource("appicon", name + QLatin1String(".svg"));
         if (path.isEmpty())
-            path = d->mpDirs->findResource("appicon", name + xpm_ext);
+            path = d->mpDirs->findResource("appicon", name + QLatin1String(".xpm"));
         return path;
     }
 
@@ -1277,8 +1117,24 @@ QPixmap KIconLoader::loadIcon(const QString& _name, KIconLoader::Group group, in
     if (favIconOverlay)
     {
         QImage favIcon(name, "PNG");
-        if (!favIcon.isNull()) // if favIcon not there yet, don't try to blend it
+        // if favIcon not there yet, don't try to blend it
+        if (!favIcon.isNull())
         {
+            // ensure it is format supported by QPainter first
+            switch (img.format()) {
+                case QImage::Format_Mono:
+                case QImage::Format_MonoLSB: {
+                    img = img.convertToFormat(QImage::Format_ARGB32);
+                    break;
+                }
+                default:
+                    break;
+            }
+
+            // ensure the icon size is suitable for overlay
+            const int iconSize = d->overlaySize(img.size());
+            favIcon = favIcon.scaled(QSize(iconSize, iconSize), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+
             QPainter p(&img);
 
             // Align the favicon overlay
@@ -1313,76 +1169,6 @@ QPixmap KIconLoader::loadIcon(const QString& _name, KIconLoader::Group group, in
     return pix;
 }
 
-QMovie *KIconLoader::loadMovie(const QString& name, KIconLoader::Group group, int size, QObject *parent) const
-{
-    QString file = moviePath( name, group, size );
-    if (file.isEmpty())
-        return 0;
-    int dirLen = file.lastIndexOf('/');
-    QString icon = iconPath(name, size ? -size : group, true);
-    if (!icon.isEmpty() && file.left(dirLen) != icon.left(dirLen))
-        return 0;
-    QMovie *movie = new QMovie(file, QByteArray(), parent);
-    if (!movie->isValid())
-    {
-        delete movie;
-        return 0;
-    }
-    return movie;
-}
-
-QString KIconLoader::moviePath(const QString& name, KIconLoader::Group group, int size) const
-{
-    if (!d->mpGroups) return QString();
-
-    d->initIconThemes();
-
-    if ( (group < -1 || group >= KIconLoader::LastGroup) && group != KIconLoader::User )
-    {
-        kDebug(264) << "Illegal icon group: " << group;
-        group = KIconLoader::Desktop;
-    }
-    if (size == 0 && group < 0)
-    {
-        kDebug(264) << "Neither size nor group specified!";
-        group = KIconLoader::Desktop;
-    }
-
-    QString file = name + ".mng";
-    if (group == KIconLoader::User)
-    {
-        file = d->mpDirs->findResource("appicon", file);
-    }
-    else
-    {
-        if (size == 0)
-            size = d->mpGroups[group].size;
-
-        K3Icon icon;
-
-        foreach(KIconThemeNode *themeNode, d->links)
-        {
-            icon = themeNode->theme->iconPath(file, size, KIconLoader::MatchExact);
-            if (icon.isValid())
-                break;
-        }
-
-        if ( !icon.isValid() )
-        {
-            foreach(KIconThemeNode *themeNode, d->links)
-            {
-                icon = themeNode->theme->iconPath(file, size, KIconLoader::MatchBest);
-                if (icon.isValid())
-                    break;
-            }
-        }
-
-        file = icon.isValid() ? icon.path : QString();
-    }
-    return file;
-}
-
-
 QStringList KIconLoader::loadAnimated(const QString& name, KIconLoader::Group group, int size) const
 {
     QStringList lst;
@@ -1459,11 +1245,10 @@ QStringList KIconLoader::queryIconsByDir( const QString& iconsDir ) const
 {
     const QDir dir(iconsDir);
     const QStringList formats = QStringList() << "*.png" << "*.xpm" << "*.svg" << "*.svgz";
-    const QStringList lst = dir.entryList(formats, QDir::Files);
     QStringList result;
-    QStringList::ConstIterator it;
-    for (it=lst.begin(); it!=lst.end(); ++it)
-        result += iconsDir + '/' + *it;
+    foreach(const QString it, dir.entryList(formats, QDir::Files)) {
+        result.append(iconsDir + '/' + it);
+    }
     return result;
 }
 
@@ -1577,23 +1362,6 @@ bool KIconLoader::alphaBlending(KIconLoader::Group group) const
     return d->mpGroups[group].alphaBlending;
 }
 
-// deprecated
-#ifndef KDE_NO_DEPRECATED
-QIcon KIconLoader::loadIconSet( const QString& name, KIconLoader::Group g, int s,
-                                bool canReturnNull )
-{
-    QIcon iconset;
-    QPixmap tmp = loadIcon(name, g, s, KIconLoader::ActiveState, QStringList(), NULL, canReturnNull);
-    iconset.addPixmap( tmp, QIcon::Active, QIcon::On );
-    // we don't use QIconSet's resizing anyway
-    tmp = loadIcon(name, g, s, KIconLoader::DisabledState, QStringList(), NULL, canReturnNull);
-    iconset.addPixmap( tmp, QIcon::Disabled, QIcon::On );
-    tmp = loadIcon(name, g, s, KIconLoader::DefaultState, QStringList(), NULL, canReturnNull);
-    iconset.addPixmap( tmp, QIcon::Normal, QIcon::On );
-    return iconset;
-}
-#endif
-
 // Easy access functions
 
 QPixmap DesktopIcon(const QString& name, int force_size, int state, const QStringList &overlays)
@@ -1602,75 +1370,30 @@ QPixmap DesktopIcon(const QString& name, int force_size, int state, const QStrin
     return loader->loadIcon(name, KIconLoader::Desktop, force_size, state, overlays);
 }
 
-// deprecated
-#ifndef KDE_NO_DEPRECATED
-QIcon DesktopIconSet(const QString& name, int force_size)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet(name, KIconLoader::Desktop, force_size);
-}
-#endif
-
 QPixmap BarIcon(const QString& name, int force_size, int state, const QStringList &overlays)
 {
     KIconLoader *loader = KIconLoader::global();
     return loader->loadIcon(name, KIconLoader::Toolbar, force_size, state, overlays);
 }
 
-// deprecated
-#ifndef KDE_NO_DEPRECATED
-QIcon BarIconSet(const QString& name, int force_size)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet( name, KIconLoader::Toolbar, force_size );
-}
-#endif
-
 QPixmap SmallIcon(const QString& name, int force_size, int state, const QStringList &overlays)
 {
     KIconLoader *loader = KIconLoader::global();
     return loader->loadIcon(name, KIconLoader::Small, force_size, state, overlays);
 }
 
-// deprecated
-#ifndef KDE_NO_DEPRECATED
-QIcon SmallIconSet(const QString& name, int force_size)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet( name, KIconLoader::Small, force_size );
-}
-#endif
-
 QPixmap MainBarIcon(const QString& name, int force_size, int state, const QStringList &overlays)
 {
     KIconLoader *loader = KIconLoader::global();
     return loader->loadIcon(name, KIconLoader::MainToolbar, force_size, state, overlays);
 }
 
-// deprecated
-#ifndef KDE_NO_DEPRECATED
-QIcon MainBarIconSet(const QString& name, int force_size)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet( name, KIconLoader::MainToolbar, force_size );
-}
-#endif
-
 QPixmap UserIcon(const QString& name, int state, const QStringList &overlays)
 {
     KIconLoader *loader = KIconLoader::global();
     return loader->loadIcon(name, KIconLoader::User, 0, state, overlays);
 }
 
-// deprecated
-#ifndef KDE_NO_DEPRECATED
-QIcon UserIconSet(const QString& name)
-{
-    KIconLoader *loader = KIconLoader::global();
-    return loader->loadIconSet( name, KIconLoader::User );
-}
-#endif
-
 int IconSize(KIconLoader::Group group)
 {
     KIconLoader *loader = KIconLoader::global();
@@ -1715,5 +1438,5 @@ void KIconLoader::newIconLoader()
     emit iconLoaderSettingsChanged();
 }
 
-#include "kiconloader.moc"
+#include "moc_kiconloader.cpp"
 
