@@ -22,17 +22,13 @@
 #ifndef KICONLOADER_H
 #define KICONLOADER_H
 
-#include <QtCore/QString>
-#include <QtCore/QStringList>
 #include <QtCore/QObject>
+#include <QtGui/QPixmap>
+#include <QtGui/QIcon>
 
 #include <kglobal.h>
 #include <kdeui_export.h>
 
-class QIcon;
-class QMovie;
-class QPixmap;
-
 class KComponentData;
 class KIconLoaderPrivate;
 class KStandardDirs;
@@ -77,6 +73,12 @@ class KIconTheme;
 class KDEUI_EXPORT KIconLoader : public QObject
 {
     Q_OBJECT
+    Q_ENUMS(Context)
+    Q_ENUMS(Type)
+    Q_ENUMS(MatchType)
+    Q_ENUMS(Group)
+    Q_ENUMS(StdSizes)
+    Q_ENUMS(States)
 
 public:
      /**
@@ -87,7 +89,6 @@ public:
         Action,        ///< An action icon (e.g. 'save', 'print').
         Application,   ///< An icon that represents an application.
         Device,        ///< An icon that represents a device.
-        FileSystem,    ///< An icon that represents a file system. @deprecated Use Place instead.
         MimeType,      ///< An icon that represents a mime type (or file type).
         Animation,     ///< An icon that is animated.
         Category,      ///< An icon that represents a category.
@@ -201,7 +202,6 @@ public:
 
     /**
      * Returns the global icon loader initialized with the global KComponentData.
-     * Therefore you must have a KComponentData instantiated before calling this.
      * @return global icon loader
      */
     static KIconLoader* global();
@@ -269,26 +269,6 @@ public:
                               int state=KIconLoader::DefaultState, const QStringList &overlays = QStringList(),
                               QString *path_store=0 ) const;
 
-    /**
-     * Creates an icon set, that will do on-demand loading of the icon.
-     * Loading itself is done by calling loadIcon .
-     *
-     * @param name The name of the icon, without extension.
-     * @param group The icon group. This will specify the size of and effects to
-     * be applied to the icon.
-     * @param size If nonzero, this overrides the size specified by @p group.
-     *             See KIconLoader::StdSizes.
-     * @param canReturnNull Can return a null iconset? If false, iconset
-     * containing the "unknown" pixmap is returned when no appropriate icon has
-     * been found.
-     * @return the icon set. Can be null when not found, depending on
-     *          @p canReturnNull.
-     *
-     * @deprecated use KIcon instead, which uses the iconloader internally
-     */
-    KDE_DEPRECATED QIcon loadIconSet(const QString& name, KIconLoader::Group group, int size = 0,
-                                     bool canReturnNull = false);
-
     /**
      * Returns the path of an icon.
      * @param name The name of the icon, without extension. If an absolute
@@ -307,31 +287,7 @@ public:
                      bool canReturnNull=false) const;
 
     /**
-     * Loads an animated icon.
-     * @param name The name of the icon.
-     * @param group The icon group. See loadIcon().
-     * @param size Override the default size for @p group.
-     *             See KIconLoader::StdSizes.
-     * @param parent The parent object of the returned QMovie.
-     * @return A QMovie object. Can be null if not found or not valid.
-     *         Ownership is passed to the caller.
-     */
-    QMovie *loadMovie(const QString& name, KIconLoader::Group group, int size=0, QObject *parent=0) const;
-
-    /**
-     * Returns the path to an animated icon.
-     * @param name The name of the icon.
-     * @param group The icon group. See loadIcon().
-     * @param size Override the default size for @p group.
-     *             See KIconLoader::StdSizes.
-     * @return the full path to the movie, ready to be passed to QMovie's constructor.
-     * Empty string if not found.
-     */
-    QString moviePath(const QString& name, KIconLoader::Group group, int size=0) const;
-
-    /**
-     * Loads an animated icon as a series of still frames. If you want to load
-     * a .mng animation as QMovie instead, please use loadMovie() instead.
+     * Loads an animated icon as a series of still frames.
      * @param name The name of the icon.
      * @param group The icon group. See loadIcon().
      * @param size Override the default size for @p group.
@@ -381,7 +337,11 @@ public:
     QStringList queryIconsByDir( const QString& iconsDir ) const;
 
     /**
-     * Returns the current size of the group.
+     * Returns the current size of the icon group.
+     * Using e.g. KIconLoader::SmallIcon will retrieve the icon size
+     * that is currently set from System Settings->Appearance->Icon
+     * sizes. SmallIcon for instance, would typically be 16x16, but
+     * the user could increase it and this setting would change as well.
      * @param group the group to check.
      * @return the current size for an icon group.
      */
@@ -438,6 +398,15 @@ public:
      */
     bool extraDesktopThemesAdded() const;
 
+    /**
+     * Draws overlays on the specified pixmap, it takes the width and height
+     * of the pixmap into consideration
+     * @param overlays to draw
+     * @param pixmap to draw on
+     * @since 4.7
+     */
+    void drawOverlays(const QStringList &overlays, QPixmap &pixmap, KIconLoader::Group group, int state = KIconLoader::DefaultState) const;
+
  public Q_SLOTS:
    /**
     * Re-initialize the global icon loader
@@ -462,13 +431,6 @@ Q_SIGNALS:
 KDEUI_EXPORT QPixmap DesktopIcon(const QString& name, int size=0,
                     int state=KIconLoader::DefaultState, const QStringList& overlays = QStringList());
 
-/**
- * \relates KIconLoader
- * Load a desktop icon, and apply the necessary effects to get an IconSet.
- * @deprecated use KIcon(name) or KIcon(name,componentData.iconLoader()) instead
- */
-KDEUI_EXPORT_DEPRECATED QIcon DesktopIconSet(const QString& name, int size=0);
-
 /**
  * \relates KIconLoader
  * Load a toolbar icon.
@@ -476,13 +438,6 @@ KDEUI_EXPORT_DEPRECATED QIcon DesktopIconSet(const QString& name, int size=0);
 KDEUI_EXPORT QPixmap BarIcon(const QString& name, int size=0, int state=KIconLoader::DefaultState,
                              const QStringList& overlays = QStringList());
 
-/**
- * \relates KIconLoader
- * Load a toolbar icon, and apply the necessary effects to get an IconSet.
- * @deprecated use KIcon(name) or KIcon(name,componentData.iconLoader()) instead
- */
-KDEUI_EXPORT_DEPRECATED QIcon BarIconSet(const QString& name, int size=0);
-
 /**
  * \relates KIconLoader
  * Load a small icon.
@@ -490,13 +445,6 @@ KDEUI_EXPORT_DEPRECATED QIcon BarIconSet(const QString& name, int size=0);
 KDEUI_EXPORT QPixmap SmallIcon(const QString& name, int size=0,
                   int state=KIconLoader::DefaultState, const QStringList &overlays = QStringList());
 
-/**
- * \relates KIconLoader
- * Load a small icon, and apply the necessary effects to get an IconSet.
- * @deprecated use KIcon(name) or KIcon(name,componentData.iconLoader()) instead
- */
-KDEUI_EXPORT_DEPRECATED QIcon SmallIconSet(const QString& name, int size=0);
-
 /**
  * \relates KIconLoader
  * Load a main toolbar icon.
@@ -504,26 +452,12 @@ KDEUI_EXPORT_DEPRECATED QIcon SmallIconSet(const QString& name, int size=0);
 KDEUI_EXPORT QPixmap MainBarIcon(const QString& name, int size=0,
                     int state=KIconLoader::DefaultState, const QStringList &overlays = QStringList());
 
-/**
- * \relates KIconLoader
- * Load a main toolbar icon, and apply the effects to get an IconSet.
- * @deprecated use KIcon(name) or KIcon(name,componentData.iconLoader()) instead
- */
-KDEUI_EXPORT_DEPRECATED QIcon MainBarIconSet(const QString& name, int size=0);
-
 /**
  * \relates KIconLoader
  * Load a user icon. User icons are searched in $appdir/pics.
  */
 KDEUI_EXPORT QPixmap UserIcon(const QString& name, int state=KIconLoader::DefaultState, const QStringList &overlays = QStringList());
 
-/**
- * \relates KIconLoader
- * Load a user icon, and apply the effects to get an IconSet.
- * @deprecated use KIcon(name) or KIcon(name,componentData.iconLoader()) instead
- */
-KDEUI_EXPORT_DEPRECATED QIcon UserIconSet(const QString& name);
-
 /**
  * \relates KIconLoader
  * Returns the current icon size for a specific group.
