@@ -23,14 +23,20 @@
 
 #include "kicontheme.h"
 #include "k3icon_p.h"
-
-#include <sys/stat.h>
-#include <unistd.h>
-#include <stdlib.h>
+#include "kdebug.h"
+#include "kicon.h"
+#include "kstandarddirs.h"
+#include "kglobal.h"
+#include "ksharedconfig.h"
+#include "kconfig.h"
+#include "kcomponentdata.h"
+#include "klocale.h"
+#include "kde_file.h"
+#include "kconfiggroup.h"
 
 #include <QtGui/QAction>
-#include <QtCore/QCharRef>
-#include <QtCore/QMutableStringListIterator>
+#include <QtCore/qstring.h>
+#include <QtCore/qstringlist.h>
 #include <QtCore/QMap>
 #include <QtCore/QSet>
 #include <QtGui/QPixmap>
@@ -39,17 +45,10 @@
 #include <QtCore/QFileInfo>
 #include <QtCore/QDir>
 
-#include <kdebug.h>
-#include <kicon.h>
-#include <kstandarddirs.h>
-#include <kglobal.h>
-#include <ksharedconfig.h>
-#include <kconfig.h>
-#include <kcomponentdata.h>
-#include <klocale.h>
-#include <kde_file.h>
-
-#include <kconfiggroup.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <limits.h>
 
 // The following define exists because the Qt SVG renderer needs
 // to be improved. This will be removed soon. (ereslibre)
@@ -144,7 +143,7 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
         icnlibs = KGlobal::dirs()->resourceDirs("data");
         for (it=icnlibs.constBegin(); it!=icnlibs.constEnd(); ++it) {
             const QString cDir = *it + appName + "/icons/" + name;
-            if (QFile::exists( cDir )) {
+            if (QDir( cDir ).exists()) {
                 themeDirs += cDir + '/';
             }
         }
@@ -153,25 +152,17 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
 
     icnlibs = KGlobal::dirs()->resourceDirs("icon")
         << KGlobal::dirs()->resourceDirs("xdgdata-icon")
-        << "/usr/share/pixmaps/"
         // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
         << KGlobal::dirs()->resourceDirs("xdgdata-pixmap");
     icnlibs.removeDuplicates();
 
-    QString fileName, mainSection;
     for (it=icnlibs.constBegin(); it!=icnlibs.constEnd(); ++it) {
         const QString cDir = *it + name + '/';
-        if (KStandardDirs::exists(cDir)) {
+        if (KGlobal::dirs()->exists(cDir)) {
             themeDirs += cDir;
             if (d->mDir.isEmpty()) {
-                if (KStandardDirs::exists(cDir + "index.theme")) {
+                if (KGlobal::dirs()->exists(cDir + "index.theme")) {
                     d->mDir = cDir;
-                    fileName = d->mDir + "index.theme";
-                    mainSection = "Icon Theme";
-                } else if (KStandardDirs::exists(cDir + "index.desktop")) {
-                    d->mDir = cDir;
-                    fileName = d->mDir + "index.desktop";
-                    mainSection = "KDE Icon Theme";
                 }
             }
         }
@@ -184,9 +175,9 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
 
     // Use KSharedConfig to avoid parsing the file many times, from each kinstance.
     // Need to keep a ref to it to make this useful
-    d->sharedConfig = KSharedConfig::openConfig(fileName);
+    d->sharedConfig = KSharedConfig::openConfig(d->mDir + "index.theme", KConfig::NoGlobals);
 
-    KConfigGroup cfg(d->sharedConfig, mainSection);
+    KConfigGroup cfg(d->sharedConfig, "Icon Theme");
     d->mName = cfg.readEntry("Name");
     d->mDesc = cfg.readEntry("Comment");
     d->mDepth = cfg.readEntry("DisplayDepth", 32);
@@ -208,7 +199,7 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
         KConfigGroup cg(d->sharedConfig, *it);
         for (itDir=themeDirs.constBegin(); itDir!=themeDirs.constEnd(); ++itDir) {
             const QString currentDir(*itDir + *it + '/');
-            if (!addedDirs.contains(currentDir) && KStandardDirs::exists(currentDir)) {
+            if (!addedDirs.contains(currentDir) && KGlobal::dirs()->exists(currentDir)) {
                 addedDirs.insert(currentDir);
                 KIconThemeDir *dir = new KIconThemeDir(*itDir, *it, cg);
                 if (!dir->isValid()) {
@@ -245,10 +236,9 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
     groups += "Panel";
     groups += "Dialog";
     const int defDefSizes[] = { 32, 22, 22, 16, 32, 32 };
-    KConfigGroup cg(d->sharedConfig, mainSection);
     for (it=groups.constBegin(), i=0; it!=groups.constEnd(); ++it, i++) {
-        d->mDefSize[i] = cg.readEntry(*it + "Default", defDefSizes[i]);
-        const QList<int> lst = cg.readEntry(*it + "Sizes", QList<int>());
+        d->mDefSize[i] = cfg.readEntry(*it + "Default", defDefSizes[i]);
+        const QList<int> lst = cfg.readEntry(*it + "Sizes", QList<int>());
         QList<int> exp;
         QList<int>::ConstIterator it2;
         for (it2=lst.begin(); it2!=lst.end(); ++it2) {
@@ -533,7 +523,7 @@ QString KIconTheme::current()
     }
 /*    if (_theme->isEmpty())
     {
-        if (QPixmap::defaultDepth() > 8)
+        if (QX11Info::appDepth() > 8)
             *_theme = defaultThemeName();
         else
             *_theme = QLatin1String("locolor");
@@ -549,11 +539,11 @@ QStringList KIconTheme::list()
         return *_theme_list;
     }
 
-    const QStringList icnlibs = KGlobal::dirs()->resourceDirs("icon")
-     << KGlobal::dirs()->resourceDirs("xdgdata-icon")
-     << "/usr/share/pixmaps"
-     // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
-     << KGlobal::dirs()->resourceDirs("xdgdata-pixmap");
+    QStringList icnlibs = KGlobal::dirs()->resourceDirs("icon")
+        << KGlobal::dirs()->resourceDirs("xdgdata-icon")
+        // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
+        << KGlobal::dirs()->resourceDirs("xdgdata-pixmap");
+    icnlibs.removeDuplicates();
 
     QStringList::ConstIterator it;
     for (it=icnlibs.begin(); it!=icnlibs.end(); ++it) {
@@ -567,7 +557,7 @@ QStringList KIconTheme::list()
             if ((*it2 == ".") || (*it2 == "..") || (*it2).startsWith(QLatin1String("default.")) ) {
                 continue;
             }
-            if (!KStandardDirs::exists(*it + *it2 + "/index.desktop") && !KStandardDirs::exists(*it + *it2 + "/index.theme")) {
+            if (!KGlobal::dirs()->exists(*it + *it2 + "/index.theme")) {
                 continue;
             }
             KIconTheme oink(*it2);
@@ -593,7 +583,7 @@ void KIconTheme::reconfigure()
 // static
 QString KIconTheme::defaultThemeName()
 {
-    return QLatin1String("oxygen");
+    return QLatin1String("ariya");
 }
 
 void KIconTheme::assignIconsToContextMenu( ContextMenus type,
@@ -650,8 +640,6 @@ KIconThemeDir::KIconThemeDir(const QString& basedir, const QString &themedir, co
         mContext = KIconLoader::Device;
     else if (tmp == "MimeTypes")
         mContext = KIconLoader::MimeType;
-    else if (tmp == "FileSystems")
-        mContext = KIconLoader::FileSystem;
     else if (tmp == "Applications")
         mContext = KIconLoader::Application;
     else if (tmp == "Actions")
