@@ -32,12 +32,9 @@
 #include "kcategorizedview.h"
 #include "kcategorizedview_p.h"
 
-#include <math.h> // trunc on C99 compliant systems
-#include <kdefakes.h> // trunc for not C99 compliant systems
-
 #include <QPainter>
 #include <QScrollBar>
-#include <QPaintEvent>
+#include <QtGui/qevent.h>
 
 #include "kcategorydrawer.h"
 #include "kcategorizedsortfilterproxymodel.h"
@@ -108,8 +105,6 @@ KCategorizedView::Private::Private(KCategorizedView *q)
     : q(q)
     , proxyModel(0)
     , categoryDrawer(0)
-    , categoryDrawerV2(0)
-    , categoryDrawerV3(0)
     , categorySpacing(5)
     , alternatingBlockColors(false)
     , collapsibleBlocks(false)
@@ -157,13 +152,7 @@ QPair<QModelIndex, QModelIndex> KCategorizedView::Private::intersectingIndexesWi
     while (bottom <= top) {
         const int middle = (bottom + top) / 2;
         const QModelIndex index = proxyModel->index(middle, q->modelColumn(), q->rootIndex());
-        QRect itemRect = q->visualRect(index);
-        const int verticalOff = q->verticalOffset();
-        const int horizontalOff = q->horizontalOffset();
-        itemRect.topLeft().ry() += verticalOff;
-        itemRect.topLeft().rx() += horizontalOff;
-        itemRect.bottomRight().ry() += verticalOff;
-        itemRect.bottomRight().rx() += horizontalOff;
+        const QRect itemRect = q->visualRect(index);
         if (itemRect.bottomRight().y() <= rect.topLeft().y()) {
             bottom = middle + 1;
         } else {
@@ -179,13 +168,7 @@ QPair<QModelIndex, QModelIndex> KCategorizedView::Private::intersectingIndexesWi
     while (bottom <= top) {
         const int middle = (bottom + top) / 2;
         const QModelIndex index = proxyModel->index(middle, q->modelColumn(), q->rootIndex());
-        QRect itemRect = q->visualRect(index);
-        const int verticalOff = q->verticalOffset();
-        const int horizontalOff = q->horizontalOffset();
-        itemRect.topLeft().ry() += verticalOff;
-        itemRect.topLeft().rx() += horizontalOff;
-        itemRect.bottomRight().ry() += verticalOff;
-        itemRect.bottomRight().rx() += horizontalOff;
+        const QRect itemRect = q->visualRect(index);
         if (itemRect.topLeft().y() <= rect.bottomRight().y()) {
             bottom = middle + 1;
         } else {
@@ -535,7 +518,7 @@ void KCategorizedView::setModel(QAbstractItemModel *model)
         disconnect(d->proxyModel, SIGNAL(layoutChanged()), this, SLOT(slotLayoutChanged()));
     }
 
-    d->proxyModel = dynamic_cast<KCategorizedSortFilterProxyModel*>(model);
+    d->proxyModel = qobject_cast<KCategorizedSortFilterProxyModel*>(model);
 
     if (d->proxyModel) {
         connect(d->proxyModel, SIGNAL(layoutChanged()), this, SLOT(slotLayoutChanged()));
@@ -648,17 +631,15 @@ KCategoryDrawer *KCategorizedView::categoryDrawer() const
 
 void KCategorizedView::setCategoryDrawer(KCategoryDrawer *categoryDrawer)
 {
-    if (d->categoryDrawerV2) {
-        disconnect(d->categoryDrawerV2, SIGNAL(collapseOrExpandClicked(QModelIndex)),
+    if (d->categoryDrawer) {
+        disconnect(d->categoryDrawer, SIGNAL(collapseOrExpandClicked(QModelIndex)),
                    this, SLOT(_k_slotCollapseOrExpandClicked(QModelIndex)));
     }
 
     d->categoryDrawer = categoryDrawer;
-    d->categoryDrawerV2 = dynamic_cast<KCategoryDrawerV2*>(categoryDrawer);
-    d->categoryDrawerV3 = dynamic_cast<KCategoryDrawerV3*>(categoryDrawer);
 
-    if (d->categoryDrawerV2) {
-        connect(d->categoryDrawerV2, SIGNAL(collapseOrExpandClicked(QModelIndex)),
+    if (d->categoryDrawer) {
+        connect(d->categoryDrawer, SIGNAL(collapseOrExpandClicked(QModelIndex)),
                 this, SLOT(_k_slotCollapseOrExpandClicked(QModelIndex)));
     }
 }
@@ -742,16 +723,7 @@ QModelIndex KCategorizedView::indexAt(const QPoint &point) const
     while (bottom <= top) {
         const int middle = (bottom + top) / 2;
         const QModelIndex index = d->proxyModel->index(middle, modelColumn(), rootIndex());
-        QRect rect = visualRect(index);
-        const int verticalOff = verticalOffset();
-        int horizontalOff = horizontalOffset();
-        if (layoutDirection() == Qt::RightToLeft) {
-            horizontalOff *= -1;
-        }
-        rect.topLeft().ry() += verticalOff;
-        rect.topLeft().rx() += horizontalOff;
-        rect.bottomRight().ry() += verticalOff;
-        rect.bottomRight().rx() += horizontalOff;
+        const QRect rect = visualRect(index);
         if (rect.contains(point)) {
             if (index.model()->flags(index) & Qt::ItemIsEnabled) {
                 return index;
@@ -760,15 +732,41 @@ QModelIndex KCategorizedView::indexAt(const QPoint &point) const
         }
         bool directionCondition;
         if (layoutDirection() == Qt::LeftToRight) {
-            directionCondition = point.x() > rect.bottomRight().x();
+            directionCondition = point.x() >= rect.bottomLeft().x();
         } else {
-            directionCondition = point.x() < rect.bottomLeft().x();
+            directionCondition = point.x() <= rect.bottomRight().x();
         }
-        if (point.y() > rect.bottomRight().y() ||
-            (point.y() > rect.topLeft().y() && point.y() < rect.bottomRight().y() && directionCondition)) {
-            bottom = middle + 1;
-        } else {
+        if (point.y() < rect.topLeft().y()) {
             top = middle - 1;
+        } else if (directionCondition) {
+            bottom = middle + 1;
+        } else if (point.y() <= rect.bottomRight().y()) {
+            top = middle - 1;
+        } else {
+            bool after = true;
+            for (int i = middle - 1;i >= bottom;i--) {
+                const QModelIndex newIndex =
+                    d->proxyModel->index(i, modelColumn(), rootIndex());
+                const QRect newRect = visualRect(newIndex);
+                if (newRect.topLeft().y() < rect.topLeft().y()) {
+                    break;
+                } else if (newRect.contains(point)) {
+                    if (newIndex.model()->flags(newIndex) & Qt::ItemIsEnabled) {
+                        return newIndex;
+                    }
+                    return QModelIndex();
+                } else if ((layoutDirection() == Qt::LeftToRight) ?
+                           (newRect.topLeft().x() <= point.x()) :
+                           (newRect.topRight().x() >= point.x())) {
+                    break;
+                } else if (newRect.bottomRight().y() >= point.y()) {
+                    after = false;
+                }
+            }
+            if (!after) {
+                return QModelIndex();
+            }
+            bottom = middle + 1;
         }
     }
     return QModelIndex();
@@ -953,7 +951,7 @@ void KCategorizedView::mouseMoveEvent(QMouseEvent *event)
         update(rect.united(d->rubberBandRect));
         d->rubberBandRect = rect;
     }
-    if (!d->categoryDrawerV2) {
+    if (!d->categoryDrawer) {
         return;
     }
     QHash<QString, Private::Block>::ConstIterator it(d->blocks.constBegin());
@@ -970,30 +968,28 @@ void KCategorizedView::mouseMoveEvent(QMouseEvent *event)
         option.rect = d->mapToViewport(option.rect);
         const QPoint mousePos = viewport()->mapFromGlobal(QCursor::pos());
         if (option.rect.contains(mousePos)) {
-            if (d->categoryDrawerV3 && d->hoveredBlock->height != -1 && *d->hoveredBlock != block) {
+            if (d->categoryDrawer && d->hoveredBlock->height != -1 && *d->hoveredBlock != block) {
                 const QModelIndex categoryIndex = d->proxyModel->index(d->hoveredBlock->firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
                 const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
-                d->categoryDrawerV3->mouseLeft(categoryIndex, option.rect);
+                d->categoryDrawer->mouseLeft(categoryIndex, option.rect);
                 *d->hoveredBlock = block;
                 d->hoveredCategory = it.key();
                 viewport()->update(option.rect);
             } else if (d->hoveredBlock->height == -1) {
                 *d->hoveredBlock = block;
                 d->hoveredCategory = it.key();
-            } else if (d->categoryDrawerV3) {
-                d->categoryDrawerV3->mouseMoved(categoryIndex, option.rect, event);
             } else {
-                d->categoryDrawerV2->mouseButtonMoved(categoryIndex, event);
+                d->categoryDrawer->mouseMoved(categoryIndex, option.rect, event);
             }
             viewport()->update(option.rect);
             return;
         }
         ++it;
     }
-    if (d->categoryDrawerV3 && d->hoveredBlock->height != -1) {
+    if (d->categoryDrawer && d->hoveredBlock->height != -1) {
         const QModelIndex categoryIndex = d->proxyModel->index(d->hoveredBlock->firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
         const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
-        d->categoryDrawerV3->mouseLeft(categoryIndex, option.rect);
+        d->categoryDrawer->mouseLeft(categoryIndex, option.rect);
         *d->hoveredBlock = Private::Block();
         d->hoveredCategory = QString();
         viewport()->update(option.rect);
@@ -1007,7 +1003,7 @@ void KCategorizedView::mousePressEvent(QMouseEvent *event)
         d->pressedPosition.rx() += horizontalOffset();
         d->pressedPosition.ry() += verticalOffset();
     }
-    if (!d->categoryDrawerV2) {
+    if (!d->categoryDrawer) {
         QListView::mousePressEvent(event);
         return;
     }
@@ -1018,11 +1014,7 @@ void KCategorizedView::mousePressEvent(QMouseEvent *event)
         const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
         const QPoint mousePos = viewport()->mapFromGlobal(QCursor::pos());
         if (option.rect.contains(mousePos)) {
-            if (d->categoryDrawerV3) {
-                d->categoryDrawerV3->mouseButtonPressed(categoryIndex, option.rect, event);
-            } else {
-                d->categoryDrawerV2->mouseButtonPressed(categoryIndex, event);
-            }
+            d->categoryDrawer->mouseButtonPressed(categoryIndex, option.rect, event);
             viewport()->update(option.rect);
             if (!event->isAccepted()) {
                 QListView::mousePressEvent(event);
@@ -1038,7 +1030,7 @@ void KCategorizedView::mouseReleaseEvent(QMouseEvent *event)
 {
     d->pressedPosition = QPoint();
     d->rubberBandRect = QRect();
-    if (!d->categoryDrawerV2) {
+    if (!d->categoryDrawer) {
         QListView::mouseReleaseEvent(event);
         return;
     }
@@ -1049,11 +1041,7 @@ void KCategorizedView::mouseReleaseEvent(QMouseEvent *event)
         const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
         const QPoint mousePos = viewport()->mapFromGlobal(QCursor::pos());
         if (option.rect.contains(mousePos)) {
-            if (d->categoryDrawerV3) {
-                d->categoryDrawerV3->mouseButtonReleased(categoryIndex, option.rect, event);
-            } else {
-                d->categoryDrawerV2->mouseButtonReleased(categoryIndex, event);
-            }
+            d->categoryDrawer->mouseButtonReleased(categoryIndex, option.rect, event);
             viewport()->update(option.rect);
             if (!event->isAccepted()) {
                 QListView::mouseReleaseEvent(event);
@@ -1072,42 +1060,22 @@ void KCategorizedView::leaveEvent(QEvent *event)
         viewport()->update(visualRect(d->hoveredIndex));
         d->hoveredIndex = QModelIndex();
     }
-    if (d->categoryDrawerV3 && d->hoveredBlock->height != -1) {
+    if (d->categoryDrawer && d->hoveredBlock->height != -1) {
         const QModelIndex categoryIndex = d->proxyModel->index(d->hoveredBlock->firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
         const QStyleOptionViewItemV4 option = d->blockRect(categoryIndex);
-        d->categoryDrawerV3->mouseLeft(categoryIndex, option.rect);
+        d->categoryDrawer->mouseLeft(categoryIndex, option.rect);
         *d->hoveredBlock = Private::Block();
         d->hoveredCategory = QString();
         viewport()->update(option.rect);
     }
 }
 
-void KCategorizedView::startDrag(Qt::DropActions supportedActions)
-{
-    QListView::startDrag(supportedActions);
-}
-
 void KCategorizedView::dragMoveEvent(QDragMoveEvent *event)
 {
     QListView::dragMoveEvent(event);
     d->hoveredIndex = indexAt(event->pos());
 }
 
-void KCategorizedView::dragEnterEvent(QDragEnterEvent *event)
-{
-    QListView::dragEnterEvent(event);
-}
-
-void KCategorizedView::dragLeaveEvent(QDragLeaveEvent *event)
-{
-    QListView::dragLeaveEvent(event);
-}
-
-void KCategorizedView::dropEvent(QDropEvent *event)
-{
-    QListView::dropEvent(event);
-}
-
 //TODO: improve se we take into account collapsed blocks
 //TODO: take into account when there is no grid and no uniformItemSizes
 QModelIndex KCategorizedView::moveCursor(CursorAction cursorAction,
@@ -1440,12 +1408,6 @@ void KCategorizedView::updateGeometries()
     //END bugs 213068, 287847 --------------------------------------------------------------
 }
 
-void KCategorizedView::currentChanged(const QModelIndex &current,
-                                      const QModelIndex &previous)
-{
-    QListView::currentChanged(current, previous);
-}
-
 void KCategorizedView::dataChanged(const QModelIndex &topLeft,
                                    const QModelIndex &bottomRight)
 {
@@ -1492,27 +1454,7 @@ void KCategorizedView::rowsInserted(const QModelIndex &parent,
     d->rowsInserted(parent, start, end);
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KCategorizedView::rowsInsertedArtifficial(const QModelIndex &parent,
-                                               int start,
-                                               int end)
-{
-    Q_UNUSED(parent);
-    Q_UNUSED(start);
-    Q_UNUSED(end);
-}
-#endif
 
-#ifndef KDE_NO_DEPRECATED
-void KCategorizedView::rowsRemoved(const QModelIndex &parent,
-                                   int start,
-                                   int end)
-{
-    Q_UNUSED(parent);
-    Q_UNUSED(start);
-    Q_UNUSED(end);
-}
-#endif
 
 void KCategorizedView::slotLayoutChanged()
 {
@@ -1530,4 +1472,4 @@ void KCategorizedView::slotLayoutChanged()
 
 //END: Public part
 
-#include "kcategorizedview.moc"
+#include "moc_kcategorizedview.cpp"
