@@ -23,8 +23,6 @@
 
 class KCategorizedSortFilterProxyModel;
 class KCategoryDrawer;
-class KCategoryDrawerV2;
-class KCategoryDrawerV3;
 
 /**
   * @internal
@@ -140,8 +138,6 @@ public:
     KCategorizedView *q;
     KCategorizedSortFilterProxyModel *proxyModel;
     KCategoryDrawer *categoryDrawer;
-    KCategoryDrawerV2 *categoryDrawerV2;
-    KCategoryDrawerV3 *categoryDrawerV3;
     int categorySpacing;
     bool alternatingBlockColors;
     bool collapsibleBlocks;
