@@ -21,7 +21,7 @@
 
 #include "kidentityproxymodel.h"
 
-#include <QtGui/QItemSelection>
+#include <QtGui/qitemselectionmodel.h>
 #include <QtCore/QStringList>
 #include <kdebug.h>
 
@@ -754,4 +754,4 @@ void KIdentityProxyModel::resetInternalData()
 
 }
 
-#include "kidentityproxymodel.moc"
+#include "moc_kidentityproxymodel.cpp"
