@@ -23,7 +23,7 @@
 #include <QtCore/QList>
 #include <QtCore/QTimer>
 #include <QtGui/QApplication>
-#include <QtGui/QContextMenuEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QHBoxLayout>
 #include <QtGui/QHeaderView>
 #include <QtGui/QLabel>
@@ -620,4 +620,4 @@ KTreeWidgetSearchLine *KTreeWidgetSearchLineWidget::searchLine() const
   return d->searchLine;
 }
 
-#include "ktreewidgetsearchline.moc"
+#include "moc_ktreewidgetsearchline.cpp"
