@@ -24,17 +24,17 @@
 
 #include <QtCore/QEvent>
 #include <QtCore/QList>
-#include <QtCore/QPersistentModelIndex>
+#include <QtCore/qabstractitemmodel.h>
 #include <QtGui/QAbstractItemDelegate>
 
 #include <kdeui_export.h>
 
-class QObject;
-class QPainter;
-class QStyleOption;
-class QStyleOptionViewItem;
-class QAbstractItemView;
-class QItemSelection;
+#include <QObject>
+#include <QPainter>
+#include <QStyleOption>
+#include <QStyleOptionViewItem>
+#include <QAbstractItemView>
+#include <QItemSelection>
 
 class KWidgetItemDelegatePrivate;
 class KWidgetItemDelegatePool;
@@ -89,7 +89,7 @@ protected:
      *       do it here.
      *
      * @note If you want to know the index for which you are creating widgets, it is
-     *       available as a QModelIndex Q_PROPERTY called "goya:creatingWidgetForIndex".
+     *       available as a QModelIndex Q_PROPERTY called "goya:creatingWidgetsForIndex".
      *       Ensure to add Q_DECLARE_METATYPE(QModelIndex) before your method definition
      *       to tell QVariant about QModelIndex.
      *
@@ -128,10 +128,6 @@ protected:
      *          widgets of a certain index to be updated your model has to emit dataChanged() on the
      *          indexes that want to be updated.
      */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED void paintWidgets(QPainter *painter, const QStyleOptionViewItem &option,
-                                     const QPersistentModelIndex &index) const;
-#endif
 
     /**
      * Sets the list of event @p types that a @p widget will block.
