@@ -27,7 +27,7 @@
 #include <QWidget>
 
 #if defined Q_WS_X11
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include <netwm.h>
 #endif
 
@@ -94,4 +94,4 @@ void KDialogJobUiDelegate::slotWarning(KJob* /*job*/, const QString &plain, cons
 }
 
 
-#include "kdialogjobuidelegate.moc"
+#include "moc_kdialogjobuidelegate.cpp"
