@@ -27,6 +27,8 @@
 #include <QWidget>
 #include <QMap>
 #include <QTime>
+#include <QLabel>
+#include <QProgressBar>
 #include <QQueue>
 #include <QCheckBox>
 
@@ -36,8 +38,6 @@
 
 class KPushButton;
 class KSqueezedTextLabel;
-class QLabel;
-class QProgressBar;
 
 class KWidgetJobTracker::Private
     : public KAbstractWidgetJobTracker::Private
