@@ -21,61 +21,47 @@
 #include <config.h>
 
 #include <kconfig.h>
-
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kprotocolinfo.h>
 #include <kcolorscheme.h>
-
 #include <kstyle.h>
+#include <kapplication.h>
 
+#include <QtCore/QDir>
+#include <QtCore/QStandardPaths>
+#include <QtCore/QProcess>
 #include <QtGui/QColor>
 #include <QtGui/QCursor>
 #include <QtGui/QDesktopWidget>
-#include <QtCore/QDir>
 #include <QtGui/QFont>
 #include <QtGui/QFontDatabase>
-#include <QtGui/QFontInfo>
 #include <QtGui/QKeySequence>
 #include <QtGui/QPixmap>
 #include <QtGui/QPixmapCache>
-#include <QApplication>
-#include <QtDBus/QtDBus>
-#include <QtGui/QStyleFactory>
-#include <QDesktopServices>
-#include "qplatformdefs.h"
-
-// next two needed so we can set their palettes
 #include <QtGui/QToolTip>
 #include <QtGui/QWhatsThis>
+#include <QtGui/QApplication>
+#include <QtGui/QStyleFactory>
+#include <QtGui/QGuiPlatformPlugin>
+#include <QtDBus/QtDBus>
+#include "qplatformdefs.h"
 
-#ifdef Q_WS_WIN
-#include <windows.h>
-#include <kkernel_win.h>
-
-static QRgb qt_colorref2qrgb(COLORREF col)
-{
-    return qRgb(GetRValue(col),GetGValue(col),GetBValue(col));
-}
-#endif
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
 #ifdef HAVE_XCURSOR
 #include <X11/Xcursor/Xcursor.h>
 #endif
 #include "fixx11h.h"
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #endif
 
 #include <stdlib.h>
 #include <kconfiggroup.h>
 
 
-//static QColor *_buttonBackground = 0;
-static KGlobalSettings::GraphicEffects _graphicEffects = KGlobalSettings::NoEffects;
-
 // TODO: merge this with KGlobalSettings::Private
 //
 // F. Kossebau: KDE5: think to make all methods static and not expose an object,
@@ -151,6 +137,9 @@ class KGlobalSettings::Private
             : q(q), activated(false), paletteCreated(false)
         {
             kdeFullSession = !qgetenv("KDE_FULL_SESSION").isEmpty();
+            if (!kdeFullSession) {
+                kdeFullSession = (QProcess::execute("kcheckrunning") == 0);
+            }
         }
 
         QPalette createApplicationPalette(const KSharedConfigPtr &config);
@@ -161,6 +150,7 @@ class KGlobalSettings::Private
         void kdisplaySetPalette();
         void kdisplaySetStyle();
         void kdisplaySetFont();
+        void kdisplaySetCursor();
         void applyGUIStyle();
 
         /**
@@ -176,8 +166,6 @@ class KGlobalSettings::Private
          */
         void applyCursorTheme();
 
-        static void reloadStyleSettings();
-
         KGlobalSettings *q;
         bool activated;
         bool paletteCreated;
@@ -219,6 +207,7 @@ void KGlobalSettings::activate(ActivateOptions options)
         if (options & ApplySettings) {
             d->kdisplaySetStyle(); // implies palette setup
             d->kdisplaySetFont();
+            d->kdisplaySetCursor();
             d->propagateQtSettings();
         }
     }
@@ -244,11 +233,9 @@ bool KGlobalSettings::smoothScroll()
 
 KGlobalSettings::TearOffHandle KGlobalSettings::insertTearOffHandle()
 {
-    int tearoff;
-    bool effectsenabled;
+    bool effectsenabled = (KGlobalSettings::graphicEffectsLevel() > KGlobalSettings::NoEffects);
     KConfigGroup g( KGlobal::config(), "KDE" );
-    effectsenabled = g.readEntry( "EffectsEnabled", false);
-    tearoff = g.readEntry("InsertTearOffHandle", KDE_DEFAULT_INSERTTEAROFFHANDLES);
+    int tearoff = g.readEntry("InsertTearOffHandle", KDE_DEFAULT_INSERTTEAROFFHANDLES);
     return effectsenabled ? (TearOffHandle) tearoff : Disable;
 }
 
@@ -283,78 +270,33 @@ bool KGlobalSettings::showContextMenusOnPress ()
     return g.readEntry("ShowOnPress", true);
 }
 
-#ifndef KDE_NO_DEPRECATED
-int KGlobalSettings::contextMenuKey ()
-{
-    KConfigGroup g(KGlobal::config(), "Shortcuts");
-    QString s = g.readEntry ("PopupMenuContext", "Menu");
-
-    // this is a bit of a code duplication with KShortcut,
-    // but seeing as that is all in kdeui these days there's little choice.
-    // this is faster for what we're really after here anyways
-    // (less allocations, only processing the first item always, etc)
-    if (s == QLatin1String("none")) {
-        return QKeySequence()[0];
-    }
-
-    const QStringList shortCuts = s.split(';');
-
-    if (shortCuts.count() < 1) {
-        return QKeySequence()[0];
-    }
-
-    s = shortCuts.at(0);
-
-    if ( s.startsWith( QLatin1String("default(") ) ) {
-        s = s.mid( 8, s.length() - 9 );
-    }
-
-    return QKeySequence::fromString(s)[0];
-}
-#endif
 
 // NOTE: keep this in sync with kdebase/workspace/kcontrol/colors/colorscm.cpp
 QColor KGlobalSettings::inactiveTitleColor()
 {
-#ifdef Q_WS_WIN
-    return qt_colorref2qrgb(GetSysColor(COLOR_INACTIVECAPTION));
-#else
     KConfigGroup g( KGlobal::config(), "WM" );
     return g.readEntry( "inactiveBackground", QColor(224,223,222) );
-#endif
 }
 
 // NOTE: keep this in sync with kdebase/workspace/kcontrol/colors/colorscm.cpp
 QColor KGlobalSettings::inactiveTextColor()
 {
-#ifdef Q_WS_WIN
-    return qt_colorref2qrgb(GetSysColor(COLOR_INACTIVECAPTIONTEXT));
-#else
     KConfigGroup g( KGlobal::config(), "WM" );
     return g.readEntry( "inactiveForeground", QColor(75,71,67) );
-#endif
 }
 
 // NOTE: keep this in sync with kdebase/workspace/kcontrol/colors/colorscm.cpp
 QColor KGlobalSettings::activeTitleColor()
 {
-#ifdef Q_WS_WIN
-    return qt_colorref2qrgb(GetSysColor(COLOR_ACTIVECAPTION));
-#else
     KConfigGroup g( KGlobal::config(), "WM" );
     return g.readEntry( "activeBackground", QColor(48,174,232));
-#endif
 }
 
 // NOTE: keep this in sync with kdebase/workspace/kcontrol/colors/colorscm.cpp
 QColor KGlobalSettings::activeTextColor()
 {
-#ifdef Q_WS_WIN
-    return qt_colorref2qrgb(GetSysColor(COLOR_CAPTIONTEXT));
-#else
     KConfigGroup g( KGlobal::config(), "WM" );
     return g.readEntry( "activeForeground", QColor(255,255,255) );
-#endif
 }
 
 int KGlobalSettings::contrast()
@@ -390,38 +332,20 @@ struct KFontData
     const char* ConfigKey;
     const char* FontName;
     int Size;
-    int Weight;
-    QFont::StyleHint StyleHint;
 };
 
 // NOTE: keep in sync with kdebase/workspace/kcontrol/fonts/fonts.cpp
 static const char GeneralId[] =      "General";
-static const char DefaultFont[] =    "Sans Serif";
-#ifdef Q_WS_MAC
-static const char DefaultMacFont[] = "Lucida Grande";
-#endif
 
 static const KFontData DefaultFontData[KGlobalSettingsData::FontTypesCount] =
 {
-#ifdef Q_WS_MAC
-    { GeneralId, "font",        DefaultMacFont, 13, -1, QFont::SansSerif },
-    { GeneralId, "fixed",       "Monaco",       10, -1, QFont::TypeWriter },
-    { GeneralId, "toolBarFont", DefaultMacFont, 11, -1, QFont::SansSerif },
-    { GeneralId, "menuFont",    DefaultMacFont, 13, -1, QFont::SansSerif },
-#elif defined(Q_WS_MAEMO_5) || defined(MEEGO_EDITION_HARMATTAN)
-    { GeneralId, "font",        DefaultFont, 16, -1, QFont::SansSerif },
-    { GeneralId, "fixed",       "Monospace", 16, -1, QFont::TypeWriter },
-    { GeneralId, "toolBarFont", DefaultFont, 16, -1, QFont::SansSerif },
-    { GeneralId, "menuFont",    DefaultFont, 16, -1, QFont::SansSerif },
-#else
-    { GeneralId, "font",        DefaultFont, 9, -1, QFont::SansSerif },
-    { GeneralId, "fixed",       "Monospace", 9, -1, QFont::TypeWriter },
-    { GeneralId, "toolBarFont", DefaultFont,  8, -1, QFont::SansSerif },
-    { GeneralId, "menuFont",    DefaultFont, 9, -1, QFont::SansSerif },
-#endif
-    { "WM",      "activeFont",           DefaultFont,  8, -1, QFont::SansSerif },
-    { GeneralId, "taskbarFont",          DefaultFont, 9, -1, QFont::SansSerif },
-    { GeneralId, "smallestReadableFont", DefaultFont,  8, -1, QFont::SansSerif }
+    { GeneralId, "font",                 KDE_DEFAULT_FONT,       9 },
+    { GeneralId, "fixed",                KDE_DEFAULT_FIXED_FONT, 9 },
+    { GeneralId, "toolBarFont",          KDE_DEFAULT_FONT,       8 },
+    { GeneralId, "menuFont",             KDE_DEFAULT_FONT,       9 },
+    { "WM",      "activeFont",           KDE_DEFAULT_FONT,       8 },
+    { GeneralId, "taskbarFont",          KDE_DEFAULT_FONT,       9 },
+    { GeneralId, "smallestReadableFont", KDE_DEFAULT_FONT,       8 }
 };
 
 QFont KGlobalSettingsData::font( FontTypes fontType )
@@ -431,8 +355,7 @@ QFont KGlobalSettingsData::font( FontTypes fontType )
     if (!cachedFont)
     {
         const KFontData& fontData = DefaultFontData[fontType];
-        cachedFont = new QFont( fontData.FontName, fontData.Size, fontData.Weight );
-        cachedFont->setStyleHint( fontData.StyleHint );
+        cachedFont = new QFont( fontData.FontName, fontData.Size );
 
         const KConfigGroup configGroup( KGlobal::config(), fontData.ConfigGroupKey );
         *cachedFont = configGroup.readEntry( fontData.ConfigKey, *cachedFont );
@@ -482,14 +405,9 @@ QFont KGlobalSettingsData::largeFont( const QString& text )
     // most preferred last
     static const char* const PreferredFontNames[] =
     {
-        "Arial",
-        "Sans Serif",
-        "Verdana",
-        "Tahoma",
-        "Lucida Sans",
-        "Lucidux Sans",
-        "Nimbus Sans",
-        "Gothic I"
+        "DejaVu Sans",
+        "FreeSans",
+        "Liberation Sans",
     };
     static const unsigned int PreferredFontNamesCount = sizeof(PreferredFontNames)/sizeof(const char*);
     for( unsigned int i=0; i<PreferredFontNamesCount; ++i )
@@ -507,7 +425,7 @@ QFont KGlobalSettingsData::largeFont( const QString& text )
     for(QStringList::ConstIterator it = fam.constBegin();
         it != fam.constEnd(); ++it)
     {
-        if (db.isSmoothlyScalable(*it) && !db.isFixedPitch(*it))
+        if (db.isScalable(*it) && !db.isFixedPitch(*it))
         {
             QFont font(*it);
             font.setPixelSize(75);
@@ -560,7 +478,6 @@ KGlobalSettings::KMouseSettings& KGlobalSettingsData::mouseSettings()
         mMouseSettings = new KGlobalSettings::KMouseSettings;
         KGlobalSettings::KMouseSettings& s = *mMouseSettings; // for convenience
 
-#ifndef Q_WS_WIN
         KConfigGroup g( KGlobal::config(), "Mouse" );
         QString setting = g.readEntry("MouseButtonMapping");
         if (setting == "RightHanded")
@@ -594,19 +511,7 @@ KGlobalSettings::KMouseSettings& KGlobalSettingsData::mouseSettings()
         // FIXME: Implement on other platforms
 #endif
         }
-#endif //Q_WS_WIN
     }
-#ifdef Q_WS_WIN
-    //not cached
-#ifndef _WIN32_WCE
-    mMouseSettings->handed = (GetSystemMetrics(SM_SWAPBUTTON) ?
-        KGlobalSettings::KMouseSettings::LeftHanded :
-        KGlobalSettings::KMouseSettings::RightHanded);
-#else
-// There is no mice under wince
-    mMouseSettings->handed =KGlobalSettings::KMouseSettings::RightHanded;
-#endif
-#endif
     return *mMouseSettings;
 }
 // KDE5: make this a const return?
@@ -617,89 +522,53 @@ KGlobalSettings::KMouseSettings & KGlobalSettings::mouseSettings()
 
 void KGlobalSettingsData::dropMouseSettingsCache()
 {
-#ifndef Q_WS_WIN
     delete mMouseSettings;
     mMouseSettings = 0;
-#endif
 }
 
 QString KGlobalSettings::desktopPath()
 {
-    QString path = QDesktopServices::storageLocation( QDesktopServices::DesktopLocation );
+    QString path = QStandardPaths::writableLocation( QStandardPaths::DesktopLocation );
     return path.isEmpty() ? QDir::homePath() : path;
 }
 
-// Autostart is not a XDG path, so we have our own code for it.
-QString KGlobalSettings::autostartPath()
-{
-    QString s_autostartPath;
-    KConfigGroup g( KGlobal::config(), "Paths" );
-    s_autostartPath = KGlobal::dirs()->localkdedir() + "Autostart/";
-    s_autostartPath = g.readPathEntry( "Autostart" , s_autostartPath );
-    s_autostartPath = QDir::cleanPath( s_autostartPath );
-    if ( !s_autostartPath.endsWith( '/' ) ) {
-        s_autostartPath.append( QLatin1Char( '/' ) );
-    }
-    return s_autostartPath;
-}
-
 QString KGlobalSettings::documentPath()
 {
-    QString path = QDesktopServices::storageLocation( QDesktopServices::DocumentsLocation );
+    QString path = QStandardPaths::writableLocation( QStandardPaths::DocumentsLocation );
     return path.isEmpty() ? QDir::homePath() : path;
 }
 
 QString KGlobalSettings::downloadPath()
 {
-    // Qt 4.4.1 does not have DOWNLOAD, so we based on old code for now
-    QString downloadPath = QDir::homePath();
-#ifndef Q_WS_WIN
-    const QString xdgUserDirs = KGlobal::dirs()->localxdgconfdir() + QLatin1String( "user-dirs.dirs" );
-    if( QFile::exists( xdgUserDirs ) ) {
-        KConfig xdgUserConf( xdgUserDirs, KConfig::SimpleConfig );
-        KConfigGroup g( &xdgUserConf, "" );
-        downloadPath  = g.readPathEntry( "XDG_DOWNLOAD_DIR", downloadPath ).remove(  '"' );
-        if ( downloadPath.isEmpty() ) {
-            downloadPath = QDir::homePath();
-        }
-    }
-#endif
-    downloadPath = QDir::cleanPath( downloadPath );
-    if ( !downloadPath.endsWith( '/' ) ) {
-        downloadPath.append( QLatin1Char(  '/' ) );
-    }
-    return downloadPath;
+    QString path = QStandardPaths::writableLocation( QStandardPaths::DownloadsLocation );
+    return path.isEmpty() ? QDir::homePath() + "/Downloads" : path;
 }
 
 QString KGlobalSettings::videosPath()
 {
-    QString path = QDesktopServices::storageLocation( QDesktopServices::MoviesLocation );
+    QString path = QStandardPaths::writableLocation( QStandardPaths::VideosLocation );
     return path.isEmpty() ? QDir::homePath() : path;
 }
 
 QString KGlobalSettings::picturesPath()
 {
-    QString path = QDesktopServices::storageLocation( QDesktopServices::PicturesLocation );
+    QString path = QStandardPaths::writableLocation( QStandardPaths::PicturesLocation );
     return path.isEmpty() ? QDir::homePath() :path;
 }
 
 QString KGlobalSettings::musicPath()
 {
-    QString path = QDesktopServices::storageLocation( QDesktopServices::MusicLocation );
+    QString path = QStandardPaths::writableLocation( QStandardPaths::MusicLocation );
     return path.isEmpty() ? QDir::homePath() : path;
 }
 
 bool KGlobalSettings::isMultiHead()
 {
-#ifdef Q_WS_WIN
-    return GetSystemMetrics(SM_CMONITORS) > 1;
-#else
     QByteArray multiHead = qgetenv("KDE_MULTIHEAD");
     if (!multiHead.isEmpty()) {
         return (multiHead.toLower() == "true");
     }
     return false;
-#endif
 }
 
 bool KGlobalSettings::wheelMouseZooms()
@@ -766,30 +635,21 @@ QRect KGlobalSettings::desktopGeometry(const QWidget* w)
 bool KGlobalSettings::showIconsOnPushButtons()
 {
     KConfigGroup g( KGlobal::config(), "KDE" );
-    return g.readEntry("ShowIconsOnPushButtons",
-                       KDE_DEFAULT_ICON_ON_PUSHBUTTON);
+    return g.readEntry("ShowIconsOnPushButtons", KDE_DEFAULT_ICON_ON_PUSHBUTTON);
 }
 
 bool KGlobalSettings::naturalSorting()
 {
     KConfigGroup g( KGlobal::config(), "KDE" );
-    return g.readEntry("NaturalSorting",
-                       KDE_DEFAULT_NATURAL_SORTING);
+    return g.readEntry("NaturalSorting", KDE_DEFAULT_NATURAL_SORTING);
 }
 
 KGlobalSettings::GraphicEffects KGlobalSettings::graphicEffectsLevel()
 {
-    // This variable stores whether _graphicEffects has the default value because it has not been
-    // loaded yet, or if it has been loaded from the user settings or defaults and contains a valid
-    // value.
-    static bool _graphicEffectsInitialized = false;
+    KConfigGroup g( KGlobal::config(), "KDE-Global GUI Settings" );
 
-    if (!_graphicEffectsInitialized) {
-        _graphicEffectsInitialized = true;
-        Private::reloadStyleSettings();
-    }
-
-    return _graphicEffects;
+    int graphicEffects = g.readEntry("GraphicEffectsLevel", int(KGlobalSettings::graphicEffectsLevelDefault()));
+    return GraphicEffects(graphicEffects);
 }
 
 KGlobalSettings::GraphicEffects KGlobalSettings::graphicEffectsLevelDefault()
@@ -797,7 +657,7 @@ KGlobalSettings::GraphicEffects KGlobalSettings::graphicEffectsLevelDefault()
     // For now, let always enable animations by default. The plan is to make
     // this code a bit smarter. (ereslibre)
 
-    return ComplexAnimationEffects;
+    return SimpleAnimationEffects;
 }
 
 bool KGlobalSettings::showFilePreview(const KUrl &url)
@@ -820,6 +680,12 @@ int KGlobalSettings::buttonLayout()
     return g.readEntry("ButtonLayout", KDE_DEFAULT_BUTTON_LAYOUT);
 }
 
+#ifdef Q_WS_X11
+QT_BEGIN_NAMESPACE
+extern void qt_x11_apply_settings_in_all_apps();
+QT_END_NAMESPACE
+#endif
+
 void KGlobalSettings::emitChange(ChangeType changeType, int arg)
 {
     QDBusMessage message = QDBusMessage::createSignal("/KGlobalSettings", "org.kde.KGlobalSettings", "notifyChange" );
@@ -831,7 +697,6 @@ void KGlobalSettings::emitChange(ChangeType changeType, int arg)
 #ifdef Q_WS_X11
     if (qApp && qApp->type() != QApplication::Tty) {
         //notify non-kde qt applications of the change
-        extern void qt_x11_apply_settings_in_all_apps();
         qt_x11_apply_settings_in_all_apps();
     }
 #endif
@@ -877,9 +742,6 @@ void KGlobalSettings::Private::_k_slotNotifyChange(int changeType, int arg)
             }
         } else {
             switch (category) {
-                case SETTINGS_STYLE:
-                    reloadStyleSettings();
-                    break;
                 case SETTINGS_MOUSE:
                     KGlobalSettingsData::self()->dropMouseSettingsCache();
                     break;
@@ -904,8 +766,7 @@ void KGlobalSettings::Private::_k_slotNotifyChange(int changeType, int arg)
         break;
 
     case BlockShortcuts:
-        // FIXME KAccel port
-        //KGlobalAccel::blockShortcuts(arg);
+        // NOTE: KGlobalAccel connects to this signal
         emit q->blockShortcuts(arg); // see kwin
         break;
 
@@ -923,51 +784,21 @@ QString kde_overrideStyle;
 
 void KGlobalSettings::Private::applyGUIStyle()
 {
-  //Platform plugin only loaded on X11 systems
-#ifdef Q_WS_X11
-    if (!kde_overrideStyle.isEmpty()) {
-        const QLatin1String currentStyleName(qApp->style()->metaObject()->className());
-        if (0 != kde_overrideStyle.compare(currentStyleName, Qt::CaseInsensitive) &&
-            0 != (QString(kde_overrideStyle + QLatin1String("Style"))).compare(currentStyleName, Qt::CaseInsensitive)) {
+    if (!kdeFullSession) {
+        return;
+    }
+
+    if (qApp->type() == KAPPLICATION_GUI_TYPE) {
+        if (kde_overrideStyle.isEmpty()) {
+            const KConfigGroup pConfig(KGlobal::config(), "General");
+            kde_overrideStyle = pConfig.readEntry("widgetStyle", KStyle::defaultStyle());
+        }
+        if (!kde_overrideStyle.isEmpty()) {
             qApp->setStyle(kde_overrideStyle);
         }
-    } else {
-        emit q->kdisplayStyleChanged();
     }
-#else
-    const QLatin1String currentStyleName(qApp->style()->metaObject()->className());
 
-    if (kde_overrideStyle.isEmpty()) {
-        const QString &defaultStyle = KStyle::defaultStyle();
-        const KConfigGroup pConfig(KGlobal::config(), "General");
-        const QString &styleStr = pConfig.readEntry("widgetStyle", defaultStyle);
-
-        if (styleStr.isEmpty() ||
-                // check whether we already use the correct style to return then
-                // (workaround for Qt misbehavior to avoid double style initialization)
-                0 == (QString(styleStr + QLatin1String("Style"))).compare(currentStyleName, Qt::CaseInsensitive) ||
-                0 == styleStr.compare(currentStyleName, Qt::CaseInsensitive)) {
-            return;
-        }
-
-        QStyle* sp = QStyleFactory::create( styleStr );
-        if (sp && currentStyleName == sp->metaObject()->className()) {
-            delete sp;
-            return;
-        }
-
-        // If there is no default style available, try falling back any available style
-        if ( !sp && styleStr != defaultStyle)
-            sp = QStyleFactory::create( defaultStyle );
-        if ( !sp )
-            sp = QStyleFactory::create( QStyleFactory::keys().first() );
-        qApp->setStyle(sp);
-    } else if (0 != kde_overrideStyle.compare(currentStyleName, Qt::CaseInsensitive) &&
-            0 != (QString(kde_overrideStyle + QLatin1String("Style"))).compare(currentStyleName, Qt::CaseInsensitive)) {
-        qApp->setStyle(kde_overrideStyle);
-    }
     emit q->kdisplayStyleChanged();
-#endif //Q_WS_X11
 }
 
 QPalette KGlobalSettings::createApplicationPalette(const KSharedConfigPtr &config)
@@ -1039,46 +870,48 @@ QPalette KGlobalSettings::Private::createNewApplicationPalette(const KSharedConf
 
 void KGlobalSettings::Private::kdisplaySetPalette()
 {
-#if !defined(Q_WS_MAEMO_5) && !defined(Q_OS_WINCE) && !defined(MEEGO_EDITION_HARMATTAN)
     if (!kdeFullSession) {
         return;
     }
 
-    if (qApp->type() == QApplication::GuiClient) {
+    if (qApp->type() == KAPPLICATION_GUI_TYPE) {
         QApplication::setPalette( q->createApplicationPalette() );
     }
     emit q->kdisplayPaletteChanged();
     emit q->appearanceChanged();
-#endif    
 }
 
-
 void KGlobalSettings::Private::kdisplaySetFont()
 {
-#if !defined(Q_WS_MAEMO_5) && !defined(Q_OS_WINCE) && !defined(MEEGO_EDITION_HARMATTAN)
     if (!kdeFullSession) {
         return;
     }
 
-    if (qApp->type() == QApplication::GuiClient) {
+    if (qApp->type() == KAPPLICATION_GUI_TYPE) {
         KGlobalSettingsData* data = KGlobalSettingsData::self();
 
         QApplication::setFont( data->font(KGlobalSettingsData::GeneralFont) );
         const QFont menuFont = data->font( KGlobalSettingsData::MenuFont );
         QApplication::setFont( menuFont, "QMenuBar" );
         QApplication::setFont( menuFont, "QMenu" );
-        QApplication::setFont( menuFont, "KPopupTitle" );
         QApplication::setFont( data->font(KGlobalSettingsData::ToolbarFont), "QToolBar" );
     }
     emit q->kdisplayFontChanged();
     emit q->appearanceChanged();
-#endif
 }
 
+void KGlobalSettings::Private::kdisplaySetCursor()
+{
+    if (!kdeFullSession) {
+        return;
+    }
+
+    applyCursorTheme();
+}
 
 void KGlobalSettings::Private::kdisplaySetStyle()
 {
-    if (qApp->type() == QApplication::GuiClient) {
+    if (qApp->type() == KAPPLICATION_GUI_TYPE) {
         applyGUIStyle();
 
         // Reread palette from config file.
@@ -1086,36 +919,17 @@ void KGlobalSettings::Private::kdisplaySetStyle()
     }
 }
 
-
-void KGlobalSettings::Private::reloadStyleSettings()
-{
-    KConfigGroup g( KGlobal::config(), "KDE-Global GUI Settings" );
-
-    // Asking for hasKey we do not ask for graphicEffectsLevelDefault() that can
-    // contain some very slow code. If we can save that time, do it. (ereslibre)
-
-    if (g.hasKey("GraphicEffectsLevel")) {
-        _graphicEffects = ((GraphicEffects) g.readEntry("GraphicEffectsLevel", QVariant((int) NoEffects)).toInt());
-
-        return;
-    }
-
-    _graphicEffects = KGlobalSettings::graphicEffectsLevelDefault();
-}
-
-
 void KGlobalSettings::Private::applyCursorTheme()
 {
 #if defined(Q_WS_X11) && defined(HAVE_XCURSOR)
     KConfig config("kcminputrc");
     KConfigGroup g(&config, "Mouse");
 
-    QString theme = g.readEntry("cursorTheme", QString());
-    int size      = g.readEntry("cursorSize", -1);
+    QByteArray theme = g.readEntry("cursorTheme", QByteArray("Oxygen_White"));
+    int size = g.readEntry("cursorSize", -1);
 
     // Default cursor size is 16 points
-    if (size == -1)
-    {
+    if (size == -1) {
         QApplication *app = static_cast<QApplication*>(QApplication::instance());
         size = app->desktop()->screen(0)->logicalDpiY() * 16 / 72;
     }
@@ -1124,8 +938,7 @@ void KGlobalSettings::Private::applyCursorTheme()
     // with a NULL theme would cause Xcursor to use "default", but
     // in 7.2 and later it will cause it to revert to the theme that
     // was configured when the application was started.
-    XcursorSetTheme(QX11Info::display(), theme.isNull() ?
-                    "default" : QFile::encodeName(theme));
+    XcursorSetTheme(QX11Info::display(), theme.constData());
     XcursorSetDefaultSize(QX11Info::display(), size);
 
     emit q->cursorChanged();
@@ -1136,16 +949,12 @@ void KGlobalSettings::Private::applyCursorTheme()
 void KGlobalSettings::Private::propagateQtSettings()
 {
     KConfigGroup cg( KGlobal::config(), "KDE" );
-#ifndef Q_WS_WIN
     int num = cg.readEntry("CursorBlinkRate", QApplication::cursorFlashTime());
     if ((num != 0) && (num < 200))
         num = 200;
     if (num > 2000)
         num = 2000;
     QApplication::setCursorFlashTime(num);
-#else
-    int num;
-#endif
     num = cg.readEntry("DoubleClickInterval", QApplication::doubleClickInterval());
     QApplication::setDoubleClickInterval(num);
     num = cg.readEntry("StartDragTime", QApplication::startDragTime());
@@ -1161,4 +970,4 @@ void KGlobalSettings::Private::propagateQtSettings()
     emit q->settingsChanged(SETTINGS_QT);
 }
 
-#include "kglobalsettings.moc"
+#include "moc_kglobalsettings.cpp"
