@@ -15,14 +15,19 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef _KGLOBALSETTINGS_H
-#define _KGLOBALSETTINGS_H
+#ifndef KGLOBALSETTINGS_H
+#define KGLOBALSETTINGS_H
 
 #include <kdeui_export.h>
 #include <ksharedconfig.h>
 #include <QtCore/QObject>
-#include <QtCore/QString>
+#include <QtCore/QPoint>
+#include <QtCore/QRect>
 #include <QtGui/QPalette>
+#include <QtGui/QColor>
+#include <QtGui/QFont>
+#include <QtGui/QWidget>
+
 
 #define KDE_DEFAULT_SINGLECLICK true
 #define KDE_DEFAULT_SMOOTHSCROLL true
@@ -31,25 +36,22 @@
 #define KDE_DEFAULT_CHANGECURSOR true
 #define KDE_DEFAULT_LARGE_CURSOR false
 #define KDE_DEFAULT_WHEEL_ZOOM false
-#ifdef Q_WS_MAEMO_5
-#define KDE_DEFAULT_ICON_ON_PUSHBUTTON false
-#else
 #define KDE_DEFAULT_ICON_ON_PUSHBUTTON true
-#endif
 #define KDE_DEFAULT_OPAQUE_RESIZE true
 #define KDE_DEFAULT_BUTTON_LAYOUT 0
 #define KDE_DEFAULT_SHADE_SORT_COLUMN true
 #define KDE_DEFAULT_ALLOW_DEFAULT_BACKGROUND_IMAGES true
 #define KDE_DEFAULT_NATURAL_SORTING true
+#define KDE_DEFAULT_FONT "DejaVu Sans"
+#define KDE_DEFAULT_FIXED_FONT "DejaVu Sans Mono"
+
+#define KDE_HOME_URL "https://osdn.net/projects/kde/"
+#define KDE_BUG_REPORT_URL "https://osdn.net/projects/kde/ticket/"
+#define KDE_BUG_REPORT_EMAIL "xakepa10@gmail.com"
+#define KDE_HELP_URL "https://osdn.net/projects/kde/wiki/"
 
 class KUrl;
 
-class QColor;
-class QFont;
-class QPoint;
-class QRect;
-class QWidget;
-
 /**
  * Access the KDE global configuration.
  *
@@ -152,17 +154,6 @@ public:
      */
     static int autoSelectDelay();
 
-    /**
-     * Returns the KDE setting for the shortcut key to open
-     * context menus.
-     *
-     * @return the key that pops up context menus.
-     * @deprecated Simply reimplement QWidget::contextMenuEvent() instead.
-     */
-#ifndef KDE_NO_DEPRECATED
-    static KDE_DEPRECATED int contextMenuKey ();
-#endif
-
     /**
      * Returns the KDE setting for context menus.
      *
@@ -222,7 +213,6 @@ public:
 
     /**
      * This returns the current mouse settings.
-     * On Windows, settings are retrieved from the system.
      * @return the current mouse settings
      */
     static KMouseSettings & mouseSettings();
@@ -233,12 +223,6 @@ public:
      */
     static QString desktopPath();
 
-    /**
-     * The path to the autostart directory of the current user.
-     * @return the path of the autostart directory
-     */
-    static QString autostartPath();
-
     /**
      * The path where documents are stored of the current user.
      * @return the path of the document directory
@@ -377,7 +361,6 @@ public:
      * Returns if the user specified multihead. In case the display
      * has multiple screens, the return value of this function specifies
      * if the user wants KDE to run on all of them or just on the primary
-     * On Windows, settings are retrieved from the system.
      * @return true if the user chose multi head
      */
     static bool isMultiHead();
@@ -463,12 +446,10 @@ public:
 
     enum GraphicEffect {
         NoEffects               = 0x0000, ///< GUI with no effects at all.
-        GradientEffects         = 0x0001, ///< GUI with only gradients enabled.
-        SimpleAnimationEffects  = 0x0002, ///< GUI with simple animations enabled.
-        ComplexAnimationEffects = 0x0006  ///< GUI with complex animations enabled.
-                                          ///< Note that ComplexAnimationsEffects implies SimpleAnimationEffects.
+        SimpleAnimationEffects  = 0x0001, ///< GUI with simple animations enabled.
+        ComplexAnimationEffects = 0x0002  ///< GUI with complex animations enabled.
+                                          ///< Note that ComplexAnimationsEffects does not imply SimpleAnimationEffects.
     };
-
     Q_DECLARE_FLAGS(GraphicEffects, GraphicEffect)
 
     /**
