@@ -18,17 +18,15 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "config.h"
 #include "kstatusnotifieritem.h"
 #include "kstatusnotifieritemprivate_p.h"
 #include "kstatusnotifieritemdbus_p.h"
 
-#include <QDBusConnection>
-#include <QPixmap>
-#include <QImage>
 #include <QApplication>
-#include <QMovie>
 #include <QPainter>
-
+#include <QMetaObject>
+#include <QTimer>
 
 #include <kdebug.h>
 #include <ksystemtrayicon.h>
@@ -45,12 +43,14 @@
 
 #include <netinet/in.h>
 
-#include <dbusmenuexporter.h>
-
 #include "statusnotifieritemadaptor.h"
 
 static const QString s_statusNotifierWatcherServiceName("org.kde.StatusNotifierWatcher");
 
+#ifdef HAVE_DBUSMENUQT
+
+#include <dbusmenuexporter.h>
+
 /**
  * Specialization to provide access to KDE icon names
  */
@@ -65,38 +65,13 @@ protected:
     virtual QString iconNameForAction(QAction *action)
     {
         KIcon icon(action->icon());
-#if QT_VERSION >= 0x040701
         // QIcon::name() is in the 4.7 git branch, but it is not in 4.7 TP.
         // If you get a build error here, you need to update your pre-release
         // of Qt 4.7.
         return icon.isNull() ? QString() : icon.name();
-#else
-        // Qt 4.6: If the icon was created by us, via our engine, serializing it
-        // will let us get to the name.
-        if (!icon.isNull()) {
-            QBuffer encBuf;
-            encBuf.open(QIODevice::WriteOnly);
-            QDataStream encode(&encBuf);
-            encode.setVersion(QDataStream::Qt_4_6);
-            encode << icon;
-            encBuf.close();
-
-            if (!encBuf.data().isEmpty()) {
-                QDataStream decode(encBuf.data());
-                QString key;
-                decode >> key;
-                if (key == QLatin1String("KIconEngine")) {
-                    QString name;
-                    decode >> name;
-                    return name;
-                }
-            }
-        }
-        
-        return QString();
-#endif
     }
 };
+#endif
 
 KStatusNotifierItem::KStatusNotifierItem(QObject *parent)
       : QObject(parent),
@@ -190,7 +165,7 @@ QString KStatusNotifierItem::iconName() const
 
 void KStatusNotifierItem::setIconByPixmap(const QIcon &icon)
 {
-    if (d->iconName.isEmpty() && d->icon.cacheKey() == icon.cacheKey()) {
+    if (d->icon.cacheKey() == icon.cacheKey()) {
         return;
     }
 
@@ -261,7 +236,7 @@ QIcon KStatusNotifierItem::overlayIconPixmap() const
     return d->overlayIcon;
 }
 
-//Icons and movie for requesting attention state
+//Icons for requesting attention state
 
 void KStatusNotifierItem::setAttentionIconByName(const QString &name)
 {
@@ -296,30 +271,6 @@ QIcon KStatusNotifierItem::attentionIconPixmap() const
     return d->attentionIcon;
 }
 
-void KStatusNotifierItem::setAttentionMovieByName(const QString &name)
-{
-    if (d->movieName == name) {
-        return;
-    }
-
-    d->movieName = name;
-
-    delete d->movie;
-    d->movie = 0;
-
-    emit d->statusNotifierItemDBus->NewAttentionIcon();
-
-    if (d->systemTrayIcon) {
-        d->movie = new QMovie(d->movieName);
-        d->systemTrayIcon->setMovie(d->movie);
-    }
-}
-
-QString KStatusNotifierItem::attentionMovieName() const
-{
-    return d->movieName;
-}
-
 //ToolTip
 
 void KStatusNotifierItem::setToolTip(const QString &iconName, const QString &title, const QString &subTitle)
@@ -444,17 +395,23 @@ void KStatusNotifierItem::setContextMenu(KMenu *menu)
     if (d->systemTrayIcon) {
         d->systemTrayIcon->setContextMenu(menu);
     } else if (d->menu != menu) {
+#ifdef HAVE_DBUSMENUQT
         if (getenv("KSNI_NO_DBUSMENU")) {
+#else
+            d->setLegacySystemTrayEnabled(true);
+#endif
             // This is a hack to make it possible to disable DBusMenu in an
             // application. The string "/NO_DBUSMENU" must be the same as in
             // DBusSystemTrayWidget::findDBusMenuInterface() in the Plasma
             // systemtray applet.
             d->menuObjectPath = "/NO_DBUSMENU";
             menu->installEventFilter(this);
+#ifdef HAVE_DBUSMENUQT
         } else {
             d->menuObjectPath = "/MenuBar";
             new KDBusMenuExporter(d->menuObjectPath, menu, d->statusNotifierItemDBus->dbusConnection());
         }
+#endif
 
         connect(menu, SIGNAL(aboutToShow()), this, SLOT(contextMenuAboutToShow()));
     }
@@ -594,21 +551,7 @@ void KStatusNotifierItem::activate(const QPoint &pos)
 
 bool KStatusNotifierItemPrivate::checkVisibility(QPoint pos, bool perform)
 {
-#ifdef Q_WS_WIN
-#if 0
-    // the problem is that we lose focus when the systray icon is activated
-    // and we don't know the former active window
-    // therefore we watch for activation event and use our stopwatch :)
-    if(GetTickCount() - dwTickCount < 300) {
-        // we were active in the last 300ms -> hide it
-        minimizeRestore(false);
-        emit activateRequested(false, pos);
-    } else {
-        minimizeRestore(true);
-        emit activateRequested(true, pos);
-    }
-#endif
-#elif defined(Q_WS_X11)
+#if   defined(Q_WS_X11)
     KWindowInfo info1 = KWindowSystem::windowInfo(associatedWidget->winId(), NET::XAWMState | NET::WMState | NET::WMDesktop);
     // mapped = visible (but possibly obscured)
     bool mapped = (info1.mappingState() == NET::Visible) && !info1.isMinimized();
@@ -651,10 +594,10 @@ bool KStatusNotifierItemPrivate::checkVisibility(QPoint pos, bool perform)
 
             NET::WindowType type = info2.windowType(NET::NormalMask | NET::DesktopMask
                 | NET::DockMask | NET::ToolbarMask | NET::MenuMask | NET::DialogMask
-                | NET::OverrideMask | NET::TopMenuMask | NET::UtilityMask | NET::SplashMask);
+                | NET::UtilityMask | NET::SplashMask);
 
-            if (type == NET::Dock || type == NET::TopMenu) {
-                continue; // obscured by dock or topmenu -> ignore
+            if (type == NET::Dock) {
+                continue; // obscured by dock -> ignore
             }
 
             if (perform) {
@@ -704,13 +647,12 @@ bool KStatusNotifierItem::eventFilter(QObject *watched, QEvent *event)
 
 //KStatusNotifierItemPrivate
 
-const int KStatusNotifierItemPrivate::s_protocolVersion = 0;
+static const int s_protocolVersion = 0;
 
 KStatusNotifierItemPrivate::KStatusNotifierItemPrivate(KStatusNotifierItem *item)
     : q(item),
       category(KStatusNotifierItem::ApplicationStatus),
       status(KStatusNotifierItem::Passive),
-      movie(0),
       menu(0),
       titleAction(0),
       statusNotifierWatcher(0),
@@ -876,12 +818,7 @@ void KStatusNotifierItemPrivate::setLegacySystemTrayEnabled(bool enabled)
 void KStatusNotifierItemPrivate::syncLegacySystemTrayIcon()
 {
     if (status == KStatusNotifierItem::NeedsAttention) {
-        if (!movieName.isNull()) {
-            if (!movie) {
-                movie = new QMovie(movieName);
-            }
-            systemTrayIcon->setMovie(movie);
-        } else if (!attentionIconName.isNull()) {
+        if (!attentionIconName.isNull()) {
             systemTrayIcon->setIcon(KIcon(attentionIconName));
         } else {
             systemTrayIcon->setIcon(attentionIcon);
@@ -993,20 +930,20 @@ KDbusImageStruct KStatusNotifierItemPrivate::imageToStruct(const QImage &image)
     icon.width = image.size().width();
     icon.height = image.size().height();
     if (image.format() == QImage::Format_ARGB32) {
-        icon.data = QByteArray((char*)image.bits(), image.numBytes());
+        icon.data = QByteArray((const char*)image.constBits(), image.byteCount());
     } else {
         QImage image32 = image.convertToFormat(QImage::Format_ARGB32);
-        icon.data = QByteArray((char*)image32.bits(), image32.numBytes());
+        icon.data = QByteArray((const char*)image32.constBits(), image32.byteCount());
     }
 
     //swap to network byte order if we are little endian
-    if (QSysInfo::ByteOrder == QSysInfo::LittleEndian) {
-        quint32 *uintBuf = (quint32 *) icon.data.data();
-        for (uint i = 0; i < icon.data.size()/sizeof(quint32); ++i) {
-            *uintBuf = htonl(*uintBuf);
-            ++uintBuf;
-        }
+#if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
+    quint32 *uintBuf = (quint32 *) icon.data.data();
+    for (uint i = 0; i < icon.data.size()/sizeof(quint32); ++i) {
+        *uintBuf = htonl(*uintBuf);
+        ++uintBuf;
     }
+#endif
 
     return icon;
 }
@@ -1036,5 +973,5 @@ KDbusImageVector KStatusNotifierItemPrivate::iconToVector(const QIcon &icon)
     return iconVector;
 }
 
-#include "kstatusnotifieritem.moc"
-#include "kstatusnotifieritemprivate_p.moc"
+#include "moc_kstatusnotifieritem.cpp"
+#include "moc_kstatusnotifieritemprivate_p.cpp"
