@@ -22,7 +22,6 @@
 #define KSTATUSNOTIFIERITEM_H
 
 #include <QtCore/QObject>
-#include <QtCore/QString>
 #include <QtDBus/QDBusArgument>
 #include <QtCore/QPoint>
 
@@ -30,9 +29,6 @@
 
 class KActionCollection;
 class KMenu;
-class QMovie;
-
-
 class KStatusNotifierItemPrivate;
 
 /**
@@ -119,7 +115,6 @@ public:
         SystemServices = 3,
         /// This application shows hardware status or a means to control it
         Hardware = 4,
-        Reserved = 129
     };
 
     /**
@@ -278,19 +273,6 @@ public:
      */
     QIcon attentionIconPixmap() const;
 
-    /**
-     * Sets a movie as the requesting attention icon.
-     * This overrides anything set in setAttentionIcon()
-     */
-    void setAttentionMovieByName(const QString &name);
-
-    /**
-     * @return the name of the movie to be displayed when the application is
-     * requesting the user attention
-     */
-    QString attentionMovieName() const;
-
-
     //ToolTip handling
     /**
      * Sets a new toolTip or this icon, a toolTip is composed of an icon,
