@@ -27,8 +27,7 @@
 #include <QtGui/QLabel>
 #include <QtGui/QLineEdit>
 #include <QtGui/QMenuBar>
-#include <QtGui/qmenudata.h>
-#include <QtCore/QMetaClassInfo>
+#include <QtCore/qmetaobject.h>
 #include <QtCore/QObject>
 #include <QList>
 #include <QtGui/QPushButton>
@@ -335,7 +334,6 @@ void KAcceleratorManagerPrivate::manageWidget(QWidget *w, Item *item)
   }
 
   if (qobject_cast<QComboBox*>(w) || qobject_cast<QLineEdit*>(w) ||
-      w->inherits("Q3TextEdit") ||
       qobject_cast<QTextEdit*>(w) ||
       qobject_cast<QAbstractSpinBox*>(w) || w->inherits( "KMultiTabBar" ) )
       return;
@@ -656,7 +654,7 @@ int KAccelString::stripAccelerator(QString &text)
     p = text.indexOf('&', p)+1;
 
     if (p <= 0 || p >= (int)text.length())
-      return -1;
+      break;
 
     if (text[p] != '&')
     {
@@ -917,4 +915,4 @@ void KAcceleratorManager::setNoAccel( QWidget *widget )
     KAcceleratorManagerPrivate::ignored_widgets[widget] = 1;
 }
 
-#include "kacceleratormanager_private.moc"
+#include "moc_kacceleratormanager_private.cpp"
