@@ -28,7 +28,7 @@
 #include <QtDBus/QDBusInterface>
 #include <QtDBus/QDBusMetaType>
 #ifdef Q_WS_X11
-#include <QtGui/QX11Info>
+#include <QtGui/qx11info_x11.h>
 #include <netwm_def.h>
 #endif
 
@@ -41,7 +41,7 @@
 #include "kmessagebox.h"
 #include "kshortcut.h"
 
-org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QString &componentUnique, bool remember = false)
+org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QString &componentUnique, bool remember)
 {
     // Check if we already have this component
     if (components.contains(componentUnique)) {
@@ -89,8 +89,8 @@ org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QStri
     if (remember)
         {
         // Connect to the signals we are interested in.
-        q->connect(component, SIGNAL(globalShortcutPressed(const QString &, const QString &, qlonglong)),
-                SLOT(_k_invokeAction(const QString &, const QString &, qlonglong)));
+        q->connect(component, SIGNAL(globalShortcutPressed(QString,QString,qlonglong)),
+                SLOT(_k_invokeAction(QString,QString,qlonglong)));
 
         components[componentUnique] = component;
         }
@@ -101,23 +101,15 @@ org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QStri
 
 
 KGlobalAccelPrivate::KGlobalAccelPrivate(KGlobalAccel *q)
-     :  isUsingForeignComponentName(false),
-        enabled(true),
-        iface("org.kde.kglobalaccel", "/kglobalaccel", QDBusConnection::sessionBus()),
+     :  iface("org.kde.kglobalaccel", "/kglobalaccel", QDBusConnection::sessionBus()),
         q(q)
 {
-    // Make sure kded is running. The iface declaration above somehow
-    // works anyway.
-    QDBusConnectionInterface* bus = QDBusConnection::sessionBus().interface();
-    if (!bus->isServiceRegistered("org.kde.kglobalaccel")) {
-        QString error;
-        int ret = KToolInvocation::startServiceByDesktopPath(
-                "kglobalaccel.desktop",
-                QStringList(),
-                &error);
-
-        if (ret > 0) {
-            kError() << "Couldn't start kglobalaccel from kglobalaccel.desktop: " << error << endl;
+    // Make sure kglobalaccel is running. The iface declaration above somehow works anyway.
+    QDBusConnectionInterface* sessionIface = QDBusConnection::sessionBus().interface();
+    if (!sessionIface->isServiceRegistered("org.kde.kglobalaccel")) {
+        QDBusReply<void> sessionReply = sessionIface->startService("org.kde.kglobalaccel");
+        if (!sessionReply.isValid()) {
+            kError() << "Couldn't start kglobalaccel service" << sessionReply.error();
         }
     }
     QDBusServiceWatcher *watcher = new QDBusServiceWatcher(iface.service(),
@@ -135,7 +127,7 @@ void KGlobalAccelPrivate::readComponentData(const KComponentData &componentData)
 
     mainComponent = componentData;
     if (componentData.aboutData()->programName().isEmpty()) {
-        kDebug(123) << componentData.componentName() << " has empty programName()";
+        kDebug(125) << componentData.componentName() << " has empty programName()";
     }
 }
 
@@ -148,8 +140,8 @@ KGlobalAccel::KGlobalAccel()
     qDBusRegisterMetaType<KGlobalShortcutInfo>();
     qDBusRegisterMetaType<QList<KGlobalShortcutInfo> >();
 
-    connect(&d->iface, SIGNAL(yourShortcutGotChanged(const QStringList &, const QList<int> &)),
-            SLOT(_k_shortcutGotChanged(const QStringList &, const QList<int> &)));
+    connect(&d->iface, SIGNAL(yourShortcutGotChanged(QStringList,QList<int>)),
+            SLOT(_k_shortcutGotChanged(QStringList,QList<int>)));
 
     if (KGlobal::hasMainComponent()) {
         d->readComponentData( KGlobal::mainComponent() );
@@ -195,10 +187,6 @@ bool KGlobalAccel::isComponentActive(const QString &componentUnique)
 }
 
 
-bool KGlobalAccel::isEnabled() const
-{
-    return d->enabled;
-}
 
 
 org::kde::kglobalaccel::Component *KGlobalAccel::getComponent(const QString &componentUnique)
@@ -207,17 +195,8 @@ org::kde::kglobalaccel::Component *KGlobalAccel::getComponent(const QString &com
 }
 
 
-void KGlobalAccel::setEnabled(bool enabled)
-{
-    d->enabled = enabled;
-}
 
 
-void KGlobalAccel::overrideMainComponentData(const KComponentData &kcd)
-{
-    d->readComponentData(kcd);
-    d->isUsingForeignComponentName = true;
-}
 
 
 KGlobalAccel *KGlobalAccel::self()
@@ -234,14 +213,10 @@ void KGlobalAccelPrivate::doRegister(KAction *action)
     }
 
     const bool isRegistered = actions.contains(action);
-    if (isRegistered)
+    if (isRegistered) {
         return;
-
-    // Under configuration mode - deprecated - we ignore the component given
-    // from the action and use our own.
-    if (isUsingForeignComponentName) {
-        action->d->componentData = mainComponent;
     }
+
     QStringList actionId = makeActionId(action);
 
     nameToAction.insertMulti(actionId.at(KGlobalAccel::ActionUnique), action);
@@ -269,15 +244,17 @@ void KGlobalAccelPrivate::remove(KAction *action, Removal removal)
     if (removal == UnRegister) {
         // Complete removal of the shortcut is requested
         // (forgetGlobalShortcut)
-        iface.unRegister(actionId);
+        iface.unregister(actionId.at(KGlobalAccel::ComponentUnique), actionId.at(KGlobalAccel::ActionUnique));
     } else {
         // If the action is a configurationAction wen only remove it from our
         // internal registry. That happened above.
         if (!action->property("isConfigurationAction").toBool()) {
             // If it's a session shortcut unregister it.
-            action->objectName().startsWith(QLatin1String("_k_session:"))
-                ? iface.unRegister(actionId)
-                : iface.setInactive(actionId);
+            if (action->objectName().startsWith(QLatin1String("_k_session:"))) {
+                iface.unregister(actionId.at(KGlobalAccel::ComponentUnique), actionId.at(KGlobalAccel::ActionUnique));
+            } else {
+                iface.setInactive(actionId);
+            }
         }
     }
 }
@@ -301,8 +278,7 @@ void KGlobalAccelPrivate::updateGlobalShortcut(KAction *action, uint flags)
     }
 
     if (flags & KAction::ActiveShortcut) {
-        bool isConfigurationAction = isUsingForeignComponentName
-            || action->property("isConfigurationAction").toBool();
+        bool isConfigurationAction = action->property("isConfigurationAction").toBool();
         uint activeSetterFlags = setterFlags;
 
         // setPresent tells kglobalaccel that the shortcut is active
@@ -356,7 +332,8 @@ QStringList KGlobalAccelPrivate::makeActionId(const KAction *action)
     Q_ASSERT(!action->objectName().isEmpty());
     ret.append(action->objectName());                   // Action Unique Name
     ret.append(componentFriendlyForAction(action));     // Component Friendly name
-    ret.append(action->text());                         // Action Friendly Name
+    const QString actionText = KGlobal::locale()->removeAcceleratorMarker(action->text());
+    ret.append(actionText);                             // Action Friendly Name
     return ret;
 }
 
@@ -402,12 +379,6 @@ void KGlobalAccelPrivate::_k_invokeAction(
         const QString &actionUnique,
         qlonglong timestamp)
 {
-    // If overrideMainComponentData() is active the app can only have
-    // configuration actions.
-    if (isUsingForeignComponentName ) {
-        return;
-    }
-
     KAction *action = 0;
     QList<KAction *> candidates = nameToAction.values(actionUnique);
     foreach (KAction *const a, candidates) {
@@ -457,15 +428,13 @@ void KGlobalAccelPrivate::_k_serviceOwnerChanged(const QString &name, const QStr
     Q_UNUSED(oldOwner);
     if (name == QLatin1String("org.kde.kglobalaccel") && !newOwner.isEmpty()) {
         // kglobalaccel was restarted
-        kDebug(123) << "detected kglobalaccel restarting, re-registering all shortcut keys";
+        kDebug(125) << "detected kglobalaccel restarting, re-registering all shortcut keys";
         reRegisterAll();
     }
 }
 
 void KGlobalAccelPrivate::reRegisterAll()
 {
-    //### Special case for isUsingForeignComponentName?
-
     //We clear all our data, assume that all data on the other side is clear too,
     //and register each action as if it just was allowed to have global shortcuts.
     //If the kded side still has the data it doesn't matter because of the
@@ -482,26 +451,6 @@ void KGlobalAccelPrivate::reRegisterAll()
     }
 }
 
-
-QList<QStringList> KGlobalAccel::allMainComponents()
-{
-    return d->iface.allMainComponents();
-}
-
-
-QList<QStringList> KGlobalAccel::allActionsForComponent(const QStringList &actionId)
-{
-    return d->iface.allActionsForComponent(actionId);
-}
-
-
-//static
-QStringList KGlobalAccel::findActionNameSystemwide(const QKeySequence &seq)
-{
-    return self()->d->iface.action(seq[0]);
-}
-
-
 QList<KGlobalShortcutInfo> KGlobalAccel::getGlobalShortcutsByKey(const QKeySequence &seq)
 {
     return self()->d->iface.getGlobalShortcutsByKey(seq[0]);
@@ -513,26 +462,6 @@ bool KGlobalAccel::isGlobalShortcutAvailable(const QKeySequence &seq, const QStr
         return self()->d->iface.isGlobalShortcutAvailable(seq[0], comp);
 }
 
-
-//static
-bool KGlobalAccel::promptStealShortcutSystemwide(QWidget *parent, const QStringList &actionIdentifier,
-                                                 const QKeySequence &seq)
-{
-    if (actionIdentifier.size() < 4) {
-        return false;
-    }
-    QString title = i18n("Conflict with Global Shortcut");
-    QString message = i18n("The '%1' key combination has already been allocated "
-                           "to the global action \"%2\" in %3.\n"
-                           "Do you want to reassign it from that action to the current one?",
-                           seq.toString(), actionIdentifier.at(KGlobalAccel::ActionFriendly),
-                           actionIdentifier.at(KGlobalAccel::ComponentFriendly));
-
-    return KMessageBox::warningContinueCancel(parent, message, title, KGuiItem(i18n("Reassign")))
-           == KMessageBox::Continue;
-}
-
-
 //static
 bool KGlobalAccel::promptStealShortcutSystemwide(
         QWidget *parent,
@@ -588,5 +517,5 @@ void KGlobalAccel::stealShortcutSystemwide(const QKeySequence &seq)
     self()->d->iface.setForeignShortcut(actionId, sc);
 }
 
-#include "kglobalaccel.moc"
+#include "moc_kglobalaccel.cpp"
 
