@@ -19,7 +19,7 @@
  * 02110-1301  USA
  */
 #include "backgroundtest.h"
-#include "backgroundtest.moc"
+#include "moc_backgroundtest.cpp"
 
 #include "speller.h"
 using namespace Sonnet;
@@ -147,7 +147,7 @@ BackgroundTest::BackgroundTest()
 void BackgroundTest::slotDone()
 {
     kDebug()<<"Text of length "<<m_len<<" checked in "
-             << m_timer.elapsed() << " msec."<<endl;
+             << m_timer.elapsed() << " msec.";
     QApplication::exit();
 }
 
