@@ -1,9 +1,9 @@
-#ifndef _KCOLORCOMBOTEST_H
-#define _KCOLORCOMBOTEST_H
+#ifndef KCOLORCOMBOTEST_H
+#define KCOLORCOMBOTEST_H
 
 #include <QtGui/QWidget>
 
-class QPushButton;
+#include <QPushButton>
 class KColorCombo;
 
 class KColorComboTest : public QWidget
