@@ -22,7 +22,7 @@
 #include <kstandarddirs.h>
 #include <qtest_kde.h>
 #include "kconfigcompiler_test.h"
-#include "kconfigcompiler_test.moc"
+#include "moc_kconfigcompiler_test.cpp"
 
 QTEST_KDEMAIN_CORE(KConfigCompiler_Test)
 
@@ -44,6 +44,7 @@ static CompilerTestSet testCases =
 	"test10.h", "test10.cpp",
 	"test11.h", "test11.cpp",
 	"test11a.h", "test11a.cpp",
+	"test12.h", "test12.cpp",
 	"test_dpointer.cpp", "test_dpointer.h",
 	"test_signal.cpp", "test_signal.h",
 	NULL
@@ -63,6 +64,7 @@ static CompilerTestSet testCasesToRun =
     "test9",
     "test10",
     "test11",
+    "test12",
     "test_dpointer",
     "test_signal",
     0
