@@ -18,12 +18,14 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include <QtTest/QtTestGui>
+
 #include <kdebug.h>
 #include <QCheckBox>
 #include <qtest_kde.h>
 #include <kdialog.h>
 #include <kpushbutton.h>
-#include <QWeakPointer>
+#include <QtCore/qsharedpointer.h>
 
 Q_DECLARE_METATYPE(KDialog::ButtonCode)
 
