@@ -19,13 +19,13 @@
 
 #include "qtest_kde.h"
 #include "kglobalsettingstest.h"
-#include "kglobalsettingstest.moc"
+#include "moc_kglobalsettingstest.cpp"
 
 QTEST_KDEMAIN( KGlobalSettingsTest, GUI )
 
 #include <kglobalsettings.h>
 #include <kdebug.h>
-#include <kprocess.h>
+#include <QtCore/QProcess>
 #include <QtCore/QEventLoop>
 #include <QtDBus/QtDBus>
 
@@ -36,7 +36,6 @@ QTEST_KDEMAIN( KGlobalSettingsTest, GUI )
  * and we check that the corresponding signals are emitted, i.e. that our process
  * got the dbus signal.
  *
- * As a nice side-effect we automatically test a bit of KProcess as well :)
  */
 
 void KGlobalSettingsTest::initTestCase()
@@ -62,21 +61,8 @@ void KGlobalSettingsTest::initTestCase()
     QSignalSpy appearance_spy( settings, SIGNAL(appearanceChanged()) )
 
 static void callClient( const QString& opt, const char* signalToWaitFor ) {
-    KProcess proc;
-#ifdef Q_OS_WIN
-    proc << "kglobalsettingsclient.exe";
-#else
-    if (QFile::exists("./kglobalsettingsclient.shell"))
-        proc << "./kglobalsettingsclient.shell";
-    else {
-        QVERIFY(QFile::exists("./kglobalsettingsclient"));
-        proc << "./kglobalsettingsclient";
-    }
-#endif
-    proc << opt;
-//     kDebug() << proc.args();
-    int ok = proc.execute();
-    QVERIFY(ok == 0);
+    QVERIFY(QFile::exists(KDEBINDIR "/kdeui-kglobalsettingsclient"));
+    QVERIFY(QProcess::execute(KDEBINDIR "/kdeui-kglobalsettingsclient", QStringList(opt)) == 0);
 
     QVERIFY(QTest::kWaitForSignal(KGlobalSettings::self(), signalToWaitFor, 5000));
 }
