@@ -24,7 +24,7 @@
 
 #include <QItemSelectionModel>
 #include <QSortFilterProxyModel>
-#include <QStandardItem>
+#include <QtGui/qstandarditemmodel.h>
 #include <QStandardItemModel>
 
 QTEST_KDEMAIN(KLinkItemSelectionModelTest, GUI)
@@ -106,4 +106,4 @@ void KLinkItemSelectionModelTest::testSubSetCurrent()
     QCOMPARE(mainIndex, m_mainModel->index(m_mainModel->rowCount() - 1, 0));
 }
 
-#include <klinkitemselectionmodeltest.moc>
+#include "moc_klinkitemselectionmodeltest.cpp"
