@@ -46,7 +46,7 @@ TopLevel::TopLevel(QWidget *parent)
     conn(i1,int);
     b1->layout()->addWidget(i1);
 
-    i2 = new KIntNumInput(i1, 42,b1);
+    i2 = new KIntNumInput(42, b1);
     i2->setLabel("percentage of usage (with slider)");
     i2->setRange(0, 100, 5);
     i2->setSuffix(" %");
@@ -54,7 +54,7 @@ TopLevel::TopLevel(QWidget *parent)
     conn(i2,int);
     b1->layout()->addWidget(i2);
 
-    i3 = new KIntNumInput(i2, 0xAF, b1,16);
+    i3 = new KIntNumInput(0xAF, b1, 16);
     i3->setLabel("Hex byte (no slider)");
     i3->setRange(0, 255, 1);
     i3->setSliderEnabled(false);
@@ -62,7 +62,7 @@ TopLevel::TopLevel(QWidget *parent)
     conn(i3,int);
     b1->layout()->addWidget(i3);
 
-    i4 = new KIntNumInput(i3, 0xfe,  b1, 16);
+    i4 = new KIntNumInput(0xfe,  b1, 16);
     i4->setLabel("Hex byte (with slider)");
     i4->setRange(0, 255, 1);
     i4->setSliderEnabled(true);
@@ -70,7 +70,7 @@ TopLevel::TopLevel(QWidget *parent)
     b1->layout()->addWidget(i4);
 
 
-    i5 = new KIntNumInput(i4, 10, b1,10);
+    i5 = new KIntNumInput(10, b1,10);
     i5->setLabel("Width (keeps aspect ratio):");
     i5->setRange(0, 200);
     i5->setSliderEnabled(false);
@@ -78,7 +78,7 @@ TopLevel::TopLevel(QWidget *parent)
     b1->layout()->addWidget(i5);
 
 
-    i6 = new KIntNumInput(i5, 20, b1, 10);
+    i6 = new KIntNumInput(20, b1, 10);
     i6->setLabel("Height (should be 2xWidth value):");
     i6->setRange(0, 200);
     i6->setReferencePoint( 10 );
@@ -90,13 +90,13 @@ TopLevel::TopLevel(QWidget *parent)
     connect( i6, SIGNAL(relativeValueChanged(double)),
 	     i5, SLOT(setRelativeValue(double)) );
 
-    i7 = new KIntNumInput(i6, 0, b1, 10);
+    i7 = new KIntNumInput(0, b1, 10);
     i7->setLabel("math test:", Qt::AlignVCenter|Qt::AlignLeft );
     i7->setRange( 0, 200, 1 );
     conn(i7,int);
     b1->layout()->addWidget(i7);
 
-    i8 = new KIntNumInput(i7, 0, b1, 10);
+    i8 = new KIntNumInput(0, b1, 10);
     i8->setLabel("plural test:", Qt::AlignVCenter|Qt::AlignLeft);
     i8->setRange(0, 100, 1);
     i8->setSuffix( ki18np( " suffix", " suffixes" ) );
@@ -106,21 +106,21 @@ TopLevel::TopLevel(QWidget *parent)
 
     QGroupBox* b2 = new QGroupBox("KDoubleNumInput", this);
     b2->setLayout(new QVBoxLayout());
-    d1 = new KDoubleNumInput(0,10,4.0,1,b2,2 /*, "perc_double_no_slider"*/);
+    d1 = new KDoubleNumInput(10,4.0,1,b2,2 /*, "perc_double_no_slider"*/);
     d1->setLabel("percent of usage (no slider)", Qt::AlignTop | Qt::AlignRight);
     d1->setRange(0.0, 4000.0, 0.01, false);
     //d1->setValue(1.00000000000000000001);
     conn(d1,double);
     b2->layout()->addWidget(d1);
 
-    d2 = new KDoubleNumInput(d1, 0,20,0.422,b2,0.1,3/*, "perc_double_with_slider"*/);
+    d2 = new KDoubleNumInput(0,20,0.422,b2,0.1,3/*, "perc_double_with_slider"*/);
     d2->setLabel("percentage of usage (with slider)", Qt::AlignBottom | Qt::AlignLeft);
     d2->setRange(0, 0.05, 0.005);
     d2->setSuffix("%");
     conn(d2,double);
     b2->layout()->addWidget(d2);
 
-    d3 = new KDoubleNumInput(d2, 0,20,16.20,b2);
+    d3 = new KDoubleNumInput(0,20,16.20,b2);
     d3->setLabel("cash: ", Qt::AlignVCenter | Qt::AlignHCenter);
     d3->setRange(0.10, 100, 0.1);
     d3->setPrefix("p");
@@ -129,7 +129,7 @@ TopLevel::TopLevel(QWidget *parent)
     b2->layout()->addWidget(d3);
 
 
-    d4 = new KDoubleNumInput(d3, 0,INT_MAX,INT_MAX/10000.0,b2,1,1);
+    d4 = new KDoubleNumInput(0,INT_MAX,INT_MAX/10000.0,b2,1,1);
 //     d4->setPrecision(3);
     d4->setRange(double(INT_MIN+1)/1000.0, double(INT_MAX)/1000.0, 1);
     d4->setLabel("math test: ", Qt::AlignVCenter | Qt::AlignLeft);
@@ -138,20 +138,20 @@ TopLevel::TopLevel(QWidget *parent)
     b2->layout()->addWidget(d4);
 
 
-    d5 = new KDoubleNumInput(d4, double(INT_MIN+1)/1e9, double(INT_MAX-1)/1e9,
+    d5 = new KDoubleNumInput(double(INT_MIN+1)/1e9, double(INT_MAX-1)/1e9,
 			     0.1, b2,0.001, 9 /*, "d5"*/);
     d5->setLabel("math test 2: ", Qt::AlignVCenter|Qt::AlignLeft);
     conn(d5,double);
     b2->layout()->addWidget(d5);
 
 
-    d6 = new KDoubleNumInput(d5, -10, 10, 0, b2,0.001, 3 /*, "d6"*/);
+    d6 = new KDoubleNumInput(-10, 10, 0, b2,0.001, 3 /*, "d6"*/);
     d6->setLabel("aspect ratio test with a negative ratio:");
     d6->setReferencePoint( 1 );
     b2->layout()->addWidget(d6);
 
 
-    d7 = new KDoubleNumInput(d6, -30, 30, 0, b2,0.001, 3 /*, "d7"*/);
+    d7 = new KDoubleNumInput(-30, 30, 0, b2,0.001, 3 /*, "d7"*/);
     d7->setReferencePoint( -3 );
     b2->layout()->addWidget(d7);
 
@@ -180,5 +180,5 @@ int main( int argc, char ** argv )
     a->exec();
 }
 
-#include "knuminputtest.moc"
+#include "moc_knuminputtest.cpp"
 
