@@ -1,11 +1,6 @@
-#define QT3_SUPPORT
-#define QT3_SUPPORT_WARNINGS
-
 #include <QtGui/QWidget>
-#include <QtCore/QString>
 #include <QtGui/QMessageBox>
 #include <QtGui/QTextEdit>
-#include <QtCore/QCOORD>
 #include <QtGui/QPixmap>
 #include <QtGui/QCursor>
 
@@ -15,14 +10,13 @@
 #include <kcmdlineargs.h>
 #include <kapplication.h>
 #include <kmainwindow.h>
-#include <kmenubar.h>
 #include "kstatusbartest.h"
 
 testWindow::testWindow (QWidget *)
     : KXmlGuiWindow (0)
  {
     // Setup Menus
-    menuBar = new KMenuBar (this);
+    menuBar = new QMenuBar (this);
     fileMenu = new QMenu;
     menuBar->addAction ( "&File" );
     QAction *action = fileMenu->addAction("&Exit");
@@ -83,7 +77,7 @@ void testWindow::slotClick(int id)
       break;
 
     case 2:
-      QMessageBox::information(0, "Go to line", "Enter line number:", "where?");
+      QMessageBox::information(0, "Go to line", "Enter line number:");
       statusbar->changeItem("16543", 2);
       break;
    }
@@ -123,5 +117,5 @@ int main( int argc, char *argv[] )
         return ret;
 } 
 
-#include "kstatusbartest.moc"
+#include "moc_kstatusbartest.cpp"
 
