@@ -1,5 +1,5 @@
 #include <QtGui/QLayout>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QMenu>
 #include <QtCore/QMimeData>
 
@@ -11,7 +11,7 @@
 #include "ktabwidgettest.h"
 
 Test::Test( QWidget* parent )
-  :KVBox( parent ), mChange(0), mLeftWidget(0), mRightWidget(0),
+  :KVBox( parent ), mLeftWidget(0), mRightWidget(0),
   mLeftPopup(0), mRightPopup(0), mTabbarContextPopup(0), mContextPopup(0)
 
 {
@@ -392,4 +392,4 @@ int main(int argc, char** argv )
     app.exec();
 }
 
-#include "ktabwidgettest.moc"
+#include "moc_ktabwidgettest.cpp"
