@@ -1,6 +1,6 @@
 /* This file is part of the KDE libraries
 
-    Copyright (c) 2007 David Faure <faure@kde.org>
+    Copyright 2007-2009 David Faure <faure@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -20,20 +20,18 @@
 
 #include "qtest_kde.h"
 #include "kxmlgui_unittest.h"
-#include <QShowEvent>
 #include <kedittoolbar.h>
 #include <kaction.h>
-#include <kactioncollection.h>
 #include <kpushbutton.h>
-#include <QMenu>
 #include <kxmlguibuilder.h>
 #include <kxmlguiclient.h>
-#include <ktoolbar.h>
-#include <kxmlguiwindow.h>
-#include <ktemporaryfile.h>
-#include "kxmlgui_unittest.moc"
+#include "testxmlguiwindow.h"
+#include "testguiclient.h"
+#include "moc_kxmlgui_unittest.cpp"
 #include <kxmlguiversionhandler_p.h>
 #include <kxmlguiversionhandler.cpp> // it's not exported, so we need to include the code here
+#include <QtGui/qevent.h>
+#include <QtGui/QMenuBar>
 
 QTEST_KDEMAIN(KXmlGui_UnitTest, GUI)
 
@@ -46,12 +44,12 @@ enum Flags {
     // next item is 16
 };
 
-static void createXmlFile(QFile& file, int version, int flags)
+static void createXmlFile(QFile& file, int version, int flags, const QByteArray& toplevelTag = "gui")
 {
     const QByteArray xml =
         "<?xml version = '1.0'?>\n"
         "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
-        "<gui version=\"" + QByteArray::number(version) + "\" name=\"foo\" >\n"
+        "<" + toplevelTag + " version=\"" + QByteArray::number(version) + "\" name=\"foo\" >\n"
         "<MenuBar>\n";
     file.write(xml);
     if (flags & AddModifiedMenus) {
@@ -65,22 +63,22 @@ static void createXmlFile(QFile& file, int version, int flags)
     file.write("</MenuBar>\n");
     if (flags & AddToolBars) {
         file.write(
-            "<ToolBar name=\"mainToolBar\" fullWidth=\"true\" >\n"
+            "<ToolBar name=\"mainToolBar\">\n"
             "  <text>Main Toolbar</text>\n"
             "  <Action name=\"print\" />\n"
             "</ToolBar>\n"
-            "<ToolBar name=\"bookmarkToolBar\" fullWidth=\"true\" >\n"
+            "<ToolBar name=\"bookmarkToolBar\">\n"
             "  <text>Bookmark Toolbar</text>\n"
             "</ToolBar>\n"
             );
     }
     if (flags & AddModifiedToolBars) {
         file.write(
-            "<ToolBar name=\"mainToolBar\" fullWidth=\"true\" >\n"
+            "<ToolBar name=\"mainToolBar\">\n"
             "  <text>Main Toolbar</text>\n"
             "  <Action name=\"home\" />\n"
             "</ToolBar>\n"
-            "<ToolBar name=\"bookmarkToolBar\" fullWidth=\"true\" >\n"
+            "<ToolBar name=\"bookmarkToolBar\">\n"
             "  <text>Modified toolbars</text>\n"
             "</ToolBar>\n"
             );
@@ -92,7 +90,7 @@ static void createXmlFile(QFile& file, int version, int flags)
             "</ActionProperties>\n"
             );
     }
-    file.write("</gui>\n");
+    file.write("</" + toplevelTag + ">\n");
 }
 
 
@@ -107,13 +105,18 @@ void KXmlGui_UnitTest::testFindVersionNumber_data()
         "<gui version=\"3\" name=\"foo\"/>\n" << "3";
     QTest::newRow("two digits") <<
         "<?xml version = '1.0'?>\n"
-        "<gui version=\"42\" name=\"foo\"/>\n" << "42";
+        "<kpartgui version=\"42\" name=\"foo\"/>\n" << "42";
     QTest::newRow("with spaces") << // as found in dirfilterplugin.rc for instance
         "<?xml version = '1.0'?>\n"
         "<gui version = \"1\" name=\"foo\"/>\n" << "1";
     QTest::newRow("with a dot") << // as was found in autorefresh.rc
         "<?xml version = '1.0'?>\n"
         "<gui version = \"0.2\" name=\"foo\"/>\n" << QString() /*error*/;
+    QTest::newRow("with a comment") << // as found in kmail.rc
+        "<!DOCTYPE kpartgui>\n"
+        "<!-- This file should be synchronized with kmail_part.rc to provide\n"
+        "the same menu entries at the same place in KMail and Kontact  -->\n"
+        "<kpartgui version=\"452\" name=\"kmmainwin\">\n" << "452";
 }
 
 void KXmlGui_UnitTest::testFindVersionNumber()
@@ -153,8 +156,9 @@ void KXmlGui_UnitTest::testVersionHandlerSameVersion()
     // Check that the toolbars modified by the user were kept
     QVERIFY(finalDoc.contains("<Action name=\"home\""));
 
-    QVERIFY(userFile.open());
-    const QString userFileContents = QString::fromUtf8(userFile.readAll());
+    QFile userFile2(firstFile);
+    QVERIFY(userFile2.open(QFile::ReadOnly));
+    const QString userFileContents = QString::fromUtf8(userFile2.readAll());
     QCOMPARE(finalDoc, userFileContents);
 }
 
@@ -199,8 +203,9 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionNothingKept()
     QVERIFY(finalDoc.startsWith("<?xml"));
     QVERIFY(finalDoc.contains("version=\"5\""));
 
-    QVERIFY(fileV5.open());
-    const QString fileV5Contents = QString::fromUtf8(fileV5.readAll());
+    QFile fileV52(fileV5.fileName());
+    QVERIFY(fileV52.open(QFile::ReadOnly));
+    const QString fileV5Contents = QString::fromUtf8(fileV52.readAll());
     QCOMPARE(finalDoc, fileV5Contents);
 }
 
@@ -211,14 +216,16 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionUserChanges()
 
     QMap<QString, int> fileToVersionMap; // makes QCOMPARE failures more readable than just temp filenames
 
+    // local file
     QFile fileV2(KStandardDirs::locateLocal("appdata", "testui.rc"));
     QVERIFY(fileV2.open(QIODevice::WriteOnly));
     createXmlFile(fileV2, 2, AddActionProperties | AddModifiedToolBars);
     fileToVersionMap.insert(fileV2.fileName(), 2);
 
+    // more-global file
     KTemporaryFile fileV5;
     QVERIFY(fileV5.open());
-    createXmlFile(fileV5, 5, AddToolBars | AddModifiedMenus);
+    createXmlFile(fileV5, 5, AddToolBars | AddModifiedMenus, "kpartgui");
     fileToVersionMap.insert(fileV5.fileName(), 5);
 
     // The highest version is neither the first nor last one in the list,
@@ -238,7 +245,7 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionUserChanges()
     fileV1.close();
 
     KXmlGuiVersionHandler versionHandler(files);
-    // We selected the local file, so in our map it has version 2.
+    // We end up with the local file, so in our map it has version 2.
     // But of course by now it says "version=5" in it :)
     QCOMPARE(fileToVersionMap.value(versionHandler.finalFile()), 2);
     const QString finalDoc = versionHandler.finalDocument();
@@ -254,28 +261,14 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionUserChanges()
     QVERIFY(finalDoc.contains("<Action name=\"home\""));
 }
 
-// because setDOMDocument and setXML are protected
-class TestGuiClient : public KXMLGUIClient
+static QStringList collectMenuNames(KXMLGUIFactory& factory)
 {
-public:
-    TestGuiClient(const QByteArray& xml, bool withUiStandards = false)
-        : KXMLGUIClient()
-    {
-        if (withUiStandards) {
-            QString uis = KStandardDirs::locate("config", "ui/ui_standards.rc", componentData());
-            QVERIFY(!uis.isEmpty());
-            setXMLFile(uis);
-        }
-
-        setXML(QString::fromLatin1(xml), true);
-    }
-};
-
-static void createActions(KActionCollection* collection, const QStringList& actionNames)
-{
-    Q_FOREACH(const QString& actionName, actionNames) {
-        collection->addAction(actionName)->setText("Action");
+    QList<QWidget*> containers = factory.containers("Menu");
+    QStringList containerNames;
+    Q_FOREACH(QWidget* w, containers) {
+        containerNames << w->objectName();
     }
+    return containerNames;
 }
 
 #if 0
@@ -295,9 +288,10 @@ static void checkActions(const QList<QAction*>& actions, const QStringList& expe
         else
             QCOMPARE(action->objectName(), expectedActions[i]);
     }
+    QCOMPARE(actions.count(), expectedActions.count());
 }
 
-void KXmlGui_UnitTest::testMergingSeparators()
+void KXmlGui_UnitTest::testPartMerging()
 {
     const QByteArray hostXml =
         "<?xml version = '1.0'?>\n"
@@ -305,27 +299,27 @@ void KXmlGui_UnitTest::testMergingSeparators()
         "<gui version=\"1\" name=\"foo\" >\n"
         "<MenuBar>\n"
         " <Menu name=\"go\"><text>&amp;Go</text>\n"
-//        "  <!-- TODO: go_up, go_back, go_forward, go_home: coming from ui_standards.rc -->\n"
-        "  <Action name=\"go_up\"/>\n"
-        "  <Action name=\"go_back\"/>\n"
-        "  <Action name=\"go_forward\"/>\n"
-        "  <Action name=\"go_home\"/>\n"
+        "  <!-- go_up, go_back, go_forward, go_home: coming from ui_standards.rc -->\n"
         "  <Merge/>\n"
-        "  <Action name=\"go_history\"/>\n"
-        "  <Action name=\"go_most_often\"/>\n"
+        "  <Action name=\"host_after_merge\"/>\n"
+        "  <Action name=\"host_after_merge_2\"/>\n"
         "  <Separator/>\n"
-        "  <Action name=\"history\"/>\n"
-        "  <Action name=\"closedtabs\"/>\n"
+        "  <DefineGroup name=\"new_merge\"/>\n"
+        "  <Action name=\"last_from_host\"/>\n"
+        " </Menu>\n"
+        " <Menu name=\"file\"><text>&amp;File</text>\n"
+        "  <DefineGroup name=\"placed_merge\" append=\"new_merge\"/>\n"
         " </Menu>\n"
         "</MenuBar>\n"
         "</gui>\n";
 
 
-    TestGuiClient hostClient(hostXml, true /*ui_standards.rc*/);
-    createActions(hostClient.actionCollection(),
-                  QStringList() << "go_up" << "go_back" << "go_forward" << "go_home"
-                  << "go_history" << "go_most_often");
-    QMainWindow mainWindow;
+    TestGuiClient hostClient;
+    hostClient.createActions(QStringList() << "go_up" << "go_back" << "go_forward" << "go_home"
+                             << "host_after_merge" << "host_after_merge_2" << "last_from_host"
+                             << "file_new" << "file_open" << "file_quit");
+    hostClient.createGUI(hostXml, true /*ui_standards.rc*/);
+    KMainWindow mainWindow;
     KXMLGUIBuilder builder(&mainWindow);
     KXMLGUIFactory factory(&builder);
     factory.addClient(&hostClient);
@@ -334,6 +328,7 @@ void KXmlGui_UnitTest::testMergingSeparators()
     QVERIFY(goMenuW);
     QMenu* goMenu = qobject_cast<QMenu *>(goMenuW);
     QVERIFY(goMenu);
+    QMenu* fileMenu = qobject_cast<QMenu *>(factory.container("file", &hostClient));
 
     //debugActions(goMenu->actions());
     checkActions(goMenu->actions(), QStringList()
@@ -341,9 +336,16 @@ void KXmlGui_UnitTest::testMergingSeparators()
                  << "go_back"
                  << "go_forward"
                  << "go_home"
-                 << "go_history"
-                 << "go_most_often"
-                 << "separator");
+                 << "separator"
+                 << "host_after_merge"
+                 << "host_after_merge_2"
+                 << "separator"
+                 << "last_from_host");
+    checkActions(fileMenu->actions(), QStringList()
+                 << "file_new"
+                 << "file_open"
+                 << "separator"
+                 << "file_quit");
 
     kDebug() << "Now merging the part";
 
@@ -358,17 +360,21 @@ void KXmlGui_UnitTest::testMergingSeparators()
         "  <Action name=\"first_page\"/>\n"
         "  <Action name=\"last_page\"/>\n"
         "  <Separator/>\n"
-        "  <Action name=\"go_document_back\"/>\n"
-        "  <Action name=\"go_document_forward\" />\n"
-        "  <Separator/>\n"
-        "  <Action name=\"go_goto_page\"/>\n"
+        "  <Action name=\"action_in_merge_group\" group=\"new_merge\"/>\n"
+        "  <Action name=\"undefined_group\" group=\"no_such_merge\"/>\n"
+        "  <Action name=\"last_from_part\"/>\n"
+        " </Menu>\n"
+        " <Menu name=\"file\"><text>&amp;File</text>\n"
+        "  <Action group=\"placed_merge\" name=\"action_in_placed_merge\"/>\n"
+        "  <Action name=\"other_file_action\"/>\n"
         " </Menu>\n"
         "</MenuBar>\n"
         "</kpartgui>\n";
 
     TestGuiClient partClient(partXml);
-    createActions(partClient.actionCollection(),
-                  QStringList() << "go_previous" << "go_next" << "first_page" << "last_page");
+    partClient.createActions(QStringList() << "go_previous" << "go_next" << "first_page" <<
+            "last_page" << "last_from_part" << "action_in_merge_group" << "undefined_group" <<
+            "action_in_placed_merge" << "other_file_action" );
     factory.addClient(&partClient);
 
     //debugActions(goMenu->actions());
@@ -377,10 +383,203 @@ void KXmlGui_UnitTest::testMergingSeparators()
                  << "go_back"
                  << "go_forward"
                  << "go_home"
+                 << "separator"
+                 // Contents of the <Merge>:
                  << "go_previous"
                  << "go_next"
                  << "separator"
-                 << "first_page");
+                 << "first_page"
+                 << "last_page"
+                 << "separator"
+                 << "undefined_group"
+                 << "last_from_part"
+                 // End of <Merge>
+                 << "host_after_merge"
+                 << "host_after_merge_2"
+                 << "separator"
+                 // Contents of <DefineGroup>
+                 << "action_in_merge_group"
+                 // End of <DefineGroup>
+                 << "last_from_host"
+        );
+        checkActions(fileMenu->actions(), QStringList()
+                 << "file_new"
+                 << "action_in_placed_merge"
+                 << "file_open"
+                 << "separator"
+                 << "file_quit"
+                 << "other_file_action");
+    factory.removeClient(&partClient);
+    factory.removeClient(&hostClient);
+}
+
+void KXmlGui_UnitTest::testPartMergingSettings() // #252911
+{
+    const QByteArray hostXml =
+        "<?xml version = '1.0'?>\n"
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"foo\" >\n"
+        "<MenuBar>\n"
+// The solution was to remove the duplicated definition
+//        " <Menu name=\"settings\"><text>&amp;Settings</text>\n"
+//        "    <Action name=\"options_configure_keybinding\"/>\n"
+//        "    <Action name=\"options_configure_toolbars\"/>\n"
+//        "    <Merge name=\"configure_merge\"/>\n"
+//        "    <Separator/>\n"
+//        "    <Merge/>\n"
+//        " </Menu>\n"
+        "</MenuBar></gui>\n";
+    TestGuiClient hostClient;
+    hostClient.createActions(QStringList() << "options_configure_keybinding" << "options_configure_toolbars");
+    hostClient.createGUI(hostXml, true /*ui_standards.rc*/);
+    //kDebug() << hostClient.domDocument().toString();
+    KMainWindow mainWindow;
+    KXMLGUIBuilder builder(&mainWindow);
+    KXMLGUIFactory factory(&builder);
+    factory.addClient(&hostClient);
+    QWidget* settingsMenu = qobject_cast<QMenu *>(factory.container("settings", &hostClient));
+    QVERIFY(settingsMenu);
+    //debugActions(settingsMenu->actions());
+
+    const QByteArray partXml =
+        "<?xml version = '1.0'?>\n"
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"foo\" >\n"
+        "<MenuBar>\n"
+        " <Menu name=\"settings\"><text>&amp;Settings</text>\n"
+        "    <Action name=\"configure_klinkstatus\"/>\n"
+        " </Menu>\n"
+        "</MenuBar></gui>\n";
+    TestGuiClient partClient(partXml);
+    partClient.createActions(QStringList() << "configure_klinkstatus");
+    factory.addClient(&partClient);
+    //debugActions(settingsMenu->actions());
+    checkActions(settingsMenu->actions(), QStringList()
+                 << "separator" // that's ok, QMenuPrivate::filterActions won't show it
+                 << "options_configure_keybinding"
+                 << "options_configure_toolbars"
+                 << "configure_klinkstatus");
+    factory.removeClient(&partClient);
+    factory.removeClient(&hostClient);
+}
+
+void KXmlGui_UnitTest::testUiStandardsMerging_data()
+{
+    QTest::addColumn<QByteArray>("xml");
+    QTest::addColumn<QStringList>("actions");
+    QTest::addColumn<QStringList>("expectedMenus");
+
+    const QByteArray xmlBegin =
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"foo\" >\n"
+        "<MenuBar>\n";
+    const QByteArray xmlEnd =
+        "</MenuBar>\n"
+        "</gui>";
+
+    // Merging an empty menu (or a menu with only non-existing actions) would make
+    // the empty menu appear at the end after all other menus (fixed for KDE-4.2)
+    QTest::newRow("empty file menu, implicit settings menu")
+        << QByteArray(xmlBegin + "<Menu name=\"file\"/>\n" + xmlEnd)
+        << (QStringList() << "options_configure_toolbars")
+        << (QStringList() << "settings");
+    QTest::newRow("file menu with non existing action, implicit settings menu")
+        << QByteArray(xmlBegin + "<Menu name=\"file\"><Action name=\"foo\"/></Menu>\n" + xmlEnd)
+        << (QStringList() << "options_configure_toolbars")
+        << (QStringList() << "settings");
+    QTest::newRow("file menu with existing action, implicit settings menu")
+        << QByteArray(xmlBegin + "<Menu name=\"file\"><Action name=\"open\"/></Menu>\n" + xmlEnd)
+        << (QStringList() << "open" << "options_configure_toolbars")
+        << (QStringList() << "file" << "settings");
+    QTest::newRow("implicit file and settings menu")
+        << QByteArray(xmlBegin + xmlEnd)
+        << (QStringList() << "file_open" << "options_configure_toolbars")
+        << (QStringList() << "file" << "settings"); // we could check that file_open is in the mainToolBar, too
+
+    // Check that unknown non-empty menus are added at the "MergeLocal" position (before settings).
+    QTest::newRow("foo menu added at the end")
+        << QByteArray(xmlBegin + "<Menu name=\"foo\"><Action name=\"foo_action\"/></Menu>\n" + xmlEnd)
+        << (QStringList() << "file_open" << "options_configure_toolbars" << "foo_action")
+        << (QStringList() << "file" << "foo" << "settings");
+
+    QTest::newRow("Bille's testcase: menu patch + menu edit")
+        << QByteArray(xmlBegin + "<Menu name=\"patch\"><Action name=\"patch_generate\"/></Menu>\n"
+        + "<Menu name=\"edit\"><Action name=\"edit_foo\"/></Menu>\n"
+        + xmlEnd)
+        << (QStringList() << "file_open" << "patch_generate" << "edit_foo")
+        << (QStringList() << "file" << "edit" << "patch");
+    QTest::newRow("Bille's testcase: menu patch + menu edit, lowercase tag")
+        << QByteArray(xmlBegin + "<Menu name=\"patch\"><Action name=\"patch_generate\"/></Menu>\n"
+        + "<menu name=\"edit\"><Action name=\"edit_foo\"/></menu>\n"
+        + xmlEnd)
+        << (QStringList() << "file_open" << "patch_generate" << "edit_foo")
+        << (QStringList() << "file" << "edit" << "patch");
+
+    // Check that <Menu append="..."> allows to insert menus at specific positions
+    QTest::newRow("Menu append")
+        << QByteArray(xmlBegin + "<Menu name=\"foo\" append=\"settings_merge\"><Action name=\"foo_action\"/></Menu>\n" + xmlEnd)
+        << (QStringList() << "file_open" << "options_configure_toolbars" << "foo_action" << "help_contents")
+        << (QStringList() << "file" << "settings" << "foo" << "help");
+    QTest::newRow("Custom first menu")
+        << QByteArray(xmlBegin + "<Menu name=\"foo\" append=\"first_menu\"><Action name=\"foo_action\"/></Menu>\n" + xmlEnd)
+        << (QStringList() << "edit_undo" << "foo_action" << "help_contents")
+        << (QStringList() << "foo" << "edit" << "help");
+
+    // Tests for noMerge="1"
+    QTest::newRow("noMerge empty file menu, implicit settings menu")
+        << QByteArray(xmlBegin + "<Menu name=\"file\" noMerge=\"1\"/>\n" + xmlEnd)
+        << (QStringList() << "file_open" << "options_configure_toolbars")
+        << (QStringList() << "file" << "settings"); // we keep empty menus, see #186382
+    QTest::newRow("noMerge empty file menu, file_open moved elsewhere")
+        << QByteArray(xmlBegin + "<Menu name=\"file\" noMerge=\"1\"/>\n<Menu name=\"foo\"><Action name=\"file_open\"/></Menu>" + xmlEnd)
+        << (QStringList() << "file_open")
+        << (QStringList() << "file" << "foo");
+    QTest::newRow("noMerge file menu with open before new")
+        << QByteArray(xmlBegin + "<Menu name=\"file\" noMerge=\"1\"><Action name=\"file_open\"/><Action name=\"file_new\"/></Menu>" + xmlEnd)
+        << (QStringList() << "file_open" << "file_new")
+        << (QStringList() << "file"); // TODO check the order of the actions in the menu? how?
+
+    // Tests for deleted="true"
+    QTest::newRow("deleted file menu, implicit settings menu")
+        << QByteArray(xmlBegin + "<Menu name=\"file\" deleted=\"true\"/>\n" + xmlEnd)
+        << (QStringList() << "file_open" << "options_configure_toolbars")
+        << (QStringList() << "settings");
+    QTest::newRow("deleted file menu, file_open moved elsewhere")
+        << QByteArray(xmlBegin + "<Menu name=\"file\" deleted=\"true\"/>\n<Menu name=\"foo\"><Action name=\"file_open\"/></Menu>" + xmlEnd)
+        << (QStringList() << "file_open")
+        << (QStringList() << "foo");
+    QTest::newRow("deleted file menu with actions (contradiction)")
+        << QByteArray(xmlBegin + "<Menu name=\"file\" deleted=\"true\"><Action name=\"file_open\"/><Action name=\"file_new\"/></Menu>" + xmlEnd)
+        << (QStringList() << "file_open" << "file_new")
+        << (QStringList());
+
+}
+
+void KXmlGui_UnitTest::testUiStandardsMerging()
+{
+    QFETCH(QByteArray, xml);
+    QFETCH(QStringList, actions);
+    QFETCH(QStringList, expectedMenus);
+
+    TestGuiClient client;
+    client.createActions(actions);
+    client.createGUI(xml, true /*ui_standards.rc*/);
+
+    const QDomDocument domDocument = client.domDocument();
+    const QDomElement docElem = domDocument.documentElement();
+    QCOMPARE(docElem.attribute("name"), QString("foo")); // not standard_containers from ui_standards.rc
+    QCOMPARE(docElem.attribute("version"), QString("1")); // not standard_containers from ui_standards.rc
+
+    KMainWindow mainWindow;
+    KXMLGUIBuilder builder(&mainWindow);
+    KXMLGUIFactory factory(&builder);
+    factory.addClient(&client);
+
+    const QStringList containerNames = collectMenuNames(factory);
+    //kDebug() << containerNames;
+    QCOMPARE(containerNames, expectedMenus);
+
+    factory.removeClient(&client);
 }
 
 void KXmlGui_UnitTest::testActionListAndSeparator()
@@ -399,9 +598,8 @@ void KXmlGui_UnitTest::testActionListAndSeparator()
         "</gui>";
 
     TestGuiClient client(xml);
-    createActions(client.actionCollection(),
-                  QStringList() << "view_add_to_new_group" << "action1");
-    QMainWindow mainWindow;
+    client.createActions(QStringList() << "view_add_to_new_group");
+    KMainWindow mainWindow;
     KXMLGUIBuilder builder(&mainWindow);
     KXMLGUIFactory factory(&builder);
     factory.addClient(&client);
@@ -418,9 +616,13 @@ void KXmlGui_UnitTest::testActionListAndSeparator()
 
     kDebug() << "Now plugging the actionlist";
 
+    KAction* action1 = new KAction(this);
+    action1->setObjectName("action1");
+    action1->setShortcut(KShortcut("Ctrl+2"));
     QList<QAction*> actionList;
-    actionList << client.actionCollection()->action("action1");
+    actionList << action1;
     client.plugActionList("view_groups_list", actionList);
+    QCOMPARE(action1->shortcut().toString(), QString("Ctrl+2"));
 
     //debugActions(menu->actions());
     checkActions(menu->actions(), QStringList()
@@ -448,36 +650,9 @@ void KXmlGui_UnitTest::testActionListAndSeparator()
                  << "action1"
                  << "separator"
                  << "view_add_to_new_group");
+    factory.removeClient(&client);
 }
 
-class TestXmlGuiWindow : public KXmlGuiWindow
-{
-public:
-    TestXmlGuiWindow(const QByteArray& xml) : KXmlGuiWindow() {
-        QVERIFY(m_userFile.open());
-        m_userFile.write(xml);
-        m_fileName = m_userFile.fileName(); // remember filename
-        Q_ASSERT(!m_fileName.isEmpty());
-        m_userFile.close(); // write to disk
-    }
-    void createGUI() {
-        KXmlGuiWindow::createGUI(m_fileName);
-    }
-
-    // Same as in KMainWindow_UnitTest
-    void reallyResize(int width, int height) {
-        const QSize oldSize = size();
-        resize(width, height);
-        // Send the pending resize event (resize() only sets Qt::WA_PendingResizeEvent)
-        QResizeEvent e(size(), oldSize);
-        QApplication::sendEvent(this, &e);
-    }
-
-private:
-    KTemporaryFile m_userFile;
-    QString m_fileName;
-};
-
 void KXmlGui_UnitTest::testHiddenToolBar()
 {
     const QByteArray xml =
@@ -499,17 +674,13 @@ void KXmlGui_UnitTest::testHiddenToolBar()
     KConfigGroup cg(KGlobal::config(), "testHiddenToolBar");
     TestXmlGuiWindow mainWindow(xml);
     mainWindow.setAutoSaveSettings(cg);
-    createActions(mainWindow.actionCollection(), QStringList() << "go_up");
+    mainWindow.createActions(QStringList() << "go_up");
     mainWindow.createGUI();
-    KXMLGUIFactory* factory = mainWindow.guiFactory();
 
-    //qDebug() << "containers:" << factory->containers("ToolBar");
-    QWidget* mainToolBarW = factory->container("mainToolBar", &mainWindow);
-    QVERIFY(mainToolBarW);
-    KToolBar* mainToolBar = qobject_cast<KToolBar *>(mainToolBarW);
-    QVERIFY(mainToolBar);
+    KToolBar* mainToolBar = mainWindow.toolBarByName("mainToolBar");
     QVERIFY(mainToolBar->isHidden());
 
+    KXMLGUIFactory* factory = mainWindow.guiFactory();
     QVERIFY(!factory->container("visibleToolBar", &mainWindow)->isHidden());
     KToolBar* hiddenToolBar = qobject_cast<KToolBar *>(factory->container("hiddenToolBar", &mainWindow));
     kDebug() << hiddenToolBar;
@@ -551,22 +722,15 @@ void KXmlGui_UnitTest::testAutoSaveSettings()
         // Test resizing first (like show() does).
         mw.reallyResize(400, 400);
 
-        createActions(mw.actionCollection(), QStringList() << "go_up");
+        mw.createActions(QStringList() << "go_up");
         mw.createGUI();
-        KXMLGUIFactory* factory = mw.guiFactory();
 
         // Resize again, should be saved
         mw.reallyResize(800, 600);
 
-        QWidget* mainToolBarW = factory->container("mainToolBar", &mw);
-        QVERIFY(mainToolBarW);
-        QToolBar* mainToolBar = qobject_cast<QToolBar *>(mainToolBarW);
-        QVERIFY(mainToolBar);
+        KToolBar* mainToolBar = mw.toolBarByName("mainToolBar");
         QCOMPARE(mw.toolBarArea(mainToolBar), Qt::TopToolBarArea);
-        QWidget* secondToolBarW = factory->container("secondToolBar", &mw);
-        QVERIFY(secondToolBarW);
-        QToolBar* secondToolBar = qobject_cast<QToolBar *>(secondToolBarW);
-        QVERIFY(secondToolBar);
+        KToolBar* secondToolBar = mw.toolBarByName("secondToolBar");
         QCOMPARE(mw.toolBarArea(secondToolBar), Qt::TopToolBarArea); // REFERENCE #1 (see below)
 
         // Move second toolbar to bottom
@@ -589,30 +753,23 @@ void KXmlGui_UnitTest::testAutoSaveSettings()
         // Check window size was restored
         QCOMPARE(mw2.size(), QSize(800, 600));
 
-        createActions(mw2.actionCollection(), QStringList() << "go_up");
+        mw2.createActions(QStringList() << "go_up");
         mw2.createGUI();
 
         // Force window layout to happen
         mw2.reallyResize(800, 600);
 
         // Check toolbar positions were restored
-        KXMLGUIFactory* factory = mw2.guiFactory();
-        QWidget* mainToolBarW = factory->container("mainToolBar", &mw2);
-        QVERIFY(mainToolBarW);
-        QToolBar* mainToolBar = qobject_cast<QToolBar *>(mainToolBarW);
-        QVERIFY(mainToolBar);
+        KToolBar* mainToolBar = mw2.toolBarByName("mainToolBar");
         QCOMPARE(mw2.toolBarArea(mainToolBar), Qt::TopToolBarArea);
-        QWidget* secondToolBarW = factory->container("secondToolBar", &mw2);
-        QVERIFY(secondToolBarW);
-        QToolBar* secondToolBar = qobject_cast<QToolBar *>(secondToolBarW);
-        QVERIFY(secondToolBar);
+        KToolBar* secondToolBar = mw2.toolBarByName("secondToolBar");
         QCOMPARE(mw2.toolBarArea(secondToolBar), Qt::BottomToolBarArea);
         mw2.applyMainWindowSettings(mw2.autoSaveConfigGroup());
         QCOMPARE(mw2.toolBarArea(secondToolBar), Qt::BottomToolBarArea);
     }
 }
 
-void KXmlGui_UnitTest::testDeletedContainers()
+void KXmlGui_UnitTest::testDeletedContainers() // deleted="true"
 {
     const QByteArray xml =
         "<?xml version = '1.0'?>\n"
@@ -634,7 +791,7 @@ void KXmlGui_UnitTest::testDeletedContainers()
     KConfigGroup cg(KGlobal::config(), "testDeletedToolBar");
     TestXmlGuiWindow mainWindow(xml);
     mainWindow.setAutoSaveSettings(cg);
-    createActions(mainWindow.actionCollection(), QStringList() << "go_up" << "file_new" << "game_new");
+    mainWindow.createActions(QStringList() << "go_up" << "file_new" << "game_new");
     mainWindow.createGUI();
     KXMLGUIFactory* factory = mainWindow.guiFactory();
 
@@ -659,3 +816,154 @@ void KXmlGui_UnitTest::testDeletedContainers()
 
     mainWindow.close();
 }
+
+void KXmlGui_UnitTest::testTopLevelSeparator() {
+    const QByteArray xml =
+        "<?xml version = '1.0'?>\n"
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"foo\" >\n"
+        "<MenuBar>\n"
+        " <Menu name=\"before_separator\"><text>Before Separator</text></Menu>\n"
+        " <Separator />\n"
+        " <Menu name=\"after_separator\"><text>After Separator</text></Menu>\n"
+        "</MenuBar>\n"
+        "</gui>";
+
+    TestXmlGuiWindow mainWindow(xml);
+    mainWindow.createGUI();
+
+    checkActions(mainWindow.menuBar()->actions(), QStringList()
+                 << "before_separator"
+                 << "separator"
+                 << "after_separator"
+                 << "separator"
+                 << "help");
+}
+
+// Check that the objectName() of the menus is set from the name in the XML file
+void KXmlGui_UnitTest::testMenuNames()
+{
+    const QByteArray xml =
+        "<?xml version = '1.0'?>\n"
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"foo\" >\n"
+        "<MenuBar>\n"
+        " <Menu name=\"filemenu\"><text>File Menu</text></Menu>\n"
+        "</MenuBar>\n"
+        "</gui>";
+
+    TestXmlGuiWindow mainWindow(xml);
+    mainWindow.createGUI();
+
+    checkActions(mainWindow.menuBar()->actions(), QStringList()
+                 << "filemenu"
+                 << "separator"
+                 << "help" );
+}
+
+// Test what happens when the application's rc file isn't found
+// We want a warning to be printed, but we don't want to see all menus from ui_standards.rc
+void KXmlGui_UnitTest::testMenusNoXmlFile()
+{
+    TestXmlGuiWindow mainWindow;
+    mainWindow.createGUIBad();
+
+    checkActions(mainWindow.menuBar()->actions(), QStringList()
+                 << "help" );
+}
+
+void KXmlGui_UnitTest::testXMLFileReplacement() {
+    // to differentiate "original" and replacement xml file, one is created with "modified" toolbars
+    KTemporaryFile fileOrig;
+    QVERIFY(fileOrig.open());
+    createXmlFile(fileOrig, 2, AddToolBars);
+    const QString filenameOrig = fileOrig.fileName();
+    fileOrig.close();
+
+    KTemporaryFile fileReplace;
+    QVERIFY(fileReplace.open());
+    createXmlFile(fileReplace, 2, AddModifiedToolBars);
+    const QString filenameReplace = fileReplace.fileName();
+    fileReplace.close();
+
+    // finally, our local xml file has <ActionProperties/>
+    QFile fileLocal(KStandardDirs::locateLocal("appdata", "testui.rc"));
+    QVERIFY(fileLocal.open(QIODevice::WriteOnly));
+    createXmlFile(fileLocal, 1, AddActionProperties);
+    const QString filenameLocal = fileLocal.fileName();
+    fileLocal.close();
+
+    TestGuiClient client;
+    // first make sure that the "original" file is loaded, correctly
+    client.setXMLFilePublic(filenameOrig);
+    QString xml = client.domDocument().toString();
+    //qDebug() << xml;
+    QVERIFY(xml.contains("<Action name=\"print\""));
+    QVERIFY(!xml.contains("<Action name=\"home\""));
+    QVERIFY(!xml.contains("<ActionProperties>"));
+
+    // now test the replacement (+ local file)
+    client.replaceXMLFile(filenameReplace, filenameLocal);
+    xml = client.domDocument().toString();
+    QVERIFY(!xml.contains("<Action name=\"print\""));
+    QVERIFY(xml.contains("<Action name=\"home\""));
+    QVERIFY(xml.contains("<ActionProperties>"));
+
+    // re-check after a reload
+    client.reloadXML();
+    QString reloadedXml = client.domDocument().toString();
+    QVERIFY(!reloadedXml.contains("<Action name=\"print\""));
+    QVERIFY(reloadedXml.contains("<Action name=\"home\""));
+    QVERIFY(reloadedXml.contains("<ActionProperties>"));
+
+    // Check what happens when the local file doesn't exist
+    TestGuiClient client2;
+    QFile::remove(filenameLocal);
+    client2.replaceXMLFile(filenameReplace, filenameLocal);
+    xml = client2.domDocument().toString();
+    //qDebug() << xml;
+    QVERIFY(!xml.contains("<Action name=\"print\""));
+    QVERIFY(xml.contains("<Action name=\"home\"")); // modified toolbars
+    QVERIFY(!xml.contains("<ActionProperties>")); // but no local xml file
+}
+
+void KXmlGui_UnitTest::testClientDestruction() { // #170806
+    const QByteArray hostXml =
+        "<?xml version = '1.0'?>\n"
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"foo\" >\n"
+        "<MenuBar>\n"
+        " <Menu name=\"file\"><text>&amp;File</text>\n"
+        " </Menu>\n"
+        " <Merge/>\n"
+        "</MenuBar>\n"
+        "</gui>";
+    const QByteArray xml = "<?xml version = '1.0'?>\n"
+        "<!DOCTYPE gui SYSTEM \"kpartgui.dtd\">\n"
+        "<gui version=\"1\" name=\"foo\" >\n"
+        "<MenuBar>\n"
+        " <Menu name=\"file\"><text>&amp;File</text>\n"
+        "  <Action name=\"file_open\"/>\n"
+        "  <Action name=\"file_quit\"/>\n"
+        " </Menu>\n"
+        "</MenuBar>\n"
+        "</gui>";
+
+    TestXmlGuiWindow mainWindow(hostXml);
+    TestGuiClient* client = new TestGuiClient(xml);
+    client->createActions(QStringList() << "file_open" << "file_quit");
+    mainWindow.insertChildClient(client);
+    mainWindow.createGUI();
+
+    checkActions(mainWindow.menuBar()->actions(), QStringList()
+                 << "file" << "separator" << "help" );
+
+    QVERIFY(mainWindow.factory()->clients().contains(client));
+    delete client;
+    QVERIFY(!mainWindow.factory()->clients().contains(client));
+
+    // No change, because deletion is fast, it doesn't do manual unplugging.
+    checkActions(mainWindow.menuBar()->actions(), QStringList()
+                 << "file" << "separator" << "help" );
+}
+
