@@ -26,7 +26,7 @@
 #include <knotification.h>
 #include <kglobal.h>
 #include <kstringhandler.h>
-#include <QtCore/QMutableVectorIterator>
+#include <QtCore/qvector.h>
 
 class KCompletionPrivate
 {
@@ -198,7 +198,6 @@ void KCompletion::addWeightedItem( const QString& item )
     }
 
     addItem( item.left( len ), weight );
-    return;
 }
 
 
@@ -228,7 +227,7 @@ QString KCompletion::makeCompletion( const QString& string )
     if ( d->myCompletionMode == KGlobalSettings::CompletionNone )
         return QString();
 
-    //kDebug(0) << "KCompletion: completing: " << string;
+    //kDebug() << "KCompletion: completing: " << string;
 
     d->matches.clear();
     d->myRotationIndex = 0;
@@ -274,7 +273,7 @@ QString KCompletion::makeCompletion( const QString& string )
     postProcessMatch( &completion );
 
     if ( !string.isEmpty() ) { // only emit match when string is not empty
-        //kDebug(0) << "KCompletion: Match: " << completion;
+        //kDebug() << "KCompletion: Match: " << completion;
         emit match( completion );
     }
 
@@ -406,7 +405,7 @@ QString KCompletion::nextMatch()
     if ( d->matches.isEmpty() ) {
         findAllCompletions( d->myLastString, &d->matches, d->myHasMultipleMatches );
         if ( !d->matches.isEmpty() )
-	    completion = d->matches.first();
+            completion = d->matches.first();
         d->myCurrentMatch = completion;
         d->myRotationIndex = 0;
         postProcessMatch( &completion );
@@ -552,7 +551,7 @@ void KCompletion::findAllCompletions(const QString& string,
                                      KCompletionMatchesWrapper *matches,
                                      bool& hasMultipleMatches) const
 {
-    //kDebug(0) << "*** finding all completions for " << string;
+    //kDebug() << "*** finding all completions for " << string;
 
     if ( string.isEmpty() )
         return;
@@ -983,6 +982,4 @@ KCompTreeNode *KCompTreeNodeList::at(uint index) const
     return cur;
 }
 
-KZoneAllocator KCompTreeNode::alloc(8192);
-
-#include "kcompletion.moc"
+#include "moc_kcompletion.cpp"
