@@ -27,7 +27,6 @@
 
 #include <QtCore/QMap>
 #include <QtCore/QObject>
-#include <QtCore/QString>
 #include <QtCore/QStringList>
 #include <QtCore/QPointer>
 
@@ -951,12 +950,6 @@ private:
     // signals internally flags to the provided values.
     void setup( bool, bool, bool );
 
-    // BCI
-protected:
-    /** Virtual hook, used to add new "virtual" functions while maintaining
-	binary compatibility. Unused in this class.
-    */
-    virtual void virtual_hook( int id, void* data );
 private:
     Q_DISABLE_COPY( KCompletionBase )
     KCompletionBasePrivate * const d;
