@@ -46,6 +46,7 @@
 #endif
 #include <errno.h>
 
+#include <qplatformdefs.h>
 #include <qwindowdefs.h>
 #include <kglobal.h>
 #include <kcomponentdata.h>
@@ -73,9 +74,6 @@
 #include <ucontext.h>
 #endif
 
-#if defined(Q_OS_WIN)
-# include <windows.h>
-#endif
 
 static KCrash::HandlerType s_emergencySaveFunction = 0;
 static KCrash::HandlerType s_crashHandler = 0;
@@ -92,9 +90,6 @@ namespace KCrash
 {
     void startProcess(int argc, const char *argv[], bool waitAndExit);
 
-#if defined(Q_OS_WIN)
-    LONG WINAPI win32UnhandledExceptionFilter(_EXCEPTION_POINTERS *exceptionInfo);
-#endif
 }
 
 void
@@ -226,16 +221,6 @@ bool KCrash::isDrKonqiEnabled()
 void
 KCrash::setCrashHandler (HandlerType handler)
 {
-#if defined(Q_OS_WIN)
-  static LPTOP_LEVEL_EXCEPTION_FILTER s_previousExceptionFilter = NULL;
-
-  if (handler && !s_previousExceptionFilter) {
-    s_previousExceptionFilter = SetUnhandledExceptionFilter(KCrash::win32UnhandledExceptionFilter);
-  } else if (!handler && s_previousExceptionFilter) {
-    SetUnhandledExceptionFilter(s_previousExceptionFilter);
-    s_previousExceptionFilter = NULL;
-  }
-#else
   if (!handler)
     handler = SIG_DFL;
 
@@ -264,7 +249,6 @@ KCrash::setCrashHandler (HandlerType handler)
 #endif
 
   sigprocmask(SIG_UNBLOCK, &mask, 0);
-#endif
 
   s_crashHandler = handler;
 }
@@ -293,10 +277,8 @@ KCrash::defaultCrashHandler (int sig)
     static int crashRecursionCounter = 0;
     crashRecursionCounter++; // Nothing before this, please !
 
-#if !defined(Q_OS_WIN)
     signal(SIGALRM, SIG_DFL);
     alarm(3); // Kill me... (in case we deadlock in malloc)
-#endif
 
 #ifdef Q_OS_SOLARIS
     (void) printstack(2 /* stderr, assuming it's still open. */);
@@ -313,14 +295,14 @@ KCrash::defaultCrashHandler (int sig)
         crashRecursionCounter++;
     }
 
-#if !defined(Q_OS_WIN)
+    // Note: KCrash closes FDs unconditionally later on if it forks to Dr Konqi
+    //       and this program's FDs do not matter if kdeinit starts Dr Konqi.
     if (!(s_flags & KeepFDs))
         closeAllFDs();
 # if defined(Q_WS_X11)
     else if (QX11Info::display())
         close(ConnectionNumber(QX11Info::display()));
 # endif
-#endif
 
     if (crashRecursionCounter < 3)
     {
@@ -342,9 +324,7 @@ KCrash::defaultCrashHandler (int sig)
 
         if (!s_launchDrKonqi) {
             setCrashHandler(0);
-#if !defined(Q_OS_WIN)
             raise(sig); // dump core, or whatever is the default action for this signal.
-#endif
             return;
         }
 
@@ -412,7 +392,7 @@ KCrash::defaultCrashHandler (int sig)
         char sidtxt[256];
         if ( kapp && !kapp->startupId().isNull()) {
             argv[i++] = "--startupid";
-            strlcpy(sidtxt, kapp->startupId().constData(), sizeof(sidtxt));
+            strncpy(sidtxt, kapp->startupId().constData(), sizeof(sidtxt));
             argv[i++] = sidtxt;
         }
 
@@ -422,12 +402,6 @@ KCrash::defaultCrashHandler (int sig)
         if ((s_flags & AutoRestart) && s_autoRestartCommand)
             argv[i++] = "--restarted"; //tell drkonqi if the app has been restarted
 
-#if defined(Q_OS_WIN)
-        char threadId[8] = { 0 };
-        sprintf( threadId, "%d", GetCurrentThreadId() );
-        argv[i++] = "--thread";
-        argv[i++] = threadId;
-#endif
 
         // NULL terminated list
         argv[i] = NULL;
@@ -443,67 +417,6 @@ KCrash::defaultCrashHandler (int sig)
     _exit(255);
 }
 
-#if defined(Q_OS_WIN)
-
-void KCrash::startProcess(int argc, const char *argv[], bool waitAndExit)
-{
-    QString cmdLine;
-    for(int i=0; i<argc; ++i) {
-        cmdLine.append('\"');
-        cmdLine.append(QFile::decodeName(argv[i]));
-        cmdLine.append("\" ");
-    }
-
-    PROCESS_INFORMATION procInfo;
-    STARTUPINFOW startupInfo = { sizeof( STARTUPINFO ), 0, 0, 0,
-                                (ulong)CW_USEDEFAULT, (ulong)CW_USEDEFAULT,
-                                (ulong)CW_USEDEFAULT, (ulong)CW_USEDEFAULT,
-                                0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
-
-    bool success = CreateProcess(0, (wchar_t*) cmdLine.utf16(), NULL, NULL,
-                                 false, CREATE_UNICODE_ENVIRONMENT, NULL, NULL,
-                                 &startupInfo, &procInfo);
-
-    if (success && waitAndExit) {
-        // wait for child to exit
-        WaitForSingleObject(procInfo.hProcess, INFINITE);
-        _exit(253);
-    }
-}
-
-//glue function for calling the unix signal handler from the windows unhandled exception filter
-LONG WINAPI KCrash::win32UnhandledExceptionFilter(_EXCEPTION_POINTERS *exceptionInfo)
-{
-    // kdbgwin needs the context inside exceptionInfo because if getting the context after the
-    // exception happened, it will walk down the stack and will stop at KiUserEventDispatch in
-    // ntdll.dll, which is supposed to dispatch the exception from kernel mode back to user mode
-    // so... let's create some shared memory
-    HANDLE hMapFile = NULL;
-    hMapFile = CreateFileMapping(
-        INVALID_HANDLE_VALUE,
-        NULL,
-        PAGE_READWRITE,
-        0,
-        sizeof(CONTEXT),
-        TEXT("Local\\KCrashShared"));
-
-    LPCTSTR pBuf = NULL;
-    pBuf = (LPCTSTR) MapViewOfFile(
-        hMapFile,
-        FILE_MAP_ALL_ACCESS,
-        0,
-        0,
-        sizeof(CONTEXT));
-    CopyMemory((PVOID) pBuf, exceptionInfo->ContextRecord, sizeof(CONTEXT));
-
-    if (s_crashHandler) {
-        s_crashHandler(exceptionInfo->ExceptionRecord->ExceptionCode);
-    }
-
-    CloseHandle(hMapFile);
-    return EXCEPTION_EXECUTE_HANDLER; //allow windows to do the default action (terminate)
-}
-#else
 
 static bool startProcessInternal(int argc, const char *argv[], bool waitAndExit, bool directly);
 static pid_t startFromKdeinit(int argc, const char *argv[]);
@@ -520,6 +433,7 @@ void KCrash::startProcess(int argc, const char *argv[], bool waitAndExit)
     // This is done because it is dangerous to use fork() in the crash handler
     // (there can be functions registered to be performed before fork(), for example handling
     // of malloc locking, which doesn't work when malloc crashes because of heap corruption).
+    // Fails on Apple OSX+KDE4, because kdeinit4 is using the wrong socket name.
     if (!(s_flags & AlwaysDirectly)) {
         startDirectly = !startProcessInternal(argc, argv, waitAndExit, false);
     }
@@ -546,11 +460,9 @@ static bool startProcessInternal(int argc, const char *argv[], bool waitAndExit,
             //if the process was started directly, use waitpid(), as it's a child...
             while(waitpid(-1, NULL, 0) != pid) {}
         } else {
-#ifdef Q_OS_LINUX
+            // PR_SET_PTRACER available since 3.4
+#if defined(Q_OS_LINUX)
             // Declare the process that will be debugging the crashed KDE app (#245529)
-#ifndef PR_SET_PTRACER
-# define PR_SET_PTRACER 0x59616d61
-#endif
             prctl(PR_SET_PTRACER, pid, 0, 0, 0);
 #endif
             //...else poll its status using kill()
@@ -570,7 +482,7 @@ static pid_t startFromKdeinit(int argc, const char *argv[])
   if( socket < -1 )
     return 0;
   klauncher_header header;
-  header.cmd = LAUNCHER_EXEC_NEW;
+  header.cmd = LAUNCHER_EXEC;
   const int BUFSIZE = 8192; // make sure this is big enough
   char buffer[ BUFSIZE + 10 ];
   int pos = 0;
@@ -605,8 +517,7 @@ static pid_t startFromKdeinit(int argc, const char *argv[])
     return 0;
   }
   long pid;
-  read_socket(socket, buffer, header.arg_length);
-  pid = *((long *) buffer);
+  read_socket(socket, (char *) &pid, sizeof(pid));
   return static_cast<pid_t>(pid);
 }
 
@@ -639,6 +550,7 @@ static char *getDisplay()
    char *screen;
    char *colon;
    char *i;
+
 /*
  don't test for a value from qglobal.h but instead distinguish
  Qt/X11 from Qt/Embedded by the fact that Qt/E apps have -DQWS
@@ -646,7 +558,7 @@ static char *getDisplay()
  but we don't want to include that here) (Simon)
 #ifdef Q_WS_X11
  */
-#ifdef NO_DISPLAY
+#if defined(NO_DISPLAY)
    display = "NODISPLAY";
 #elif !defined(QWS)
    display = getenv("DISPLAY");
@@ -668,10 +580,6 @@ static char *getDisplay()
       *screen = '\0';
    while((i = strchr(result, ':')))
      *i = '_';
-#ifdef __APPLE__
-   while((i = strchr(result, '/')))
-     *i = '_';
-#endif
    return result;
 }
 
@@ -725,68 +633,50 @@ static int read_socket(int sock, char *buffer, int len)
 
 static int openSocket()
 {
-  kde_socklen_t socklen;
+  socklen_t socklen;
   int s;
   struct sockaddr_un server;
 #define MAX_SOCK_FILE 255
   char sock_file[MAX_SOCK_FILE + 1];
-  const char *home_dir = getenv("HOME");
-  const char *kde_home = getenv("KDEHOME");
+  const QByteArray tmp_dir = QFile::encodeName(KGlobal::dirs()->resourceDirs("tmp").first());
   char *display;
 
   sock_file[0] = sock_file[MAX_SOCK_FILE] = 0;
 
-  if (!kde_home || !kde_home[0])
+  if (tmp_dir.isEmpty())
   {
-     kde_home = "~/" KDE_DEFAULT_HOME "/";
+    fprintf(stderr, "Warning: no temp dir!\n");
+    return -1;
   }
-
-  if (kde_home[0] == '~')
-  {
-     if (!home_dir || !home_dir[0])
-     {
-        fprintf(stderr, "Warning: $HOME not set!\n");
-        return -1;
-     }
-     if (strlen(home_dir) > (MAX_SOCK_FILE-100))
-     {
-        fprintf(stderr, "Warning: Home directory path too long!\n");
-        return -1;
-     }
-     kde_home++;
-     strlcpy(sock_file, home_dir, MAX_SOCK_FILE);
-  }
-  strlcat(sock_file, kde_home, MAX_SOCK_FILE);
+  strncat(sock_file, tmp_dir.constData(), MAX_SOCK_FILE - strlen(sock_file));
 
   /** Strip trailing '/' **/
   if ( sock_file[strlen(sock_file)-1] == '/')
      sock_file[strlen(sock_file)-1] = 0;
 
-  strlcat(sock_file, "/socket-", MAX_SOCK_FILE);
-  if (gethostname(sock_file+strlen(sock_file), MAX_SOCK_FILE - strlen(sock_file) - 1) != 0)
-  {
-     perror("Warning: Could not determine hostname: ");
-     return -1;
-  }
   sock_file[sizeof(sock_file)-1] = '\0';
 
   /* append $DISPLAY */
   display = getDisplay();
+#if !defined (NO_DISPLAY)
   if (display == NULL)
   {
      fprintf(stderr, "Error: Could not determine display.\n");
      return -1;
   }
+#endif
 
   if (strlen(sock_file)+strlen(display)+strlen("/kdeinit4_")+2 > MAX_SOCK_FILE)
   {
      fprintf(stderr, "Warning: Socket name will be too long.\n");
-     free(display);
+     free (display);
      return -1;
   }
   strcat(sock_file, "/kdeinit4_");
+#if !defined (NO_DISPLAY)
   strcat(sock_file, display);
   free(display);
+#endif
 
   if (strlen(sock_file) >= sizeof(server.sun_path))
   {
@@ -806,7 +696,8 @@ static int openSocket()
 
   server.sun_family = AF_UNIX;
   strcpy(server.sun_path, sock_file);
-  printf("sock_file=%s\n", sock_file);
+  // Use stderr, to make the message visible on the Apple OS X Console log.
+  fprintf(stderr, "KCrash: Connect sock_file=%s\n", sock_file);
   socklen = sizeof(server);
   if(connect(s, (struct sockaddr *)&server, socklen) == -1)
   {
@@ -817,4 +708,3 @@ static int openSocket()
   return s;
 }
 
-#endif // Q_OS_UNIX
