@@ -27,7 +27,7 @@
 #include <QtGui/QFrame>
 
 class KVBox;
-class QSystemTrayIcon;
+#include <QSystemTrayIcon>
 
 /**
  * @short A dialog-like popup that displays messages without interrupting the user.
@@ -97,27 +97,13 @@ public:
     /**
      * Creates a popup for the specified widget.
      */
-    explicit KPassivePopup( QWidget *parent=0, Qt::WFlags f = 0 );
+    explicit KPassivePopup( QWidget *parent=0, Qt::WindowFlags f = 0 );
 
     /**
      * Creates a popup for the specified window.
      */
     explicit KPassivePopup( WId parent );
 
-#if 0 // These break macos and win32 where the definition of WId makes them ambiguous
-    /**
-     * Creates a popup for the specified widget.
-     * THIS WILL BE REMOVED, USE setPopupStyle().
-     */
-    explicit KPassivePopup( int popupStyle, QWidget *parent=0, Qt::WFlags f=0 ) KDE_DEPRECATED;
-
-    /**
-     * Creates a popup for the specified window.
-     * THIS WILL BE REMOVED, USE setPopupStyle().
-     */
-    KPassivePopup( int popupStyle, WId parent, Qt::WFlags f=0 ) KDE_DEPRECATED;
-#endif
-
     /**
      * Cleans up.
      */
