@@ -28,10 +28,10 @@
 #include <QtGui/QStyle>
 #include <QtGui/QPainter>
 #include <QtGui/QBoxLayout>
-#include <QtGui/QPaintEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QPainterPath>
-#include <QtGui/QLinearGradient>
-#include <QtGui/QStyleOptionFrame>
+#include <QtGui/qbrush.h>
+#include <QtGui/qstyleoption.h>
 
 #include <kcolorscheme.h>
 
@@ -92,6 +92,7 @@ void KCapacityBar::setText(const QString &text)
     if (updateGeom) {
         updateGeometry();
     }
+
     update();
 }
 
@@ -367,8 +368,9 @@ QSize KCapacityBar::minimumSizeHint() const
 void KCapacityBar::paintEvent(QPaintEvent *event)
 {
     QPainter p(this);
-    drawCapacityBar(&p, event->rect());
+    p.setClipRect(event->rect());
+    drawCapacityBar(&p, contentsRect());
     p.end();
 }
 
-#include "kcapacitybar.moc"
+#include "moc_kcapacitybar.cpp"
