@@ -29,7 +29,7 @@
 #include <QtGui/QComboBox>
 #include <QtGui/QStyle>
 #include <QtGui/QScrollBar>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
 
 #include <kdebug.h>
 #include <kconfig.h>
@@ -54,6 +54,7 @@ KCompletionBox::KCompletionBox( QWidget *parent )
     d->emitSelected    = true;
 
     setWindowFlags( Qt::ToolTip ); // calls setVisible, so must be done after initializations
+    setUniformItemSizes(true);
 
     setLineWidth( 1 );
     setFrameStyle( QFrame::Box | QFrame::Plain );
@@ -246,9 +247,6 @@ bool KCompletionBox::eventFilter( QObject *o, QEvent *e )
         } else if ( type == QEvent::FocusOut ) {
             QFocusEvent* event = static_cast<QFocusEvent*>( e );
             if (event->reason() != Qt::PopupFocusReason
-#ifdef Q_WS_WIN
-                && (event->reason() != Qt::ActiveWindowFocusReason || QApplication::activeWindow() != this)
-#endif
                 )
                 hide();
         }
@@ -579,4 +577,4 @@ bool KCompletionBox::activateOnSelect() const
     return d->emitSelected;
 }
 
-#include "kcompletionbox.moc"
+#include "moc_kcompletionbox.cpp"
