@@ -21,7 +21,7 @@
 
 #include <QtGui/QAbstractItemView>
 #include <QtGui/QApplication>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QMenu>
 #include <QtGui/QLineEdit>
 #include <QtGui/QWidgetAction>
@@ -81,6 +81,7 @@ KDateComboBoxPrivate::KDateComboBoxPrivate(KDateComboBox *q)
                       m_dateMenu(new QMenu(q)),
                       m_datePicker(new KDatePicker(q)),
                       m_datePickerAction(new QWidgetAction(q)),
+                      m_warningShown(false),
                       m_displayFormat(KLocale::ShortDate)
 {
     m_options = KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker | KDateComboBox::DateKeywords;
@@ -458,11 +459,6 @@ void KDateComboBox::setDateMap(QMap<QDate, QString> dateMap)
     }
 }
 
-bool KDateComboBox::eventFilter(QObject *object, QEvent *event)
-{
-    return KComboBox::eventFilter(object, event);
-}
-
 void KDateComboBox::keyPressEvent(QKeyEvent *keyEvent)
 {
     QDate temp;
@@ -534,29 +530,4 @@ void KDateComboBox::showPopup()
     d->m_dateMenu->popup(popupPoint);
 }
 
-void KDateComboBox::hidePopup()
-{
-    KComboBox::hidePopup();
-}
-
-void KDateComboBox::mousePressEvent(QMouseEvent *event)
-{
-    KComboBox::mousePressEvent(event);
-}
-
-void KDateComboBox::wheelEvent(QWheelEvent *event)
-{
-    KComboBox::wheelEvent(event);
-}
-
-void KDateComboBox::focusInEvent(QFocusEvent *event)
-{
-    KComboBox::focusInEvent(event);
-}
-
-void KDateComboBox::resizeEvent(QResizeEvent *event)
-{
-    KComboBox::resizeEvent(event);
-}
-
-#include "kdatecombobox.moc"
+#include "moc_kdatecombobox.cpp"
