@@ -26,12 +26,12 @@
 #include <QtGui/QApplication>
 #include <QtGui/QFont>
 #include <QtGui/QLayout>
-#include <QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QMenu>
 #include <QtGui/QPainter>
 #include <QtGui/QStyle>
 #include <QtGui/QToolButton>
-#include <QtGui/QDoubleValidator>
+#include <QtGui/qvalidator.h>
 
 #include <kcalendarsystem.h>
 #include <klocalizeddate.h>
@@ -44,8 +44,8 @@
 #include <klineedit.h>
 #include <knotification.h>
 
-#include "kdatepicker.moc"
-#include "kdatepicker_p.moc"
+#include "moc_kdatepicker.cpp"
+#include "moc_kdatepicker_p.cpp"
 
 // Week numbers are defined by ISO 8601
 // See http://www.merlyn.demon.co.uk/weekinfo.htm for details
@@ -57,9 +57,7 @@ KDatePickerPrivateYearSelector::KDatePickerPrivateYearSelector(
     calendar = cal;
     oldDate = currentDate;
 
-    QFont font;
-    font = KGlobalSettings::generalFont();
-    setFont( font );
+    setFont( KGlobalSettings::generalFont() );
 
     setFrame( false );
 
@@ -655,8 +653,7 @@ void KDatePicker::setCloseButton( bool enable )
         d->navigationLayout->addWidget( d->closeButton );
         d->closeButton->setToolTip( i18nc( "@action:button", "Close" ) );
         d->closeButton->setIcon( SmallIcon( "window-close" ) );
-        connect( d->closeButton, SIGNAL(clicked()),
-                 topLevelWidget(), SLOT(close()) );
+        connect( d->closeButton, SIGNAL(clicked()), window(), SLOT(close()) );
     } else {
         delete d->closeButton;
         d->closeButton = 0L;
