@@ -20,7 +20,7 @@
 #include "kdatetimeedit.h"
 
 #include <QtCore/QStringList>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QMenu>
 #include <QtGui/QLineEdit>
 #include <QtGui/QWidgetAction>
@@ -141,7 +141,7 @@ void KDateTimeEditPrivate::initDateWidget()
 void KDateTimeEditPrivate::initTimeWidget()
 {
     ui.m_timeCombo->blockSignals(true);
-    ui.m_timeCombo->setVisible((m_options &KDateTimeEdit::ShowDate) == KDateTimeEdit::ShowDate);
+    ui.m_timeCombo->setVisible((m_options &KDateTimeEdit::ShowTime) == KDateTimeEdit::ShowTime);
     KTimeComboBox::Options options;
     if ((m_options &KDateTimeEdit::EditTime) == KDateTimeEdit::EditTime) {
         options = options | KTimeComboBox::EditTime;
@@ -577,25 +577,10 @@ KTimeZones::ZoneMap KDateTimeEdit::timeZones() const
     return d->m_zones;
 }
 
-bool KDateTimeEdit::eventFilter(QObject *object, QEvent *event)
-{
-    return QWidget::eventFilter(object, event);
-}
-
-void KDateTimeEdit::focusInEvent(QFocusEvent *event)
-{
-    QWidget::focusInEvent(event);
-}
-
 void KDateTimeEdit::focusOutEvent(QFocusEvent *event)
 {
     d->warnDateTime();
     QWidget::focusOutEvent(event);
 }
 
-void KDateTimeEdit::resizeEvent(QResizeEvent *event)
-{
-    QWidget::resizeEvent(event);
-}
-
-#include "kdatetimeedit.moc"
+#include "moc_kdatetimeedit.cpp"
