@@ -18,9 +18,9 @@
 
 #include "kdatetimewidget.h"
 
-#include <QtCore/QDate>
+#include <QtCore/qdatetime.h>
 #include <QtGui/QLayout>
-#include <QTimeEdit>
+#include <QtGui/qdatetimeedit.h>
 
 #include <kdebug.h>
 
@@ -69,7 +69,7 @@ void KDateTimeWidget::init()
 
   connect(d->dateWidget, SIGNAL(changed(QDate)),
           SLOT(slotValueChanged()));
-  connect(d->timeWidget, SIGNAL(timeChanged(const QTime &)),
+  connect(d->timeWidget, SIGNAL(timeChanged(QTime)),
           SLOT(slotValueChanged()));
 }
 
@@ -94,4 +94,4 @@ void KDateTimeWidget::slotValueChanged()
   emit valueChanged(datetime);
 }
 
-#include "kdatetimewidget.moc"
+#include "moc_kdatetimewidget.cpp"
