@@ -24,23 +24,23 @@
 
 #include <QtGui/QAbstractItemView>
 #include <QtGui/QApplication>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QMenu>
-#include <QtGui/QWheelEvent>
+#include <QtGui/qevent.h>
 
 #include <klocale.h>
 #include <knotification.h>
-#include <kpixmapprovider.h>
 #include <kstandardshortcut.h>
 #include <kicontheme.h>
 #include <kicon.h>
-
+#include <kiconloader.h>
+#include <kmimetype.h>
 #include <kdebug.h>
 
 class KHistoryComboBox::Private
 {
 public:
-    Private(KHistoryComboBox *q): q(q), myPixProvider(0) {}
+    Private(KHistoryComboBox *q): q(q) {}
 
     KHistoryComboBox *q;
 
@@ -59,7 +59,6 @@ public:
      * Needed to allow going back after rotation.
      */
     bool myRotated;
-    KPixmapProvider *myPixProvider;
 };
 
 // we are always read-write
@@ -88,7 +87,6 @@ void KHistoryComboBox::init( bool useCompletion )
     setInsertPolicy( NoInsert );
     d->myIterateIndex = -1;
     d->myRotated = false;
-    d->myPixProvider = 0L;
 
     // obey HISTCONTROL setting
     QByteArray histControl = qgetenv("HISTCONTROL");
@@ -106,7 +104,6 @@ void KHistoryComboBox::init( bool useCompletion )
 
 KHistoryComboBox::~KHistoryComboBox()
 {
-    delete d->myPixProvider;
     delete d;
 }
 
@@ -204,10 +201,11 @@ void KHistoryComboBox::addToHistory( const QString& item )
     }
 
     // now add the item
-    if ( d->myPixProvider )
-        insertItem( 0, d->myPixProvider->pixmapFor(item, KIconLoader::SizeSmall), item);
-    else
-        insertItem( 0, item );
+#warning implement icon for KUrl/QUrl into KIconLoader?
+    // the logic is the same as in KIO::pixmapForUrl() but kdeui cannot depend on kio
+    const QString iconName = KMimeType::iconNameForUrl( KUrl(item), KIconLoader::Desktop );
+    const QPixmap pixmap = KIconLoader::global()->loadMimeTypeIcon( iconName, KIconLoader::Desktop, iconSize().height() );
+    insertItem( 0, pixmap, item );
 
     if ( wasCurrent )
         setCurrentIndex( 0 );
@@ -373,25 +371,6 @@ void KHistoryComboBox::slotReset()
     d->myRotated = false;
 }
 
-
-void KHistoryComboBox::setPixmapProvider( KPixmapProvider *prov )
-{
-    if ( d->myPixProvider == prov )
-        return;
-
-    delete d->myPixProvider;
-    d->myPixProvider = prov;
-
-    // re-insert all the items with/without pixmap
-    // I would prefer to use changeItem(), but that doesn't honor the pixmap
-    // when using an editable combobox (what we do)
-    if ( count() > 0 ) {
-        QStringList items( historyItems() );
-        clear();
-        insertItems( items );
-    }
-}
-
 void KHistoryComboBox::insertItems( const QStringList& items )
 {
     QStringList::ConstIterator it = items.constBegin();
@@ -400,11 +379,10 @@ void KHistoryComboBox::insertItems( const QStringList& items )
     while ( it != itEnd ) {
         const QString item = *it;
         if ( !item.isEmpty() ) { // only insert non-empty items
-            if ( d->myPixProvider )
-                addItem( d->myPixProvider->pixmapFor(item, KIconLoader::SizeSmall),
-                            item );
-            else
-                addItem( item );
+            // the logic is the same as in KIO::pixmapForUrl() but kdeui cannot depend on kio
+            const QString iconName = KMimeType::iconNameForUrl( KUrl(item), KIconLoader::Desktop );
+            const QPixmap pixmap = KIconLoader::global()->loadMimeTypeIcon( iconName, KIconLoader::Desktop, iconSize().height() );
+            addItem( pixmap, item );
         }
         ++it;
     }
@@ -435,14 +413,9 @@ void KHistoryComboBox::slotSimulateActivated( const QString& text )
     }
 }
 
-KPixmapProvider *KHistoryComboBox::pixmapProvider() const
-{
-  return d->myPixProvider;
-}
-
 void KHistoryComboBox::reset()
 {
   slotReset();
 }
 
-#include "khistorycombobox.moc"
+#include "moc_khistorycombobox.cpp"
