@@ -24,7 +24,7 @@
 
 #include "kkeyserver.h"
 
-#include <QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QTimer>
 #include <QtCore/QHash>
 #include <QHBoxLayout>
@@ -112,44 +112,6 @@ public:
     }
 
 
-    bool isShiftAsModifierAllowed(int keyQt)
-    {
-        // Shift only works as a modifier with certain keys. It's not possible
-        // to enter the SHIFT+5 key sequence for me because this is handled as
-        // '%' by qt on my keyboard.
-        // The working keys are all hardcoded here :-(
-        if (keyQt >= Qt::Key_F1 && keyQt <= Qt::Key_F35)
-            return true;
-
-        if (QChar(keyQt).isLetter())
-            return true;
-
-        switch (keyQt) {
-            case Qt::Key_Return:
-            case Qt::Key_Space:
-            case Qt::Key_Backspace:
-            case Qt::Key_Escape:
-            case Qt::Key_Print:
-            case Qt::Key_ScrollLock:
-            case Qt::Key_Pause:
-            case Qt::Key_PageUp:
-            case Qt::Key_PageDown:
-            case Qt::Key_Insert:
-            case Qt::Key_Delete:
-            case Qt::Key_Home:
-            case Qt::Key_End:
-            case Qt::Key_Up:
-            case Qt::Key_Down:
-            case Qt::Key_Left:
-            case Qt::Key_Right:
-                return true;
-
-            default:
-                return false;
-        }
-    }
-
-
     bool promptStealShortcutSystemwide(
             QWidget *parent,
             const QHash<QKeySequence, QList<KGlobalShortcutInfo> > &shortcuts,
@@ -291,6 +253,7 @@ KKeySequenceWidget::KKeySequenceWidget(QWidget *parent)
    d(new KKeySequenceWidgetPrivate(this))
 {
     d->init();
+    setFocusProxy( d->keyButton );
     connect(d->keyButton, SIGNAL(clicked()), this, SLOT(captureKeySequence()));
     connect(d->clearButton, SIGNAL(clicked()), this, SLOT(clearKeySequence()));
     connect(&d->modifierlessTimeout, SIGNAL(timeout()), this, SLOT(doneRecording()));
@@ -384,11 +347,6 @@ void KKeySequenceWidget::setClearButtonShown(bool show)
     d->clearButton->setVisible(show);
 }
 
-void KKeySequenceWidget::setCheckActionList(const QList<QAction*> &checkList) // deprecated
-{
-    d->checkList = checkList;
-    Q_ASSERT(d->checkActionCollections.isEmpty()); // don't call this method if you call setCheckActionCollections!
-}
 
 void KKeySequenceWidget::setCheckActionCollections(const QList<KActionCollection *>& actionCollections)
 {
@@ -514,17 +472,6 @@ void KKeySequenceWidgetPrivate::doneRecording(bool validate)
 
 bool KKeySequenceWidgetPrivate::conflictWithGlobalShortcuts(const QKeySequence &keySequence)
 {
-#ifdef Q_WS_WIN
-    //on windows F12 is reserved by the debugger at all times, so we can't use it for a global shortcut
-    if (KKeySequenceWidget::GlobalShortcuts && keySequence.toString().contains("F12")) {
-        QString title = i18n("Reserved Shortcut");
-        QString message = i18n("The F12 key is reserved on Windows, so cannot be used for a global shortcut.\n"
-                               "Please choose another one.");
-
-        KMessageBox::sorry(q, message, title);
-        return false;
-    }
-#endif
 
     if (!(checkAgainstShortcutTypes & KKeySequenceWidget::GlobalShortcuts)) {
         return false;
@@ -533,7 +480,7 @@ bool KKeySequenceWidgetPrivate::conflictWithGlobalShortcuts(const QKeySequence &
     // Global shortcuts are on key+modifier shortcuts. They can clash with
     // each of the keys of a multi key shortcut.
     QHash<QKeySequence, QList<KGlobalShortcutInfo> > others;
-    for (uint i=0; i<keySequence.count(); ++i) {
+    for (int i=0; i<keySequence.count(); ++i) {
         QKeySequence tmp(keySequence[i]);
 
         if (!KGlobalAccel::isGlobalShortcutAvailable(tmp, componentName)) {
@@ -552,7 +499,7 @@ bool KKeySequenceWidgetPrivate::conflictWithGlobalShortcuts(const QKeySequence &
     // error it just silently fails. So be nice because this is
     // most likely the first action that is done in the slot
     // listening to keySequenceChanged().
-    for (uint i=0; i<keySequence.count(); ++i) {
+    for (int i=0; i<keySequence.count(); ++i) {
         KGlobalAccel::stealShortcutSystemwide(keySequence[i]);
     }
     return false;
@@ -681,10 +628,7 @@ void KKeySequenceWidgetPrivate::updateShortcutDisplay()
         if (modifierKeys) {
             if (!s.isEmpty()) s.append(",");
             if (modifierKeys & Qt::META)  s += KKeyServer::modToStringUser(Qt::META) + '+';
-#if defined(Q_WS_MAC)
-            if (modifierKeys & Qt::ALT)   s += KKeyServer::modToStringUser(Qt::ALT) + '+';
-            if (modifierKeys & Qt::CTRL)  s += KKeyServer::modToStringUser(Qt::CTRL) + '+';
-#elif defined(Q_WS_X11)
+#if   defined(Q_WS_X11)
             if (modifierKeys & Qt::CTRL)  s += KKeyServer::modToStringUser(Qt::CTRL) + '+';
             if (modifierKeys & Qt::ALT)   s += KKeyServer::modToStringUser(Qt::ALT) + '+';
 #endif
@@ -793,7 +737,7 @@ void KKeySequenceButton::keyPressEvent(QKeyEvent *e)
             if ((keyQt == Qt::Key_Backtab) && (d->modifierKeys & Qt::SHIFT)) {
                 keyQt = Qt::Key_Tab | d->modifierKeys;
             }
-            else if (d->isShiftAsModifierAllowed(keyQt)) {
+            else if (KKeyServer::isShiftAsModifierAllowed(keyQt)) {
                 keyQt |= d->modifierKeys;
             }
             else
@@ -849,10 +793,6 @@ QKeySequence KKeySequenceWidgetPrivate::appendToSequence(const QKeySequence& seq
         return QKeySequence(keyQt);
     case 1:
         return QKeySequence(seq[0], keyQt);
-    case 2:
-        return QKeySequence(seq[0], seq[1], keyQt);
-    case 3:
-        return QKeySequence(seq[0], seq[1], seq[2], keyQt);
     default:
         return seq;
     }
@@ -879,5 +819,5 @@ bool KKeySequenceWidgetPrivate::isOkWhenModifierless(int keyQt)
     }
 }
 
-#include "kkeysequencewidget.moc"
-#include "kkeysequencewidget_p.moc"
+#include "moc_kkeysequencewidget.cpp"
+#include "moc_kkeysequencewidget_p.cpp"
