@@ -30,7 +30,6 @@
 
 #include <kaction.h>
 #include <kapplication.h>
-#include <kauthorized.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <kcursor.h>
@@ -42,6 +41,7 @@
 #include <kmenu.h>
 #include <kstandardaction.h>
 #include <kstandardshortcut.h>
+#include <kurl.h>
 
 #include <QtCore/QTimer>
 #include <QtGui/QClipboard>
@@ -109,9 +109,6 @@ public:
         // KDE5: remove userTextChanged signal, textEdited does the same...
         if (!completionRunning && (txt != userText)) {
             userText = txt;
-#ifndef KDE_NO_DEPRECATED
-            emit q->userTextChanged(txt);
-#endif
         }
     }
 
@@ -122,9 +119,6 @@ public:
         if (!completionRunning && (txt != userText)) {
             userText = txt;
             q->setModified(true);
-#ifndef KDE_NO_DEPRECATED
-            emit q->userTextChanged(txt);
-#endif
             emit q->textEdited(txt);
             emit q->textChanged(txt);
         }
@@ -411,9 +405,6 @@ void KLineEdit::setCompletionMode( KGlobalSettings::Completion mode )
     if ( echoMode() != QLineEdit::Normal )
         mode = KGlobalSettings::CompletionNone; // Override the request.
 
-    if ( kapp && !KAuthorized::authorize("lineedit_text_completion") )
-        mode = KGlobalSettings::CompletionNone;
-
     if ( mode == KGlobalSettings::CompletionPopupAuto ||
          mode == KGlobalSettings::CompletionAuto ||
          mode == KGlobalSettings::CompletionMan )
@@ -1113,7 +1104,7 @@ void KLineEdit::mouseDoubleClickEvent( QMouseEvent* e )
 void KLineEdit::mousePressEvent( QMouseEvent* e )
 {
     if  ( (e->button() == Qt::LeftButton ||
-           e->button() == Qt::MidButton ) &&
+           e->button() == Qt::MiddleButton ) &&
           d->clearButton ) {
         d->clickInClear = ( d->clearButton == childAt(e->pos()) || d->clearButton->underMouse() );
 
@@ -1130,7 +1121,7 @@ void KLineEdit::mousePressEvent( QMouseEvent* e )
 
     // if middle clicking and if text is present in the clipboard then clear the selection
     // to prepare paste operation
-    if ( e->button() == Qt::MidButton ) {
+    if ( e->button() == Qt::MiddleButton ) {
         if ( hasSelectedText() && !isReadOnly() ) {
             if ( QApplication::clipboard()->text( QClipboard::Selection ).length() >0 ) {
                 backspace();
@@ -1146,7 +1137,7 @@ void KLineEdit::mouseReleaseEvent( QMouseEvent* e )
     if ( d->clickInClear ) {
         if ( d->clearButton == childAt(e->pos()) || d->clearButton->underMouse() ) {
             QString newText;
-            if ( e->button() == Qt::MidButton ) {
+            if ( e->button() == Qt::MiddleButton ) {
                 newText = QApplication::clipboard()->text( QClipboard::Selection );
                 setText( newText );
             } else {
@@ -1206,7 +1197,7 @@ QMenu* KLineEdit::createStandardContextMenu()
     // If a completion object is present and the input
     // widget is not read-only, show the Text Completion
     // menu item.
-    if ( compObj() && !isReadOnly() && KAuthorized::authorize("lineedit_text_completion") )
+    if ( compObj() && !isReadOnly() )
     {
         QMenu *subMenu = popup->addMenu( KIcon("text-completion"), i18nc("@title:menu", "Text Completion") );
         connect( subMenu, SIGNAL(triggered(QAction*)),
@@ -1802,16 +1793,6 @@ void KLineEdit::paintEvent( QPaintEvent *ev )
     }
 }
 
-void KLineEdit::focusInEvent( QFocusEvent *ev )
-{
-    QLineEdit::focusInEvent( ev );
-}
-
-void KLineEdit::focusOutEvent( QFocusEvent *ev )
-{
-    QLineEdit::focusOutEvent( ev );
-}
-
 void KLineEdit::setClickMessage( const QString &msg )
 {
     d->enableClickMsg = !msg.isEmpty();
@@ -1819,19 +1800,7 @@ void KLineEdit::setClickMessage( const QString &msg )
     update();
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KLineEdit::setContextMenuEnabled( bool showMenu )
-{
-    QLineEdit::setContextMenuPolicy( showMenu ? Qt::DefaultContextMenu : Qt::NoContextMenu );
-}
-#endif
 
-#ifndef KDE_NO_DEPRECATED
-bool KLineEdit::isContextMenuEnabled() const
-{
-    return  ( contextMenuPolicy() == Qt::DefaultContextMenu );
-}
-#endif
 
 void KLineEdit::setPasswordMode(bool b)
 {
@@ -1869,5 +1838,5 @@ void KLineEdit::doCompletion(const QString& txt)
     d->completionRunning = false;
 }
 
-#include "klineedit.moc"
-#include "klineedit_p.moc"
+#include "moc_klineedit.cpp"
+#include "moc_klineedit_p.cpp"
