@@ -30,12 +30,12 @@
 #ifndef KLINEEDIT_H
 #define KLINEEDIT_H
 
-#include <QtGui/QLineEdit>
+#include <QLineEdit>
+#include <QAction>
+#include <QMenu>
 
 #include <kcompletion.h>
 
-class QAction;
-class QMenu;
 class KCompletionBox;
 class KUrl;
 class KLineEditPrivate;
@@ -152,7 +152,6 @@ class KDEUI_EXPORT KLineEdit : public QLineEdit, public KCompletionBase //krazy:
     friend class KLineEditStyle;
 
     Q_OBJECT
-    Q_PROPERTY( bool contextMenuEnabled READ isContextMenuEnabled WRITE setContextMenuEnabled )
     Q_PROPERTY( bool urlDropsEnabled READ urlDropsEnabled WRITE setUrlDropsEnabled )
     Q_PROPERTY( bool trapEnterKeyEvent READ trapReturnKey WRITE setTrapReturnKey )
     Q_PROPERTY( bool squeezedTextEnabled READ isSqueezedTextEnabled WRITE setSqueezedTextEnabled )
@@ -206,29 +205,6 @@ public:
     */
     void setCompletionModeDisabled( KGlobalSettings::Completion mode, bool disable = true );
 
-   /**
-    * Enables/disables the popup (context) menu.
-    *
-    * Note that when this function is invoked with its argument
-    * set to @p true, then both the context menu and the completion
-    * menu item are enabled.  If you do not want to the completion
-    * item to be visible simply invoke hideModechanger() right
-    * after calling this method.  Also by default, the context
-    * menu is automatically created if this widget is editable. Thus
-    * you need to call this function with the argument set to false
-    * if you do not want this behavior.
-    *
-    * @param showMenu If @p true, show the context menu.
-    * @deprecated use setContextMenuPolicy
-    */
-    virtual KDE_DEPRECATED void setContextMenuEnabled( bool showMenu );
-
-    /**
-     * Returns @p true when the context menu is enabled.
-     * @deprecated use contextMenuPolicy
-     */
-    KDE_DEPRECATED bool isContextMenuEnabled() const;
-
     /**
      * Enables/Disables handling of URL drops. If enabled and the user
      * drops an URL, the decoded URL will be inserted. Otherwise the default
@@ -396,20 +372,6 @@ Q_SIGNALS:
      */
     void substringCompletion( const QString& );
 
-    /**
-     * Emitted when the text is changed NOT by the suggested autocompletion:
-     * either when the user is physically typing keys, or when the text is changed programmatically,
-     * for example, by calling setText().
-     * But not when automatic completion changes the text temporarily.
-     *
-     * @since 4.2.2
-     * @deprecated since 4.5. You probably want to connect to textEdited() instead,
-     * which is emitted whenever the text is actually changed by the user
-     * (by typing or accepting autocompletion), without side effects from
-     * suggested autocompletion either. userTextChanged isn't needed anymore.
-     */
-    QT_MOC_COMPAT void userTextChanged( const QString & );
-
     /**
      * Emitted when the text rotation key-bindings are pressed.
      *
@@ -451,7 +413,8 @@ Q_SIGNALS:
 public Q_SLOTS:
 
     /**
-     * Re-implemented for internal reasons. API not changed.
+     * Sets the lineedit to read-only. Similar to QLineEdit::setReadOnly
+     * but also takes care of the background color, and the clear button.
      */
     virtual void setReadOnly(bool);
 
@@ -460,7 +423,7 @@ public Q_SLOTS:
      * the history list.
      *
      * This function simply iterates over all possible matches in case
-     * multimple matches are found as a result of a text completion request.
+     * multiple matches are found as a result of a text completion request.
      * It will have no effect if only a single match is found.
      *
      * @param type The key-binding invoked.
@@ -620,10 +583,6 @@ protected:
 
     virtual void paintEvent( QPaintEvent *ev );
 
-    virtual void focusInEvent( QFocusEvent *ev );
-
-    virtual void focusOutEvent( QFocusEvent *ev );
-
 private Q_SLOTS:
     void completionMenuActivated( QAction *act );
     void tripleClickTimeout();  // resets possibleTripleClick
