@@ -36,23 +36,23 @@
 #include <QtCore/QList>
 #include <QtCore/QObject>
 #include <QtCore/QTimer>
-#include <QtGui/QCloseEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QDesktopWidget>
 #include <QtGui/QDockWidget>
 #include <QtGui/QLayout>
 #include <QtGui/QSessionManager>
 #include <QtGui/QStyle>
 #include <QtGui/QWidget>
+#include <QtGui/QMenuBar>
+#include <QtDBus/QDBusConnection>
 
 #include <kaction.h>
 #include <kapplication.h>
-#include <kauthorized.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kdialog.h>
 #include <khelpmenu.h>
 #include <klocale.h>
-#include <kmenubar.h>
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
 #include <ktoolbar.h>
@@ -71,13 +71,6 @@
 
 #include <config.h>
 
-static bool no_query_exit = false;
-
-static KMenuBar *internalMenuBar(KMainWindow *mw)
-{
-    return KGlobal::findDirectChild<KMenuBar *>(mw);
-}
-
 static KStatusBar *internalStatusBar(KMainWindow *mw)
 {
     // Don't use qFindChild here, it's recursive!
@@ -119,7 +112,7 @@ bool DockResizeListener::eventFilter(QObject *watched, QEvent *event)
     case QEvent::Resize:
     case QEvent::Move:
     case QEvent::Hide:
-        m_win->k_ptr->setSettingsDirty(KMainWindowPrivate::CompressCalls);
+        m_win->k_ptr->setSettingsDirty(true);
         break;
 
     default:
@@ -164,7 +157,6 @@ public:
         // not really a fast method but the only compatible one
         if ( sm.allowsInteraction() ) {
             bool canceled = false;
-            ::no_query_exit = true;
 
             foreach (KMainWindow *window, KMainWindow::memberList()) {
                 if ( !window->testAttribute( Qt::WA_WState_Hidden ) ) {
@@ -189,18 +181,9 @@ public:
                     */
                 }
             }
-            ::no_query_exit = false;
             if (canceled)
                return false;
 
-            KMainWindow* last = 0;
-            foreach (KMainWindow *window, KMainWindow::memberList()) {
-                if ( !window->testAttribute( Qt::WA_WState_Hidden ) ) {
-                    last = window;
-                }
-            }
-            if ( last )
-                return last->queryExit();
             // else
             return true;
         }
@@ -253,7 +236,6 @@ void KMainWindowPrivate::init(KMainWindow *_q)
     helpMenu = 0;
 
     //actionCollection()->setWidget( this );
-    QObject::connect(qApp, SIGNAL(aboutToQuit()), q, SLOT(_k_shuttingDown()));
     QObject::connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)),
                      q, SLOT(_k_slotSettingsChanged(int)));
 
@@ -268,7 +250,6 @@ void KMainWindowPrivate::init(KMainWindow *_q)
     //d->kaccel = actionCollection()->kaccel();
     settingsTimer = 0;
     sizeTimer = 0;
-    shuttingDown = false;
     if ((care_about_geometry = being_first)) {
         being_first = false;
 
@@ -307,7 +288,7 @@ static bool endsWithHashNumber( const QString& s )
 
 static inline bool isValidDBusObjectPathCharacter(const QChar &c)
 {
-    register ushort u = c.unicode();
+    ushort u = c.unicode();
     return (u >= 'a' && u <= 'z')
             || (u >= 'A' && u <= 'Z')
             || (u >= '0' && u <= '9')
@@ -386,7 +367,7 @@ void KMainWindowPrivate::polish(KMainWindow *q)
                                        QDBusConnection::ExportAdaptors);
 }
 
-void KMainWindowPrivate::setSettingsDirty(CallCompression callCompression)
+void KMainWindowPrivate::setSettingsDirty(bool compressCalls)
 {
     if (!letDirtySettings) {
         return;
@@ -394,7 +375,7 @@ void KMainWindowPrivate::setSettingsDirty(CallCompression callCompression)
 
     settingsDirty = true;
     if (autoSaveSettings) {
-        if (callCompression == CompressCalls) {
+        if (compressCalls) {
             if (!settingsTimer) {
                 settingsTimer = new QTimer(q);
                 settingsTimer->setInterval(500);
@@ -546,7 +527,7 @@ bool KMainWindow::restore( int number, bool show )
 
 void KMainWindow::setCaption( const QString &caption )
 {
-    setPlainCaption( KDialog::makeStandardCaption( caption, this ) );
+    setWindowTitle( KDialog::makeStandardCaption( caption, this ) );
 }
 
 void KMainWindow::setCaption( const QString &caption, bool modified )
@@ -558,12 +539,7 @@ void KMainWindow::setCaption( const QString &caption, bool modified )
         flags |= KDialog::ModifiedCaption;
     }
 
-    setPlainCaption( KDialog::makeStandardCaption(caption, this, flags) );
-}
-
-void KMainWindow::setPlainCaption( const QString &caption )
-{
-	setWindowTitle(caption);
+    setWindowTitle( KDialog::makeStandardCaption(caption, this, flags) );
 }
 
 void KMainWindow::appHelpActivated( void )
@@ -593,27 +569,9 @@ void KMainWindow::closeEvent ( QCloseEvent *e )
 
     if (queryClose()) {
         e->accept();
-
-        int not_withdrawn = 0;
-        foreach (KMainWindow* mw, KMainWindow::memberList()) {
-            if ( !mw->isHidden() && mw->isTopLevel() && mw != this )
-                not_withdrawn++;
-        }
-
-        if ( !no_query_exit && not_withdrawn <= 0 ) { // last window close accepted?
-            if (!( queryExit() && ( !kapp || !kapp->sessionSaving() ) && !d->shuttingDown )) {
-              // cancel closing, it's stupid to end up with no windows at all....
-              e->ignore();
-            }
-        }
     } else e->ignore(); //if the window should not be closed, don't close it
 }
 
-bool KMainWindow::queryExit()
-{
-    return true;
-}
-
 bool KMainWindow::queryClose()
 {
     return true;
@@ -680,7 +638,7 @@ void KMainWindow::saveMainWindowSettings(const KConfigGroup &_cg)
            cg.writeEntry("StatusBar", sb->isHidden() ? "Disabled" : "Enabled");
     }
 
-    QMenuBar* mb = internalMenuBar(this);
+    QMenuBar* mb = menuBar();
     if (mb) {
        const QString MenuBar = QLatin1String("MenuBar");
        if(!cg.hasDefault("MenuBar") && !mb->isHidden() )
@@ -743,7 +701,7 @@ bool KMainWindow::readPropertiesInternal( KConfig *config, int number )
     return true;
 }
 
-void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg, bool force)
+void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg)
 {
     K_D(KMainWindow);
     kDebug(200) << "KMainWindow::applyMainWindowSettings " << cg.name();
@@ -767,7 +725,7 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg, bool force)
            sb->show();
     }
 
-    QMenuBar* mb = internalMenuBar(this);
+    QMenuBar* mb = menuBar();
     if (mb) {
         QString entry = cg.readEntry ("MenuBar", "Enabled");
         if ( entry == "Disabled" )
@@ -792,7 +750,7 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg, bool force)
         group += (toolbar->objectName().isEmpty() ? QString::number(n) : QString(" ")+toolbar->objectName());
 
         KConfigGroup toolbarGroup(&cg, group);
-        toolbar->applySettings(toolbarGroup, force);
+        toolbar->applySettings(toolbarGroup);
         n++;
     }
 
@@ -812,91 +770,6 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg, bool force)
     d->letDirtySettings = oldLetDirtySettings;
 }
 
-#ifdef Q_WS_WIN
-
-/*
- The win32 implementation for restoring/savin windows size differs
- from the unix/max implementation in three topics:
-
-1. storing and restoring the position, which may not work on x11
-    see http://doc.trolltech.com/4.3/geometry.html#x11-peculiarities
-2. using QWidget::saveGeometry() and QWidget::restoreGeometry()
-    this would probably be usable on x11 and/or on mac, but I'm unable to
-    check this on unix/mac, so I leave this fix to the x11/mac experts.
-3. store geometry separately for each resolution -> on unix/max the size
-    and with of the window are already saved separately on non windows
-    system although not using ...Geometry functions -> could also be
-    fixed by x11/mac experts.
-*/
-void KMainWindow::restoreWindowSize( const KConfigGroup & _cg )
-{
-    K_D(KMainWindow);
-
-    int scnum = QApplication::desktop()->screenNumber(window());
-    QRect desk = QApplication::desktop()->screenGeometry(scnum);
-
-    QString geometryKey = QString::fromLatin1("geometry-%1-%2").arg(desk.width()).arg(desk.height());
-    QByteArray geometry = _cg.readEntry( geometryKey, QByteArray() );
-    // if first time run, center window
-    if (!restoreGeometry( QByteArray::fromBase64(geometry) ))
-        move( (desk.width()-width())/2, (desk.height()-height())/2 );
-}
-
-void KMainWindow::saveWindowSize( const KConfigGroup & _cg ) const
-{
-    K_D(const KMainWindow);
-    int scnum = QApplication::desktop()->screenNumber(window());
-    QRect desk = QApplication::desktop()->screenGeometry(scnum);
-
-    // geometry is saved separately for each resolution
-    QString geometryKey = QString::fromLatin1("geometry-%1-%2").arg(desk.width()).arg(desk.height());
-    QByteArray geometry = saveGeometry();
-    KConfigGroup cg(_cg);
-    cg.writeEntry( geometryKey, geometry.toBase64() );
-}
-
-#elif defined(Q_OS_MAC)
-
-void KMainWindow::restoreWindowSize( const KConfigGroup & _cg )
-{
-
-    QString geometryKey = QString::fromLatin1("geometry");
-    QByteArray geometry = _cg.readEntry( geometryKey, QByteArray() );
-    kDebug(200) << "restoreWindowSize():" << geometryKey << "=" << geometry;
-    if (!restoreGeometry( QByteArray::fromBase64(geometry) )) {
-        // try first if there data has been stored using the X11-like approach from earlier kdelibs versions.
-        // This code is copied from restoreWindowSize() below.
-        int scnum = QApplication::desktop()->screenNumber(window());
-        QRect desk = QApplication::desktop()->screenGeometry(scnum);
-        const QSize size( _cg.readEntry( QString::fromLatin1("Width %1").arg(desk.width()), 0 ),
-                    _cg.readEntry( QString::fromLatin1("Height %1").arg(desk.height()), 0 ) );
-        if ( !size.isEmpty() ) {
-            kDebug(200) << "restoreWindowSize(): falling back to legacy saved state" << size;
-            if (size.width() > desk.width() || size.height() > desk.height()) {
-                setWindowState( Qt::WindowMaximized );
-            }
-            else {
-                resize( size );
-            }
-        }
-        else {
-            // if first time run, centre window
-            kDebug(200) << "restoreWindowSize(): moving the window to the screen centre of" << desk;
-            move( (desk.width()-width())/2, (desk.height()-height())/2 );
-        }
-    }
-}
-
-void KMainWindow::saveWindowSize( const KConfigGroup & _cg ) const
-{
-    QString geometryKey = QString::fromLatin1("geometry");
-    QByteArray geometry = saveGeometry();
-    kDebug(200) << "saveWindowSize():" << geometryKey << "=" << geometry;
-    KConfigGroup cg(_cg);
-    cg.writeEntry( geometryKey, geometry.toBase64() );
-}
-
-#else // Q_WS_X11 and select others.
 void KMainWindow::saveWindowSize( const KConfigGroup & _cg ) const
 {
     K_D(const KMainWindow);
@@ -974,7 +847,6 @@ void KMainWindow::restoreWindowSize( const KConfigGroup & config )
         }
     }
 }
-#endif
 
 bool KMainWindow::initialGeometrySet() const
 {
@@ -1062,9 +934,6 @@ bool KMainWindow::event( QEvent* ev )
 {
     K_D(KMainWindow);
     switch( ev->type() ) {
-#if defined(Q_WS_WIN) || defined(Q_OS_MAC)
-    case QEvent::Move:
-#endif
     case QEvent::Resize:
         d->setSizeDirty();
         break;
@@ -1128,19 +997,7 @@ bool KMainWindow::event( QEvent* ev )
 
 bool KMainWindow::hasMenuBar()
 {
-    return internalMenuBar(this);
-}
-
-KMenuBar *KMainWindow::menuBar()
-{
-    KMenuBar * mb = internalMenuBar(this);
-    if ( !mb ) {
-        mb = new KMenuBar( this );
-        // trigger a re-layout and trigger a call to the private
-        // setMenuBar method.
-        setMenuBar(mb);
-    }
-    return mb;
+    return menuBar();
 }
 
 KStatusBar *KMainWindow::statusBar()
@@ -1155,21 +1012,6 @@ KStatusBar *KMainWindow::statusBar()
     return sb;
 }
 
-void KMainWindowPrivate::_k_shuttingDown()
-{
-    // Needed for Qt <= 3.0.3 at least to prevent reentrancy
-    // when queryExit() shows a dialog. Check before removing!
-    static bool reentrancy_protection = false;
-    if (!reentrancy_protection)
-    {
-       reentrancy_protection = true;
-       shuttingDown = true;
-       // call the virtual queryExit
-       q->queryExit();
-       reentrancy_protection = false;
-    }
-}
-
 void KMainWindowPrivate::_k_slotSettingsChanged(int category)
 {
     Q_UNUSED(category);
@@ -1222,5 +1064,5 @@ QString KMainWindow::dbusName() const
     return k_func()->dbusName;
 }
 
-#include "kmainwindow.moc"
+#include "moc_kmainwindow.cpp"
 
