@@ -33,13 +33,12 @@
 #include <kdeui_export.h>
 
 #include <QtGui/QMainWindow>
-#include <QtCore/QMetaClassInfo>
+#include <QtCore/qmetaobject.h>
 
 class KMenu;
 class KConfig;
 class KConfigGroup;
 class KStatusBar;
-class KMenuBar;
 class KMWSessionManager;
 class KMainWindowPrivate;
 class KToolBar;
@@ -50,9 +49,6 @@ class KToolBar;
     inline const classname ## Private *k_func() const { return reinterpret_cast<classname ## Private *>(k_ptr); } \
     friend class classname ## Private;
 
-// This is mostly from KDE3. TODO KDE5: remove the constructor parameter.
-#define KDE_DEFAULT_WINDOWFLAGS 0
-
 /**
  * @short %KDE top level main window
  *
@@ -147,7 +143,7 @@ public:
      * for the composer windows "composer#".
      *
      */
-    explicit KMainWindow( QWidget* parent = 0, Qt::WindowFlags f = KDE_DEFAULT_WINDOWFLAGS );
+    explicit KMainWindow( QWidget* parent = 0, Qt::WindowFlags f = 0 );
 
     /**
      * \brief Destructor.
@@ -163,7 +159,7 @@ public:
      * It contains entries for the
      * help system (activated by F1), an optional "What's This?" entry
      * (activated by Shift F1), an application specific dialog box,
-     * and an "About KDE" dialog box.
+     * and an "About Katana" dialog box.
      *
      * Example (adding a standard help menu to your application):
      * \code
@@ -190,7 +186,7 @@ public:
      * It contains entries for the
      * help system (activated by F1), an optional "What's This?" entry
      * (activated by Shift F1), an application specific dialog box,
-     * and an "About KDE" dialog box. You must create the application
+     * and an "About Katana" dialog box. You must create the application
      * specific dialog box yourself. When the "About application"
      * menu entry is activated, a signal will trigger the
      * showAboutApplication slot. See showAboutApplication for more
@@ -269,13 +265,6 @@ public:
      */
      bool hasMenuBar();
 
-    /**
-     * Returns a pointer to the menu bar.
-     *
-     * If there is no menu bar yet one will be created.
-     **/
-    KMenuBar *menuBar();
-
     /**
      * Returns a pointer to the status bar.
      *
@@ -390,9 +379,8 @@ public:
      * groups in the config file and apply them.
      *
      * @param config Config group to read the settings from.
-     * @param forceGlobal see the same argument in KToolBar::applySettings
      */
-    virtual void applyMainWindowSettings( const KConfigGroup &config, bool forceGlobal = false);
+    virtual void applyMainWindowSettings( const KConfigGroup &config);
 
     /**
      * Save settings for statusbar, menubar and toolbar to their respective
@@ -440,14 +428,6 @@ public Q_SLOTS:
      */
     virtual void setCaption( const QString &caption, bool modified );
 
-    /**
-     * Make a plain caption without any modifications.
-     *
-     * @param caption Your caption. This is the string that will be
-     * displayed in the window title.
-     */
-    virtual void setPlainCaption( const QString &caption );
-
     /**
      * Open the help page for the application.
      *
@@ -487,54 +467,10 @@ protected:
     virtual bool event( QEvent * event );
 
     /**
-     * Reimplemented to call the queryClose() and queryExit() handlers.
+     * Reimplemented to call the queryClose() handlers.
      */
     virtual void closeEvent ( QCloseEvent *);
 
-    // KDE4 This seems to be flawed to me. Either the app has only one
-    // mainwindow, so queryClose() is enough, or if it can have more of them,
-    // then the windows should take care of themselves, and queryExit()
-    // would be useful only for the annoying 'really quit' dialog, which
-    // also doesn't make sense in apps with multiple mainwindows.
-    // And saving configuration in something called queryExit()? IMHO
-    // one can e.g. use QCoreApplication::aboutToQuit(), which if nothing else
-    // has at least better fitting name.
-    // See also KApplication::sessionSaving().
-    // This stuff should get changed somehow, so that it at least doesn't
-    // mess with session management.
-    /**
-       Called before the very last window is closed, either by the
-       user or indirectly by the session manager.
-
-       It is not recommended to do any user interaction in this
-       function other than indicating severe errors. Better ask the
-       user on queryClose() (see below).
-
-       A typical usage of queryExit() is to write configuration data back.
-       Note that the application may continue to run after queryExit()
-       (the user may have canceled a shutdown), so you should not do any cleanups
-       here. The purpose of queryExit() is purely to prepare the application
-       (with possible user interaction) so it can safely be closed later (without
-       user interaction).
-
-       If you need to do serious things on exit (like shutting a
-       dial-up connection down), connect to the signal
- QCoreApplication::aboutToQuit().
-
-       Default implementation returns @p true. Returning @p false will
-       cancel the exiting. In the latter case, the last window will
-       remain visible. If KApplication::sessionSaving() is true, refusing
-       the exit will also cancel KDE logout.
-
-       @see queryClose()
-       @see KApplication::sessionSaving()
-
-       @deprecated since 4.14 Do not reimplement queryExit. Either reimplement queryClose
-       (called for every window) or connect QCoreApplication::aboutToQuit() into a slot
-       of a non-gui object (not a KMainWindow, it will be deleted before that!).
-     */
-    virtual bool queryExit();
-
     /**
        Called before the window is closed, either by the user or indirectly by
        the session manager.
@@ -566,7 +502,6 @@ protected:
        its location might not be properly saved. In addition, the session shutdown
        may be canceled, in which case the document should remain open.
 
-       @see queryExit()
        @see KApplication::sessionSaving()
     */
     virtual bool queryClose();
@@ -690,7 +625,6 @@ protected:
 
     KMainWindowPrivate * const k_ptr;
 private:
-    Q_PRIVATE_SLOT(k_func(), void _k_shuttingDown())
     Q_PRIVATE_SLOT(k_func(), void _k_slotSettingsChanged(int))
     Q_PRIVATE_SLOT(k_func(), void _k_slotSaveAutoSaveSize())
 };
