@@ -19,8 +19,8 @@
 */
 
 #include "kmenu.h"
-#include "khbox.h"
 
+#include <QtCore/qmetaobject.h>
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
 #include <QtCore/QTimer>
@@ -28,8 +28,7 @@
 #include <QtGui/QCursor>
 #include <QtGui/QFontMetrics>
 #include <QtGui/QHBoxLayout>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QMenuItem>
+#include <QtGui/qevent.h>
 #include <QtGui/QLabel>
 #include <QtGui/QPainter>
 #include <QtGui/QStyle>
@@ -44,6 +43,7 @@
 static const char KMENU_TITLE[] = "kmenu_title";
 
 class KMenu::KMenuPrivate
+    : public QObject
 {
 public:
     KMenuPrivate (KMenu *_parent);
@@ -54,6 +54,30 @@ public:
     void showCtxMenu(const QPoint &pos);
     void skipTitles(QKeyEvent *event);
 
+    /**
+     * @internal
+     *
+     * This event filter which is installed
+     * on the title of the menu, which is a QToolButton. This will
+     * prevent clicks (what would change down and focus properties on
+     * the title) on the title of the menu.
+     *
+     * @author Rafael Fernández López <ereslibre@kde.org>
+     */
+    bool eventFilter(QObject *object, QEvent *event)
+    {
+        Q_UNUSED(object);
+
+        if (event->type() == QEvent::Paint ||
+            event->type() == QEvent::KeyPress ||
+            event->type() == QEvent::KeyRelease) {
+            return false;
+        }
+
+        event->accept();
+        return true;
+    }
+
     KMenu *parent;
 
     // variables for keyboard navigation
@@ -75,42 +99,6 @@ public:
     QMenu* ctxMenu;
     QPointer<QAction> highlightedAction;
 
-    class EventSniffer;
-    EventSniffer *eventSniffer;
-};
-
-/**
-  * @internal
-  *
-  * This event sniffer is an event filter which will be installed
-  * on the title of the menu, which is a QToolButton. This will
-  * prevent clicks (what would change down and focus properties on
-  * the title) on the title of the menu.
-  *
-  * @author Rafael Fernández López <ereslibre@kde.org>
-  */
-class KMenu::KMenuPrivate::EventSniffer
-    : public QObject
-{
-public:
-    EventSniffer(QObject *parent = 0)
-        : QObject(parent) { }
-
-    ~EventSniffer() { }
-
-    bool eventFilter(QObject *object, QEvent *event)
-    {
-        Q_UNUSED(object);
-
-        if (event->type() == QEvent::Paint ||
-            event->type() == QEvent::KeyPress ||
-            event->type() == QEvent::KeyRelease) {
-            return false;
-        }
-
-        event->accept();
-        return true;
-    }
 };
 
 KMenu::KMenuPrivate::KMenuPrivate (KMenu *_parent)
@@ -124,7 +112,6 @@ KMenu::KMenuPrivate::KMenuPrivate (KMenu *_parent)
     , keyboardModifiers(Qt::NoModifier)
     , ctxMenu(0)
     , highlightedAction(0)
-    , eventSniffer(new EventSniffer)
 {
     resetKeyboardVars();
     KAcceleratorManager::manage(parent);
@@ -133,7 +120,6 @@ KMenu::KMenuPrivate::KMenuPrivate (KMenu *_parent)
 KMenu::KMenuPrivate::~KMenuPrivate ()
 {
     delete ctxMenu;
-    delete eventSniffer;
 }
 
 
@@ -196,7 +182,7 @@ QAction* KMenu::addTitle(const QIcon &icon, const QString &text, QAction* before
     QWidgetAction *action = new QWidgetAction(this);
     action->setObjectName(KMENU_TITLE);
     QToolButton *titleButton = new QToolButton(this);
-    titleButton->installEventFilter(d->eventSniffer); // prevent clicks on the title of the menu
+    titleButton->installEventFilter(d); // prevent clicks on the title of the menu
     titleButton->setDefaultAction(buttonAction);
     titleButton->setDown(true); // prevent hover style changes in some styles
     titleButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
@@ -242,7 +228,6 @@ void KMenu::keyPressEvent(QKeyEvent* e)
         return;
     }
 
-    QAction* a = 0L;
     bool firstpass = true;
     QString keyString = e->text();
 
@@ -251,7 +236,7 @@ void KMenu::keyPressEvent(QKeyEvent* e)
     if (key == Qt::Key_Escape || key == Qt::Key_Return || key == Qt::Key_Enter
             || key == Qt::Key_Up || key == Qt::Key_Down || key == Qt::Key_Left
             || key == Qt::Key_Right || key == Qt::Key_F1 || key == Qt::Key_PageUp
-            || key == Qt::Key_PageDown || key == Qt::Key_Back || key == Qt::Key_Select) {
+            || key == Qt::Key_PageDown || key == Qt::Key_Select) {
 
         d->resetKeyboardVars();
         // continue event processing by QMenu
@@ -295,11 +280,6 @@ void KMenu::keyPressEvent(QKeyEvent* e)
 
             // clear active item
             setActiveAction(0L);
-
-        } else {
-            // the key sequence is not a null string
-            // therefore the lastHitAction is valid
-            a = d->lastHitAction;
         }
 
     } else if (key == Qt::Key_Backspace && menuAction()) {
@@ -312,7 +292,7 @@ void KMenu::keyPressEvent(QKeyEvent* e)
     d->keySeq += keyString;
     const int seqLen = d->keySeq.length();
 
-    foreach (a, actions()) {
+    foreach (QAction *a, actions()) {
         // don't search disabled entries
         if (!a->isEnabled())
             continue;
@@ -446,7 +426,7 @@ void KMenu::mousePressEvent(QMouseEvent* e)
         d->ctxMenu->hide();
     }
 
-    if( e->button() == Qt::MidButton)
+    if( e->button() == Qt::MiddleButton)
       return;
 
     QMenu::mousePressEvent(e);
@@ -458,11 +438,16 @@ void KMenu::mouseReleaseEvent(QMouseEvent* e)
     d->keyboardModifiers = e->modifiers();
     d->mouseButtons = e->buttons();
 
-    if ( e->button() == Qt::MidButton) {
+    if ( e->button() == Qt::MiddleButton) {
       if(activeAction() ) {
-        QMetaObject::invokeMethod(activeAction(), "triggered", Qt::DirectConnection,
-               Q_ARG(Qt::MouseButtons, e->button()),
+        const QMetaObject *metaObject = activeAction()->metaObject();
+        const int index = metaObject->indexOfMethod("triggered(Qt::MouseButtons,Qt::KeyboardModifiers)");
+        if (index != -1) {
+          const QMetaMethod method = metaObject->method(index);
+          method.invoke(activeAction(), Qt::DirectConnection,
+              Q_ARG(Qt::MouseButtons, e->button()),
               Q_ARG(Qt::KeyboardModifiers, QApplication::keyboardModifiers() ));
+        }
       }
       return;
     }
@@ -634,4 +619,4 @@ KMenuContext::KMenuContext(QPointer<KMenu> menu,QPointer<QAction> action)
 {
 }
 
-#include "kmenu.moc"
+#include "moc_kmenu.cpp"
