@@ -32,7 +32,7 @@
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QPainter>
-#include <QShowEvent>
+#include <QtGui/qevent.h>
 #include <QTimeLine>
 #include <QToolButton>
 #include <QStyle>
@@ -56,7 +56,7 @@ public:
     KMessageWidget::MessageType messageType;
     bool wordWrap;
     QList<QToolButton*> buttons;
-    QPixmap contentSnapShot;
+    QImage contentSnapShot;
 
     void createLayout();
     void updateSnapShot();
@@ -94,6 +94,10 @@ void KMessageWidgetPrivate::init(KMessageWidget *q_ptr)
 
     KAction* closeAction = KStandardAction::close(q, SLOT(animatedHide()), q);
 
+    // The default shortcut assigned by KStandardAction is Ctrl+W,
+    // which might conflict with application-specific shortcuts.
+    closeAction->setShortcut(QKeySequence());
+
     closeButton = new QToolButton(content);
     closeButton->setAutoRaise(true);
     closeButton->setDefaultAction(closeAction);
@@ -170,7 +174,7 @@ void KMessageWidgetPrivate::updateSnapShot()
     // window layouts to be activated. Calling this method from resizeEvent()
     // can lead to infinite recursion, see:
     // https://bugs.kde.org/show_bug.cgi?id=311336
-    contentSnapShot = QPixmap(content->size());
+    contentSnapShot = QImage(content->size(), QImage::Format_ARGB32_Premultiplied);
     contentSnapShot.fill(Qt::transparent);
     content->render(&contentSnapShot, QPoint(), QRegion(), QWidget::DrawChildren);
 }
@@ -340,17 +344,11 @@ void KMessageWidget::paintEvent(QPaintEvent* event)
     if (d->timeLine->state() == QTimeLine::Running) {
         QPainter painter(this);
         painter.setOpacity(d->timeLine->currentValue() * d->timeLine->currentValue());
-        painter.drawPixmap(0, 0, d->contentSnapShot);
+        painter.drawImage(0, 0, d->contentSnapShot);
+        painter.end();
     }
 }
 
-void KMessageWidget::showEvent(QShowEvent* event)
-{
-    // Keep this method here to avoid breaking binary compatibility:
-    // QFrame::showEvent() used to be reimplemented.
-    QFrame::showEvent(event);
-}
-
 bool KMessageWidget::wordWrap() const
 {
     return d->wordWrap;
@@ -457,4 +455,4 @@ void KMessageWidget::setIcon(const QIcon& icon)
 }
 
 
-#include "kmessagewidget.moc"
+#include "moc_kmessagewidget.cpp"
