@@ -98,6 +98,7 @@ class KDEUI_EXPORT KMessageWidget : public QFrame
     Q_PROPERTY(bool wordWrap READ wordWrap WRITE setWordWrap)
     Q_PROPERTY(bool closeButtonVisible READ isCloseButtonVisible WRITE setCloseButtonVisible)
     Q_PROPERTY(MessageType messageType READ messageType WRITE setMessageType)
+    Q_PROPERTY(QIcon icon READ icon WRITE setIcon)
 public:
     enum MessageType {
         Positive,
@@ -133,6 +134,12 @@ public:
 
     int heightForWidth(int width) const;
 
+    /**
+     * The icon shown on the left of the text. By default, no icon is shown.
+     * @since 4.11
+     */
+    QIcon icon() const;
+
 public Q_SLOTS:
     void setText(const QString &text);
 
@@ -154,6 +161,12 @@ public Q_SLOTS:
      */
     void animatedHide();
 
+    /**
+     * Define an icon to be shown on the left of the text
+     * @since 4.11
+     */
+    void setIcon(const QIcon &icon);
+
 Q_SIGNALS:
     /**
      * This signal is emitted when the user clicks a link in the text label.
@@ -164,6 +177,15 @@ Q_SIGNALS:
      */
     void linkActivated(const QString& contents);
 
+    /**
+     * This signal is emitted when the user hovers over a link in the text label.
+     * The URL referred to by the href anchor is passed in contents.
+     * @param contents text of the href anchor
+     * @see QLabel::linkHovered()
+     * @since 4.11
+     */
+    void linkHovered(const QString& contents);
+
 protected:
     void paintEvent(QPaintEvent *event);
 
@@ -171,8 +193,6 @@ protected:
 
     void resizeEvent(QResizeEvent *event);
 
-    void showEvent(QShowEvent *event);
-
 private:
     KMessageWidgetPrivate *const d;
     friend class KMessageWidgetPrivate;
