@@ -24,15 +24,15 @@
 
 #include "kmultitabbar.h"
 #include "kmultitabbar_p.h"
-#include "kmultitabbar.moc"
-#include "kmultitabbar_p.moc"
+#include "moc_kmultitabbar.cpp"
+#include "moc_kmultitabbar_p.cpp"
 
-#include <QtGui/QActionEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QLayout>
 #include <QtGui/QPainter>
 #include <QtGui/QFontMetrics>
 #include <QtGui/QStyle>
-#include <QStyleOptionButton>
+#include <QtGui/qstyleoption.h>
 
 #include <kiconloader.h>
 #include <kdebug.h>
@@ -143,7 +143,7 @@ void KMultiTabBarInternal::setPosition(enum KMultiTabBar::KMultiTabBarPosition p
 
 KMultiTabBarButton::KMultiTabBarButton(const QPixmap& pic, const QString& text,
                                        int id, QWidget *parent)
-	: QPushButton(QIcon(pic), text, parent), m_id(id), d(0)
+	: QPushButton(QIcon(pic), text, parent), m_id(id)
 {
 	connect(this,SIGNAL(clicked()),this,SLOT(slotClicked()));
 
@@ -175,13 +175,13 @@ int KMultiTabBarButton::id() const
 
 void KMultiTabBarButton::hideEvent( QHideEvent* he) {
 	QPushButton::hideEvent(he);
-	KMultiTabBar *tb=dynamic_cast<KMultiTabBar*>(parentWidget());
+	KMultiTabBar *tb=qobject_cast<KMultiTabBar*>(parentWidget());
 	if (tb) tb->updateSeparator();
 }
 
 void KMultiTabBarButton::showEvent( QShowEvent* he) {
 	QPushButton::showEvent(he);
-	KMultiTabBar *tb=dynamic_cast<KMultiTabBar*>(parentWidget());
+	KMultiTabBar *tb=qobject_cast<KMultiTabBar*>(parentWidget());
 	if (tb) tb->updateSeparator();
 }
 
