@@ -23,22 +23,20 @@
 #include "knuminput.h"
 
 #include <config.h>
-#ifdef HAVE_LIMITS_H
-#include <limits.h>
-#endif
-
-#include <cmath>
 
 #include <QtGui/QApplication>
 #include <QtGui/QLabel>
 #include <QtGui/QLineEdit>
-#include <QtGui/QResizeEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QSlider>
 
 #include <kdebug.h>
 #include <kdialog.h>
 #include <klocalizedstring.h>
 
+#include <limits.h>
+#include <cmath>
+
 static inline int calcDiffByTen(int x, int y)
 {
     // calculate ( x - y ) / 10 without overflowing ints:
@@ -95,14 +93,6 @@ KNumInput::KNumInput(QWidget* parent)
     setFocusPolicy(Qt::StrongFocus);
 }
 
-#ifndef KDE_NO_DEPRECATED
-KNumInput::KNumInput(QWidget* parent, KNumInput* below)
-    : QWidget(parent), d(new KNumInputPrivate(this, below))
-{
-    setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
-    setFocusPolicy(Qt::StrongFocus);
-}
-#endif
 
 KNumInput::~KNumInput()
 {
@@ -335,14 +325,6 @@ public:
 };
 
 
-#ifndef KDE_NO_DEPRECATED
-KIntNumInput::KIntNumInput(KNumInput* below, int val, QWidget *parent, int _base)
-    : KNumInput(parent, below)
-    , d(new KIntNumInputPrivate(this, val))
-{
-    init(val, _base);
-}
-#endif
 
 KIntNumInput::KIntNumInput(QWidget *parent)
     : KNumInput(parent)
@@ -470,13 +452,6 @@ void KIntNumInput::setRange(int lower, int upper, int singleStep)
     setSliderEnabled(priv->slider);
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KIntNumInput::setRange(int lower, int upper, int singleStep, bool slider)
-{
-    setRange(lower, upper, singleStep);
-    setSliderEnabled(slider);
-}
-#endif
 
 void KIntNumInput::setMinimum(int min)
 {
@@ -710,16 +685,6 @@ KDoubleNumInput::KDoubleNumInput(double lower, double upper, double value, QWidg
     init(value, lower, upper, singleStep, precision);
 }
 
-#ifndef KDE_NO_DEPRECATED
-KDoubleNumInput::KDoubleNumInput(KNumInput *below,
-                                 double lower, double upper, double value, QWidget *parent,
-                                 double singleStep, int precision)
-    : KNumInput(parent, below)
-    , d(new KDoubleNumInputPrivate(value))
-{
-    init(value, lower, upper, singleStep, precision);
-}
-#endif
 
 KDoubleNumInput::~KDoubleNumInput()
 {
@@ -1085,4 +1050,4 @@ void KDoubleNumInput::setExponentRatio(double dbl)
 }
 
 
-#include "knuminput.moc"
+#include "moc_knuminput.cpp"
