@@ -38,7 +38,7 @@
 #include <stdlib.h>
 #include <QtGui/QCursor>
 #include <QtGui/QApplication>
-#include <QMouseEvent>
+#include <QtGui/qevent.h>
 #include "kactioncollection.h"
 
 class KPixmapRegionSelectorWidget::Private
@@ -138,8 +138,6 @@ void KPixmapRegionSelectorWidget::setSelectedRegion(const QRect &rect)
    {
       d->m_selectedRegion=rect;
       d->updatePixmap();
-
-      QRect r=unzoomedSelectedRegion();
    }
 }
 
@@ -525,4 +523,4 @@ void KPixmapRegionSelectorWidget::setMaximumWidgetSize(int width, int height)
    resize(d->m_label->width(), d->m_label->height());
 }
 
-#include "kpixmapregionselectorwidget.moc"
+#include "moc_kpixmapregionselectorwidget.cpp"
