@@ -19,12 +19,13 @@
 #include "ksqueezedtextlabel.h"
 #include <kdebug.h>
 #include <klocale.h>
-#include <QContextMenuEvent>
+#include <QtGui/qevent.h>
 #include <kaction.h>
 #include <QMenu>
 #include <QClipboard>
 #include <QApplication>
 #include <QMimeData>
+#include <QTextDocument>
 #include <kglobalsettings.h>
 
 class KSqueezedTextLabelPrivate
@@ -175,7 +176,6 @@ void KSqueezedTextLabel::contextMenuEvent(QContextMenuEvent* ev)
 
 void KSqueezedTextLabel::mouseReleaseEvent(QMouseEvent* ev)
 {
-#if QT_VERSION >= 0x040700
     if (QApplication::clipboard()->supportsSelection() &&
         textInteractionFlags() != Qt::NoTextInteraction &&
         ev->button() == Qt::LeftButton &&
@@ -191,15 +191,22 @@ void KSqueezedTextLabel::mouseReleaseEvent(QMouseEvent* ev)
             // charsAfterSelection = 1 (z)
             // final selection length= 26 - 2 - 1 = 23
             const int start = selectionStart();
-            const int charsAfterSelection = text().length() - start - selectedText().length();
-            txt = d->fullText.mid(selectionStart(), d->fullText.length() - start - charsAfterSelection);
+            int charsAfterSelection = text().length() - start - selectedText().length();
+            txt = d->fullText;
+            // Strip markup tags
+            if (textFormat() == Qt::RichText
+                || (textFormat() == Qt::AutoText && Qt::mightBeRichText(txt))) {
+                txt.replace(QRegExp("<[^>]*>"), "");
+                // account for stripped characters
+                charsAfterSelection -= d->fullText.length() - txt.length();
+            }
+            txt = txt.mid(selectionStart(), txt.length() - start - charsAfterSelection);
         }
         QApplication::clipboard()->setText(txt, QClipboard::Selection);
     } else
-#endif
     {
         QLabel::mouseReleaseEvent(ev);
     }
 }
 
-#include "ksqueezedtextlabel.moc"
+#include "moc_ksqueezedtextlabel.cpp"
