@@ -22,22 +22,17 @@
 #include "ktabwidget.h"
 
 #include <QtGui/QApplication>
-#include <QtGui/QDragMoveEvent>
-#include <QtGui/QDropEvent>
-#include <QtGui/QMouseEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QStyle>
 #include <QtGui/QStyleOption>
 #include <QtGui/QTextDocument>
-#include <QtGui/QWheelEvent>
 #include <QtCore/QList>
 
 #include <ksharedconfig.h>
 #include <kiconloader.h>
 #include <kstringhandler.h>
 #include <kdebug.h>
-
 #include <ktabbar.h>
-
 #include <kconfiggroup.h>
 
 class KTabWidget::Private
@@ -78,6 +73,8 @@ class KTabWidget::Private
     void resizeTabs( int changedTabIndex = -1 );
     void updateTab( int index );
     void removeTab( int index );
+
+    void slotTabMoved( int from, int to );
 };
 
 bool KTabWidget::Private::isEmptyTabbarSpace( const QPoint &point ) const
@@ -218,7 +215,17 @@ void KTabWidget::Private::updateTab( int index )
     m_parent->QTabWidget::setTabText( index, title );
 }
 
-KTabWidget::KTabWidget( QWidget *parent, Qt::WFlags flags )
+void KTabWidget::Private::slotTabMoved(int from, int to)
+{
+    /* called from Qt slot when Qt has moved the tab, so we only
+       need to adjust the m_tabNames list */
+    if (m_automaticResizeTabs) {
+        QString movedName = m_tabNames.takeAt(from);
+        m_tabNames.insert(to, movedName);
+    }
+}
+
+KTabWidget::KTabWidget( QWidget *parent, Qt::WindowFlags flags )
   : QTabWidget( parent ),
     d( new Private( this ) )
 {
@@ -227,18 +234,16 @@ KTabWidget::KTabWidget( QWidget *parent, Qt::WFlags flags )
   setObjectName( "tabbar" );
   setAcceptDrops( true );
 
-  connect(tabBar(), SIGNAL(contextMenu( int, const QPoint & )), SLOT(contextMenu( int, const QPoint & )));
-  connect(tabBar(), SIGNAL(tabDoubleClicked( int )), SLOT(mouseDoubleClick( int )));
+  connect(tabBar(), SIGNAL(contextMenu(int,QPoint)), SLOT(contextMenu(int,QPoint)));
+  connect(tabBar(), SIGNAL(tabDoubleClicked(int)), SLOT(mouseDoubleClick(int)));
   connect(tabBar(), SIGNAL(newTabRequest()), this, SIGNAL(mouseDoubleClick())); // #185487
-  connect(tabBar(), SIGNAL(mouseMiddleClick( int )), SLOT(mouseMiddleClick( int )));
-  connect(tabBar(), SIGNAL(initiateDrag( int )), SLOT(initiateDrag( int )));
-  connect(tabBar(), SIGNAL(testCanDecode(const QDragMoveEvent *, bool & )), SIGNAL(testCanDecode(const QDragMoveEvent *, bool & )));
-  connect(tabBar(), SIGNAL(receivedDropEvent( int, QDropEvent * )), SLOT(receivedDropEvent( int, QDropEvent * )));
-  connect(tabBar(), SIGNAL(moveTab( int, int )), SLOT(moveTab( int, int )));
-  connect(tabBar(), SIGNAL(tabCloseRequested( int )), SLOT(closeRequest( int )));
-#ifndef QT_NO_WHEELEVENT
-  connect(tabBar(), SIGNAL(wheelDelta( int )), SLOT(wheelDelta( int )));
-#endif
+  connect(tabBar(), SIGNAL(mouseMiddleClick(int)), SLOT(mouseMiddleClick(int)));
+  connect(tabBar(), SIGNAL(initiateDrag(int)), SLOT(initiateDrag(int)));
+  connect(tabBar(), SIGNAL(testCanDecode(const QDragMoveEvent*,bool&)), SIGNAL(testCanDecode(const QDragMoveEvent*,bool&)));
+  connect(tabBar(), SIGNAL(receivedDropEvent(int,QDropEvent*)), SLOT(receivedDropEvent(int,QDropEvent*)));
+  connect(tabBar(), SIGNAL(moveTab(int,int)), SLOT(moveTab(int,int)));
+  connect(tabBar(), SIGNAL(tabMoved(int,int)), SLOT(slotTabMoved(int,int)));
+  connect(tabBar(), SIGNAL(tabCloseRequested(int)), SLOT(closeRequest(int)));
 }
 
 KTabWidget::~KTabWidget()
@@ -306,31 +311,10 @@ QColor KTabWidget::tabTextColor( int index ) const
   return tabBar()->tabTextColor( index );
 }
 
-void KTabWidget::setTabReorderingEnabled( bool on)
-{
-  static_cast<KTabBar*>(tabBar())->setTabReorderingEnabled( on );
-}
-
-bool KTabWidget::isTabReorderingEnabled() const
-{
-  return static_cast<KTabBar*>(tabBar())->isTabReorderingEnabled();
-}
-
-void KTabWidget::setTabCloseActivatePrevious( bool previous)
-{
-  static_cast<KTabBar*>(tabBar())->setTabCloseActivatePrevious( previous );
-}
-
-bool KTabWidget::tabCloseActivatePrevious() const
-{
-  return static_cast<KTabBar*>(tabBar())->tabCloseActivatePrevious();
-}
-
 int KTabWidget::tabBarWidthForMaxChars( int maxLength )
 {
-  int hframe, overlap;
+  int hframe;
   hframe  = tabBar()->style()->pixelMetric( QStyle::PM_TabBarTabHSpace, 0L, tabBar() );
-  overlap = tabBar()->style()->pixelMetric( QStyle::PM_TabBarTabOverlap, 0L, tabBar() );
 
   const QFontMetrics fm = tabBar()->fontMetrics();
   int x = 0;
@@ -343,10 +327,6 @@ int KTabWidget::tabBarWidthForMaxChars( int maxLength )
     if ( !tabBar()->tabIcon( i ).isNull() ) {
       iw = tabBar()->tabIcon( i ).pixmap( style()->pixelMetric( QStyle::PM_SmallIconSize ), QIcon::Normal ).width() + 4;
     }
-    if ( isCloseButtonEnabled() ) {
-      // FIXME: how to get the size of the close button directly from the tabBar()?
-      iw += KIconLoader::SizeSmall * 3 / 2;
-    }
     x += ( tabBar()->style()->sizeFromContents( QStyle::CT_TabBarTab, 0L,
          QSize( qMax( lw + hframe + iw, QApplication::globalStrut().width() ), 0 ),
          this ) ).width();
@@ -448,13 +428,10 @@ void KTabWidget::dropEvent( QDropEvent *event )
 #ifndef QT_NO_WHEELEVENT
 void KTabWidget::wheelEvent( QWheelEvent *event )
 {
-  if ( event->orientation() == Qt::Horizontal )
-    return;
-
   if ( d->isEmptyTabbarSpace( event->pos() ) )
-    wheelDelta( event->delta() );
+    QCoreApplication::sendEvent( tabBar(), event );
   else
-    event->ignore();
+    QTabWidget::wheelEvent( event );
 }
 
 void KTabWidget::wheelDelta( int delta )
@@ -501,7 +478,7 @@ void KTabWidget::mousePressEvent( QMouseEvent *event )
 
 void KTabWidget::mouseReleaseEvent( QMouseEvent *event )
 {
-  if ( event->button() == Qt::MidButton ) {
+  if ( event->button() == Qt::MiddleButton ) {
     if ( d->isEmptyTabbarSpace( event->pos() ) ) {
       emit( mouseMiddleClick() );
       return;
@@ -536,19 +513,6 @@ void KTabWidget::mouseMiddleClick( int index )
   emit( mouseMiddleClick( widget( index ) ) );
 }
 
-// Helper: return true if w is inside parent (directly or indirectly)
-static bool isWidgetInside(QWidget* w, QWidget* parent)
-{
-  while (w) {
-      if (w == parent)
-          return true;
-      if (w->isWindow())
-          break;
-      w = w->parentWidget();
-  }
-  return false;
-}
-
 void KTabWidget::moveTab( int from, int to )
 {
   setUpdatesEnabled(false);
@@ -570,7 +534,7 @@ void KTabWidget::moveTab( int from, int to )
 
   // Don't lose focus due to moving the tab (#159295)
   // (removeTab hides the widget, which gives focus to the "next in chain", could be anything)
-  if (isWidgetInside(fw, w)) {
+  if (w->isAncestorOf(fw)) {
       fw->setFocus();
   }
 
@@ -588,20 +552,6 @@ void KTabWidget::moveTab( int from, int to )
 
   setUpdatesEnabled(true);
 
-  emit ( movedTab( from, to ) );
-}
-
-void KTabWidget::removePage( QWidget *widget )
-{
-  // not just calling removeTab() because that one is also virtual.
-  const int index = indexOf(widget);
-  if ( d->m_automaticResizeTabs ) {
-    setUpdatesEnabled(false);
-    d->removeTab(index);
-    setUpdatesEnabled(true);
-  } else {
-    d->removeTab(index);
-  }
 }
 
 void KTabWidget::removeTab( int index )
@@ -616,40 +566,6 @@ void KTabWidget::removeTab( int index )
   }
 }
 
-void KTabWidget::setHoverCloseButton( bool button )
-{
-  // deprecated
-  setTabsClosable( button );
-}
-
-bool KTabWidget::hoverCloseButton() const
-{
-  // deprecated
-  return false;
-}
-
-void KTabWidget::setHoverCloseButtonDelayed( bool delayed )
-{
-  // deprecated
-  Q_UNUSED( delayed );
-}
-
-bool KTabWidget::hoverCloseButtonDelayed() const
-{
-  // deprecated
-  return tabsClosable();
-}
-
-void KTabWidget::setCloseButtonEnabled( bool enable )
-{
-  static_cast<KTabBar*>( tabBar() )->setTabsClosable( enable );
-}
-
-bool KTabWidget::isCloseButtonEnabled() const
-{
-  return static_cast<KTabBar*>( tabBar() )->tabsClosable();
-}
-
 void KTabWidget::setAutomaticResizeTabs( bool enabled )
 {
   if ( d->m_automaticResizeTabs == enabled )
@@ -698,9 +614,4 @@ void KTabWidget::tabRemoved( int idx )
 // d->m_tabNames is now updated in KTabWidget::Private::removeTab()
 }
 
-/* This function is kept only for BC reasons, it is not useful anymore */
-void KTabWidget::currentChanged( int )
-{
-}
-
-#include "ktabwidget.moc"
+#include "moc_ktabwidget.cpp"
