@@ -20,24 +20,21 @@
 */
 
 #include "ktextedit.h"
-#include <ktoolinvocation.h>
-#include <kdebug.h>
 
 #include <QApplication>
 #include <QClipboard>
-#include <QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QMenu>
 #include <QPainter>
 #include <QScrollBar>
 #include <QTextCursor>
 #include <QTextDocumentFragment>
-#include <QDBusInterface>
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
 
 #include <configdialog.h>
 #include <dialog.h>
 #include "backgroundchecker.h"
+#include <kdebug.h>
+#include <kspeech.h>
 #include <kaction.h>
 #include <kcursor.h>
 #include <kglobalsettings.h>
@@ -128,7 +125,6 @@ class KTextEdit::Private
 
     void checkSpelling(bool force);
     KTextEdit *parent;
-    KTextEditSpellInterface *spellInterface;
     QAction *autoSpellCheckAction;
     QAction *allowTab;
     QAction *spellCheckAction;
@@ -308,7 +304,6 @@ QRect KTextEdit::Private::clickMessageRect() const
 
 void KTextEdit::Private::init()
 {
-    spellInterface = 0;
     KCursor::setAutoHideCursor(parent, true, false);
     parent->connect(parent, SIGNAL(languageChanged(QString)),
                     parent, SLOT(setSpellCheckingLanguage(QString)));
@@ -481,9 +476,6 @@ bool KTextEdit::Private::handleShortcut(const QKeyEvent* event)
   } else if (findReplaceEnabled && KStandardShortcut::findNext().contains(key)) {
       parent->slotFindNext();
       return true;
-  } else if (findReplaceEnabled && KStandardShortcut::findPrev().contains(key)) {
-      parent->slotFindPrevious();
-      return true;
   } else if (findReplaceEnabled && KStandardShortcut::replace().contains(key)) {
       if (!parent->isReadOnly())
           parent->slotReplace();
@@ -511,7 +503,7 @@ void KTextEdit::deleteWordBack()
 
 void KTextEdit::deleteWordForward()
 {
-  deleteWord(textCursor(), QTextCursor::WordRight);
+  deleteWord(textCursor(), QTextCursor::NextWord);
 }
 
 QMenu *KTextEdit::mousePopupMenu()
@@ -563,19 +555,15 @@ QMenu *KTextEdit::mousePopupMenu()
   if (d->findReplaceEnabled) {
       KAction *findAction = KStandardAction::find(this, SLOT(slotFind()), popup);
       KAction *findNextAction = KStandardAction::findNext(this, SLOT(slotFindNext()), popup);
-      KAction *findPrevAction = KStandardAction::findPrev(this, SLOT(slotFindPrevious()), popup);
       if (emptyDocument) {
           findAction->setEnabled(false);
           findNextAction->setEnabled(false);
-          findPrevAction->setEnabled(false);
       } else {
           findNextAction->setEnabled(d->find != 0);
-          findPrevAction->setEnabled(d->find != 0);
       }
       popup->addSeparator();
       popup->addAction(findAction);
       popup->addAction(findNextAction);
-      popup->addAction(findPrevAction);
 
       if (!isReadOnly()) {
           KAction *replaceAction = KStandardAction::replace(this, SLOT(slotReplace()), popup);
@@ -585,33 +573,25 @@ QMenu *KTextEdit::mousePopupMenu()
           popup->addAction(replaceAction);
       }
   }
-  popup->addSeparator();
-  QAction *speakAction = popup->addAction(i18n("Speak Text"));
-  speakAction->setIcon(KIcon("preferences-desktop-text-to-speech"));
-  speakAction->setEnabled(!emptyDocument );
-  connect( speakAction, SIGNAL(triggered(bool)), this, SLOT(slotSpeakText()) );
+  if (KSpeech::isSupported()) {
+    popup->addSeparator();
+    QAction *speakAction = popup->addAction(i18n("Speak Text"));
+    speakAction->setIcon(KIcon("preferences-desktop-text-to-speech"));
+    speakAction->setEnabled(!emptyDocument );
+    connect( speakAction, SIGNAL(triggered(bool)), this, SLOT(slotSpeakText()) );
+  }
   return popup;
 }
 
 void KTextEdit::slotSpeakText()
 {
-    // If KTTSD not running, start it.
-    if (!QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.kttsd"))
-    {
-        QString error;
-        if (KToolInvocation::startServiceByDesktopName("kttsd", QStringList(), &error))
-        {
-            KMessageBox::error(this, i18n( "Starting Jovie Text-to-Speech Service Failed"), error );
-            return;
-        }
-    }
-    QDBusInterface ktts("org.kde.kttsd", "/KSpeech", "org.kde.KSpeech");
     QString text;
     if(textCursor().hasSelection())
         text = textCursor().selectedText();
     else
         text = toPlainText();
-    ktts.asyncCall("say", text, 0);
+    KSpeech kspeech(this);
+    kspeech.say(text);
 }
 
 void KTextEdit::contextMenuEvent(QContextMenuEvent *event)
@@ -662,12 +642,8 @@ void KTextEdit::contextMenuEvent(QContextMenuEvent *event)
     // If the user clicked somewhere else, move the cursor there.
     // If the user clicked on a misspelled word, select that word.
     // Same behavior as in OpenOffice Writer.
-    bool inQuote = false;
-    if (d->spellInterface &&
-        !d->spellInterface->shouldBlockBeSpellChecked(cursorAtMouse.block().text()))
-        inQuote = true;
     if (!selectedWordClicked) {
-        if (wordIsMisspelled && !inQuote)
+        if (wordIsMisspelled)
             setTextCursor(wordSelectCursor);
         else
             setTextCursor(cursorAtMouse);
@@ -676,10 +652,14 @@ void KTextEdit::contextMenuEvent(QContextMenuEvent *event)
 
     // Use standard context menu for already selected words, correctly spelled
     // words and words inside quotes.
-    if (!wordIsMisspelled || selectedWordClicked || inQuote) {
-        QMetaObject::invokeMethod(this, "mousePopupMenuImplementation", Q_ARG(QPoint, event->globalPos()));
-    }
-    else {
+    if (!wordIsMisspelled || selectedWordClicked) {
+        QMenu *popup = mousePopupMenu();
+        if (popup) {
+            aboutToShowContextMenu(popup);
+            popup->exec(event->globalPos());
+            delete popup;
+        }
+    } else {
         QMenu menu; //don't use KMenu here we don't want auto management accelerator
 
         //Add the suggestions to the menu
@@ -751,23 +731,15 @@ void KTextEdit::setHighlighter(Sonnet::Highlighter *_highLighter)
 
 void KTextEdit::setCheckSpellingEnabled(bool check)
 {
-    if (d->spellInterface)
-        d->spellInterface->setSpellCheckingEnabled(check);
-    else
-        setCheckSpellingEnabledInternal(check);
-}
+    emit checkSpellingChanged( check );
+    if ( check == d->checkSpellingEnabled )
+        return;
 
-void KTextEdit::setCheckSpellingEnabledInternal( bool check )
-{
-  emit checkSpellingChanged( check );
-  if ( check == d->checkSpellingEnabled )
-    return;
+    // From the above statment we know know that if we're turning checking
+    // on that we need to create a new highlighter and if we're turning it
+    // off we should remove the old one.
 
-  // From the above statment we know know that if we're turning checking
-  // on that we need to create a new highlighter and if we're turning it
-  // off we should remove the old one.
-
-  d->checkSpellingEnabled = check;
+    d->checkSpellingEnabled = check;
     if ( check )
     {
         if ( hasFocus() ) {
@@ -793,15 +765,7 @@ void KTextEdit::focusInEvent( QFocusEvent *event )
 
 bool KTextEdit::checkSpellingEnabled() const
 {
-    if (d->spellInterface)
-      return d->spellInterface->isSpellCheckingEnabled();
-    else
-      return checkSpellingEnabledInternal();
-}
-
-bool KTextEdit::checkSpellingEnabledInternal() const
-{
-  return d->checkSpellingEnabled;
+    return d->checkSpellingEnabled;
 }
 
 void KTextEdit::setReadOnly( bool readOnly )
@@ -976,18 +940,6 @@ void KTextEdit::slotDoFind()
     slotFindNext();
 }
 
-void KTextEdit::slotFindPrevious()
-{
-    if (!d->find) {
-        return;
-    }
-    const long oldOptions = d->find->options();
-    d->find->setOptions(oldOptions ^ KFind::FindBackwards);
-    slotFindNext();
-    if (d->find) {
-        d->find->setOptions(oldOptions);
-    }
-}
 
 void KTextEdit::slotFindNext()
 {
@@ -1058,15 +1010,9 @@ void KTextEdit::showTabAction( bool show )
     d->showTabAction = show;
 }
 
-void KTextEdit::setSpellInterface(KTextEditSpellInterface *spellInterface)
-{
-    d->spellInterface = spellInterface;
-}
-
 bool KTextEdit::Private::overrideShortcut(const QKeyEvent* event)
 {
   const int key = event->key() | event->modifiers();
-  qDebug() << key;
 
   if ( KStandardShortcut::copy().contains( key ) ) {
     return true;
@@ -1104,8 +1050,6 @@ bool KTextEdit::Private::overrideShortcut(const QKeyEvent* event)
       return true;
   } else if (findReplaceEnabled && KStandardShortcut::findNext().contains(key)) {
       return true;
-  } else if (findReplaceEnabled && KStandardShortcut::findPrev().contains(key)) {
-      return true;
   } else if (findReplaceEnabled && KStandardShortcut::replace().contains(key)) {
       return true;
   } else if (event->matches(QKeySequence::SelectAll)) { // currently missing in QTextEdit
@@ -1170,24 +1114,9 @@ void KTextEdit::paintEvent(QPaintEvent *ev)
     }
 }
 
-void KTextEdit::focusOutEvent(QFocusEvent *ev)
-{
-    QTextEdit::focusOutEvent(ev);
-}
-
 void KTextEdit::showAutoCorrectButton(bool show)
 {
     d->showAutoCorrectionButton = show;
 }
 
-void KTextEdit::mousePopupMenuImplementation(const QPoint& pos)
-{
-    QMenu *popup = mousePopupMenu();
-    if ( popup ) {
-       aboutToShowContextMenu(popup);
-       popup->exec( pos );
-       delete popup;
-    }
-}
-
-#include "ktextedit.moc"
+#include "moc_ktextedit.cpp"
