@@ -32,14 +32,13 @@
 #include <QtGui/QDesktopWidget>
 #include <QtGui/QFrame>
 #include <QtGui/QLayout>
-#include <QtGui/QMouseEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QToolButton>
-#include <QtXml/QDomElement>
+#include <QtXml/qdom.h>
 
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <kapplication.h>
-#include <kauthorized.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kedittoolbar.h>
@@ -92,9 +91,6 @@ class KToolBar::Private
     Private(KToolBar *qq)
       : q(qq),
         isMainToolBar(false),
-#ifndef KDE_NO_DEPRECATED
-        enableContext(true),
-#endif
         unlockedMovable(true),
         contextOrient(0),
         contextMode(0),
@@ -148,9 +144,6 @@ class KToolBar::Private
 
     KToolBar *q;
     bool isMainToolBar : 1;
-#ifndef KDE_NO_DEPRECATED
-    bool enableContext : 1;
-#endif
     bool unlockedMovable : 1;
     static bool s_editable;
     static bool s_locked;
@@ -252,10 +245,7 @@ void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
              q->mainWindow(), SLOT(setSettingsDirty()));
   }
 
-  if (!KAuthorized::authorize("movable_toolbars"))
-    q->setMovable(false);
-  else
-    q->setMovable(!KToolBar::toolBarsLocked());
+  q->setMovable(!KToolBar::toolBarsLocked());
 
   connect(q, SIGNAL(movableChanged(bool)),
            q, SLOT(slotMovableChanged(bool)));
@@ -811,26 +801,12 @@ KToolBar::~KToolBar()
   delete d;
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KToolBar::setContextMenuEnabled(bool enable)
-{
-  d->enableContext = enable;
-}
-#endif
 
-#ifndef KDE_NO_DEPRECATED
-bool KToolBar::contextMenuEnabled() const
-{
-  return d->enableContext;
-}
-#endif
 
 void KToolBar::saveSettings(KConfigGroup &cg)
 {
     Q_ASSERT(!cg.name().isEmpty());
 
-    cg.deleteEntry("Hidden"); // remove old key to avoid bugs from the compat code in applySettings. KDE5: remove.
-
     const int currentIconSize = iconSize().width();
     //kDebug() << objectName() << currentIconSize << d->iconSizeSettings.toString() << "defaultValue=" << d->iconSizeSettings.defaultValue();
     if (!cg.hasDefault("IconSize") && currentIconSize == d->iconSizeSettings.defaultValue()) {
@@ -851,13 +827,6 @@ void KToolBar::saveSettings(KConfigGroup &cg)
     }
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KToolBar::setXMLGUIClient(KXMLGUIClient *client)
-{
-    d->xmlguiClients.clear();
-    d->xmlguiClients << client;
-}
-#endif
 
 void KToolBar::addXMLGUIClient( KXMLGUIClient *client )
 {
@@ -869,25 +838,6 @@ void KToolBar::removeXMLGUIClient( KXMLGUIClient *client )
     d->xmlguiClients.remove(client);
 }
 
-void KToolBar::contextMenuEvent(QContextMenuEvent* event)
-{
-#ifndef KDE_NO_DEPRECATED
-    if (mainWindow() && d->enableContext) {
-        QPointer<KToolBar> guard(this);
-        const QPoint globalPos = event->globalPos();
-        d->contextMenu(globalPos)->exec(globalPos);
-
-        // "Configure Toolbars" recreates toolbars, so we might not exist anymore.
-        if (guard) {
-            d->slotContextAboutToHide();
-        }
-        return;
-    }
-#endif
-
-    QToolBar::contextMenuEvent(event);
-}
-
 Qt::ToolButtonStyle KToolBar::toolButtonStyleSetting()
 {
     KConfigGroup group(KGlobal::config(), "Toolbar style");
@@ -1036,22 +986,9 @@ void KToolBar::saveState(QDomElement &current) const
 }
 
 // called by KMainWindow::applyMainWindowSettings to read from the user settings
-void KToolBar::applySettings(const KConfigGroup &cg, bool forceGlobal)
+void KToolBar::applySettings(const KConfigGroup &cg)
 {
     Q_ASSERT(!cg.name().isEmpty());
-    Q_UNUSED(forceGlobal); // KDE5: remove
-
-    // a small leftover from kde3: separate bool for hidden/shown. But it's also part of saveMainWindowSettings,
-    // it is not really useful anymore, except in the unlikely case where someone would call this by hand.
-    // KDE5: remove the block below
-    if (cg.hasKey("Hidden")) {
-        const bool hidden = cg.readEntry("Hidden", false);
-        if (hidden)
-            hide();
-        else {
-            show();
-        }
-    }
 
     if (cg.hasKey("IconSize")) {
         d->iconSizeSettings[Level_UserSettings] = cg.readEntry("IconSize", 0);
@@ -1081,8 +1018,6 @@ int KToolBar::iconSizeDefault() const
 
 void KToolBar::slotMovableChanged(bool movable)
 {
-  if (movable && !KAuthorized::authorize("movable_toolbars"))
-    setMovable(false);
 }
 
 void KToolBar::dragEnterEvent(QDragEnterEvent *event)
@@ -1099,7 +1034,7 @@ void KToolBar::dragEnterEvent(QDragEnterEvent *event)
 
     foreach (const QString& actionName, actionNames) {
       foreach (KActionCollection* ac, KActionCollection::allCollections()) {
-        QAction* newAction = ac->action(actionName.toAscii().constData());
+        QAction* newAction = ac->action(actionName.toLatin1().constData());
         if (newAction) {
           d->actionsBeingDragged.append(newAction);
           break;
@@ -1297,7 +1232,7 @@ bool KToolBar::eventFilter(QObject * watched, QEvent * event)
             // Handle MMB on toolbar buttons
             if (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonRelease) {
                 QMouseEvent* me = static_cast<QMouseEvent*>(event);
-                if (me->button() == Qt::MidButton /*&&
+                if (me->button() == Qt::MiddleButton /*&&
                                                  act->receivers(SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)))*/) {
                     QAction* act = tbActions.first();
                     if (me->type() == QEvent::MouseButtonPress)
@@ -1430,4 +1365,4 @@ bool KToolBar::toolBarsLocked()
     return KToolBar::Private::s_locked;
 }
 
-#include "ktoolbar.moc"
+#include "moc_ktoolbar.cpp"
