@@ -26,7 +26,7 @@
 
 #include <kdeui_export.h>
 #include <QtCore/QObject>
-#include <QtGui/QWidgetList> //For WId
+#include <QtGui/qwindowdefs.h> //For WId
 #include <netwm_def.h>
 #include <kwindowinfo.h>
 
@@ -477,6 +477,31 @@ public:
      */
     static void doNotManage( const QString& title );
 
+    /**
+     * Allows a window from another process to raise and activate itself.
+     * Depending on the window manager, the grant may only be temporary,
+     * or for a single activation, and it may require the current process
+     * to be the "foreground" one" (ie. the process with the input focus).
+     *
+     * You should call this function before executing actions that may trigger
+     * the showing of a window or dialog in another process, e.g. a dbus signal
+     * or function call, or any other inter-process notification mechanism.
+     *
+     * This is mostly used on Windows, where windows are not allowed to be raised
+     * and activated if their process is not the foreground one, but it may also
+     * apply to other window managers.
+     *
+     * @param pid if specified, the grant only applies to windows belonging to the
+     *            specific process. By default, a value of -1 means all processes.
+     */
+    static void allowExternalProcessWindowActivation( int pid = -1 );
+
+    /**
+     * Sets whether the client wishes to block compositing (for better performance)
+     * @since 4.7
+     */
+    static void setBlockingCompositing( WId window, bool active );
+
 #ifdef Q_WS_X11
     /**
      * @internal
@@ -596,6 +621,20 @@ Q_SIGNALS:
      */
     void showingDesktopChanged( bool showing );
 
+    /**
+     * Compositing was enabled or disabled.
+     *
+     * Note that this signal may be emitted before any compositing plugins
+     * have been initialized in the window manager.
+     *
+     * Since most KWin effect require compositor you can safely assume that
+     * when the compositor is not active effects like shadows are not
+     * possible too.
+     *
+     * @since 4.7.1
+     */
+    void compositingChanged( bool enabled );
+
 protected:
     virtual void connectNotify( const char* signal );
 
@@ -604,8 +643,10 @@ private:
 
     KWindowSystem() {}
 
-    enum { INFO_BASIC=1, // desktop info, not per-window
-           INFO_WINDOWS=2 }; // also per-window info
+    enum {
+        INFO_BASIC=1, // desktop info, not per-window
+        INFO_WINDOWS=2 // also per-window info
+     };
 
     static void init(int);
 
