@@ -23,52 +23,50 @@
 
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kuniqueapplication.h>
 #include <kdebug.h>
+#include <ksystemeventfilter.h>
 #include <kxerrorhandler.h>
-#include <kxutils.h>
 #include <netwm.h>
+#include <QtGui/QApplication>
 #include <QtGui/QBitmap>
 #include <QDesktopWidget>
 #include <QtGui/QDialog>
-#include <QtDBus/QtDBus>
-#include <QtGui/QX11Info>
+#include <QtDBus/QDBusInterface>
+#include <QtGui/qx11info_x11.h>
 #include <X11/Xatom.h>
 
-class KWindowSystemStaticContainer {
-public:
-    KWindowSystemStaticContainer() : d(0) {}
-    KWindowSystem kwm;
-    KWindowSystemPrivate* d;
-};
+#include <config.h>
 
+#ifdef HAVE_XFIXES
+#include <X11/extensions/Xfixes.h>
+#endif
 
-K_GLOBAL_STATIC(KWindowSystemStaticContainer, g_kwmInstanceContainer)
-
+static Atom net_wm_cm;
+static void create_atoms( Display* dpy = QX11Info::display() );
 
 static unsigned long windows_properties[ 2 ] = { NET::ClientList | NET::ClientListStacking |
-                                     NET::Supported |
-				     NET::NumberOfDesktops |
-				     NET::DesktopGeometry |
-                                     NET::DesktopViewport |
-				     NET::CurrentDesktop |
-				     NET::DesktopNames |
-				     NET::ActiveWindow |
-				     NET::WorkArea, /**/
-                                     NET::WM2ShowingDesktop };
+                                    NET::Supported |
+                                    NET::NumberOfDesktops |
+                                    NET::DesktopGeometry |
+                                    NET::DesktopViewport |
+                                    NET::CurrentDesktop |
+                                    NET::DesktopNames |
+                                    NET::ActiveWindow |
+                                    NET::WorkArea, /**/
+                                    NET::WM2ShowingDesktop };
 
 // ClientList and ClientListStacking is not per-window information, but a desktop information,
 // so track it even with only INFO_BASIC
 static unsigned long desktop_properties[ 2 ] = { NET::ClientList | NET::ClientListStacking |
-                                     NET::Supported |
-				     NET::NumberOfDesktops |
-				     NET::DesktopGeometry |
-                                     NET::DesktopViewport |
-				     NET::CurrentDesktop |
-				     NET::DesktopNames |
-				     NET::ActiveWindow |
-				     NET::WorkArea, /**/
-                                     NET::WM2ShowingDesktop };
+                                    NET::Supported |
+                                    NET::NumberOfDesktops |
+                                    NET::DesktopGeometry |
+                                    NET::DesktopViewport |
+                                    NET::CurrentDesktop |
+                                    NET::DesktopNames |
+                                    NET::ActiveWindow |
+                                    NET::WorkArea, /**/
+                                    NET::WM2ShowingDesktop };
 
 class KWindowSystemPrivate
     : public QWidget, public NETRootInfo
@@ -91,7 +89,10 @@ public:
     QList<StrutData> strutWindows;
     QList<WId> possibleStrutWindows;
     bool strutSignalConnected;
+    bool compositingEnabled;
+    bool haveXfixes;
     int what;
+    int xfixesEventBase;
     bool mapViewport();
 
     void addClient(Window);
@@ -103,17 +104,42 @@ public:
     bool removeStrutWindow( WId );
 };
 
+class KWindowSystemStaticContainer {
+public:
+    KWindowSystemStaticContainer() : d(0) {}
+    ~KWindowSystemStaticContainer() { if (d) d->deleteLater(); }
+    KWindowSystem kwm;
+    KWindowSystemPrivate* d;
+};
+
+
+K_GLOBAL_STATIC(KWindowSystemStaticContainer, g_kwmInstanceContainer)
+
 KWindowSystemPrivate::KWindowSystemPrivate(int _what)
     : QWidget(0),
       NETRootInfo( QX11Info::display(),
                    _what >= KWindowSystem::INFO_WINDOWS ? windows_properties : desktop_properties,
                    2, -1, false ),
       strutSignalConnected( false ),
-      what( _what )
+      haveXfixes( false ),
+      what( _what ),
+      xfixesEventBase(0)
 {
-    if (kapp)
-        kapp->installX11EventFilter( this );
     (void ) qApp->desktop(); //trigger desktop widget creation to select root window events
+
+#ifdef HAVE_XFIXES
+    int errorBase;
+    if ((haveXfixes = XFixesQueryExtension(QX11Info::display(), &xfixesEventBase, &errorBase))) {
+        create_atoms();
+        XFixesSelectSelectionInput(QX11Info::display(), winId(), net_wm_cm,
+                                   XFixesSetSelectionOwnerNotifyMask |
+                                   XFixesSelectionWindowDestroyNotifyMask |
+                                   XFixesSelectionClientCloseNotifyMask);
+        compositingEnabled = XGetSelectionOwner(QX11Info::display(), net_wm_cm) != None;
+    }
+#endif
+
+    KSystemEventFilter::installEventFilter(this);
 }
 
 // not virtual, but it's called directly only from init()
@@ -127,65 +153,95 @@ bool KWindowSystemPrivate::x11Event( XEvent * ev )
 {
     KWindowSystem* s_q = KWindowSystem::self();
 
+#ifdef HAVE_XFIXES
+    if ( haveXfixes && ev->type == xfixesEventBase + XFixesSelectionNotify ) {
+        if ( ev->xany.window == winId() ) {
+            XFixesSelectionNotifyEvent *event = reinterpret_cast<XFixesSelectionNotifyEvent*>(ev);
+            bool haveOwner = event->owner != None;
+            if (compositingEnabled != haveOwner) {
+                compositingEnabled = haveOwner;
+                emit s_q->compositingChanged( compositingEnabled );
+            }
+            return true;
+        }
+        // Qt compresses XFixesSelectionNotifyEvents without caring about the actual window
+        // gui/kernel/qapplication_x11.cpp
+        // until that can be assumed fixed, we also react on events on the root (caused by Qts own compositing tracker)
+        if ( ev->xany.window == QX11Info::appRootWindow() ) {
+            XFixesSelectionNotifyEvent *event = reinterpret_cast<XFixesSelectionNotifyEvent*>(ev);
+            if (event->selection == net_wm_cm) {
+                bool haveOwner = event->owner != None;
+                if (compositingEnabled != haveOwner) {
+                    compositingEnabled = haveOwner;
+                    emit s_q->compositingChanged( compositingEnabled );
+                }
+                // NOTICE this is not our event, we just randomly captured it from Qt -> pass on
+                return false;
+            }
+        }
+        return false;
+    }
+#endif
+
     if ( ev->xany.window == QX11Info::appRootWindow() ) {
         int old_current_desktop = currentDesktop();
         WId old_active_window = activeWindow();
         int old_number_of_desktops = numberOfDesktops();
         bool old_showing_desktop = showingDesktop();
         unsigned long m[ 5 ];
-	NETRootInfo::event( ev, m, 5 );
+        NETRootInfo::event( ev, m, 5 );
 
-	if (( m[ PROTOCOLS ] & CurrentDesktop ) && currentDesktop() != old_current_desktop )
-	    emit s_q->currentDesktopChanged( currentDesktop() );
-	if (( m[ PROTOCOLS ] & DesktopViewport ) && mapViewport() && currentDesktop() != old_current_desktop )
-	    emit s_q->currentDesktopChanged( currentDesktop() );
-	if (( m[ PROTOCOLS ] & ActiveWindow ) && activeWindow() != old_active_window )
-	    emit s_q->activeWindowChanged( activeWindow() );
-	if ( m[ PROTOCOLS ] & DesktopNames )
-	    emit s_q->desktopNamesChanged();
-	if (( m[ PROTOCOLS ] & NumberOfDesktops ) && numberOfDesktops() != old_number_of_desktops )
-	    emit s_q->numberOfDesktopsChanged( numberOfDesktops() );
-	if (( m[ PROTOCOLS ] & DesktopGeometry ) && mapViewport() && numberOfDesktops() != old_number_of_desktops )
-	    emit s_q->numberOfDesktopsChanged( numberOfDesktops() );
-	if ( m[ PROTOCOLS ] & WorkArea )
-	    emit s_q->workAreaChanged();
-	if ( m[ PROTOCOLS ] & ClientListStacking ) {
-	    updateStackingOrder();
-	    emit s_q->stackingOrderChanged();
-	}
+        if (( m[ PROTOCOLS ] & CurrentDesktop ) && currentDesktop() != old_current_desktop )
+            emit s_q->currentDesktopChanged( currentDesktop() );
+        if (( m[ PROTOCOLS ] & DesktopViewport ) && mapViewport() && currentDesktop() != old_current_desktop )
+            emit s_q->currentDesktopChanged( currentDesktop() );
+        if (( m[ PROTOCOLS ] & ActiveWindow ) && activeWindow() != old_active_window )
+            emit s_q->activeWindowChanged( activeWindow() );
+        if ( m[ PROTOCOLS ] & DesktopNames )
+            emit s_q->desktopNamesChanged();
+        if (( m[ PROTOCOLS ] & NumberOfDesktops ) && numberOfDesktops() != old_number_of_desktops )
+            emit s_q->numberOfDesktopsChanged( numberOfDesktops() );
+        if (( m[ PROTOCOLS ] & DesktopGeometry ) && mapViewport() && numberOfDesktops() != old_number_of_desktops )
+            emit s_q->numberOfDesktopsChanged( numberOfDesktops() );
+        if ( m[ PROTOCOLS ] & WorkArea )
+            emit s_q->workAreaChanged();
+        if ( m[ PROTOCOLS ] & ClientListStacking ) {
+            updateStackingOrder();
+            emit s_q->stackingOrderChanged();
+        }
         if(( m[ PROTOCOLS2 ] & WM2ShowingDesktop ) && showingDesktop() != old_showing_desktop ) {
-	    emit s_q->showingDesktopChanged( showingDesktop());
+            emit s_q->showingDesktopChanged( showingDesktop());
         }
     } else  if ( windows.contains( ev->xany.window ) ){
-	NETWinInfo ni( QX11Info::display(), ev->xany.window, QX11Info::appRootWindow(), 0 );
+        NETWinInfo ni( QX11Info::display(), ev->xany.window, QX11Info::appRootWindow(), 0 );
         unsigned long dirty[ 2 ];
-	ni.event( ev, dirty, 2 );
-	if ( ev->type ==PropertyNotify ) {
+        ni.event( ev, dirty, 2 );
+        if ( ev->type ==PropertyNotify ) {
             if( ev->xproperty.atom == XA_WM_HINTS )
-	        dirty[ NETWinInfo::PROTOCOLS ] |= NET::WMIcon; // support for old icons
+                dirty[ NETWinInfo::PROTOCOLS ] |= NET::WMIcon; // support for old icons
             else if( ev->xproperty.atom == XA_WM_NAME )
                 dirty[ NETWinInfo::PROTOCOLS ] |= NET::WMName; // support for old name
             else if( ev->xproperty.atom == XA_WM_ICON_NAME )
                 dirty[ NETWinInfo::PROTOCOLS ] |= NET::WMIconName; // support for old iconic name
         }
         if( mapViewport() && ( dirty[ NETWinInfo::PROTOCOLS ] & (NET::WMState | NET::WMGeometry) )) {
-	    /* geometry change -> possible viewport change
-	     * state change -> possible NET::Sticky change
-	     */
+            /* geometry change -> possible viewport change
+            * state change -> possible NET::Sticky change
+            */
             dirty[ NETWinInfo::PROTOCOLS ] |= NET::WMDesktop;
-	}
-	if ( (dirty[ NETWinInfo::PROTOCOLS ] & NET::WMStrut) != 0 ) {
+        }
+        if ( (dirty[ NETWinInfo::PROTOCOLS ] & NET::WMStrut) != 0 ) {
             removeStrutWindow( ev->xany.window );
             if ( !possibleStrutWindows.contains( ev->xany.window ) )
-        	possibleStrutWindows.append( ev->xany.window );
-	}
-	if ( dirty[ NETWinInfo::PROTOCOLS ] || dirty[ NETWinInfo::PROTOCOLS2 ] ) {
-	    emit s_q->windowChanged( ev->xany.window );
-	    emit s_q->windowChanged( ev->xany.window, dirty );
-	    emit s_q->windowChanged( ev->xany.window, dirty[ NETWinInfo::PROTOCOLS ] );
-	    if ( (dirty[ NETWinInfo::PROTOCOLS ] & NET::WMStrut) != 0 )
-		emit s_q->strutChanged();
-	}
+                possibleStrutWindows.append( ev->xany.window );
+        }
+        if ( dirty[ NETWinInfo::PROTOCOLS ] || dirty[ NETWinInfo::PROTOCOLS2 ] ) {
+            emit s_q->windowChanged( ev->xany.window );
+            emit s_q->windowChanged( ev->xany.window, dirty );
+            emit s_q->windowChanged( ev->xany.window, dirty[ NETWinInfo::PROTOCOLS ] );
+            if ( (dirty[ NETWinInfo::PROTOCOLS ] & NET::WMStrut) != 0 )
+                emit s_q->strutChanged();
+        }
     }
 
     return false;
@@ -207,7 +263,7 @@ void KWindowSystemPrivate::updateStackingOrder()
 {
     stackingOrder.clear();
     for ( int i = 0; i <  clientListStackingCount(); i++ )
-	stackingOrder.append( clientListStacking()[i] );
+        stackingOrder.append( clientListStacking()[i] );
 }
 
 void KWindowSystemPrivate::addClient(Window w)
@@ -273,18 +329,17 @@ static bool atoms_created = false;
 static Atom kde_wm_change_state;
 static Atom _wm_protocols;
 static Atom kwm_utf8_string;
-static Atom net_wm_cm;
 
-static void create_atoms( Display* dpy = QX11Info::display()) {
+static void create_atoms( Display* dpy ) {
     if (!atoms_created){
-	const int max = 20;
-	Atom* atoms[max];
-	const char* names[max];
-	Atom atoms_return[max];
-	int n = 0;
+        const int max = 20;
+        Atom* atoms[max];
+        const char* names[max];
+        Atom atoms_return[max];
+        int n = 0;
 
-	atoms[n] = &kde_wm_change_state;
-	names[n++] = "_KDE_WM_CHANGE_STATE";
+        atoms[n] = &kde_wm_change_state;
+        names[n++] = "_KDE_WM_CHANGE_STATE";
 
         atoms[n] = &_wm_protocols;
         names[n++] = "WM_PROTOCOLS";
@@ -297,29 +352,29 @@ static void create_atoms( Display* dpy = QX11Info::display()) {
         atoms[n] = &net_wm_cm;
         names[n++] = net_wm_cm_name;
 
-	// we need a const_cast for the shitty X API
-	XInternAtoms( dpy, const_cast<char**>(names), n, false, atoms_return );
-	for (int i = 0; i < n; i++ )
-	    *atoms[i] = atoms_return[i];
+        // we need a const_cast for the shitty X API
+        XInternAtoms( dpy, const_cast<char**>(names), n, false, atoms_return );
+        for (int i = 0; i < n; i++ )
+            *atoms[i] = atoms_return[i];
 
-	atoms_created = True;
+        atoms_created = True;
     }
 }
 
 static void sendClientMessageToRoot(Window w, Atom a, long x, long y = 0, long z = 0 ){
-  XEvent ev;
-  long mask;
+    XEvent ev;
+    long mask;
 
-  memset(&ev, 0, sizeof(ev));
-  ev.xclient.type = ClientMessage;
-  ev.xclient.window = w;
-  ev.xclient.message_type = a;
-  ev.xclient.format = 32;
-  ev.xclient.data.l[0] = x;
-  ev.xclient.data.l[1] = y;
-  ev.xclient.data.l[2] = z;
-  mask = SubstructureRedirectMask;
-  XSendEvent(QX11Info::display(), QX11Info::appRootWindow(), False, mask, &ev);
+    memset(&ev, 0, sizeof(ev));
+    ev.xclient.type = ClientMessage;
+    ev.xclient.window = w;
+    ev.xclient.message_type = a;
+    ev.xclient.format = 32;
+    ev.xclient.data.l[0] = x;
+    ev.xclient.data.l[1] = y;
+    ev.xclient.data.l[2] = z;
+    mask = SubstructureRedirectMask;
+    XSendEvent(QX11Info::display(), QX11Info::appRootWindow(), False, mask, &ev);
 }
 
 KWindowSystem* KWindowSystem::self()
@@ -338,15 +393,15 @@ KWindowSystemPrivate* KWindowSystem::s_d_func()
 void KWindowSystem::connectNotify( const char* signal )
 {
     int what = INFO_BASIC;
-    if( QLatin1String( signal ) == SIGNAL(workAreaChanged()))
+    if( qstrcmp(signal, SIGNAL(workAreaChanged())) == 0)
         what = INFO_WINDOWS;
-    else if( QLatin1String( signal ) == SIGNAL(strutChanged()))
+    else if( qstrcmp(signal, SIGNAL(strutChanged())) == 0)
         what = INFO_WINDOWS;
-    else if( QLatin1String( signal ) == QMetaObject::normalizedSignature(SIGNAL(windowChanged(WId,const unsigned long*))).constData())
+    else if( QMetaObject::normalizedSignature(SIGNAL(windowChanged(WId,const ulong*))) == signal)
         what = INFO_WINDOWS;
-    else if( QLatin1String( signal ) ==  QMetaObject::normalizedSignature(SIGNAL(windowChanged(WId,unsigned int))).constData())
+    else if( QMetaObject::normalizedSignature(SIGNAL(windowChanged(WId,uint))) == signal)
         what = INFO_WINDOWS;
-    else if( QLatin1String( signal ) ==  QMetaObject::normalizedSignature(SIGNAL(windowChanged(WId))).constData())
+    else if( QMetaObject::normalizedSignature(SIGNAL(windowChanged(WId))) == signal)
         what = INFO_WINDOWS;
 
     init( what );
@@ -470,10 +525,10 @@ void KWindowSystem::setOnAllDesktops( WId win, bool b )
     }
     NETWinInfo info( QX11Info::display(), win, QX11Info::appRootWindow(), NET::WMDesktop );
     if ( b )
-	info.setDesktop( NETWinInfo::OnAllDesktops, true );
+        info.setDesktop( NETWinInfo::OnAllDesktops, true );
     else if ( info.desktop( true )  == NETWinInfo::OnAllDesktops ) {
-	NETRootInfo rinfo( QX11Info::display(), NET::CurrentDesktop );
-	info.setDesktop( rinfo.currentDesktop( true ), true );
+        NETRootInfo rinfo( QX11Info::display(), NET::CurrentDesktop );
+        info.setDesktop( rinfo.currentDesktop( true ), true );
     }
 }
 
@@ -531,7 +586,6 @@ void KWindowSystem::activateWindow( WId win, long time )
         time = QX11Info::appUserTime();
     info.setActiveWindow( win, NET::FromApplication, time,
         qApp->activeWindow() ? qApp->activeWindow()->winId() : 0 );
-    KUniqueApplication::setHandleAutoStarted();
 }
 
 void KWindowSystem::forceActiveWindow( WId win, long time )
@@ -540,7 +594,6 @@ void KWindowSystem::forceActiveWindow( WId win, long time )
     if( time == 0 )
         time = QX11Info::appTime();
     info.setActiveWindow( win, NET::FromTool, time, 0 );
-    KUniqueApplication::setHandleAutoStarted();
 }
 
 void KWindowSystem::demandAttention( WId win, bool set )
@@ -597,37 +650,33 @@ QPixmap KWindowSystem::icon( WId win, int width, int height, bool scale, int fla
         NETWinInfo info( QX11Info::display(), win, QX11Info::appRootWindow(), NET::WMIcon );
         NETIcon ni = info.icon( width, height );
         if ( ni.data && ni.size.width > 0 && ni.size.height > 0 ) {
-    	    QImage img( (uchar*) ni.data, (int) ni.size.width, (int) ni.size.height, QImage::Format_ARGB32 );
-	    if ( scale && width > 0 && height > 0 &&img.size() != QSize( width, height ) && !img.isNull() )
-	        img = img.scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
-	    if ( !img.isNull() )
-	        result = QPixmap::fromImage( img );
-	    return result;
+            QImage img( (uchar*) ni.data, (int) ni.size.width, (int) ni.size.height, QImage::Format_ARGB32 );
+            if ( scale && width > 0 && height > 0 &&img.size() != QSize( width, height ) && !img.isNull() )
+                img = img.scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+            if ( !img.isNull() )
+                result = QPixmap::fromImage( img );
+            return result;
         }
     }
 
     if( flags & WMHints ) {
         Pixmap p = None;
-        Pixmap p_mask = None;
 
         XWMHints *hints = XGetWMHints(QX11Info::display(), win );
         if (hints && (hints->flags & IconPixmapHint)){
     	    p = hints->icon_pixmap;
         }
-        if (hints && (hints->flags & IconMaskHint)){
-	    p_mask = hints->icon_mask;
-        }
         if (hints)
-	    XFree((char*)hints);
+            XFree((char*)hints);
 
         if (p != None){
-            QPixmap pm = KXUtils::createPixmapFromHandle( p, p_mask );
+            QPixmap pm = QPixmap::fromX11Pixmap( p );
             if ( scale && width > 0 && height > 0 && !pm.isNull()
                  && ( pm.width() != width || pm.height() != height) ){
-                result = QPixmap::fromImage( pm.toImage().scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation ) );
-	    } else {
+                result = pm.scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+            } else {
                 result = pm;
-	    }
+            }
         }
     }
 
@@ -647,20 +696,20 @@ QPixmap KWindowSystem::icon( WId win, int width, int height, bool scale, int fla
         // its own:
         if( result.isNull() ) {
 
-	    XClassHint	hint;
-	    if( XGetClassHint( QX11Info::display(), win, &hint ) ) {
-	        QString className = hint.res_class;
+            XClassHint	hint;
+            if( XGetClassHint( QX11Info::display(), win, &hint ) ) {
+                QString className = hint.res_class;
 
                 QPixmap pm = KIconLoader::global()->loadIcon( className.toLower(), KIconLoader::Small, iconWidth,
-                                                           KIconLoader::DefaultState, QStringList(), 0, true );
-	        if( scale && !pm.isNull() )
-		    result = QPixmap::fromImage( pm.toImage().scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation ) );
-	        else
-		    result = pm;
+                                                            KIconLoader::DefaultState, QStringList(), 0, true );
+                if( scale && !pm.isNull() )
+                    result = pm.scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+                else
+                    result = pm;
 
-	        XFree( hint.res_name );
-	        XFree( hint.res_class );
-	    }
+                XFree( hint.res_name );
+                XFree( hint.res_class );
+            }
         }
     }
 
@@ -670,10 +719,10 @@ QPixmap KWindowSystem::icon( WId win, int width, int height, bool scale, int fla
         if ( result.isNull() ) {
             QPixmap pm = KIconLoader::global()->loadIcon( "xorg", KIconLoader::Small, iconWidth,
                                                           KIconLoader::DefaultState, QStringList(), 0, true );
-	    if( scale && !pm.isNull() )
-		result = QPixmap::fromImage( pm.toImage().scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation ) );
-	    else
-		result = pm;
+            if( scale && !pm.isNull() )
+                result = pm.scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+            else
+                result = pm;
         }
     }
     return result;
@@ -682,7 +731,7 @@ QPixmap KWindowSystem::icon( WId win, int width, int height, bool scale, int fla
 void KWindowSystem::setIcons( WId win, const QPixmap& icon, const QPixmap& miniIcon )
 {
     if ( icon.isNull() )
-	return;
+        return;
     NETWinInfo info( QX11Info::display(), win, QX11Info::appRootWindow(), 0 );
     QImage img = icon.toImage().convertToFormat( QImage::Format_ARGB32 );
     NETIcon ni;
@@ -691,7 +740,7 @@ void KWindowSystem::setIcons( WId win, const QPixmap& icon, const QPixmap& miniI
     ni.data = (unsigned char *) img.bits();
     info.setIcon( ni, true );
     if ( miniIcon.isNull() )
-	return;
+        return;
     img = miniIcon.toImage().convertToFormat( QImage::Format_ARGB32 );
     if ( img.isNull() )
         return;
@@ -724,10 +773,9 @@ void KWindowSystem::minimizeWindow( WId win, bool animation)
     if ( !animation )
     {
         create_atoms();
-	sendClientMessageToRoot( win, kde_wm_change_state, IconicState, 1 );
+        sendClientMessageToRoot( win, kde_wm_change_state, IconicState, 1 );
     }
-	QX11Info inf;
-    XIconifyWindow( QX11Info::display(), win, inf.screen() );
+    XIconifyWindow( QX11Info::display(), win, DefaultScreen( QX11Info::display()) );
 }
 
 void KWindowSystem::unminimizeWindow( WId win, bool animation )
@@ -735,7 +783,7 @@ void KWindowSystem::unminimizeWindow( WId win, bool animation )
     if ( !animation )
     {
         create_atoms();
-	sendClientMessageToRoot( win, kde_wm_change_state, NormalState, 1 );
+        sendClientMessageToRoot( win, kde_wm_change_state, NormalState, 1 );
     }
     XMapWindow( QX11Info::display(), win );
 }
@@ -760,16 +808,24 @@ void KWindowSystem::lowerWindow( WId win )
 
 bool KWindowSystem::compositingActive()
 {
+    bool ret = false;
     if( QX11Info::display()) {
-        create_atoms();
-        return XGetSelectionOwner( QX11Info::display(), net_wm_cm ) != None;
+        init( INFO_BASIC );
+        if (s_d_func()->haveXfixes) {
+            ret = s_d_func()->compositingEnabled;
+        } else {
+            create_atoms();
+            ret = XGetSelectionOwner( QX11Info::display(), net_wm_cm );
+        }
     } else { // work even without QApplication instance
         Display* dpy = XOpenDisplay( NULL );
-        create_atoms( dpy );
-        bool ret = XGetSelectionOwner( dpy, net_wm_cm ) != None;
-        XCloseDisplay( dpy );
-        return ret;
+        if (dpy) {
+            create_atoms( dpy );
+            ret = XGetSelectionOwner( dpy, net_wm_cm ) != None;
+            XCloseDisplay( dpy );
+        }
     }
+    return ret;
 }
 
 QRect KWindowSystem::workArea( int desktop )
@@ -808,7 +864,7 @@ QRect KWindowSystem::workArea( const QList<WId>& exclude, int desktop )
 // windows are cached here.
         NETStrut strut;
         QList< KWindowSystemPrivate::StrutData >::Iterator it2 = s_d->strutWindows.begin();
-        for( ; it2 != s_d->strutWindows.end(); ++it2 )
+        for( ; it2 != s_d->strutWindows.end(); ++it2 ) {
             if( (*it2).window == *it1 )
                 break;
 
@@ -826,8 +882,10 @@ QRect KWindowSystem::workArea( const QList<WId>& exclude, int desktop )
 
                 if( !(info.desktop() == desktop || info.desktop() == NETWinInfo::OnAllDesktops) )
                     continue;
-            } else
+            } else {
                 continue; // not a strut window
+            }
+        }
 
         QRect r = all;
         if ( strut.left > 0 )
@@ -839,7 +897,7 @@ QRect KWindowSystem::workArea( const QList<WId>& exclude, int desktop )
         if ( strut.bottom > 0  )
             r.setBottom( r.bottom() - (int) strut.bottom );
 
-        a = a.intersect(r);
+        a = a.intersected(r);
     }
     return a;
 }
@@ -976,6 +1034,12 @@ void KWindowSystem::allowExternalProcessWindowActivation( int pid )
     Q_UNUSED(pid)
 }
 
+void KWindowSystem::setBlockingCompositing( WId window, bool active )
+{
+    NETWinInfo info( QX11Info::display(), window, QX11Info::appRootWindow(), 0 );
+    info.setBlockingCompositing( active );
+}
+
 
 bool KWindowSystem::mapViewport()
 {
@@ -1066,4 +1130,4 @@ QPoint KWindowSystem::constrainViewportRelativePosition( const QPoint& pos )
     return QPoint( x - c.x, y - c.y );
 }
 
-#include "kwindowsystem.moc"
+#include "moc_kwindowsystem.cpp"
