@@ -21,22 +21,19 @@
 #include "kxmlguiversionhandler_p.h"
 #include "kxmlguifactory.h"
 #include "kxmlguibuilder.h"
+#include "kcomponentdata.h"
+#include "kstandarddirs.h"
+#include "kdebug.h"
+#include "kaction.h"
+#include "kactioncollection.h"
 
 #include <QtCore/QDir>
 #include <QtCore/QFile>
-#include <QtXml/QDomDocument>
-#include <QtCore/QTextIStream>
+#include <QtXml/qdom.h>
+#include <QtCore/QTextStream>
 #include <QtCore/QRegExp>
 #include <QtCore/QPointer>
 
-#include <kcomponentdata.h>
-#include <kstandarddirs.h>
-#include <kdebug.h>
-#include <kauthorized.h>
-
-#include "kaction.h"
-#include "kactioncollection.h"
-
 #include <assert.h>
 
 class KXMLGUIClientPrivate
@@ -51,6 +48,12 @@ public:
   }
   ~KXMLGUIClientPrivate()
   {
+    if (m_actionCollection) {
+      m_actionCollection->deleteLater();
+    }
+    if (m_builder) {
+      delete m_builder;
+    }
   }
 
   bool mergeXML( QDomElement &base, QDomElement &additive,
@@ -108,7 +111,6 @@ KXMLGUIClient::~KXMLGUIClient()
       client->d->m_parent = 0;
   }
 
-  delete d->m_actionCollection;
   delete d;
 }
 
@@ -137,7 +139,7 @@ KActionCollection *KXMLGUIClient::actionCollection() const
 
 QAction *KXMLGUIClient::action( const QDomElement &element ) const
 {
-  static const QString &attrName = KGlobal::staticQString( "name" );
+  static const QString attrName = QString::fromLatin1( "name" );
   return actionCollection()->action( qPrintable(element.attribute( attrName )) );
 }
 
@@ -310,17 +312,17 @@ static bool equalstr(const QString& a, const QString& b) {
 
 bool KXMLGUIClientPrivate::mergeXML( QDomElement &base, QDomElement &additive, KActionCollection *actionCollection )
 {
-    static const QString &tagAction = KGlobal::staticQString( "Action" );
-    static const QString &tagMerge = KGlobal::staticQString( "Merge" );
-    static const QString &tagSeparator = KGlobal::staticQString( "Separator" );
-    static const QString &attrName = KGlobal::staticQString( "name" );
-    static const QString &attrAppend = KGlobal::staticQString( "append" );
-    static const QString &attrWeakSeparator = KGlobal::staticQString( "weakSeparator" );
-    static const QString &tagMergeLocal = KGlobal::staticQString( "MergeLocal" );
-    static const QString &tagText = KGlobal::staticQString( "text" );
-    static const QString &attrAlreadyVisited = KGlobal::staticQString( "alreadyVisited" );
-    static const QString &attrNoMerge = KGlobal::staticQString( "noMerge" );
-    static const QString &attrOne = KGlobal::staticQString( "1" );
+    static const QString tagAction = QString::fromLatin1( "Action" );
+    static const QString tagMerge = QString::fromLatin1( "Merge" );
+    static const QString tagSeparator = QString::fromLatin1( "Separator" );
+    static const QString attrName = QString::fromLatin1( "name" );
+    static const QString attrAppend = QString::fromLatin1( "append" );
+    static const QString attrWeakSeparator = QString::fromLatin1( "weakSeparator" );
+    static const QString tagMergeLocal = QString::fromLatin1( "MergeLocal" );
+    static const QString tagText = QString::fromLatin1( "text" );
+    static const QString attrAlreadyVisited = QString::fromLatin1( "alreadyVisited" );
+    static const QString attrNoMerge = QString::fromLatin1( "noMerge" );
+    static const QString attrOne = QString::fromLatin1( "1" );
 
     // there is a possibility that we don't want to merge in the
     // additive.. rather, we might want to *replace* the base with the
@@ -358,8 +360,7 @@ bool KXMLGUIClientPrivate::mergeXML( QDomElement &base, QDomElement &additive, K
             // not implemented, then we remove the element
             if (equalstr(tag, tagAction)) {
                 const QString name =  e.attribute(attrName);
-                if (!actionCollection->action(name) ||
-                    !KAuthorized::authorizeKAction(name))
+                if (!actionCollection->action(name))
                 {
                     // remove this child as we aren't using it
                     base.removeChild( e );
@@ -507,15 +508,15 @@ bool KXMLGUIClientPrivate::isEmptyContainer(const QDomElement& base, KActionColl
 
         const QString tag = e.tagName();
 
-        static const QString &tagAction = KGlobal::staticQString("Action");
-        static const QString &tagSeparator = KGlobal::staticQString("Separator");
-        static const QString &tagText = KGlobal::staticQString("text");
-        static const QString &tagMerge = KGlobal::staticQString("Merge");
+        static const QString tagAction = QString::fromLatin1("Action");
+        static const QString tagSeparator = QString::fromLatin1("Separator");
+        static const QString tagText = QString::fromLatin1("text");
+        static const QString tagMerge = QString::fromLatin1("Merge");
         if (equalstr(tag, tagAction)) {
             // if base contains an implemented action, then we must not get
             // deleted (note that the actionCollection contains both,
             // "global" and "local" actions)
-            static const QString &attrName = KGlobal::staticQString("name");
+            static const QString attrName = QString::fromLatin1("name");
             if (actionCollection->action(e.attribute(attrName))) {
                 return false;
             }
@@ -524,7 +525,7 @@ bool KXMLGUIClientPrivate::isEmptyContainer(const QDomElement& base, KActionColl
             // if we have a separator which has *not* the weak attribute
             // set, then it must be owned by the "local" tree in which case
             // we must not get deleted either
-            static const QString &attrWeakSeparator = KGlobal::staticQString("weakSeparator");
+            static const QString attrWeakSeparator = QString::fromLatin1("weakSeparator");
             const QString weakAttr = e.attribute(attrWeakSeparator);
             if (weakAttr.isEmpty() || weakAttr.toInt() != 1) {
                 return false;
@@ -554,9 +555,9 @@ bool KXMLGUIClientPrivate::isEmptyContainer(const QDomElement& base, KActionColl
 
 QDomElement KXMLGUIClientPrivate::findMatchingElement( const QDomElement &base, const QDomElement &additive )
 {
-  static const QString &tagAction = KGlobal::staticQString( "Action" );
-  static const QString &tagMergeLocal = KGlobal::staticQString( "MergeLocal" );
-  static const QString &attrName = KGlobal::staticQString( "name" );
+  static const QString tagAction = QString::fromLatin1( "Action" );
+  static const QString tagMergeLocal = QString::fromLatin1( "MergeLocal" );
+  static const QString attrName = QString::fromLatin1( "name" );
 
   QDomNode n = additive.firstChild();
   while ( !n.isNull() )
@@ -711,19 +712,15 @@ void KXMLGUIClient::stateChanged(const QString &newstate, KXMLGUIClient::Reverse
 
   // Enable actions which need to be enabled...
   //
-  for ( QStringList::const_iterator it = stateChange.actionsToEnable.constBegin();
-        it != stateChange.actionsToEnable.constEnd(); ++it ) {
-
-    QAction *action = actionCollection()->action(qPrintable((*it)));
+  foreach ( const QString it, stateChange.actionsToEnable ) {
+    QAction *action = actionCollection()->action(qPrintable(it));
     if (action) action->setEnabled(setTrue);
   }
 
   // and disable actions which need to be disabled...
   //
-  for ( QStringList::const_iterator it = stateChange.actionsToDisable.constBegin();
-        it != stateChange.actionsToDisable.constEnd(); ++it ) {
-
-    QAction *action = actionCollection()->action(qPrintable((*it)));
+  foreach ( const QString it, stateChange.actionsToDisable ) {
+    QAction *action = actionCollection()->action(qPrintable(it));
     if (action) action->setEnabled(setFalse);
   }
 
@@ -747,5 +744,3 @@ void KXMLGUIClient::prepareXMLUnplug( QWidget * w )
     client->prepareXMLUnplug( w );
 }
 
-void KXMLGUIClient::virtual_hook( int, void* )
-{ /*BASE::virtual_hook( id, data );*/ }
