@@ -26,11 +26,11 @@
 #include <assert.h>
 
 #include <QtCore/QDir>
-#include <QtXml/QDomDocument>
+#include <QtXml/qdom.h>
 #include <QtCore/QFile>
-#include <QtCore/QTextIStream>
+#include <QtCore/QTextStream>
 #include <QtGui/QWidget>
-#include <QtCore/QDate>
+#include <QtCore/qdatetime.h>
 #include <QtCore/QVariant>
 #include <QTextCodec>
 
@@ -53,11 +53,11 @@ public:
 
     KXMLGUIFactoryPrivate()
     {
-        static const QString &defaultMergingName = KGlobal::staticQString( "<default>" );
-        static const QString &actionList = KGlobal::staticQString( "actionlist" );
-        static const QString &name = KGlobal::staticQString( "name" );
+        static const QString defaultMergingName = QString::fromLatin1( "<default>" );
+        static const QString actionList = QString::fromLatin1( "actionlist" );
+        static const QString name = QString::fromLatin1( "name" );
 
-        m_rootNode = new ContainerNode( 0L, QString(), 0L );
+        m_rootNode = new ContainerNode( 0L, QString(), QString() );
         m_defaultMergingName = defaultMergingName;
         tagActionList = actionList;
         attrName = name;
@@ -164,29 +164,6 @@ bool KXMLGUIFactory::saveConfigFile( const QDomDocument& doc,
     return true;
 }
 
-/**
- * Removes all QDomComment objects from the specified node and all its children.
- */
-static void removeDOMComments( QDomNode &node )
-{
-    QDomNode n = node.firstChild();
-    while ( !n.isNull() )
-    {
-        if ( n.nodeType() == QDomNode::CommentNode )
-        {
-            QDomNode tmp = n;
-            n = n.nextSibling();
-            node.removeChild( tmp );
-        }
-        else
-        {
-            QDomNode tmp = n;
-            n = n.nextSibling();
-            removeDOMComments( tmp );
-        }
-    }
-}
-
 KXMLGUIFactory::KXMLGUIFactory( KXMLGUIBuilder *builder, QObject *parent )
     : QObject( parent ),d(new KXMLGUIFactoryPrivate)
 {
@@ -386,7 +363,8 @@ void KXMLGUIFactoryPrivate::saveDefaultActionProperties(const QList<QAction *>&
         else
         {
             // A QAction used with KXMLGUI? Set our property and ignore it.
-            kError(240) << "Attempt to use QAction" << action->objectName() << "with KXMLGUIFactory!";
+	    if ( !action->isSeparator() )
+              kError(240) << "Attempt to use QAction" << action->objectName() << "with KXMLGUIFactory!";
             action->setProperty("_k_DefaultShortcut", KShortcut());
         }
 
@@ -611,7 +589,12 @@ void KXMLGUIFactoryPrivate::applyActionProperties( const QDomElement &actionProp
 void KXMLGUIFactoryPrivate::configureAction( QAction *action, const QDomNamedNodeMap &attributes,
         ShortcutOption shortcutOption )
 {
-    for ( uint i = 0; i < attributes.length(); i++ )
+      // the lenght() method had a TODO which is done in Katie
+#ifdef QT_KATIE
+      for (int i = 0; i < attributes.length(); i++ )
+#else
+      for (uint i = 0; i < attributes.length(); i++ )
+#endif
     {
         QDomAttr attr = attributes.item( i ).toAttr();
         if ( attr.isNull() )
@@ -624,7 +607,7 @@ void KXMLGUIFactoryPrivate::configureAction( QAction *action, const QDomNamedNod
 void KXMLGUIFactoryPrivate::configureAction( QAction *action, const QDomAttr &attribute,
         ShortcutOption shortcutOption )
 {
-    static const QString &attrShortcut = KGlobal::staticQString( "shortcut" );
+    static const QString attrShortcut = QString::fromLatin1( "shortcut" );
 
     QString attrName = attribute.name();
     // If the attribute is a deprecated "accel", change to "shortcut".
@@ -697,7 +680,7 @@ QDomDocument KXMLGUIFactoryPrivate::shortcutSchemeDoc(KXMLGUIClient *client)
 
 void KXMLGUIFactoryPrivate::applyShortcutScheme(KXMLGUIClient *client, const QList<QAction*> &actions, const QDomDocument& scheme)
 {
-    static const QString &actionPropElementName = KGlobal::staticQString( "ActionProperties" );
+    static const QString actionPropElementName = QString::fromLatin1( "ActionProperties" );
 
     KConfigGroup cg = KGlobal::config()->group( "Shortcut Schemes" );
     QString schemeName = cg.readEntry("Current Scheme", "Default");
@@ -781,8 +764,8 @@ QDomElement KXMLGUIFactory::actionPropertiesElement( QDomDocument& doc )
 
 QDomElement KXMLGUIFactory::findActionByName( QDomElement& elem, const QString& sName, bool create )
 {
-        static const QString& attrName = KGlobal::staticQString( "name" );
-	static const QString& tagAction = KGlobal::staticQString( "Action" );
+        static const QString attrName = QString::fromLatin1( "name" );
+	static const QString tagAction = QString::fromLatin1( "Action" );
 	for( QDomNode it = elem.firstChild(); !it.isNull(); it = it.nextSibling() ) {
 		QDomElement e = it.toElement();
 		if( e.attribute( attrName ) == sName )
@@ -798,7 +781,7 @@ QDomElement KXMLGUIFactory::findActionByName( QDomElement& elem, const QString&
         return QDomElement();
 }
 
-#include "kxmlguifactory.moc"
+#include "moc_kxmlguifactory.cpp"
 
 /* vim: et sw=4
  */
