@@ -20,14 +20,14 @@
 #include "kxmlguifactory_p.h"
 #include "kxmlguiclient.h"
 #include "kxmlguibuilder.h"
-
-#include <QtGui/QWidget>
-
 #include <kglobal.h>
 #include <kdebug.h>
+#include <kcomponentdata.h>
+#include <ktoolbar.h>
+
+#include <QWidget>
 
 #include <assert.h>
-#include <kcomponentdata.h>
 
 using namespace KXMLGUI;
 
@@ -236,7 +236,7 @@ void ContainerNode::plugActionList( BuildState &state )
 
 void ContainerNode::plugActionList( BuildState &state, const MergingIndexList::Iterator &mergingIdxIt )
 {
-    static const QString &tagActionList = KGlobal::staticQString( "actionlist" );
+    static const QString tagActionList = QString::fromLatin1( "actionlist" );
 
     MergingIndex mergingIdx = *mergingIdxIt;
 
@@ -277,7 +277,7 @@ void ContainerNode::unplugActionList( BuildState &state )
 
 void ContainerNode::unplugActionList( BuildState &state, const MergingIndexList::Iterator &mergingIdxIt )
 {
-    static const QString &tagActionList = KGlobal::staticQString( "actionlist" );
+    static const QString tagActionList = QString::fromLatin1( "actionlist" );
 
     MergingIndex mergingIdx = *mergingIdxIt;
 
@@ -378,7 +378,7 @@ void ContainerNode::destructChildren( const QDomElement &element, BuildState &st
 QDomElement ContainerNode::findElementForChild( const QDomElement &baseElement,
                                                 ContainerNode *childNode )
 {
-    static const QString &attrName = KGlobal::staticQString( "name" );
+    static const QString attrName = QString::fromLatin1( "name" );
 
     // ### slow
     for ( QDomNode n = baseElement.firstChild(); !n.isNull();
@@ -426,7 +426,7 @@ void ContainerNode::unplugActions( BuildState &state )
 
 void ContainerNode::unplugClient( ContainerClient *client )
 {
-    static const QString &tagActionList = KGlobal::staticQString( "actionlist" );
+    static const QString tagActionList = QString::fromLatin1( "actionlist" );
 
     assert( builder );
 
@@ -437,6 +437,11 @@ void ContainerNode::unplugClient( ContainerClient *client )
     for (; custIt != custEnd; ++custIt )
         builder->removeCustomElement( container, *custIt );
 
+    KToolBar *bar = qobject_cast<KToolBar*>(container);
+    if (bar) {
+        bar->removeXMLGUIClient(client->client);
+    }
+
     client->actions.unplug( container );
 
     // now adjust all merging indices
@@ -510,7 +515,7 @@ int ContainerNode::calcMergingIndex( const QString &mergingName,
 
 int BuildHelper::calcMergingIndex( const QDomElement &element, MergingIndexList::Iterator &it, QString &group )
 {
-    static const QString &attrGroup = KGlobal::staticQString( "group" );
+    static const QString attrGroup = QString::fromLatin1( "group" );
 
     bool haveGroup = false;
     group = element.attribute( attrGroup );
@@ -534,7 +539,7 @@ BuildHelper::BuildHelper( BuildState &state, ContainerNode *node )
     : containerClient( 0 ), ignoreDefaultMergingIndex( false ), m_state( state ),
       parentNode( node )
 {
-    static const QString &defaultMergingName = KGlobal::staticQString( "<default>" );
+    static const QString defaultMergingName = QString::fromLatin1( "<default>" );
 
     // create a list of supported container and custom tags
     customTags = m_state.builderCustomTags;
@@ -569,12 +574,12 @@ void BuildHelper::build( const QDomElement &element )
 void BuildHelper::processElement( const QDomElement &e )
 {
     // some often used QStrings
-    static const QString &tagAction = KGlobal::staticQString( "action" );
-    static const QString &tagMerge = KGlobal::staticQString( "merge" );
-    static const QString &tagState = KGlobal::staticQString( "state" );
-    static const QString &tagDefineGroup = KGlobal::staticQString( "definegroup" );
-    static const QString &tagActionList = KGlobal::staticQString( "actionlist" );
-    static const QString &attrName = KGlobal::staticQString( "name" );
+    static const QString tagAction = QString::fromLatin1( "action" );
+    static const QString tagMerge = QString::fromLatin1( "merge" );
+    static const QString tagState = QString::fromLatin1( "state" );
+    static const QString tagDefineGroup = QString::fromLatin1( "definegroup" );
+    static const QString tagActionList = QString::fromLatin1( "actionlist" );
+    static const QString attrName = QString::fromLatin1( "name" );
 
     QString tag( e.tagName().toLower() );
     QString currName( e.attribute( attrName ) );
@@ -687,22 +692,22 @@ void BuildHelper::processStateElement( const QDomElement &element )
 
 void BuildHelper::processMergeElement( const QString &tag, const QString &name, const QDomElement &e )
 {
-    static const QString &tagDefineGroup = KGlobal::staticQString( "definegroup" );
-    static const QString &tagActionList = KGlobal::staticQString( "actionlist" );
-    static const QString &defaultMergingName = KGlobal::staticQString( "<default>" );
-    static const QString &attrGroup = KGlobal::staticQString( "group" );
+    static const QString tagDefineGroup = QString::fromLatin1( "definegroup" );
+    static const QString tagActionList = QString::fromLatin1( "actionlist" );
+    static const QString defaultMergingName = QString::fromLatin1( "<default>" );
+    static const QString attrGroup = QString::fromLatin1( "group" );
 
     QString mergingName( name );
     if ( mergingName.isEmpty() )
     {
         if ( tag == tagDefineGroup )
         {
-            kError(240) << "cannot define group without name!" << endl;
+            kError(240) << "cannot define group without name!";
             return;
         }
         if ( tag == tagActionList )
         {
-            kError(240) << "cannot define actionlist without name!" << endl;
+            kError(240) << "cannot define actionlist without name!";
             return;
         }
         mergingName = defaultMergingName;
@@ -751,7 +756,7 @@ void BuildHelper::processMergeElement( const QString &tag, const QString &name,
 void BuildHelper::processContainerElement( const QDomElement &e, const QString &tag,
                                            const QString &name )
 {
-    static const QString &defaultMergingName = KGlobal::staticQString( "<default>" );
+    static const QString defaultMergingName = QString::fromLatin1( "<default>" );
 
     ContainerNode *containerNode = parentNode->findContainer( name, tag,
                                                               &containerList,
@@ -795,6 +800,16 @@ void BuildHelper::processContainerElement( const QDomElement &e, const QString &
         containerNode = new ContainerNode( container, tag, name, parentNode,
                                            m_state.guiClient, builder, containerAction,
                                            mergingName, group, cusTags, conTags );
+    } else {
+        if ( tag == QLatin1String( "toolbar" ) ) {
+            KToolBar *bar = qobject_cast<KToolBar*>(containerNode->container);
+            if (bar) {
+                if ( m_state.guiClient && !m_state.guiClient->xmlFile().isEmpty() )
+                    bar->addXMLGUIClient(m_state.guiClient);
+            } else {
+                kWarning() << "toolbar container is not a KToolBar";
+            }
+        }
     }
 
     BuildHelper( m_state, containerNode ).build( e );
