@@ -36,26 +36,23 @@
 
 #include <config.h>
 
-#include <QCloseEvent>
 #include <QDesktopWidget>
 #include <QDockWidget>
-#include <QtXml/QDomDocument>
+#include <QtXml/qdom.h>
+#include <QtGui/qevent.h>
+#include <QtGui/QMenuBar>
 #include <QtGui/QLayout>
-#include <QtCore/QObject>
 #include <QtGui/QSessionManager>
 #include <QtGui/QStyle>
-#include <QtCore/QTimer>
 #include <QtGui/QWidget>
-#include <QtCore/QList>
+#include <QtDBus/QDBusConnection>
 #include <kaction.h>
 #include <kapplication.h>
-#include <kauthorized.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kedittoolbar.h>
 #include <khelpmenu.h>
 #include <klocale.h>
-#include <kmenubar.h>
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
 #include <ktoolbar.h>
@@ -101,7 +98,7 @@ QAction *KXmlGuiWindow::toolBarMenuAction()
 {
     K_D(KXmlGuiWindow);
     if ( !d->toolBarHandler )
-	return 0;
+        return 0;
 
     return d->toolBarHandler->toolBarMenuAction();
 }
@@ -118,6 +115,8 @@ void KXmlGuiWindow::setupToolbarMenuActions()
 KXmlGuiWindow::~KXmlGuiWindow()
 {
     K_D(KXmlGuiWindow);
+    if (d->toolBarHandler)
+        d->toolBarHandler->deleteLater();
     delete d->factory;
 }
 
@@ -271,6 +270,7 @@ void KXmlGuiWindow::createGUI( const QString &xmlfile )
     setXMLGUIBuildDocument( QDomDocument() );
 
     // do the actual GUI building
+    guiFactory()->reset();
     guiFactory()->addClient( this );
 
     //  setUpdatesEnabled( true );
@@ -326,37 +326,29 @@ void KXmlGuiWindow::createStandardStatusBarAction(){
         d->showStatusBarAction->setChecked(sb->isHidden());
     } else {
         // If the language has changed, we'll need to grab the new text and whatsThis
-	KAction *tmpStatusBar = KStandardAction::showStatusbar(NULL, NULL, NULL);
+        KAction *tmpStatusBar = KStandardAction::showStatusbar(NULL, NULL, NULL);
         d->showStatusBarAction->setText(tmpStatusBar->text());
         d->showStatusBarAction->setWhatsThis(tmpStatusBar->whatsThis());
-	delete tmpStatusBar;
+        delete tmpStatusBar;
     }
 }
 
-void KXmlGuiWindow::finalizeGUI( bool /*force*/ )
+void KXmlGuiWindow::finalizeGUI( KXMLGUIClient *client )
 {
-    // FIXME: this really needs to be removed with a code more like the one we had on KDE3.
-    //        what we need to do here is to position correctly toolbars so they don't overlap.
-    //        Also, take in count plugins could provide their own toolbars and those also need to
-    //        be restored.
+    Q_UNUSED(client);
     if (autoSaveSettings() && autoSaveConfigGroup().isValid()) {
         applyMainWindowSettings(autoSaveConfigGroup());
     }
 }
 
-void KXmlGuiWindow::applyMainWindowSettings(const KConfigGroup &config, bool force)
+void KXmlGuiWindow::applyMainWindowSettings(const KConfigGroup &config)
 {
     K_D(KXmlGuiWindow);
-    KMainWindow::applyMainWindowSettings(config, force);
-    KStatusBar *sb = qFindChild<KStatusBar *>(this);
+    KMainWindow::applyMainWindowSettings(config);
+    KStatusBar *sb = this->findChild<KStatusBar*>();
     if (sb && d->showStatusBarAction)
         d->showStatusBarAction->setChecked(!sb->isHidden());
 }
 
-// KDE5 TODO: change it to "using KXMLGUIBuilder::finalizeGUI;" in the header
-// and remove the reimplementation
-void KXmlGuiWindow::finalizeGUI( KXMLGUIClient *client )
-{ KXMLGUIBuilder::finalizeGUI( client ); }
-
-#include "kxmlguiwindow.moc"
+#include "moc_kxmlguiwindow.cpp"
 
