@@ -32,7 +32,7 @@
 #include "kxmlguiclient.h"
 #include "kxmlguibuilder.h"
 #include <kmainwindow.h>
-#include <QtCore/QMetaClassInfo>
+#include <QtCore/qmetaobject.h>
 
 class KMenu;
 class KXMLGUIFactory;
@@ -41,8 +41,6 @@ class KConfigGroup;
 class KToolBar;
 class KXmlGuiWindowPrivate;
 
-#define KDE_DEFAULT_WINDOWFLAGS 0
-
 /**
  * @short %KDE top level main window with predefined action layout
  *
@@ -104,7 +102,7 @@ public:
      * for the composer windows "composer#".
      *
      */
-    explicit KXmlGuiWindow( QWidget* parent = 0, Qt::WindowFlags f = KDE_DEFAULT_WINDOWFLAGS );
+    explicit KXmlGuiWindow( QWidget* parent = 0, Qt::WindowFlags f = 0 );
 
     /**
      * \brief Destructor.
@@ -288,16 +286,10 @@ public:
      */
     void setupToolbarMenuActions();
 
-    // KDE5 TODO: change it to "using KXMLGUIBuilder::finalizeGUI;"
     virtual void finalizeGUI( KXMLGUIClient *client );
 
-    /**
-     * @internal
-     */
-    void finalizeGUI( bool force );
-
     // reimplemented for internal reasons
-    virtual void applyMainWindowSettings(const KConfigGroup &config, bool force = false);
+    virtual void applyMainWindowSettings(const KConfigGroup &config);
 
 public Q_SLOTS:
     /**
