@@ -24,14 +24,14 @@
 #include "kdiroperatordetailview_p.h"
 #include "kdirsortfilterproxymodel.h"
 #include "kfileitem.h"
-#include "kfilemetapreview.h"
-#include "kpreviewwidgetbase.h"
+#include "kimagefilepreview.h"
 #include "knewfilemenu.h"
 
 #include <config-kfile.h>
 
 #include <unistd.h>
 
+#include <QtCore/QStack>
 #include <QtCore/QDir>
 #include <QtCore/QRegExp>
 #include <QtCore/QTimer>
@@ -42,13 +42,13 @@
 #include <QtGui/QLabel>
 #include <QtGui/QLayout>
 #include <QtGui/QListView>
-#include <QtGui/QMouseEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QTreeView>
 #include <QtGui/QPushButton>
 #include <QtGui/QProgressBar>
 #include <QtGui/QScrollBar>
 #include <QtGui/QSplitter>
-#include <QtGui/QWheelEvent>
+#include <QtGui/qevent.h>
 
 #include <kaction.h>
 #include <kapplication.h>
@@ -81,9 +81,6 @@
 #include <kconfiggroup.h>
 #include <kdeversion.h>
 
-
-template class QHash<QString, KFileItem>;
-
 // QDir::SortByMask is not only undocumented, it also omits QDir::Type which  is another
 // sorting mode.
 static const int QDirSortMask = QDir::SortByMask | QDir::Type;
@@ -199,14 +196,11 @@ public:
 
     // private methods
     bool checkPreviewInternal() const;
-    void checkPath(const QString &txt, bool takeFiles = false);
     bool openUrl(const KUrl &url, KDirLister::OpenUrlFlags flags = KDirLister::NoFlags);
     int sortColumn() const;
     Qt::SortOrder sortOrder() const;
     void updateSorting(QDir::SortFlags sort);
 
-    static bool isReadable(const KUrl &url);
-
     KFile::FileView allViews();
 
     // private slots
@@ -287,7 +281,6 @@ public:
     bool onlyDoubleClickSelectsFiles;
     QString lastURL; // used for highlighting a directory on cdUp
     QTimer *progressDelayTimer;
-    int dropOptions;
 
     KActionMenu *actionMenu;
     KActionCollection *actionCollection;
@@ -325,7 +318,6 @@ KDirOperator::Private::Private(KDirOperator *_parent) :
     dirHighlighting(false),
     onlyDoubleClickSelectsFiles(!KGlobalSettings::singleClick()),
     progressDelayTimer(0),
-    dropOptions(0),
     actionMenu(0),
     actionCollection(0),
     newFileMenu(0),
@@ -383,15 +375,12 @@ KDirOperator::KDirOperator(const KUrl& _url, QWidget *parent) :
     d->viewKind = KFile::Simple;
 
     if (_url.isEmpty()) { // no dir specified -> current dir
-        QString strPath = QDir::currentPath();
-        strPath.append(QChar('/'));
-        d->currUrl = QUrl::fromLocalFile(strPath);
+        d->currUrl = QUrl::fromLocalFile(QDir::currentPath());
     } else {
         d->currUrl = _url;
-        if (d->currUrl.protocol().isEmpty())
+        if (d->currUrl.protocol().isEmpty()) {
             d->currUrl.setProtocol(QLatin1String("file"));
-
-        d->currUrl.addPath("/"); // make sure we have a trailing slash!
+        }
     }
 
     // We set the direction of this widget to LTR, since even on RTL desktops
@@ -445,14 +434,6 @@ QDir::SortFlags KDirOperator::sorting() const
 
 bool KDirOperator::isRoot() const
 {
-#ifdef Q_WS_WIN
-    if (url().isLocalFile()) {
-        const QString path = url().toLocalFile();
-        if (path.length() == 3)
-            return (path[0].isLetter() && path[1] == ':' && path[2] == '/');
-        return false;
-    } else
-#endif
     return url().path() == QString(QLatin1Char('/'));
 }
 
@@ -635,7 +616,7 @@ void KDirOperator::Private::_k_togglePreview(bool on)
     if (on) {
         viewKind = viewKind | KFile::PreviewContents;
         if (preview == 0) {
-            preview = new KFileMetaPreview(parent);
+            preview = new KImageFilePreview(parent);
             actionCollection->action("preview")->setChecked(true);
             splitter->addWidget(preview);
         }
@@ -951,7 +932,7 @@ void KDirOperator::setIconsZoom(int _value)
     const int val = (maxSize * value / 100) + KIconLoader::SizeSmall;
     d->itemView->setIconSize(QSize(val, val));
     d->updateListViewGrid();
-    d->previewGenerator->updatePreviews();
+    d->previewGenerator->updateIcons();
 
     emit currentIconSizeChanged(value);
 }
@@ -966,92 +947,45 @@ void KDirOperator::close()
     d->dirLister->stop();
 }
 
-void KDirOperator::Private::checkPath(const QString &, bool /*takeFiles*/) // SLOT
-{
-#if 0
-    // copy the argument in a temporary string
-    QString text = _txt;
-    // it's unlikely to happen, that at the beginning are spaces, but
-    // for the end, it happens quite often, I guess.
-    text = text.trimmed();
-    // if the argument is no URL (the check is quite fragil) and it's
-    // no absolute path, we add the current directory to get a correct url
-    if (text.find(':') < 0 && text[0] != '/')
-        text.insert(0, d->currUrl);
-
-    // in case we have a selection defined and someone patched the file-
-    // name, we check, if the end of the new name is changed.
-    if (!selection.isNull()) {
-        int position = text.lastIndexOf('/');
-        ASSERT(position >= 0); // we already inserted the current d->dirLister in case
-        QString filename = text.mid(position + 1, text.length());
-        if (filename != selection)
-            selection.clear();
-    }
-
-    KUrl u(text); // I have to take care of entered URLs
-    bool filenameEntered = false;
-
-    if (u.isLocalFile()) {
-        // the empty path is kind of a hack
-        KFileItem i("", u.toLocalFile());
-        if (i.isDir())
-            setUrl(text, true);
-        else {
-            if (takeFiles)
-                if (acceptOnlyExisting && !i.isFile())
-                    warning("you entered an invalid URL");
-                else
-                    filenameEntered = true;
-        }
-    } else
-        setUrl(text, true);
-
-    if (filenameEntered) {
-        filename_ = u.url();
-        emit fileSelected(filename_);
-
-        QApplication::restoreOverrideCursor();
-
-        accept();
-    }
-#endif
-    kDebug(kfile_area) << "TODO KDirOperator::checkPath()";
-}
-
 void KDirOperator::setUrl(const KUrl& _newurl, bool clearforward)
 {
-    KUrl newurl;
+    KUrl newurl(_newurl);
 
-    if (!_newurl.isValid())
+    if (!newurl.isValid()) {
         newurl = QUrl::fromLocalFile(QDir::homePath());
-    else
-        newurl = _newurl;
-
-    newurl.adjustPath( KUrl::AddTrailingSlash );
+    }
+    newurl.adjustPath(KUrl::RemoveTrailingSlash);
 
     // already set
-    if (newurl.equals(d->currUrl, KUrl::CompareWithoutTrailingSlash))
+    if (newurl.equals(d->currUrl)) {
         return;
+    }
 
-    if (!Private::isReadable(newurl)) {
+    // TODO: something is trying to set relative file path, that is ugly
+    // workaround for it and the caller should set the full path
+    if (newurl.isRelative()) {
+        newurl.setPath(d->currUrl.prettyUrl() + "/" + newurl.prettyUrl());
+    }
+
+    QDir urldir(newurl.toLocalFile());
+    if (!urldir.exists() || !urldir.isReadable()) {
         // maybe newurl is a file? check its parent directory
-        newurl.setPath(newurl.directory(KUrl::ObeyTrailingSlash));
-        if (newurl.equals(d->currUrl, KUrl::CompareWithoutTrailingSlash))
-            return; // parent is current dir, nothing to do (fixes #173454, too)
-        KIO::UDSEntry entry;
-        bool res = KIO::NetAccess::stat(newurl, entry, this);
-        KFileItem i(entry, newurl);
-        if ((!res || !Private::isReadable(newurl)) && i.isDir()) {
-            resetCursor();
-            KMessageBox::error(d->itemView,
-                               i18n("The specified folder does not exist "
-                                    "or was not readable."));
-            return;
-        } else if (!i.isDir()) {
+        newurl.setPath(newurl.directory());
+        // parent is current
+        if (newurl.equals(d->currUrl)) {
             return;
         }
+
+        urldir.setPath(newurl.toLocalFile());
+        if (!urldir.exists() || !urldir.isReadable()) {
+            resetCursor();
+            KMessageBox::error(d->itemView,
+                i18n("The specified folder does not exist or was not readable."));
+            return;
+        }
+        newurl.setPath(urldir.path());
     }
+    newurl.adjustPath(KUrl::RemoveTrailingSlash);
 
     if (clearforward) {
         // autodelete should remove this one
@@ -1060,7 +994,7 @@ void KDirOperator::setUrl(const KUrl& _newurl, bool clearforward)
         d->forwardStack.clear();
     }
 
-    d->lastURL = d->currUrl.url(KUrl::RemoveTrailingSlash);
+    d->lastURL = d->currUrl.url();
     d->currUrl = newurl;
 
     pathChanged();
@@ -1180,10 +1114,10 @@ void KDirOperator::pathChanged()
     // when KIO::Job emits finished, the slot will restore the cursor
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
-    if (!Private::isReadable(d->currUrl)) {
+    QDir urldir(d->currUrl.toLocalFile());
+    if (!urldir.isReadable()) {
         KMessageBox::error(d->itemView,
-                           i18n("The specified folder does not exist "
-                                "or was not readable."));
+            i18n("The specified folder does not exist or was not readable."));
         if (d->backStack.isEmpty())
             home();
         else
@@ -1312,15 +1246,8 @@ void KDirOperator::activatedMenu(const KFileItem &item, const QPoint &pos)
     d->actionMenu->menu()->exec(pos);
 }
 
-void KDirOperator::changeEvent(QEvent *event)
-{
-    QWidget::changeEvent(event);
-}
-
 bool KDirOperator::eventFilter(QObject *watched, QEvent *event)
 {
-    Q_UNUSED(watched);
-
     // If we are not hovering any items, check if there is a current index
     // set. In that case, we show the preview of that item.
     switch(event->type()) {
@@ -1388,7 +1315,7 @@ bool KDirOperator::Private::checkPreviewInternal() const
     if (parent->dirOnlyMode() && supported.indexOf("inode/directory") == -1)
         return false;
 
-    QStringList mimeTypes = dirLister->mimeFilters();
+    const QStringList mimeTypes = dirLister->mimeFilters();
     const QStringList nameFilter = dirLister->nameFilter().split(' ', QString::SkipEmptyParts);
 
     if (mimeTypes.isEmpty() && nameFilter.isEmpty() && !supported.isEmpty())
@@ -1397,41 +1324,33 @@ bool KDirOperator::Private::checkPreviewInternal() const
         QRegExp r;
         r.setPatternSyntax(QRegExp::Wildcard);   // the "mimetype" can be "image/*"
 
-        if (!mimeTypes.isEmpty()) {
-            QStringList::ConstIterator it = supported.begin();
+        foreach(const QString it, supported) {
+            r.setPattern(it);
 
-            for (; it != supported.end(); ++it) {
-                r.setPattern(*it);
-
-                QStringList result = mimeTypes.filter(r);
-                if (!result.isEmpty()) {   // matches! -> we want previews
-                    return true;
-                }
+            const QStringList result = mimeTypes.filter(r);
+            if (!result.isEmpty()) {   // matches! -> we want previews
+                return true;
             }
         }
 
-        if (!nameFilter.isEmpty()) {
-            // find the mimetypes of all the filter-patterns
-            QStringList::const_iterator it1 = nameFilter.begin();
-            for (; it1 != nameFilter.end(); ++it1) {
-                if ((*it1) == "*") {
+        // find the mimetypes of all the filter-patterns
+        foreach(const QString it1, nameFilter) {
+            if (it1 == "*") {
+                return true;
+            }
+
+            KMimeType::Ptr mt = KMimeType::findByPath(it1, 0, true /*fast mode, no file contents exist*/);
+            if (!mt)
+                continue;
+            const QString mime = mt->name();
+
+            // the "mimetypes" we get from the PreviewJob can be "image/*"
+            // so we need to check in wildcard mode
+            foreach(const QString it2, supported) {
+                r.setPattern(it2);
+                if (r.indexIn(mime) != -1) {
                     return true;
                 }
-
-                KMimeType::Ptr mt = KMimeType::findByPath(*it1, 0, true /*fast mode, no file contents exist*/);
-                if (!mt)
-                    continue;
-                QString mime = mt->name();
-
-                // the "mimetypes" we get from the PreviewJob can be "image/*"
-                // so we need to check in wildcard mode
-                QStringList::ConstIterator it2 = supported.begin();
-                for (; it2 != supported.end(); ++it2) {
-                    r.setPattern(*it2);
-                    if (r.indexIn(mime) != -1) {
-                        return true;
-                    }
-                }
             }
         }
     }
@@ -1456,19 +1375,11 @@ QAbstractItemView* KDirOperator::createView(QWidget* parent, KFile::FileView vie
 void KDirOperator::setAcceptDrops(bool b)
 {
     // TODO:
-    //if (d->fileView)
-    //   d->fileView->widget()->setAcceptDrops(b);
+    //if (d->itemView)
+    //   d->itemView->setAcceptDrops(b);
     QWidget::setAcceptDrops(b);
 }
 
-void KDirOperator::setDropOptions(int options)
-{
-    d->dropOptions = options;
-    // TODO:
-    //if (d->fileView)
-    //   d->fileView->setDropOptions(options);
-}
-
 void KDirOperator::setView(KFile::FileView viewKind)
 {
     bool preview = (KFile::isPreviewInfo(viewKind) || KFile::isPreviewContents(viewKind));
@@ -1560,7 +1471,7 @@ void KDirOperator::setView(QAbstractItemView *view)
     d->itemView->viewport()->setAttribute(Qt::WA_Hover);
     d->itemView->setContextMenuPolicy(Qt::CustomContextMenu);
     d->itemView->setMouseTracking(true);
-    //d->itemView->setDropOptions(d->dropOptions);
+    //d->itemView->setAcceptDrops(acceptDrops());
 
     // first push our settings to the view, then listen for changes from the view
     QTreeView* treeView = qobject_cast<QTreeView*>(d->itemView);
@@ -1663,7 +1574,7 @@ void KDirOperator::setDirLister(KDirLister *lister)
     d->dirLister->setAutoUpdate(true);
     d->dirLister->setDelayedMimeTypes(true);
 
-    QWidget* mainWidget = topLevelWidget();
+    QWidget* mainWidget = window();
     d->dirLister->setMainWindow(mainWidget);
     kDebug(kfile_area) << "mainWidget=" << mainWidget;
 
@@ -2157,7 +2068,7 @@ void KDirOperator::writeConfig(KConfigGroup& configGroup)
     // don't save the preview when an application specific preview is in use.
     bool appSpecificPreview = false;
     if (d->preview) {
-        KFileMetaPreview *tmp = dynamic_cast<KFileMetaPreview*>(d->preview);
+        KImageFilePreview *tmp = qobject_cast<KImageFilePreview*>(d->preview);
         appSpecificPreview = (tmp == 0);
     }
 
@@ -2618,33 +2529,9 @@ void KDirOperator::setDecorationPosition(QStyleOptionViewItem::Position position
     d->actionCollection->action("decorationAtTop")->setChecked(!decorationAtLeft);
 }
 
-// ### temporary code
-#include <dirent.h>
-bool KDirOperator::Private::isReadable(const KUrl& url)
-{
-    if (!url.isLocalFile())
-        return true; // what else can we say?
-
-    KDE_struct_stat buf;
-#ifdef Q_WS_WIN
-    QString ts = url.toLocalFile();
-#else
-    QString ts = url.path(KUrl::AddTrailingSlash);
-#endif
-    bool readable = (KDE::stat(ts, &buf) == 0);
-    if (readable) { // further checks
-        DIR *test;
-        test = opendir(QFile::encodeName(ts));    // we do it just to test here
-        readable = (test != 0);
-        if (test)
-            closedir(test);
-    }
-    return readable;
-}
-
 void KDirOperator::Private::_k_slotDirectoryCreated(const KUrl& url)
 {
     parent->setUrl(url, true);
 }
 
-#include "kdiroperator.moc"
+#include "moc_kdiroperator.cpp"
