@@ -26,7 +26,6 @@
 
 #include <kactioncollection.h>
 #include <kapplication.h>
-#include <kauthorized.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <khistorycombobox.h>
@@ -47,7 +46,6 @@
 #include <krecentdirs.h>
 #include <ktoggleaction.h>
 #include <kurlcompletion.h>
-#include <kurlpixmapprovider.h>
 #include <kdebug.h>
 #include <kpropertiesdialog.h>
 #include <kpushbutton.h>
@@ -208,17 +206,6 @@ void KDirSelectDialog::Private::slotComboTextChanged( const QString& text )
 {
     m_treeView->blockSignals(true);
     KUrl url( text );
-#ifdef Q_OS_WIN
-    if( url.isLocalFile() && !m_treeView->rootUrl().isParentOf( url ) )
-    {
-        KUrl tmp = url.upUrl();
-        while(tmp != KUrl("file:///")) {
-            url = tmp;
-            tmp = url.upUrl();
-        }
-        m_treeView->setRootUrl( url );
-    }
-#endif
     m_treeView->setCurrentUrl( url );
     m_treeView->blockSignals( false );
 }
@@ -271,11 +258,7 @@ void KDirSelectDialog::Private::slotProperties()
 
 KDirSelectDialog::KDirSelectDialog(const KUrl &startDir, bool localOnly,
                                    QWidget *parent)
-#ifdef Q_WS_WIN
-    : KDialog( parent , Qt::WindowMinMaxButtonsHint),
-#else
     : KDialog( parent ),
-#endif
       d( new Private( localOnly, this ) )
 {
     setCaption( i18nc("@title:window","Select Folder") );
@@ -312,7 +295,6 @@ KDirSelectDialog::KDirSelectDialog(const KUrl &startDir, bool localOnly,
     d->m_urlCombo->setLayoutDirection( Qt::LeftToRight );
     d->m_urlCombo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
     d->m_urlCombo->setTrapReturnKey( true );
-    d->m_urlCombo->setPixmapProvider( new KUrlPixmapProvider() );
     KUrlCompletion *comp = new KUrlCompletion();
     comp->setMode( KUrlCompletion::DirCompletion );
     d->m_urlCombo->setCompletionObject( comp, true );
@@ -500,4 +482,4 @@ KUrl KDirSelectDialog::selectDirectory( const KUrl& startDir,
         return KUrl();
 }
 
-#include "kdirselectdialog.moc"
+#include "moc_kdirselectdialog.cpp"
