@@ -31,8 +31,8 @@
 #include <kmimetype.h>
 #include <kio/global.h>
 #include <kprotocolinfo.h>
-#include <kstringhandler.h>
 #include <kurlrequester.h>
+#include <kconfiggroup.h>
 
 #include <QtCore/QMimeData>
 #include <QtGui/QApplication>
@@ -47,19 +47,19 @@
 #include <QtGui/QStyle>
 
 #include <unistd.h>
-#include <kvbox.h>
-#include <kconfiggroup.h>
-
 
 bool KFilePlaceEditDialog::getInformation(bool allowGlobal, KUrl& url,
                                           QString& label, QString& icon,
+                                          bool isAddingNewPlace,
                                           bool& appLocal, int iconSize,
                                           QWidget *parent )
 {
     KFilePlaceEditDialog *dialog = new KFilePlaceEditDialog(allowGlobal, url,
                                                             label, icon,
+                                                            isAddingNewPlace,
                                                             appLocal,
-                                                            iconSize, parent );
+                                                            iconSize,
+                                                            parent );
     if ( dialog->exec() == QDialog::Accepted ) {
         // set the return parameters
         url         = dialog->url();
@@ -77,12 +77,16 @@ bool KFilePlaceEditDialog::getInformation(bool allowGlobal, KUrl& url,
 
 KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const KUrl& url,
                                            const QString& label,
-                                           const QString &icon, bool appLocal,
-                                           int iconSize,
+                                           const QString &icon,
+                                           bool isAddingNewPlace,
+                                           bool appLocal, int iconSize,
                                            QWidget *parent)
     : KDialog( parent )
 {
-    setCaption( i18n("Edit Places Entry") );
+    if (isAddingNewPlace)
+        setCaption( i18n("Add Places Entry") );
+    else
+        setCaption( i18n("Edit Places Entry") );
     setButtons( Ok | Cancel );
     setModal(true);
     setDefaultButton(Ok);
@@ -114,6 +118,8 @@ KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const KUrl& url,
     layout->addRow( i18n("&Location:"), m_urlEdit );
     m_urlEdit->setWhatsThis( whatsThisText );
     layout->labelForField(m_urlEdit)->setWhatsThis( whatsThisText );
+    // Room for at least 40 chars (average char width is half of height)
+    m_urlEdit->setMinimumWidth( m_urlEdit->fontMetrics().height() * (40 / 2) );
 
     whatsThisText = i18n("<qt>This is the icon that will appear in the Places panel.<br /><br />"
                          "Click on the button to select a different icon.</qt>");
@@ -146,7 +152,7 @@ KFilePlaceEditDialog::KFilePlaceEditDialog(bool allowGlobal, const KUrl& url,
     }
     else
         m_appLocal = 0L;
-    connect(m_urlEdit->lineEdit(),SIGNAL(textChanged ( const QString & )),this,SLOT(urlChanged(const QString & )));
+    connect(m_urlEdit->lineEdit(),SIGNAL(textChanged(QString)),this,SLOT(urlChanged(QString)));
     if (!label.isEmpty()) {
         // editing existing entry
         m_labelEdit->setFocus();
@@ -202,4 +208,4 @@ bool KFilePlaceEditDialog::applicationLocal() const
 }
 
 
-#include "kfileplaceeditdialog.moc"
+#include "moc_kfileplaceeditdialog.cpp"
