@@ -19,12 +19,8 @@
 */
 #include "kfileplacesmodel.h"
 #include "kfileplacesitem_p.h"
+#include "kfileplacessharedbookmarks_p.h"
 
-#ifdef _WIN32_WCE
-#include "Windows.h"
-#include "WinBase.h"
-#include <QtCore/QDir>
-#endif
 
 #include <QtCore/QMimeData>
 #include <QtCore/QTimer>
@@ -60,9 +56,10 @@
 class KFilePlacesModel::Private
 {
 public:
-    Private(KFilePlacesModel *self) : q(self), bookmarkManager(0) {}
+    Private(KFilePlacesModel *self) : q(self), bookmarkManager(0), sharedBookmarks(0) {}
     ~Private()
     {
+        delete sharedBookmarks;
         qDeleteAll(items);
     }
 
@@ -74,6 +71,7 @@ public:
 
     Solid::Predicate predicate;
     KBookmarkManager *bookmarkManager;
+    KFilePlacesSharedBookmarks * sharedBookmarks;
 
     void reloadAndSignal();
     QList<KFilePlacesItem *> loadBookmarkList();
@@ -81,6 +79,7 @@ public:
     void _k_initDeviceList();
     void _k_deviceAdded(const QString &udi);
     void _k_deviceRemoved(const QString &udi);
+    void _k_contentChanged(const QString &udi, const bool hascontent);
     void _k_itemChanged(const QString &udi);
     void _k_reloadBookmarks();
     void _k_storageSetupDone(Solid::ErrorType error, QVariant errorData);
@@ -90,8 +89,8 @@ public:
 KFilePlacesModel::KFilePlacesModel(QObject *parent)
     : QAbstractItemModel(parent), d(new Private(this))
 {
-    const QString file = KStandardDirs().localxdgdatadir() + "user-places.xbel";
-    d->bookmarkManager = KBookmarkManager::managerForExternalFile(file);
+    const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
+    d->bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
 
     // Let's put some places in there if it's empty. We have a corner case here:
     // Given you have bookmarked some folders (which have been saved on
@@ -118,19 +117,9 @@ KFilePlacesModel::KFilePlacesModel(QObject *parent)
         KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
                                               "Network", I18N_NOOP2("KFile System Bookmarks", "Network"),
                                               KUrl("remote:/"), "network-workgroup");
-#if defined(_WIN32_WCE)
-        // adding drives
-        foreach ( const QFileInfo& info, QDir::drives() ) {
-            QString driveIcon = "drive-harddisk";
-            KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
-                                                  info.absoluteFilePath(), info.absoluteFilePath(),
-                                                  KUrl(info.absoluteFilePath()), driveIcon);
-        }
-#elif !defined(Q_OS_WIN)
         KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
                                               "Root", I18N_NOOP2("KFile System Bookmarks", "Root"),
                                               KUrl("/"), "folder-red");
-#endif
         KFilePlacesItem::createSystemBookmark(d->bookmarkManager,
                                               "Trash", I18N_NOOP2("KFile System Bookmarks", "Trash"),
                                               KUrl("trash:/"), "user-trash");
@@ -143,6 +132,9 @@ KFilePlacesModel::KFilePlacesModel(QObject *parent)
         d->bookmarkManager->saveAs(file);
     }
 
+    // create after, so if we have own places, they are added afterwards, in case of equal priorities
+    d->sharedBookmarks = new KFilePlacesSharedBookmarks(d->bookmarkManager);
+
     QString predicate("[[[[ StorageVolume.ignored == false AND [ StorageVolume.usage == 'FileSystem' OR StorageVolume.usage == 'Encrypted' ]]"
         " OR "
         "[ IS StorageAccess AND StorageDrive.driveType == 'Floppy' ]]"
@@ -313,6 +305,8 @@ void KFilePlacesModel::Private::_k_initDeviceList()
             q, SLOT(_k_deviceAdded(QString)));
     connect(notifier, SIGNAL(deviceRemoved(QString)),
             q, SLOT(_k_deviceRemoved(QString)));
+    connect(notifier, SIGNAL(contentChanged(QString,bool)),
+            q, SLOT(_k_contentChanged(QString,bool)));
 
     const QList<Solid::Device> &deviceList = Solid::Device::listFromQuery(predicate);
 
@@ -341,6 +335,15 @@ void KFilePlacesModel::Private::_k_deviceRemoved(const QString &udi)
     }
 }
 
+void KFilePlacesModel::Private::_k_contentChanged(const QString &udi, const bool hascontent)
+{
+    if (hascontent) {
+        _k_deviceAdded(udi);
+    } else {
+        _k_deviceRemoved(udi);
+    }
+}
+
 void KFilePlacesModel::Private::_k_itemChanged(const QString &id)
 {
     for (int row = 0; row<items.size(); ++row) {
@@ -732,10 +735,6 @@ QAction *KFilePlacesModel::teardownActionForIndex(const QModelIndex &index) cons
 
         Solid::StorageDrive *drive = device.as<Solid::StorageDrive>();
 
-        if (drive==0) {
-            drive = device.parent().as<Solid::StorageDrive>();
-        }
-
         bool hotpluggable = false;
         bool removable = false;
 
@@ -800,7 +799,7 @@ void KFilePlacesModel::requestEject(const QModelIndex &index)
 {
     Solid::Device device = deviceForIndex(index);
 
-    Solid::OpticalDrive *drive = device.parent().as<Solid::OpticalDrive>();
+    Solid::OpticalDrive *drive = device.as<Solid::OpticalDrive>();
 
     if (drive!=0) {
         connect(drive, SIGNAL(ejectDone(Solid::ErrorType,QVariant,QString)),
@@ -864,4 +863,4 @@ void KFilePlacesModel::Private::_k_storageTeardownDone(Solid::ErrorType error, Q
     }
 }
 
-#include "kfileplacesmodel.moc"
+#include "moc_kfileplacesmodel.cpp"
