@@ -123,6 +123,11 @@ KFilePlacesSharedBookmarks::KFilePlacesSharedBookmarks(KBookmarkManager * mgr)
     connect(m_sharedBookmarkManager, SIGNAL(bookmarksChanged(QString)),
               this, SLOT(slotSharedBookmarksChanged()));
 
+    connect(m_placesBookmarkManager, SIGNAL(changed(QString,QString)),
+              this, SLOT(slotBookmarksChanged()));
+    connect(m_placesBookmarkManager, SIGNAL(bookmarksChanged(QString)),
+              this, SLOT(slotBookmarksChanged()));
+    
     integrateSharedBookmarks();
 }
 
@@ -266,11 +271,11 @@ void KFilePlacesSharedBookmarks::slotSharedBookmarksChanged()
     if (dirty) m_placesBookmarkManager->emitChanged();
 }
 
-void KFilePlacesSharedBookmarks::updateSharedBookmarks()
+void KFilePlacesSharedBookmarks::slotBookmarksChanged()
 {
     //kDebug() << "places bookmarks changed";
     bool dirty = exportSharedBookmarks();
     if (dirty) m_sharedBookmarkManager->emitChanged();
 }
 
-#include "kfileplacessharedbookmarks_p.moc"
+#include "moc_kfileplacessharedbookmarks_p.cpp"
