@@ -25,7 +25,7 @@
 #include <QtCore/QTimer>
 #include <QtGui/QPainter>
 #include <QtGui/QAbstractItemDelegate>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QApplication>
 #include <QtGui/QScrollBar>
 
@@ -37,6 +37,7 @@
 #include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <klocale.h>
+#include <ksettings.h>
 #include <kmessagebox.h>
 #include <knotification.h>
 #include <kio/job.h>
@@ -58,6 +59,7 @@
 
 class KFilePlacesViewDelegate : public QAbstractItemDelegate
 {
+    Q_OBJECT
 public:
     KFilePlacesViewDelegate(KFilePlacesView *parent);
     virtual ~KFilePlacesViewDelegate();
@@ -85,7 +87,6 @@ public:
     qreal contentsOpacity(const QModelIndex &index) const;
 
 private:
-    KFilePlacesView *m_view;
     int m_iconSize;
 
     QList<QPersistentModelIndex> m_appearingItems;
@@ -104,7 +105,6 @@ private:
 
 KFilePlacesViewDelegate::KFilePlacesViewDelegate(KFilePlacesView *parent) :
     QAbstractItemDelegate(parent),
-    m_view(parent),
     m_iconSize(48),
     m_appearingIconSize(0),
     m_appearingOpacity(0.0),
@@ -402,19 +402,19 @@ KFilePlacesView::KFilePlacesView(QWidget *parent)
             this, SLOT(_k_adaptItemsUpdate(qreal)));
     d->adaptItemsTimeline.setDuration(500);
     d->adaptItemsTimeline.setUpdateInterval(5);
-    d->adaptItemsTimeline.setCurveShape(QTimeLine::EaseInOutCurve);
+    d->adaptItemsTimeline.setEasingCurve(QEasingCurve(QEasingCurve::InOutSine));
 
     connect(&d->itemAppearTimeline, SIGNAL(valueChanged(qreal)),
             this, SLOT(_k_itemAppearUpdate(qreal)));
     d->itemAppearTimeline.setDuration(500);
     d->itemAppearTimeline.setUpdateInterval(5);
-    d->itemAppearTimeline.setCurveShape(QTimeLine::EaseInOutCurve);
+    d->itemAppearTimeline.setEasingCurve(QEasingCurve(QEasingCurve::InOutSine));
 
     connect(&d->itemDisappearTimeline, SIGNAL(valueChanged(qreal)),
             this, SLOT(_k_itemDisappearUpdate(qreal)));
     d->itemDisappearTimeline.setDuration(500);
     d->itemDisappearTimeline.setUpdateInterval(5);
-    d->itemDisappearTimeline.setCurveShape(QTimeLine::EaseInOutCurve);
+    d->itemDisappearTimeline.setEasingCurve(QEasingCurve(QEasingCurve::InOutSine));
 
     viewport()->installEventFilter(d->watcher);
     connect(d->watcher, SIGNAL(entryEntered(QModelIndex)),
@@ -470,7 +470,7 @@ void KFilePlacesView::setUrl(const KUrl &url)
 
     if (index.isValid()) {
         if (current!=index && placesModel->isHidden(current) && !d->showAll) {
-            KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(itemDelegate());
+            KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate*>(itemDelegate());
             delegate->addDisappearingItem(current);
 
             if (d->itemDisappearTimeline.state()!=QTimeLine::Running) {
@@ -480,7 +480,7 @@ void KFilePlacesView::setUrl(const KUrl &url)
         }
 
         if (current!=index && placesModel->isHidden(index) && !d->showAll) {
-            KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(itemDelegate());
+            KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate*>(itemDelegate());
             delegate->addAppearingItem(index);
 
             if (d->itemAppearTimeline.state()!=QTimeLine::Running) {
@@ -511,7 +511,7 @@ void KFilePlacesView::setShowAll(bool showAll)
 
     d->showAll = showAll;
 
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(itemDelegate());
+    KFilePlacesViewDelegate *delegate = static_cast<KFilePlacesViewDelegate*>(itemDelegate());
 
     int rowCount = placesModel->rowCount();
     QModelIndex current = placesModel->closestItem(d->currentUrl);
@@ -556,7 +556,7 @@ void KFilePlacesView::keyPressEvent(QKeyEvent *event)
 void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
 {
     KFilePlacesModel *placesModel = qobject_cast<KFilePlacesModel*>(model());
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(itemDelegate());
 
     if (placesModel==0) return;
 
@@ -577,8 +577,8 @@ void KFilePlacesView::contextMenuEvent(QContextMenuEvent *event)
         if (!placesModel->isDevice(index)) {
             if (placesModel->url(index) == KUrl("trash:/")) {
                 emptyTrash = menu.addAction(KIcon("trash-empty"), i18nc("@action:inmenu", "Empty Trash"));
-                KConfig trashConfig("trashrc", KConfig::SimpleConfig);
-                emptyTrash->setEnabled(!trashConfig.group("Status").readEntry("Empty", true));
+                KSettings trashConfig("trashrc", KSettings::SimpleConfig);
+                emptyTrash->setEnabled(!trashConfig.value("Status/Empty", true).toBool());
                 menu.addSeparator();
             }
             add = menu.addAction(KIcon("document-new"), i18n("Add Entry..."));
@@ -731,7 +731,7 @@ void KFilePlacesView::dragEnterEvent(QDragEnterEvent *event)
     QListView::dragEnterEvent(event);
     d->dragging = true;
 
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(itemDelegate());
     delegate->setShowHoverIndication(false);
 
     d->dropRect = QRect();
@@ -742,7 +742,7 @@ void KFilePlacesView::dragLeaveEvent(QDragLeaveEvent *event)
     QListView::dragLeaveEvent(event);
     d->dragging = false;
 
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(itemDelegate());
     delegate->setShowHoverIndication(true);
 
     setDirtyRegion(d->dropRect);
@@ -793,7 +793,7 @@ void KFilePlacesView::dropEvent(QDropEvent *event)
     QListView::dropEvent(event);
     d->dragging = false;
 
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(itemDelegate());
     delegate->setShowHoverIndication(true);
 }
 
@@ -856,7 +856,7 @@ void KFilePlacesView::rowsInserted(const QModelIndex &parent, int start, int end
     QListView::rowsInserted(parent, start, end);
     setUrl(d->currentUrl);
 
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(itemDelegate());
     KFilePlacesModel *placesModel = qobject_cast<KFilePlacesModel*>(model());
 
     for (int i=start; i<=end; ++i) {
@@ -892,7 +892,7 @@ QSize KFilePlacesView::sizeHint() const
            textWidth = qMax(textWidth,fm.width(index.data(Qt::DisplayRole).toString()));
     }
 
-    const int iconSize = KIconLoader::global()->currentSize(KIconLoader::Dialog);
+    const int iconSize = KIconLoader::global()->currentSize(KIconLoader::Small) + 3 * LATERAL_MARGIN;
     return QSize(iconSize + textWidth + fm.height() / 2, height);
 }
 
@@ -918,7 +918,7 @@ void KFilePlacesView::Private::setCurrentIndex(const QModelIndex &index)
 
 void KFilePlacesView::Private::adaptItemSize()
 {
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(q->itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(q->itemDelegate());
     if (!delegate) return;
 
     if (!autoResizeItems) {
@@ -946,7 +946,7 @@ void KFilePlacesView::Private::adaptItemSize()
 
     if (rowCount==0) return; // We've nothing to display anyway
 
-    const int minSize = 16;
+    const int minSize = IconSize(KIconLoader::Small);
     const int maxSize = 64;
 
     int textWidth = 0;
@@ -1122,14 +1122,14 @@ void KFilePlacesView::Private::_k_adaptItemsUpdate(qreal value)
 
     int size = oldSize+add;
 
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(q->itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(q->itemDelegate());
     delegate->setIconSize(size);
     q->scheduleDelayedItemsLayout();
 }
 
 void KFilePlacesView::Private::_k_itemAppearUpdate(qreal value)
 {
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(q->itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(q->itemDelegate());
 
     delegate->setAppearingItemProgress(value);
     q->scheduleDelayedItemsLayout();
@@ -1137,7 +1137,7 @@ void KFilePlacesView::Private::_k_itemAppearUpdate(qreal value)
 
 void KFilePlacesView::Private::_k_itemDisappearUpdate(qreal value)
 {
-    KFilePlacesViewDelegate *delegate = dynamic_cast<KFilePlacesViewDelegate*>(q->itemDelegate());
+    KFilePlacesViewDelegate *delegate = qobject_cast<KFilePlacesViewDelegate*>(q->itemDelegate());
 
     delegate->setDisappearingItemProgress(value);
 
@@ -1195,4 +1195,5 @@ void KFilePlacesView::dataChanged(const QModelIndex &topLeft, const QModelIndex
 }
 
 #include "kfileplacesview.moc"
-#include "kfileplacesview_p.moc"
+#include "moc_kfileplacesview.cpp"
+#include "moc_kfileplacesview_p.cpp"
