@@ -63,12 +63,10 @@
 #include <QtGui/QLineEdit>
 #include <QtGui/QSplitter>
 #include <QtGui/QAbstractProxyModel>
-#include <QtGui/QHelpEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QApplication>
-#include <QtCore/QFSFileEngine>
 #include <kshell.h>
 #include <kmessagebox.h>
-#include <kauthorized.h>
 
 class KFileWidgetPrivate
 {
@@ -292,30 +290,6 @@ static const char autocompletionWhatsThisText[] = I18N_NOOP("<qt>While typing in
                                                   "This feature can be controlled by clicking with the right mouse button "
                                                   "and selecting a preferred mode from the <b>Text Completion</b> menu.</qt>");
 
-// returns true if the string contains "<a>:/" sequence, where <a> is at least 2 alpha chars
-static bool containsProtocolSection( const QString& string )
-{
-    int len = string.length();
-    static const char prot[] = ":/";
-    for (int i=0; i < len;) {
-        i = string.indexOf( QLatin1String(prot), i );
-        if (i == -1)
-            return false;
-        int j=i-1;
-        for (; j >= 0; j--) {
-            const QChar& ch( string[j] );
-            if (ch.toLatin1() == 0 || !ch.isLetter())
-                break;
-            if (ch.isSpace() && (i-j-1) >= 2)
-                return true;
-        }
-        if (j < 0 && i >= 2)
-            return true; // at least two letters before ":/"
-        i += 3; // skip : and / and one char
-    }
-    return false;
-}
-
 KFileWidget::KFileWidget( const KUrl& _startDir, QWidget *parent )
     : QWidget(parent), KAbstractFileWidget(), d(new KFileWidgetPrivate(this))
 {
@@ -359,20 +333,10 @@ KFileWidget::KFileWidget( const KUrl& _startDir, QWidget *parent )
 
     KUrl u;
     KUrlComboBox *pathCombo = d->urlNavigator->editor();
-#ifdef Q_WS_WIN
-    foreach( const QFileInfo &drive,QFSFileEngine::drives() )
-    {
-        u.setPath( drive.filePath() );
-        pathCombo->addDefaultUrl(u,
-                                 KIO::pixmapForUrl( u, 0, KIconLoader::Small ),
-                                 i18n("Drive: %1",  u.toLocalFile()));
-    }
-#else
     u.setPath(QDir::rootPath());
     pathCombo->addDefaultUrl(u,
                              KIO::pixmapForUrl(u, 0, KIconLoader::Small),
                              u.toLocalFile());
-#endif
 
     u.setPath(QDir::homePath());
     pathCombo->addDefaultUrl(u, KIO::pixmapForUrl(u, 0, KIconLoader::Small),
@@ -885,7 +849,7 @@ void KFileWidget::slotOk()
         // the user, convert it to relative
         if (!locationEditCurrentText.isEmpty() && !(mode & KFile::Directory) &&
             (QDir::isAbsolutePath(locationEditCurrentText) ||
-             containsProtocolSection(locationEditCurrentText))) {
+             !KUrl::isRelativeUrl(locationEditCurrentText))) {
 
             QString fileName;
             KUrl url(locationEditCurrentText);
@@ -945,12 +909,6 @@ void KFileWidget::slotOk()
         KIO::StatJob *statJob = KIO::stat(url, KIO::HideProgressInfo);
         bool res = KIO::NetAccess::synchronousRun(statJob, this);
 
-        if (!KAuthorized::authorizeUrlAction("open", KUrl(), url)) {
-            QString msg = KIO::buildErrorString(KIO::ERR_ACCESS_DENIED, d->url.prettyUrl());
-            KMessageBox::error(this, msg);
-            return;
-        }
-
         // if we are on local mode, make sure we haven't got a remote base url
         if ((mode & KFile::LocalOnly) && !d->mostLocalUrl(d->url).isLocalFile()) {
             KMessageBox::sorry(this,
@@ -1048,7 +1006,6 @@ void KFileWidget::accept()
     d->addToRecentDocuments();
 
     if (!(mode() & KFile::Files)) { // single selection
-        emit fileSelected(d->url.url()); // old
         emit fileSelected(d->url);
     }
 
@@ -1078,7 +1035,6 @@ void KFileWidgetPrivate::_k_fileHighlighted(const KFileItem &i)
             setLocationText( url );
         }
 
-        emit q->fileHighlighted(url.url()); // old
         emit q->fileHighlighted(url);
     } else {
         multiSelectionChanged();
@@ -1446,7 +1402,7 @@ void KFileWidgetPrivate::_k_urlEntered(const KUrl& url)
     urlNavigator->setLocationUrl(url);
 
     // is trigged in ctor before completion object is set
-    KUrlCompletion *completion = dynamic_cast<KUrlCompletion*>(locationEdit->completionObject());
+    KUrlCompletion *completion = qobject_cast<KUrlCompletion*>(locationEdit->completionObject());
     if (completion) {
         completion->setDir( url.path() );
     }
@@ -1615,7 +1571,7 @@ KUrl::List& KFileWidgetPrivate::parseSelectedUrls()
     urlList.clear();
     if ( filenames.contains( '/' )) { // assume _one_ absolute filename
         KUrl u;
-        if ( containsProtocolSection( filenames ) )
+        if ( !KUrl::isRelativeUrl(filenames) )
             u = filenames;
         else
             u.setPath( filenames );
@@ -1924,7 +1880,7 @@ void KFileWidgetPrivate::readRecentFiles()
     combo->setUrl(ops->url());
     // since we delayed this moment, initialize the directory of the completion object to
     // our current directory (that was very probably set on the constructor)
-    KUrlCompletion *completion = dynamic_cast<KUrlCompletion*>(locationEdit->completionObject());
+    KUrlCompletion *completion = qobject_cast<KUrlCompletion*>(locationEdit->completionObject());
     if (completion) {
         completion->setDir(ops->url().url());
     }
@@ -2004,7 +1960,7 @@ KFileWidget::OperationMode KFileWidget::operationMode() const
 void KFileWidgetPrivate::_k_slotAutoSelectExtClicked()
 {
 //     kDebug (kfile_area) << "slotAutoSelectExtClicked(): "
-//                          << autoSelectExtCheckBox->isChecked() << endl;
+//                          << autoSelectExtCheckBox->isChecked();
 
     // whether the _user_ wants it on/off
     autoSelectExtChecked = autoSelectExtCheckBox->isChecked();
@@ -2084,39 +2040,6 @@ void KFileWidgetPrivate::_k_slotIconSizeSliderMoved(int _value)
     QApplication::sendEvent(iconSizeSlider, &toolTipEvent);
 }
 
-static QString getExtensionFromPatternList(const QStringList &patternList)
-{
-//     kDebug(kfile_area);
-
-    QString ret;
-//     kDebug (kfile_area) << "\tgetExtension " << patternList;
-
-    QStringList::ConstIterator patternListEnd = patternList.end();
-    for (QStringList::ConstIterator it = patternList.begin();
-         it != patternListEnd;
-         ++it)
-    {
-//         kDebug (kfile_area) << "\t\ttry: \'" << (*it) << "\'";
-
-        // is this pattern like "*.BMP" rather than useless things like:
-        //
-        // README
-        // *.
-        // *.*
-        // *.JP*G
-        // *.JP?
-        if ((*it).startsWith (QLatin1String("*.")) &&
-            (*it).length() > 2 &&
-            (*it).indexOf('*', 2) < 0 && (*it).indexOf ('?', 2) < 0)
-        {
-            ret = (*it).mid (1);
-            break;
-        }
-    }
-
-    return ret;
-}
-
 static QString stripUndisplayable (const QString &string)
 {
     QString ret = string;
@@ -2174,7 +2097,21 @@ void KFileWidgetPrivate::updateAutoSelectExtension()
             if (filter.indexOf ('/') < 0)
             {
                 extensionList = filter.split(' ', QString::SkipEmptyParts);
-                defaultExtension = getExtensionFromPatternList(extensionList);
+                foreach (const QString it, extensionList) {
+                    // is this pattern like "*.BMP" rather than useless things like:
+                    //
+                    // README
+                    // *.
+                    // *.*
+                    // *.JP*G
+                    // *.JP?
+                    if (it.startsWith(QLatin1String("*.")) &&
+                        it.length() > 2 &&
+                        it.indexOf('*', 2) < 0 && it.indexOf('?', 2) < 0) {
+                        defaultExtension = it.mid(1);
+                        break;
+                    }
+                }
             }
             // e.g. "text/html"
             else
@@ -2716,29 +2653,6 @@ void KFileWidget::setCustomWidget(const QString& text, QWidget* widget)
     d->lafBox->addWidget(widget, 2, 1, Qt::AlignVCenter);
 }
 
-void KFileWidget::virtual_hook( int id, void* data )
-{
-    // this is a workaround to avoid binary compatibility breakage
-    // since setConfirmOverwrite in kabstractfilewidget.h is a new function
-    // introduced for 4.2. As stated in kabstractfilewidget.h this workaround
-    // is going to become a virtual function for KDE5
-
-    switch (id) {
-        case 0: { // setConfirmOverwrite(bool)
-                bool *enable = static_cast<bool*>(data);
-                d->confirmOverwrite = *enable;
-            }
-            break;
-        case 1: { // setInlinePreviewShown(bool)
-                bool *show = static_cast<bool*>(data);
-                d->setInlinePreviewShown(*show);
-            }
-            break;
-        default:
-            break;
-    }
-}
-
 KDirOperator* KFileWidget::dirOperator()
 {
     return d->ops;
@@ -2785,4 +2699,4 @@ void KFileWidgetPrivate::setInlinePreviewShown(bool show)
 }
 
 
-#include "kfilewidget.moc"
+#include "moc_kfilewidget.cpp"
