@@ -18,6 +18,7 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "config-kfile.h"
 #include "knewfilemenu.h"
 #include "knameandurlinputdialog.h"
 
@@ -138,7 +139,7 @@ public:
 
 void KNewFileMenuSingleton::parseFiles()
 {
-    //kDebug(1203);
+    //kDebug(kfile_area);
     filesParsed = true;
     QMutableListIterator<KNewFileMenuSingleton::Entry> templIter(*templatesList);
     while (templIter.hasNext()) {
@@ -171,7 +172,7 @@ void KNewFileMenuSingleton::parseFiles()
                         {
                             // A relative path, then (that's the default in the files we ship)
                             QString linkDir = filePath.left(filePath.lastIndexOf('/') + 1 /*keep / */);
-                            //kDebug(1203) << "linkDir=" << linkDir;
+                            //kDebug(kfile_area) << "linkDir=" << linkDir;
                             templatePath = linkDir + templatePath;
                         }
                     }
@@ -194,7 +195,7 @@ void KNewFileMenuSingleton::parseFiles()
                     text.truncate(text.length() - 8);
             }
             templ.text = text;
-            /*kDebug(1203) << "Updating entry with text=" << text
+            /*kDebug(kfile_area) << "Updating entry with text=" << text
                           << "entryType=" << templ.entryType
                           << "templatePath=" << templ.templatePath;*/
         }
@@ -361,7 +362,7 @@ public:
 bool KNewFileMenuPrivate::checkSourceExists(const QString& src)
 {
     if (!QFile::exists(src)) {
-        kWarning(1203) << src << "doesn't exist" ;
+        kWarning(kfile_area) << src << "doesn't exist" ;
 
 	KDialog* dialog = new KDialog(m_parentWidget);
 	dialog->setCaption( i18n("Sorry") );
@@ -552,7 +553,7 @@ void KNewFileMenuPrivate::executeStrategy()
             // which KIO::symlink obviously doesn't emit... Needs code in FileUndoManager.
             //KIO::FileUndoManager::self()->recordJob(KIO::FileUndoManager::Link, lstSrc, dest, kjob);
         } else {
-            //kDebug(1203) << "KIO::copyAs(" << uSrc.url() << "," << dest.url() << ")";
+            //kDebug(kfile_area) << "KIO::copyAs(" << uSrc.url() << "," << dest.url() << ")";
             KIO::CopyJob * job = KIO::copyAs(uSrc, dest);
             job->setDefaultPermissions(true);
             kjob = job;
@@ -596,15 +597,12 @@ void KNewFileMenuPrivate::fillMenu()
     {
         KNewFileMenuSingleton::Entry& entry = *templ;
         if (entry.entryType != KNewFileMenuSingleton::Separator) {
-            // There might be a .desktop for that one already, if it's a kdelnk
-            // This assumes we read .desktop files before .kdelnk files ...
-
-            // In fact, we skip any second item that has the same text as another one.
-            // Duplicates in a menu look bad in any case.
+            // There might be a .desktop for that one already. In fact, we skip any second item
+            // that has the same text as another one. Duplicates in a menu look bad in any case.
 
             const bool bSkip = seenTexts.contains(entry.text);
             if (bSkip) {
-                kDebug(1203) << "skipping" << entry.filePath;
+                kDebug(kfile_area) << "skipping" << entry.filePath;
             } else {
                 seenTexts.insert(entry.text);
                 //const KNewFileMenuSingleton::Entry entry = templatesList->at(i-1);
@@ -800,21 +798,17 @@ void KNewFileMenuPrivate::_k_slotCreateHiddenDirectory()
 void KNewFileMenuPrivate::_k_slotFillTemplates()
 {
     KNewFileMenuSingleton* s = kNewMenuGlobals;
-    //kDebug(1203);
+    //kDebug(kfile_area);
     // Ensure any changes in the templates dir will call this
     if (! s->dirWatch) {
         s->dirWatch = new KDirWatch;
         const QStringList dirs = m_actionCollection->componentData().dirs()->resourceDirs("templates");
         for (QStringList::const_iterator it = dirs.constBegin() ; it != dirs.constEnd() ; ++it) {
-            //kDebug(1203) << "Templates resource dir:" << *it;
+            //kDebug(kfile_area) << "Templates resource dir:" << *it;
             s->dirWatch->addDir(*it);
         }
         QObject::connect(s->dirWatch, SIGNAL(dirty(QString)),
                          q, SLOT(_k_slotFillTemplates()));
-        QObject::connect(s->dirWatch, SIGNAL(created(QString)),
-                         q, SLOT(_k_slotFillTemplates()));
-        QObject::connect(s->dirWatch, SIGNAL(deleted(QString)),
-                         q, SLOT(_k_slotFillTemplates()));
         // Ok, this doesn't cope with new dirs in KDEDIRS, but that's another story
     }
     ++s->templatesVersion;
@@ -826,7 +820,7 @@ void KNewFileMenuPrivate::_k_slotFillTemplates()
     const QStringList files = m_actionCollection->componentData().dirs()->findAllResources("templates");
     QMap<QString, KNewFileMenuSingleton::Entry> slist; // used for sorting
     Q_FOREACH(const QString& file, files) {
-        //kDebug(1203) << file;
+        //kDebug(kfile_area) << file;
         if (file[0] != '.') {
             KNewFileMenuSingleton::Entry e;
             e.filePath = file;
@@ -926,31 +920,20 @@ void KNewFileMenuPrivate::_k_slotUrlDesktopFile()
     if (m_copyData.m_chosenFileName.isEmpty() || linkUrl.isEmpty())
         return;
 
-    // It's a "URL" desktop file; we need to make a temp copy of it, to modify it
-    // before copying it to the final destination [which could be a remote protocol]
-    KTemporaryFile tmpFile;
-    tmpFile.setAutoRemove(false); // done below
-    if (!tmpFile.open()) {
-        kError() << "Couldn't create temp file!";
-        return;
-    }
-
     if (!checkSourceExists(m_copyData.m_templatePath)) {
         return;
     }
 
-    // First copy the template into the temp file
-    QFile file(m_copyData.m_templatePath);
-    if (!file.open(QIODevice::ReadOnly)) {
-        kError() << "Couldn't open template" << m_copyData.m_templatePath;
+    // It's a "URL" desktop file; we need to make a temp copy of it, to modify it
+    // before copying it to the final destination [which could be a remote protocol]
+    const QString tempFileName = KTemporaryFile::filePath();
+    Q_ASSERT(!tempFileName.isEmpty());
+
+    bool ok = QFile::copy(m_copyData.m_templatePath, tempFileName);
+    if (!ok) {
+        kError() << "Couldn't copy template" << m_copyData.m_templatePath << "to" << tempFileName;
         return;
     }
-    const QByteArray data = file.readAll();
-    tmpFile.write(data);
-    const QString tempFileName = tmpFile.fileName();
-    Q_ASSERT(!tempFileName.isEmpty());
-    tmpFile.close();
-    file.close();
 
     KDesktopFile df(tempFileName);
     KConfigGroup group = df.desktopGroup();
@@ -983,17 +966,17 @@ KNewFileMenu::KNewFileMenu(KActionCollection* collection, const QString& name, Q
 
 KNewFileMenu::~KNewFileMenu()
 {
-    //kDebug(1203) << this;
+    //kDebug(kfile_area) << this;
     delete d;
 }
 
 void KNewFileMenu::checkUpToDate()
 {
     KNewFileMenuSingleton* s = kNewMenuGlobals;
-    //kDebug(1203) << this << "m_menuItemsVersion=" << d->m_menuItemsVersion
+    //kDebug(kfile_area) << this << "m_menuItemsVersion=" << d->m_menuItemsVersion
     //              << "s->templatesVersion=" << s->templatesVersion;
     if (d->m_menuItemsVersion < s->templatesVersion || s->templatesVersion == 0) {
-        //kDebug(1203) << "recreating actions";
+        //kDebug(kfile_area) << "recreating actions";
         // We need to clean up the action collection
         // We look for our actions using the group
         foreach (QAction* action, d->m_newMenuGroup->actions())
@@ -1147,5 +1130,5 @@ QStringList KNewFileMenu::supportedMimeTypes() const
 }
 
 
-#include "knewfilemenu.moc"
+#include "moc_knewfilemenu.cpp"
 
