@@ -40,13 +40,13 @@
 #include <kurifilter.h>
 
 #include <QtCore/QDir>
-#include <QtCore/QLinkedList>
+#include <QtCore/QList>
 #include <QtCore/QTimer>
 #include <QtGui/QApplication>
 #include <QtGui/QBoxLayout>
 #include <QtGui/QClipboard>
-#include <QtGui/QDropEvent>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
+#include <QtGui/qevent.h>
 #include <QtGui/QLabel>
 #include <QtGui/QPainter>
 #include <QtGui/QStyleOption>
@@ -58,10 +58,6 @@ using namespace KDEPrivate;
 struct LocationData
 {
     KUrl url;
-#ifndef KDE_NO_DEPRECATED
-    KUrl rootUrl;      // KDE5: remove after the deprecated methods have been removed
-    QPoint pos;        // KDE5: remove after the deprecated methods have been removed
-#endif
     QByteArray state;
 };
 
@@ -346,7 +342,7 @@ void KUrlNavigator::Private::openPathSelectorMenu()
     const KUrl firstVisibleUrl = m_navButtons.first()->url();
 
     QString spacer;
-    KMenu* popup = new KMenu(q);
+    QPointer<KMenu> popup = new KMenu(q);
     popup->setLayoutDirection(Qt::LeftToRight);
 
     const QString placePath = retrievePlacePath();
@@ -381,7 +377,10 @@ void KUrlNavigator::Private::openPathSelectorMenu()
         q->setLocationUrl(url);
     }
 
-    popup->deleteLater();
+    // Delete the menu, unless it has been deleted in its own nested event loop already.
+    if (popup) {
+        popup->deleteLater();
+    }
 }
 
 void KUrlNavigator::Private::switchView()
@@ -404,11 +403,6 @@ void KUrlNavigator::Private::dropUrls(const KUrl& destination, QDropEvent* event
     if (!urls.isEmpty()) {
         emit q->urlsDropped(destination, event);
 
-#ifndef KDE_NO_DEPRECATED
-        // KDE5: remove, as the signal has been replaced by
-        // urlsDropped(const KUrl& destination, QDropEvent* event)
-        emit q->urlsDropped(urls, destination);
-#endif
     }
 }
 
@@ -416,7 +410,7 @@ void KUrlNavigator::Private::slotNavigatorButtonClicked(const KUrl& url, Qt::Mou
 {
     if (button & Qt::LeftButton) {
         q->setLocationUrl(url);
-    } else if (button & Qt::MidButton) {
+    } else if (button & Qt::MiddleButton) {
         emit q->tabRequested(url);
     }
 }
@@ -425,28 +419,28 @@ void KUrlNavigator::Private::openContextMenu()
 {
     q->setActive(true);
 
-    KMenu popup(q);
+    QPointer<KMenu> popup = new KMenu(q);
 
     // provide 'Copy' action, which copies the current URL of
     // the URL navigator into the clipboard
-    QAction* copyAction = popup.addAction(KIcon("edit-copy"), i18n("Copy"));
+    QAction* copyAction = popup->addAction(KIcon("edit-copy"), i18n("Copy"));
 
     // provide 'Paste' action, which copies the current clipboard text
     // into the URL navigator
-    QAction* pasteAction = popup.addAction(KIcon("edit-paste"), i18n("Paste"));
+    QAction* pasteAction = popup->addAction(KIcon("edit-paste"), i18n("Paste"));
     QClipboard* clipboard = QApplication::clipboard();
     pasteAction->setEnabled(!clipboard->text().isEmpty());
 
-    popup.addSeparator();
+    popup->addSeparator();
 
     // provide radiobuttons for toggling between the edit and the navigation mode
-    QAction* editAction = popup.addAction(i18n("Edit"));
+    QAction* editAction = popup->addAction(i18n("Edit"));
     editAction->setCheckable(true);
 
-    QAction* navigateAction = popup.addAction(i18n("Navigate"));
+    QAction* navigateAction = popup->addAction(i18n("Navigate"));
     navigateAction->setCheckable(true);
 
-    QActionGroup* modeGroup = new QActionGroup(&popup);
+    QActionGroup* modeGroup = new QActionGroup(popup);
     modeGroup->addAction(editAction);
     modeGroup->addAction(navigateAction);
     if (q->isUrlEditable()) {
@@ -455,14 +449,14 @@ void KUrlNavigator::Private::openContextMenu()
         navigateAction->setChecked(true);
     }
 
-    popup.addSeparator();
+    popup->addSeparator();
 
     // allow showing of the full path
-    QAction* showFullPathAction = popup.addAction(i18n("Show Full Path"));
+    QAction* showFullPathAction = popup->addAction(i18n("Show Full Path"));
     showFullPathAction->setCheckable(true);
     showFullPathAction->setChecked(q->showFullPath());
 
-    QAction* activatedAction = popup.exec(QCursor::pos());
+    QAction* activatedAction = popup->exec(QCursor::pos());
     if (activatedAction == copyAction) {
         QMimeData* mimeData = new QMimeData();
         mimeData->setText(q->locationUrl().pathOrUrl());
@@ -476,6 +470,11 @@ void KUrlNavigator::Private::openContextMenu()
     } else if (activatedAction == showFullPathAction) {
         q->setShowFullPath(showFullPathAction->isChecked());
     }
+
+    // Delete the menu, unless it has been deleted in its own nested event loop already.
+    if (popup) {
+        popup->deleteLater();
+    }
 }
 
 void KUrlNavigator::Private::slotPathBoxChanged(const QString& text)
@@ -642,7 +641,7 @@ void KUrlNavigator::Private::updateButtonVisibility()
     bool isLastButton = true;
     bool hasHiddenButtons = false;
 
-    QLinkedList<KUrlNavigatorButton*> buttonsToShow;
+    QList<KUrlNavigatorButton*> buttonsToShow;
     while (it != itBegin) {
         --it;
         KUrlNavigatorButton* button = (*it);
@@ -674,7 +673,7 @@ void KUrlNavigator::Private::updateButtonVisibility()
         // Check whether going upwards is possible. If this is the case, show the drop-down button.
         KUrl url = m_navButtons.front()->url();
         url.adjustPath(KUrl::AddTrailingSlash);
-        const bool visible = !url.equals(url.upUrl()) && (url.protocol() != "nepomuksearch");
+        const bool visible = !url.equals(url.upUrl());
         m_dropDownButton->setVisible(visible);
     }
 }
@@ -693,11 +692,7 @@ QString KUrlNavigator::Private::firstButtonText() const
     if (text.isEmpty()) {
         const KUrl currentUrl = q->locationUrl();
         if (currentUrl.isLocalFile()) {
-#ifdef Q_OS_WIN
-            text = currentUrl.path().length() > 1 ? currentUrl.path().left(2) : QDir::rootPath();
-#else
             text = m_showFullPath ? QLatin1String("/") : i18n("Custom Path");
-#endif
         } else {
             text = currentUrl.protocol() + QLatin1Char(':');
             if (!currentUrl.host().isEmpty()) {
@@ -726,11 +721,7 @@ KUrl KUrlNavigator::Private::buttonUrl(int index) const
         if (index == 0) {
             // prevent the last "/" from being stripped
             // or we end up with an empty path
-#ifdef Q_OS_WIN
-            pathOrUrl = pathOrUrl.length() > 1 ? pathOrUrl.left(2) : QDir::rootPath();
-#else
             pathOrUrl = QLatin1String("/");
-#endif
         } else {
             pathOrUrl = pathOrUrl.section('/', 0, index);
         }
@@ -781,7 +772,6 @@ bool KUrlNavigator::Private::isCompressedPath(const KUrl& url) const
             mime->is("application/x-xz-compressed-tar") ||
             mime->is("application/x-tar") ||
             mime->is("application/x-tarz") ||
-            mime->is("application/x-tzo") || // (not sure KTar supports those?)
             mime->is("application/zip") ||
             mime->is("application/x-archive");
 }
@@ -1082,29 +1072,8 @@ void KUrlNavigator::setFocus()
     }
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KUrlNavigator::setUrl(const KUrl& url)
-{
-    // deprecated
-    setLocationUrl(url);
-}
-#endif
 
-#ifndef KDE_NO_DEPRECATED
-void KUrlNavigator::saveRootUrl(const KUrl& url)
-{
-    // deprecated
-    d->m_history[d->m_historyIndex].rootUrl = url;
-}
-#endif
 
-#ifndef KDE_NO_DEPRECATED
-void KUrlNavigator::savePosition(int x, int y)
-{
-    // deprecated
-    d->m_history[d->m_historyIndex].pos = QPoint(x, y);
-}
-#endif
 
 void KUrlNavigator::keyPressEvent(QKeyEvent* event)
 {
@@ -1122,7 +1091,7 @@ void KUrlNavigator::keyReleaseEvent(QKeyEvent* event)
 
 void KUrlNavigator::mouseReleaseEvent(QMouseEvent* event)
 {
-    if (event->button() == Qt::MidButton) {
+    if (event->button() == Qt::MiddleButton) {
         const QRect bounds = d->m_toggleEditableMode->geometry();
         if (bounds.contains(event->pos())) {
             // The middle mouse button has been clicked above the
@@ -1203,62 +1172,4 @@ QStringList KUrlNavigator::customProtocols() const
     return d->m_customProtocols;
 }
 
-#ifndef KDE_NO_DEPRECATED
-const KUrl& KUrlNavigator::url() const
-{
-    // deprecated
-
-    // Workaround required because of flawed interface ('const KUrl&' is returned
-    // instead of 'KUrl'): remember the URL to prevent a dangling pointer
-    static KUrl url;
-    url = locationUrl();
-    return url;
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-KUrl KUrlNavigator::url(int index) const
-{
-    // deprecated
-    return d->buttonUrl(index);
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-KUrl KUrlNavigator::historyUrl(int historyIndex) const
-{
-    // deprecated
-    return locationUrl(historyIndex);
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-const KUrl& KUrlNavigator::savedRootUrl() const
-{
-    // deprecated
-
-    // Workaround required because of flawed interface ('const KUrl&' is returned
-    // instead of 'KUrl'): remember the root URL to prevent a dangling pointer
-    static KUrl rootUrl;
-    rootUrl = d->m_history[d->m_historyIndex].rootUrl;
-    return rootUrl;
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-QPoint KUrlNavigator::savedPosition() const
-{
-    // deprecated
-    return d->m_history[d->m_historyIndex].pos;
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-void KUrlNavigator::setHomeUrl(const QString& homeUrl)
-{
-    // deprecated
-    setLocationUrl(KUrl(homeUrl));
-}
-#endif
-
-#include "kurlnavigator.moc"
+#include "moc_kurlnavigator.cpp"
