@@ -27,19 +27,17 @@
 
 #include <kurl.h>
 #include <QtGui/QWidget>
-#include <QtCore/QByteArray>
 
 class KFilePlacesModel;
 class KUrlComboBox;
-class QMouseEvent;
+#include <QMouseEvent>
 
 /**
  * @brief Widget that allows to navigate through the paths of an URL.
  *
  * The URL navigator offers two modes:
- * - Editable:     Represents the 'classic' mode, where the URL of the location
- *                 is editable inside a line editor. By pressing RETURN
- *                 the URL will get activated.
+ * - Editable:     The URL of the location is editable inside an editor.
+ *                 By pressing RETURN the URL will get activated.
  * - Non editable ("breadcrumb view"): The URL of the location is represented by
  *                 a number of buttons, where each button represents a path
  *                 of the URL. By clicking on a button the path will get
@@ -113,7 +111,7 @@ public:
      * data << QPoint(x, y);
      * data << ...;
      * ...
-     * urlNavigator::saveLocationState(state);
+     * urlNavigator->saveLocationState(state);
      * \endcode
      *
      * @since 4.5
@@ -164,6 +162,8 @@ public:
      *
      * @see KUrlNavigator::setHomeUrl()
      */
+    // KDE5: Remove the home-property. It is sufficient to invoke
+    // KUrlNavigator::setLocationUrl(homeUrl) on application-side.
     void goHome();
 
     /**
@@ -171,6 +171,8 @@ public:
      * home URL is set, the default home path of the user is used.
      * @since 4.5
      */
+    // KDE5: Remove the home-property. It is sufficient to invoke
+    // KUrlNavigator::setLocationUrl(homeUrl) on application-side.
     void setHomeUrl(const KUrl& url);
 
     KUrl homeUrl() const;
@@ -265,6 +267,8 @@ public:
      * If an application supports only some special protocols, they can be set
      * with \a protocols .
      */
+    // KDE5: Think about removing the custom-protocols-property. It had been used
+    // only by one application currently which uses a different approach now.
     void setCustomProtocols(const QStringList& protocols);
 
     /**
@@ -272,47 +276,6 @@ public:
      */
     QStringList customProtocols() const;
 
-    /**
-     * @return     The current URL of the location.
-     * @deprecated Use KUrlNavigator::locationUrl() instead.
-     */
-    KDE_DEPRECATED const KUrl& url() const;
-
-    /**
-     * @return The portion of the current URL up to the path part given
-     * by \a index. Assuming that the current URL is /home/peter/Documents/Music,
-     * then the following URLs are returned for an index:
-     * - index <= 0: /home
-     * - index is 1: /home/peter
-     * - index is 2: /home/peter/Documents
-     * - index >= 3: /home/peter/Documents/Music
-     * @deprecated It should not be necessary for a client of KUrlNavigator to query this information.
-     */
-    KDE_DEPRECATED KUrl url(int index) const;
-
-    /**
-     * @return URL for the history element with the index \a historyIndex.
-     *         The history index 0 represents the most recent URL.
-     * @since 4.3
-     * @deprecated Use KUrlNavigator::locationUrl(historyIndex) instead.
-     */
-    KDE_DEPRECATED KUrl historyUrl(int historyIndex) const;
-
-    /**
-     * @return The saved root URL for the current URL (see KUrlNavigator::saveRootUrl()).
-     * @deprecated Use KUrlNavigator::locationState() instead.
-     */
-    KDE_DEPRECATED const KUrl& savedRootUrl() const;
-
-    /**
-     * @return The saved contents position of the upper left corner
-     *         for the current URL.
-     * @deprecated Use KUrlNavigator::locationState() instead.
-     */
-    KDE_DEPRECATED QPoint savedPosition() const;
-
-    /** @deprecated Use setHomeUrl(const KUrl& url) instead. */
-    KDE_DEPRECATED void setHomeUrl(const QString& homeUrl);
 
 public Q_SLOTS:
     /**
@@ -331,26 +294,11 @@ public Q_SLOTS:
      */
     void requestActivation();
 
-    /* @see QWidget::setFocus() */
+#if !defined(DOXYGEN_SHOULD_SKIP_THIS)
+    // KDE5: Remove and listen for focus-signal instead
     void setFocus();
+#endif
 
-    /**
-     * Sets the location to \a url.
-     * @deprecated Use KUrlNavigator::setLocationUrl(url).
-     */
-    KDE_DEPRECATED void setUrl(const KUrl& url);
-
-    /**
-     * Saves the used root URL of the content for the current history element.
-     * @deprecated Use KUrlNavigator::saveLocationState() instead.
-     */
-    KDE_DEPRECATED void saveRootUrl(const KUrl& url);
-
-    /**
-     * Saves the coordinates of the contents for the current history element.
-     * @deprecated Use KUrlNavigator::saveLocationState() instead.
-     */
-    KDE_DEPRECATED void savePosition(int x, int y);
 
 Q_SIGNALS:
     /**
@@ -408,42 +356,34 @@ Q_SIGNALS:
      */
     void tabRequested(const KUrl& url);
 
-    /**
-     * Is emitted if the URLs \a urls have been dropped
-     * to the destination \a destination.
-     * @deprecated Use
-     * KUrlNavigator::urlsDropped(const KUrl& destination, QDropEvent* event)
-     * instead.
-     */
-    // KDE5: remove, as the signal has been replaced by
-    // urlsDropped(const KUrl& destination, QDropEvent* event)
-    KDE_DEPRECATED void urlsDropped(const KUrl::List& urls,
-                                    const KUrl& destination);
 
 protected:
-    /*
+#if !defined(DOXYGEN_SHOULD_SKIP_THIS)
+    /**
      * If the Escape key is pressed, the navigation bar should switch
      * to the breadcrumb view.
      * @see QWidget::keyPressEvent()
      */
     virtual void keyPressEvent(QKeyEvent* event);
-    
+
     /**
-     * Reimplemented for internal purposes
+     * Reimplemented for internal purposes.
      */
     virtual void keyReleaseEvent(QKeyEvent* event);
 
-    /*
+    /**
      * Paste the clipboard content as URL, if the middle mouse
      * button has been clicked.
      * @see QWidget::mouseReleaseEvent()
      */
     virtual void mouseReleaseEvent(QMouseEvent* event);
 
-    /* @see QWidget::resizeEvent() */
     virtual void resizeEvent(QResizeEvent* event);
 
+    virtual void wheelEvent(QWheelEvent* event);
+
     virtual bool eventFilter(QObject* watched, QEvent* event);
+#endif
 
 private:
     Q_PRIVATE_SLOT(d, void slotReturnPressed())
