@@ -31,14 +31,10 @@
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <sys/wait.h>
-#ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>		// Needed on some systems.
-#endif
-
+#include <sys/select.h> // Needed on some systems.
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
-#include "proctitle.h"
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,16 +42,12 @@
 #include <unistd.h>
 #include <locale.h>
 
+#include <qplatformdefs.h>
 #include <QtCore/QLibrary>
 #include <QtCore/QString>
 #include <QtCore/QFile>
-#include <QtCore/QDate>
-#include <QtCore/QFileInfo>
 #include <QtCore/QRegExp>
-#include <QtGui/QFont>
 #include <kcomponentdata.h>
-#include <klibrary.h>
-#include <kdemacros.h>
 #include <kstandarddirs.h>
 #include <kglobal.h>
 #include <kconfig.h>
@@ -64,6 +56,10 @@
 #include <kdebug.h>
 #include <kde_file.h>
 #include <ksavefile.h>
+#include <kpluginloader.h>
+#include <kdeversion.h>
+#include "klauncher_cmds.h"
+#include "proctitle.h"
 
 #ifdef Q_OS_LINUX
 #include <sys/prctl.h>
@@ -72,14 +68,6 @@
 #endif
 #endif
 
-#ifdef Q_WS_MACX
-#include <kkernel_mac.h>
-#endif
-
-#include <kdeversion.h>
-
-#include "klauncher_cmds.h"
-
 #ifdef Q_WS_X11
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -87,16 +75,6 @@
 #include <kstartupinfo.h>
 #endif
 
-#ifdef Q_WS_X11
-static const char *extra_libs[] = {
-    "libkio.so.5",
-    "libkparts.so.4",
-#ifdef __KDE_HAVE_GCC_VISIBILITY
-    "libplasma.so.3"
-#endif
-};
-#endif
-
 // #define SKIP_PROCTITLE 1
 
 extern char **environ;
@@ -115,10 +93,6 @@ static char sock_file[MAX_SOCK_FILE];
 #define DISPLAY "DISPLAY"
 #elif defined(Q_WS_QWS)
 #define DISPLAY "QWS_DISPLAY"
-#elif defined(Q_WS_MACX)
-#define DISPLAY "MAC_DISPLAY"
-#elif defined(Q_WS_WIN)
-#define DISPLAY "WIN_DISPLAY"
 #else
 #error Use QT/X11 or QT/Embedded
 #endif
@@ -136,7 +110,6 @@ static struct {
   int exit_status;
   pid_t fork;
   pid_t launcher_pid;
-  pid_t kded_pid;
   int n;
   char **argv;
   int (*func)(int, char *[]);
@@ -163,10 +136,6 @@ int kdeinit_x_errhandler( Display *, XErrorEvent *err );
 }
 #endif
 
-#ifdef KDEINIT_OOM_PROTECT
-static int oom_pipe = -1;
-#endif
-
 /*
  * Clean up the file descriptor table by closing all file descriptors
  * that are still open.
@@ -182,10 +151,7 @@ static void cleanup_fds()
         maxfd = rl.rlim_max;
     for (int fd = 3; fd < maxfd; ++fd)
     {
-#ifdef KDEINIT_OOM_PROTECT
-       if( fd != oom_pipe )
-#endif
-          close(fd);
+        close(fd);
     }
 }
 
@@ -400,20 +366,19 @@ static void complete_startup_info( KStartupInfoId& id, pid_t pid )
 }
 #endif
 
-QByteArray execpath_avoid_loops( const QByteArray& exec, int envc, const char* envs, bool avoid_loops )
+static QByteArray execpath_avoid_loops( const QByteArray& exec, int envc, const char* envs, bool avoid_loops )
 {
      QStringList paths;
-     const QRegExp pathSepRegExp(QString::fromLatin1("[:\b]"));
+     static const QChar pathSep = QChar::fromLatin1(':');
      if( envc > 0 ) /* use the passed environment */
      {
          const char* path = get_env_var( "PATH=", envc, envs );
          if( path != NULL )
-             paths = QFile::decodeName(path).split(pathSepRegExp);
+             paths = QFile::decodeName(path).split(pathSep);
      } else {
-         paths = QString::fromLocal8Bit(qgetenv("PATH")).split(pathSepRegExp, QString::KeepEmptyParts);
+         paths = QString::fromLocal8Bit(qgetenv("PATH")).split(pathSep, QString::KeepEmptyParts);
      }
-     QString execpath =
-         s_instance->dirs()->findExe(QFile::decodeName(exec), paths.join(QLatin1String(":")));
+     QString execpath = s_instance->dirs()->findExe(QFile::decodeName(exec), paths.join(pathSep));
      if (avoid_loops && !execpath.isEmpty()) {
          const int pos = execpath.lastIndexOf(QLatin1Char('/'));
          const QString bin_path = execpath.left(pos);
@@ -425,48 +390,13 @@ QByteArray execpath_avoid_loops( const QByteArray& exec, int envc, const char* e
                  break; // -->
              }
          }
-         execpath = s_instance->dirs()->findExe(QFile::decodeName(exec), paths.join(QLatin1String(":")));
+         execpath = s_instance->dirs()->findExe(QFile::decodeName(exec), paths.join(pathSep));
      }
      return QFile::encodeName(execpath);
 }
 
-#ifdef KDEINIT_OOM_PROTECT
-static void oom_protect_sighandler( int ) {
-}
-
-static void reset_oom_protect() {
-   if( oom_pipe <= 0 )
-      return;
-   struct sigaction act, oldact;
-   act.sa_handler = oom_protect_sighandler;
-   act.sa_flags = 0;
-   sigemptyset( &act.sa_mask );
-   sigaction( SIGUSR1, &act, &oldact );
-   sigset_t sigs, oldsigs;
-   sigemptyset( &sigs );
-   sigaddset( &sigs, SIGUSR1 );
-   sigprocmask( SIG_BLOCK, &sigs, &oldsigs );
-   pid_t pid = getpid();
-   if( write( oom_pipe, &pid, sizeof( pid_t )) > 0 ) {
-      sigsuspend( &oldsigs ); // wait for the signal to come
-   } else {
-#ifndef NDEBUG
-      fprintf( stderr, "Failed to reset OOM protection: %d\n", pid );
-#endif
-   }
-   sigprocmask( SIG_SETMASK, &oldsigs, NULL );
-   sigaction( SIGUSR1, &oldact, NULL );
-   close( oom_pipe );
-   oom_pipe = -1;
-}
-#else
-static void reset_oom_protect() {
-}
-#endif
-
 static pid_t launch(int argc, const char *_name, const char *args,
                     const char *cwd=0, int envc=0, const char *envs=0,
-                    bool reset_env = false,
                     const char *tty=0, bool avoid_loops = false,
                     const char* startup_id_str = "0" ) // krazy:exclude=doublequote_chars
 {
@@ -480,12 +410,8 @@ static pid_t launch(int argc, const char *_name, const char *args,
         name = _name;
         lib = QFile::decodeName(name);
         exec = name;
-        KLibrary klib(QLatin1String("libkdeinit4_") + lib, *s_instance );
+        KPluginLoader klib(lib, *s_instance );
         libpath = klib.fileName();
-        if( libpath.isEmpty()) {
-            KLibrary klib(lib, *s_instance);
-            libpath = klib.fileName();
-        }
         execpath = execpath_avoid_loops(exec, envc, envs, avoid_loops);
     } else {
         name = _name;
@@ -495,19 +421,6 @@ static pid_t launch(int argc, const char *_name, const char *args,
         if (lib.endsWith(QLatin1String(".so")))
             libpath = lib;
         else {
-            // try to match an absolute path to an executable binary (either in bin/ or in libexec/)
-            // to a kdeinit module in the same prefix
-            if( lib.contains( QLatin1String( "/lib" KDELIBSUFF "/kde4/libexec/" ))) {
-                libpath = QString( lib ).replace( QLatin1String( "/lib" KDELIBSUFF "/kde4/libexec/" ),
-                    QLatin1String("/lib" KDELIBSUFF "/libkdeinit4_")) + QLatin1String(".so");
-            } else if( lib.contains( QLatin1String( "/bin/" ))) {
-                libpath = QString( lib ).replace( QLatin1String( "/bin/" ),
-                    QLatin1String("/lib" KDELIBSUFF "/libkdeinit4_")) + QLatin1String(".so");
-            }
-            // Don't confuse the user with "Could not load libkdeinit4_foo.so" if it doesn't exist
-            if (!QFile::exists(libpath)) {
-                libpath.clear();
-            }
             execpath = exec;
         }
     }
@@ -537,9 +450,6 @@ static pid_t launch(int argc, const char *_name, const char *args,
 #endif
   // find out this path before forking, doing it afterwards
   // crashes on some platforms, notably OSX
-#ifdef Q_WS_MAC
-  const QString bundlepath = s_instance->dirs()->findExe(QFile::decodeName(execpath));
-#endif
 
   d.errorMsg = 0;
   d.fork = fork();
@@ -555,10 +465,9 @@ static pid_t launch(int argc, const char *_name, const char *args,
      break;
   case 0:
   {
-     /** Child **/
+     // Child
      close(d.fd[0]);
      close_fds();
-     reset_oom_protect();
 
      // Try to chdir, either to the requested directory or to the user's document path by default.
      // We ignore errors - if you write a desktop file with Exec=foo and Path=/doesnotexist,
@@ -567,22 +476,6 @@ static pid_t launch(int argc, const char *_name, const char *args,
          (void)chdir(cwd);
      }
 
-     if( reset_env ) // KWRAPPER/SHELL
-     {
-
-         QList<QByteArray> unset_envs;
-         for( int tmp_env_count = 0;
-              environ[tmp_env_count];
-              tmp_env_count++)
-             unset_envs.append( environ[ tmp_env_count ] );
-         foreach(const QByteArray &tmp, unset_envs)
-         {
-             int pos = tmp.indexOf( '=' );
-             if( pos >= 0 )
-                 unsetenv( tmp.left( pos ));
-         }
-     }
-
      for (int i = 0;  i < envc; i++)
      {
         putenv((char *)envs);
@@ -601,14 +494,6 @@ static pid_t launch(int argc, const char *_name, const char *args,
        QByteArray procTitle;
        d.argv = (char **) malloc(sizeof(char *) * (argc+1));
        d.argv[0] = (char *) _name;
-#ifdef Q_WS_MAC
-       QString argvexe = s_instance->dirs()->findExe(QString::fromLatin1(d.argv[0]));
-       if (!argvexe.isEmpty()) {
-          QByteArray cstr = argvexe.toLocal8Bit();
-          kDebug(7016) << "kdeinit4: launch() setting argv: " << cstr.data();
-          d.argv[0] = strdup(cstr.data());
-       }
-#endif
        for (int i = 1;  i < argc; i++)
        {
           d.argv[i] = (char *) args;
@@ -620,9 +505,9 @@ static pid_t launch(int argc, const char *_name, const char *args,
        d.argv[argc] = 0;
 
 #ifndef SKIP_PROCTITLE
-       /** Give the process a new name **/
+       // Give the process a new name
 #ifdef Q_OS_LINUX
-       /* set the process name, so that killall works like intended */
+       // Set the process name so that killall works like intended
        r = prctl(PR_SET_NAME, (unsigned long) name.data(), 0, 0, 0);
        if ( r == 0 )
            proctitle_set( "%s [kdeinit]%s", name.data(), procTitle.data() ? procTitle.data() : "" );
@@ -640,10 +525,6 @@ static pid_t launch(int argc, const char *_name, const char *args,
         exitWithErrorMsg(errorMsg);
      }
 
-
-     if ( !qgetenv("KDE_IS_PRELINKED").isEmpty() && !execpath.isEmpty())
-         libpath.truncate(0);
-
      QLibrary l(libpath);
 
      if ( !libpath.isEmpty() )
@@ -676,14 +557,8 @@ static pid_t launch(int argc, const char *_name, const char *args,
 
         setup_tty( tty );
 
-        QByteArray executable = execpath;
-#ifdef Q_WS_MAC
-        if (!bundlepath.isEmpty())
-           executable = QFile::encodeName(bundlepath);
-#endif
-
-        if (!executable.isEmpty())
-           execvp(executable, d.argv);
+        if (!execpath.isEmpty())
+           execvp(execpath.constData(), d.argv);
 
         d.result = 1; // Error
         write(d.fd[1], &d.result, 1);
@@ -691,19 +566,15 @@ static pid_t launch(int argc, const char *_name, const char *args,
         exit(255);
      }
 
-     void * sym = l.resolve( "kdeinitmain");
-     if (!sym )
-        {
-        sym = l.resolve( "kdemain" );
-        if ( !sym )
-           {
-            QString ltdlError = l.errorString();
-            fprintf(stderr, "Could not find kdemain: %s\n", qPrintable(ltdlError) );
-              QString errorMsg = i18n("Could not find 'kdemain' in '%1'.\n%2",
-                                      libpath, ltdlError);
-              exitWithErrorMsg(errorMsg);
-           }
-        }
+    void * sym = l.resolve( "kdemain" );
+    if ( !sym )
+    {
+        QString ltdlError = l.errorString();
+        fprintf(stderr, "Could not find kdemain: %s\n", qPrintable(ltdlError) );
+            QString errorMsg = i18n("Could not find 'kdemain' in '%1'.\n%2",
+                                    libpath, ltdlError);
+            exitWithErrorMsg(errorMsg);
+    }
 
      d.result = 0; // Success
      write(d.fd[1], &d.result, 1);
@@ -728,7 +599,7 @@ static pid_t launch(int argc, const char *_name, const char *args,
      break;
   }
   default:
-     /** Parent **/
+     // Parent
      close(d.fd[1]);
      bool exec = false;
      for(;;)
@@ -868,10 +739,51 @@ static void init_signals()
   sigaction( SIGPIPE, &act, 0L);
 }
 
+static void shutdown_kdeinit()
+{
+  QT_SOCKLEN_T socklen;
+
+  /** Test if socket file is already present
+   *  note that access() resolves symlinks, and so we check the actual
+   *  socket file if it exists
+   */
+  if (access(sock_file, W_OK) == 0)
+  {
+     int s;
+     struct sockaddr_un server;
+
+//     fprintf(stderr, "kdeinit4: Warning, socket_file already exists!\n");
+     // Create the socket stream
+     s = socket(PF_UNIX, SOCK_STREAM, 0);
+     if (s < 0)
+     {
+        perror("socket() failed");
+        exit(255);
+     }
+     server.sun_family = AF_UNIX;
+     strcpy(server.sun_path, sock_file);
+     socklen = sizeof(server);
+
+     if(connect(s, (struct sockaddr *)&server, socklen) == 0)
+     {
+        fprintf(stderr, "kdeinit4: Shutting down running client.\n");
+        klauncher_header request_header;
+        request_header.cmd = LAUNCHER_TERMINATE_KDEINIT;
+        request_header.arg_length = 0;
+        write(s, &request_header, sizeof(request_header));
+        sleep(1); // Give it some time
+     }
+     close(s);
+  }
+
+  // Delete any stale socket file (and symlink)
+  unlink(sock_file);
+}
+
 static void init_kdeinit_socket()
 {
   struct sockaddr_un sa;
-  kde_socklen_t socklen;
+  QT_SOCKLEN_T socklen;
   long options;
   const QByteArray home_dir = qgetenv("HOME");
   int max_tries = 10;
@@ -916,45 +828,9 @@ static void init_kdeinit_socket()
 #endif
   }
 
-  /** Test if socket file is already present
-   *  note that access() resolves symlinks, and so we check the actual
-   *  socket file if it exists
-   */
-  if (access(sock_file, W_OK) == 0)
-  {
-     int s;
-     struct sockaddr_un server;
+  shutdown_kdeinit();
 
-//     fprintf(stderr, "kdeinit4: Warning, socket_file already exists!\n");
-     /*
-      * create the socket stream
-      */
-     s = socket(PF_UNIX, SOCK_STREAM, 0);
-     if (s < 0)
-     {
-        perror("socket() failed");
-        exit(255);
-     }
-     server.sun_family = AF_UNIX;
-     strcpy(server.sun_path, sock_file);
-     socklen = sizeof(server);
-
-     if(connect(s, (struct sockaddr *)&server, socklen) == 0)
-     {
-        fprintf(stderr, "kdeinit4: Shutting down running client.\n");
-        klauncher_header request_header;
-        request_header.cmd = LAUNCHER_TERMINATE_KDEINIT;
-        request_header.arg_length = 0;
-        write(s, &request_header, sizeof(request_header));
-        sleep(1); // Give it some time
-     }
-     close(s);
-  }
-
-  /** Delete any stale socket file (and symlink) **/
-  unlink(sock_file);
-
-  /** create socket **/
+  // Create socket
   d.wrapper = socket(PF_UNIX, SOCK_STREAM, 0);
   if (d.wrapper < 0)
   {
@@ -978,7 +854,7 @@ static void init_kdeinit_socket()
   }
 
   while (1) {
-      /** bind it **/
+      // Bind it
       socklen = sizeof(sa);
       memset(&sa, 0, socklen);
       sa.sun_family = AF_UNIX;
@@ -986,17 +862,17 @@ static void init_kdeinit_socket()
       if(bind(d.wrapper, (struct sockaddr *)&sa, socklen) != 0)
       {
           if (max_tries == 0) {
-	      perror("kdeinit4: Aborting. bind() failed");
-	      fprintf(stderr, "Could not bind to socket '%s'\n", sock_file);
-	      close(d.wrapper);
-	      exit(255);
-	  }
-	  max_tries--;
+              perror("kdeinit4: Aborting. bind() failed");
+              fprintf(stderr, "Could not bind to socket '%s'\n", sock_file);
+              close(d.wrapper);
+              exit(255);
+          }
+          max_tries--;
       } else
           break;
   }
 
-  /** set permissions **/
+  // Set permissions
   if (chmod(sock_file, 0600) != 0)
   {
      perror("kdeinit4: Aborting. Can not set permissions on socket");
@@ -1115,11 +991,8 @@ static bool handle_launcher_request(int sock, const char *who)
       d.launcher_ok = true;
    }
    else if (request_header.arg_length &&
-      ((request_header.cmd == LAUNCHER_EXEC) ||
-       (request_header.cmd == LAUNCHER_EXT_EXEC) ||
-       (request_header.cmd == LAUNCHER_SHELL ) ||
-       (request_header.cmd == LAUNCHER_KWRAPPER) ||
-       (request_header.cmd == LAUNCHER_EXEC_NEW)))
+      ((request_header.cmd == LAUNCHER_EXEC_ASN) ||
+       (request_header.cmd == LAUNCHER_EXEC)))
    {
       pid_t pid;
       klauncher_header response_header;
@@ -1148,46 +1021,25 @@ static bool handle_launcher_request(int sock, const char *who)
         arg_n = arg_n + strlen(arg_n) + 1;
       }
 
-      if( request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER )
+      memcpy( &l, arg_n, sizeof( long ));
+      envc = l;
+      arg_n += sizeof(long);
+      envs = arg_n;
+      for(int i = 0; i < envc; i++)
       {
-         // Shell or kwrapper
-         cwd = arg_n; arg_n += strlen(cwd) + 1;
-      }
-      if( request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER
-          || request_header.cmd == LAUNCHER_EXT_EXEC || request_header.cmd == LAUNCHER_EXEC_NEW )
-      {
-         memcpy( &l, arg_n, sizeof( long ));
-         envc = l;
-         arg_n += sizeof(long);
-         envs = arg_n;
-         for(int i = 0; i < envc; i++)
-         {
-           arg_n = arg_n + strlen(arg_n) + 1;
-         }
-         if( request_header.cmd == LAUNCHER_KWRAPPER )
-         {
-             tty = arg_n;
-             arg_n += strlen( tty ) + 1;
-         }
+        arg_n = arg_n + strlen(arg_n) + 1;
       }
+      memcpy( &l, arg_n, sizeof( long ));
+      avoid_loops = l;
+      arg_n += sizeof( long );
 
-     if( request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER
-         || request_header.cmd == LAUNCHER_EXT_EXEC || request_header.cmd == LAUNCHER_EXEC_NEW )
-     {
-         memcpy( &l, arg_n, sizeof( long ));
-         avoid_loops = l;
-         arg_n += sizeof( long );
-     }
-
-     if( request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER
-         || request_header.cmd == LAUNCHER_EXT_EXEC )
+     if( request_header.cmd == LAUNCHER_EXEC_ASN )
      {
          startup_id_str = arg_n;
          arg_n += strlen( startup_id_str ) + 1;
      }
 
-     if ((request_header.arg_length > (arg_n - request_data)) &&
-         (request_header.cmd == LAUNCHER_EXT_EXEC || request_header.cmd == LAUNCHER_EXEC_NEW ))
+     if (request_header.arg_length > (arg_n - request_data))
      {
          // Optional cwd
          cwd = arg_n; arg_n += strlen(cwd) + 1;
@@ -1203,25 +1055,9 @@ static bool handle_launcher_request(int sock, const char *who)
        return true; // sure?
      }
 
-      // support for the old a bit broken way of setting DISPLAY for multihead
-      QByteArray olddisplay = qgetenv(DISPLAY);
-      QByteArray kdedisplay = qgetenv("KDE_DISPLAY");
-      bool reset_display = (! olddisplay.isEmpty() &&
-                            ! kdedisplay.isEmpty() &&
-                            olddisplay != kdedisplay);
-
-      if (reset_display)
-          setenv(DISPLAY, kdedisplay, true);
-
       pid = launch( argc, name, args, cwd, envc, envs,
-          request_header.cmd == LAUNCHER_SHELL || request_header.cmd == LAUNCHER_KWRAPPER,
           tty, avoid_loops, startup_id_str );
 
-      if (reset_display) {
-          unsetenv("KDE_DISPLAY");
-          setenv(DISPLAY, olddisplay, true);
-      }
-
       if (pid && (d.result == 0))
       {
          response_header.cmd = LAUNCHER_OK;
@@ -1271,15 +1107,6 @@ static bool handle_launcher_request(int sock, const char *who)
       }
       setenv( env_name, env_value, 1);
    }
-   else if (request_header.cmd == LAUNCHER_TERMINATE_KDE)
-   {
-#ifndef NDEBUG
-       fprintf(stderr,"kdeinit4: terminate KDE.\n");
-#endif
-#ifdef Q_WS_X11
-       kdeinit_xio_errhandler( 0L );
-#endif
-   }
    else if (request_header.cmd == LAUNCHER_TERMINATE_KDEINIT)
    {
 #ifndef NDEBUG
@@ -1394,7 +1221,7 @@ static void handle_requests(pid_t waitForPid)
       if (d.wrapper >= 0 && FD_ISSET(d.wrapper, &rd_set))
       {
          struct sockaddr_un client;
-         kde_socklen_t sClient = sizeof(client);
+         QT_SOCKLEN_T sClient = sizeof(client);
          int sock = accept(d.wrapper, (struct sockaddr *)&client, &sClient);
          if (sock >= 0)
          {
@@ -1429,56 +1256,11 @@ static void handle_requests(pid_t waitForPid)
 
 static void kdeinit_library_path()
 {
-   const QStringList ltdl_library_path =
-     QFile::decodeName(qgetenv("LTDL_LIBRARY_PATH")).split(QLatin1Char(':'),QString::SkipEmptyParts);
-#ifdef Q_OS_DARWIN
-   const QByteArray ldlibpath = qgetenv("DYLD_LIBRARY_PATH");
-#else
-   const QByteArray ldlibpath = qgetenv("LD_LIBRARY_PATH");
-#endif
-   const QStringList ld_library_path =
-     QFile::decodeName(ldlibpath).split(QLatin1Char(':'),QString::SkipEmptyParts);
-
-   QByteArray extra_path;
-   const QStringList candidates = s_instance->dirs()->resourceDirs("lib");
-   for (QStringList::ConstIterator it = candidates.begin();
-        it != candidates.end();
-        ++it)
-   {
-      QString d = *it;
-      if (ltdl_library_path.contains(d))
-          continue;
-      if (ld_library_path.contains(d))
-          continue;
-      if (d[d.length()-1] == QLatin1Char('/'))
-      {
-         d.truncate(d.length()-1);
-         if (ltdl_library_path.contains(d))
-            continue;
-         if (ld_library_path.contains(d))
-            continue;
-      }
-      if ((d == QLatin1String("/lib")) || (d == QLatin1String("/usr/lib")))
-         continue;
-
-      QByteArray dir = QFile::encodeName(d);
-
-      if (access(dir, R_OK))
-          continue;
-
-      if ( !extra_path.isEmpty())
-         extra_path += ':';
-      extra_path += dir;
-   }
-
-//   if (!extra_path.isEmpty())
-//      lt_dlsetsearchpath(extra_path.data());
-
    QByteArray display = qgetenv(DISPLAY);
    if (display.isEmpty())
    {
 #if defined(Q_WS_X11) || defined(Q_WS_QWS)
-     fprintf(stderr, "kdeinit4: Aborting. $"DISPLAY" is not set.\n");
+     fprintf(stderr, "kdeinit4: Aborting. $" DISPLAY " is not set.\n");
      exit(255);
 #endif
    }
@@ -1487,12 +1269,9 @@ static void kdeinit_library_path()
      display.truncate(i);
 
    display.replace(':','_');
-#ifdef __APPLE__
-   display.replace('/','_');
-#endif
    // WARNING, if you change the socket name, adjust kwrapper too
    const QString socketFileName = QString::fromLatin1("kdeinit4_%1").arg(QLatin1String(display));
-   QByteArray socketName = QFile::encodeName(KStandardDirs::locateLocal("socket", socketFileName, *s_instance));
+   QByteArray socketName = QFile::encodeName(KStandardDirs::locateLocal("tmp", socketFileName, *s_instance));
    if (socketName.length() >= MAX_SOCK_FILE)
    {
      fprintf(stderr, "kdeinit4: Aborting. Socket name will be too long:\n");
@@ -1505,13 +1284,12 @@ static void kdeinit_library_path()
 int kdeinit_xio_errhandler( Display *disp )
 {
     // disp is 0L when KDE shuts down. We don't want those warnings then.
-
     if ( disp )
-    qWarning( "kdeinit4: Fatal IO error: client killed" );
+       kWarning() << "Fatal IO error: client killed";
 
     if (sock_file[0])
     {
-      /** Delete any stale socket file **/
+      // Delete any stale socket file
       unlink(sock_file);
     }
 
@@ -1520,29 +1298,27 @@ int kdeinit_xio_errhandler( Display *disp )
     {
        if (d.launcher_pid)
           kill(d.launcher_pid, SIGTERM);
-       if (d.kded_pid)
-          kill(d.kded_pid, SIGTERM);
        exit( 0 );
     }
 
     if ( disp )
-    qWarning( "kdeinit4: sending SIGHUP to children." );
+       kWarning() << "Sending SIGHUP to children.";
 
-    /* this should remove all children we started */
+    // this should remove all children we started
     KDE_signal(SIGHUP, SIG_IGN);
     kill(0, SIGHUP);
 
     sleep(2);
 
     if ( disp )
-    qWarning( "kdeinit4: sending SIGTERM to children." );
+       kWarning() << "Sending SIGTERM to children.";
 
-    /* and if they don't listen to us, this should work */
+    // And if they don't listen to us, this should work
     KDE_signal(SIGTERM, SIG_IGN);
     kill(0, SIGTERM);
 
     if ( disp )
-    qWarning( "kdeinit4: Exit." );
+       kWarning() << "Exit.";
 
     exit( 0 );
     return 0;
@@ -1579,15 +1355,15 @@ static void setupX()
     XSetIOErrorHandler(kdeinit_xio_errhandler);
     XSetErrorHandler(kdeinit_x_errhandler);
 /*
-    Handle the tricky case of running via kdesu/su/sudo/etc. There the usual case
-    is that kdesu (etc.) creates a file with xauth information, sets XAUTHORITY,
+    Handle the tricky case of running via kdesudo/su/sudo/etc. There the usual case
+    is that kdesudo (etc.) creates a file with xauth information, sets XAUTHORITY,
     runs the command and removes the xauth file after the command finishes. However,
     dbus and kdeinit daemon currently don't clean up properly and keeping running.
-    Which means that running a KDE app via kdesu the second time talks to kdeinit
+    Which means that running a KDE app via kdesudo the second time talks to kdeinit
     with obsolete xauth information, which makes it unable to connect to X or launch
     any X11 applications.
     Even fixing the cleanup probably wouldn't be sufficient, since it'd be possible to
-    launch one kdesu session, another one, exit the first one and the app from the second
+    launch one kdesudo session, another one, exit the first one and the app from the second
     session would be using kdeinit from the first one.
     So the trick here is to duplicate the xauth file to another file in KDE's tmp
     location, make the file have a consistent name so that future sessions will use it
@@ -1600,9 +1376,6 @@ static void setupX()
         if((i = display.lastIndexOf('.')) > display.lastIndexOf(':') && i >= 0)
             display.truncate(i);
         display.replace(':','_');
-#ifdef __APPLE__
-        display.replace('/','_');
-#endif
         QString xauth = s_instance->dirs()->saveLocation( "tmp" ) + QLatin1String( "xauth-" )
             + QString::number( getuid()) + QLatin1String( "-" ) + QString::fromLocal8Bit( display );
         KSaveFile xauthfile( xauth );
@@ -1649,68 +1422,54 @@ static void secondary_child_handler(int)
 
 }
 
-int main(int argc, char **argv, char **envp)
+int main(int argc, char **argv)
 {
-#ifndef _WIN32_WCE
     setlocale (LC_ALL, "");
     setlocale (LC_NUMERIC, "C");
-#endif
 
    pid_t pid;
    bool do_fork = true;
    int launch_klauncher = 1;
-   int launch_kded = 1;
-   int keep_running = 1;
+   int do_shutdown = 0;
    d.suicide = false;
 
-   /** Save arguments first... **/
-   char **safe_argv = (char **) malloc( sizeof(char *) * argc);
+   // Check arguments first...
    for(int i = 0; i < argc; i++)
    {
-      safe_argv[i] = strcpy((char*)malloc(strlen(argv[i])+1), argv[i]);
-      if (strcmp(safe_argv[i], "--no-klauncher") == 0)
+      if (strcmp(argv[i], "--no-klauncher") == 0)
          launch_klauncher = 0;
-      if (strcmp(safe_argv[i], "--no-kded") == 0)
-         launch_kded = 0;
-#ifdef Q_WS_MACX
-      // make it nofork to match KUniqueApplication, technically command-line incompatible
-      if (strcmp(safe_argv[i], "--nofork") == 0)
-#else
-      if (strcmp(safe_argv[i], "--no-fork") == 0)
-#endif
+      if (strcmp(argv[i], "--no-fork") == 0)
          do_fork = false;
-      if (strcmp(safe_argv[i], "--suicide") == 0)
+      if (strcmp(argv[i], "--suicide") == 0)
          d.suicide = true;
-      if (strcmp(safe_argv[i], "--exit") == 0)
-         keep_running = 0;
-      if (strcmp(safe_argv[i], "--version") == 0)
+      if (strcmp(argv[i], "--shutdown") == 0)
+         do_shutdown = 1;
+      if (strcmp(argv[i], "--version") == 0)
       {
-	 printf("Qt: %s\n", qVersion());
-	 printf("KDE: %s\n", KDE_VERSION_STRING);
-	 exit(0);
+         printf("Katie: %s\n", qVersion());
+         printf("KDE: %s\n", KDE_VERSION_STRING);
+         exit(0);
       }
-#ifdef KDEINIT_OOM_PROTECT
-      if (strcmp(safe_argv[i], "--oom-pipe") == 0 && i+1<argc)
-         oom_pipe = atol(argv[i+1]);
-#endif
-      if (strcmp(safe_argv[i], "--help") == 0)
+      if (strcmp(argv[i], "--help") == 0)
       {
         printf("Usage: kdeinit4 [options]\n");
-     // printf("    --no-dcop         Do not start dcopserver\n");
-#ifdef Q_WS_MACX
-        printf("    --nofork          Do not fork\n");
-#else
         printf("    --no-fork         Do not fork\n");
-#endif
-     // printf("    --no-klauncher    Do not start klauncher\n");
-        printf("    --no-kded         Do not start kded\n");
+        printf("    --no-klauncher    Do not start klauncher\n");
         printf("    --suicide         Terminate when no KDE applications are left running\n");
-	printf("    --version         Show version information\n");
-     // printf("    --exit            Terminate when kded has run\n");
+        printf("    --version         Show version information\n");
+        printf("    --shutdown        Shutdown running kdeinit4 instance\n");
         exit(0);
       }
    }
 
+   if (do_shutdown) {
+      KDE_signal(SIGPIPE, SIG_IGN);
+      s_instance = new KComponentData("kdeinit4", QByteArray(), KComponentData::SkipMainComponentRegistration);
+      kdeinit_library_path();
+      shutdown_kdeinit();
+      return 0;
+   }
+
    cleanup_fds();
 
    // Redirect stdout to stderr. We have no reason to use stdout anyway.
@@ -1718,9 +1477,6 @@ int main(int argc, char **argv, char **envp)
    (void)dup2(2, 1);
 
    if (do_fork) {
-#ifdef Q_WS_MACX
-      mac_fork_and_reexec_self();
-#else
       if (pipe(d.initpipe) != 0) {
           perror("kdeinit4: pipe failed");
           return 1;
@@ -1745,19 +1501,17 @@ int main(int argc, char **argv, char **envp)
       }
       close(d.initpipe[0]);
       d.initpipe[0] = -1;
-#endif
    }
 
-   /** Make process group leader (for shutting down children later) **/
-   if(keep_running)
-      setsid();
+   // Make process group leader (for shutting down children later)
+   setsid();
 
-   /** Create our instance **/
+   // Create our instance
    s_instance = new KComponentData("kdeinit4", QByteArray(), KComponentData::SkipMainComponentRegistration);
 
-   /** Prepare to change process name **/
+   // Prepare to change process name
 #ifndef SKIP_PROCTITLE
-   proctitle_init(argc, argv, envp);
+   proctitle_init(argc, argv);
 #endif
 
    kdeinit_library_path();
@@ -1765,14 +1519,10 @@ int main(int argc, char **argv, char **envp)
    // (do it only after kdeinit_library_path, that one indirectly uses KConfig,
    // which seems to be buggy and always use KGlobal instead of the matching KComponentData)
    Q_ASSERT(!KGlobal::hasMainComponent());
-   // don't change envvars before proctitle_init()
-   unsetenv("LD_BIND_NOW");
-   unsetenv("DYLD_BIND_AT_LAUNCH");
    KApplication::loadedByKdeinit = true;
 
    d.maxname = strlen(argv[0]);
    d.launcher_pid = 0;
-   d.kded_pid = 0;
    d.wrapper = -1;
    d.accepted_fd = -1;
    d.debug_wait = false;
@@ -1783,36 +1533,9 @@ int main(int argc, char **argv, char **envp)
    setupX();
 #endif
 
-   if (keep_running)
-   {
-      /*
-       * Create ~/.kde/tmp-<hostname>/kdeinit4-<display> socket for incoming wrapper
-       * requests.
-       */
-      init_kdeinit_socket();
-   }
-#ifdef Q_WS_X11
-    if (!d.suicide && qgetenv("KDE_IS_PRELINKED").isEmpty()) {
-        const int extrasCount = sizeof(extra_libs)/sizeof(extra_libs[0]);
-        for (int i=0; i<extrasCount; i++) {
-            QString extra = KStandardDirs::locate("lib", QLatin1String(extra_libs[i]), *s_instance);
+   // Create socket for incoming wrapper requests
+   init_kdeinit_socket();
 
-            // can't use KLibLoader here as it would unload the library
-            // again
-            if (!extra.isEmpty()) {
-                QLibrary l(extra);
-                l.setLoadHints(QLibrary::ExportExternalSymbolsHint);
-                (void)l.load();
-            }
-#ifndef NDEBUG
-            else {
-                fprintf( stderr, "%s was not found.\n", extra_libs[i] );
-            }
-#endif
-
-        }
-    }
-#endif
    if (launch_klauncher)
    {
       start_klauncher();
@@ -1823,71 +1546,10 @@ int main(int argc, char **argv, char **envp)
    X11fd = initXconnection();
 #endif
 
-   {
-      QFont::initialize();
-#ifdef Q_WS_X11
-      if (XSupportsLocale ())
-      {
-         // Similar to QApplication::create_xim()
-	 // but we need to use our own display
-	 XOpenIM (X11display, 0, 0, 0);
-      }
-#endif
-   }
-
-   if (launch_kded)
-   {
-      setenv("KDED_STARTED_BY_KDEINIT", "1", true);
-      pid = launch( 1, KDED_EXENAME, 0 );
-      unsetenv("KDED_STARTED_BY_KDEINIT");
-#ifndef NDEBUG
-      fprintf(stderr, "kdeinit4: Launched KDED, pid = %ld result = %d\n", (long) pid, d.result);
-#endif
-      d.kded_pid = pid;
-      handle_requests(pid);
-   }
-
-   for(int i = 1; i < argc; i++)
-   {
-      if (safe_argv[i][0] == '+')
-      {
-         pid = launch( 1, safe_argv[i]+1, 0);
-#ifndef NDEBUG
-      fprintf(stderr, "kdeinit4: Launched '%s', pid = %ld result = %d\n", safe_argv[i]+1, (long) pid, d.result);
-#endif
-         handle_requests(pid);
-      }
-      else if (safe_argv[i][0] == '-'
-#ifdef KDEINIT_OOM_PROTECT
-          || isdigit(safe_argv[i][0])
-#endif
-          )
-      {
-         // Ignore
-      }
-      else
-      {
-         pid = launch( 1, safe_argv[i], 0 );
-#ifndef NDEBUG
-      fprintf(stderr, "kdeinit4: Launched '%s', pid = %ld result = %d\n", safe_argv[i], (long) pid, d.result);
-#endif
-      }
-   }
-
-   /** Free arguments **/
-   for(int i = 0; i < argc; i++)
-   {
-      free(safe_argv[i]);
-   }
-   free (safe_argv);
-
 #ifndef SKIP_PROCTITLE
    proctitle_set("kdeinit4 Running...");
 #endif
 
-   if (!keep_running)
-      return 0;
-
    if (d.initpipe[1] != -1)
    {
       char c = 0;
