@@ -37,12 +37,13 @@
 #include <X11/Xlib.h>
 #endif
 
-#include <QtCore/QFile>
+#include <QtCore/qfile.h>
+#include <QtCore/qfileinfo.h>
+#include <qplatformdefs.h>
 
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kde_file.h>
-#include <klibrary.h>
 #include <klocale.h>
 #include <kprotocolmanager.h>
 #include <kprotocolinfo.h>
@@ -61,8 +62,10 @@
 
 // #define KLAUNCHER_VERBOSE_OUTPUT
 
+#ifdef KLAUNCHER_VERBOSE_OUTPUT
 static const char* const s_DBusStartupTypeToString[] =
     { "DBusNone", "DBusUnique", "DBusMulti", "DBusWait", "ERROR" };
+#endif
 
 using namespace KIO;
 
@@ -77,10 +80,6 @@ IdleSlave::IdleSlave(QObject *parent)
    mOnHold = false;
 }
 
-template<int T> struct PIDType { typedef pid_t PID_t; } ;
-template<> struct PIDType<2> { typedef qint16 PID_t; } ;
-template<> struct PIDType<4> { typedef qint32 PID_t; } ;
-
 void
 IdleSlave::gotInput()
 {
@@ -89,7 +88,7 @@ IdleSlave::gotInput()
    if (mConn.read( &cmd, data) == -1)
    {
       // Communication problem with slave.
-      //kError(7016) << "SlavePool: No communication with slave." << endl;
+      // kError(7016) << "No communication with slave.";
       deleteLater();
    }
    else if (cmd == MSG_SLAVE_ACK)
@@ -98,20 +97,18 @@ IdleSlave::gotInput()
    }
    else if (cmd != MSG_SLAVE_STATUS)
    {
-      kError(7016) << "SlavePool: Unexpected data from slave." << endl;
+      kError(7016) << "Unexpected data from slave.";
       deleteLater();
    }
    else
    {
       QDataStream stream( data );
-      PIDType<sizeof(pid_t)>::PID_t stream_pid;
-      pid_t pid;
+      qint64 pid;
       QByteArray protocol;
       QString host;
       qint8 b;
-      stream >> stream_pid >> protocol >> host >> b;
-      pid = stream_pid;
-// Overload with (bool) onHold, (KUrl) url.
+      stream >> pid >> protocol >> host >> b;
+      // Overload with (bool) onHold, (KUrl) url.
       if (!stream.atEnd())
       {
          KUrl url;
@@ -120,7 +117,7 @@ IdleSlave::gotInput()
          mUrl = url;
       }
 
-      mPid = pid;
+      mPid = static_cast<pid_t>(pid);
       mConnected = (b != 0);
       mProtocol = QString::fromLatin1(protocol);
       mHost = host;
@@ -169,16 +166,27 @@ IdleSlave::age(time_t now) const
    return (int) difftime(now, mBirthDate);
 }
 
-static KLauncher* g_klauncher_self;
+static KLauncher* g_klauncher_self = NULL;
+
+
+// From qcore_unix_p.h. We could also port to QLocalSocket :)
+#define K_EINTR_LOOP(var, cmd)                    \
+    do {                                        \
+        var = cmd;                              \
+    } while (var == -1 && errno == EINTR)
+
+ssize_t kde_safe_write(int fd, const void *buf, size_t count)
+{
+    ssize_t ret = 0;
+    K_EINTR_LOOP(ret, QT_WRITE(fd, buf, count));
+    if (ret < 0)
+        kWarning() << "write failed:" << strerror(errno);
+    return ret;
+}
 
-#ifndef USE_KPROCESS_FOR_KIOSLAVES
 KLauncher::KLauncher(int _kdeinitSocket)
   : QObject(0),
     kdeinitSocket(_kdeinitSocket)
-#else
-KLauncher::KLauncher()
-  : QObject(0)
-#endif
 {
 #ifdef Q_WS_X11
    mCached_dpy = NULL;
@@ -200,40 +208,34 @@ KLauncher::KLauncher()
    if (!mConnectionServer.isListening())
    {
       // Severe error!
-      qDebug("KLauncher: Fatal error, can't create tempfile!");
+      kDebug() << "Fatal error, can't create tempfile!";
       ::_exit(1);
    }
 
    connect(&mTimer, SIGNAL(timeout()), SLOT(idleTimeout()));
 
-#ifndef USE_KPROCESS_FOR_KIOSLAVES
    kdeinitNotifier = new QSocketNotifier(kdeinitSocket, QSocketNotifier::Read);
    connect(kdeinitNotifier, SIGNAL(activated(int)),
            this, SLOT(slotKDEInitData(int)));
    kdeinitNotifier->setEnabled( true );
-#endif
    lastRequest = 0;
    bProcessingQueue = false;
 
    mSlaveDebug = QString::fromLocal8Bit(qgetenv("KDE_SLAVE_DEBUG_WAIT"));
    if (!mSlaveDebug.isEmpty())
    {
-      qWarning("Klauncher running in slave-debug mode for slaves of protocol '%s'", qPrintable(mSlaveDebug));
+      kWarning() << "Running in slave-debug mode for slaves of protocol:" << qPrintable(mSlaveDebug);
    }
    mSlaveValgrind = QString::fromLocal8Bit(qgetenv("KDE_SLAVE_VALGRIND"));
    if (!mSlaveValgrind.isEmpty())
    {
       mSlaveValgrindSkin = QString::fromLocal8Bit(qgetenv("KDE_SLAVE_VALGRIND_SKIN"));
-      qWarning("Klauncher running slaves through valgrind for slaves of protocol '%s'", qPrintable(mSlaveValgrind));
+      kWarning() << "Running slaves through valgrind for slaves of protocol:" << qPrintable(mSlaveValgrind);
    }
-#ifdef USE_KPROCESS_FOR_KIOSLAVES
-   kDebug(7016) << "LAUNCHER_OK";
-#else
    klauncher_header request_header;
    request_header.cmd = LAUNCHER_OK;
    request_header.arg_length = 0;
-   write(kdeinitSocket, &request_header, sizeof(request_header));
-#endif
+   kde_safe_write(kdeinitSocket, &request_header, sizeof(request_header));
 }
 
 KLauncher::~KLauncher()
@@ -264,21 +266,15 @@ KLauncher::destruct()
 
 void KLauncher::setLaunchEnv(const QString &name, const QString &value)
 {
-#ifndef USE_KPROCESS_FOR_KIOSLAVES
    klauncher_header request_header;
    QByteArray requestData;
    requestData.append(name.toLocal8Bit()).append('\0').append(value.toLocal8Bit()).append('\0');
    request_header.cmd = LAUNCHER_SETENV;
    request_header.arg_length = requestData.size();
-   write(kdeinitSocket, &request_header, sizeof(request_header));
-   write(kdeinitSocket, requestData.data(), request_header.arg_length);
-#else
-   Q_UNUSED(name);
-   Q_UNUSED(value);
-#endif
+   kde_safe_write(kdeinitSocket, &request_header, sizeof(request_header));
+   kde_safe_write(kdeinitSocket, requestData.data(), request_header.arg_length);
 }
 
-#ifndef USE_KPROCESS_FOR_KIOSLAVES
 /*
  * Read 'len' bytes from 'sock' into buffer.
  * returns -1 on failure, 0 on no data.
@@ -319,12 +315,10 @@ read_socket(int sock, char *buffer, int len)
   }
   return 0;
 }
-#endif
 
 void
 KLauncher::slotKDEInitData(int)
 {
-#ifndef USE_KPROCESS_FOR_KIOSLAVES
    klauncher_header request_header;
    QByteArray requestData;
 
@@ -342,22 +336,19 @@ KLauncher::slotKDEInitData(int)
                         request_header.arg_length);
 
    processRequestReturn(request_header.cmd,requestData);
-#endif
 }
 
 void KLauncher::processRequestReturn(int status, const QByteArray &requestData)
 {
    if (status == LAUNCHER_CHILD_DIED)
    {
-     long *request_data;
-     request_data = (long *) requestData.data();
+     long *request_data = (long *) requestData.data();
      processDied(request_data[0], request_data[1]);
      return;
    }
    if (lastRequest && (status == LAUNCHER_OK))
    {
-     long *request_data;
-     request_data = (long *) requestData.data();
+     long *request_data = (long *) requestData.data();
      lastRequest->pid = (pid_t) (*request_data);
      kDebug(7016).nospace() << lastRequest->name << " (pid " << lastRequest->pid <<
         ") up and running.";
@@ -378,7 +369,7 @@ void KLauncher::processRequestReturn(int status, const QByteArray &requestData)
    if (lastRequest && (status == LAUNCHER_ERROR))
    {
      lastRequest->status = KLaunchRequest::Error;
-     kDebug(7016) << lastRequest->name << " failed." << endl;
+     kDebug(7016) << lastRequest->name << " failed.";
      if (!requestData.isEmpty())
         lastRequest->errorMsg = QString::fromUtf8((char *) requestData.data());
      lastRequest = 0;
@@ -522,9 +513,9 @@ KLauncher::slotAutoStart()
       if (service.isEmpty())
       {
          // Done
-	 if( !mAutoStart.phaseDone())
-	 {
-	    mAutoStart.setPhaseDone();
+        if( !mAutoStart.phaseDone())
+        {
+            mAutoStart.setPhaseDone();
             switch( mAutoStart.phase())
                 {
                 case 0:
@@ -598,11 +589,10 @@ KLauncher::requestDone(KLaunchRequest *request)
       if ( requestResult.dbusName.isNull() ) // null strings can't be sent
           requestResult.dbusName.clear();
       Q_ASSERT( !requestResult.error.isNull() );
-      PIDType<sizeof(pid_t)>::PID_t stream_pid = requestResult.pid;
       QDBusConnection::sessionBus().send(request->transaction.createReply(QVariantList() << requestResult.result
                                      << requestResult.dbusName
                                      << requestResult.error
-                                     << stream_pid));
+                                     << static_cast<qint64>(requestResult.pid)));
    }
 #ifdef KLAUNCHER_VERBOSE_OUTPUT
    kDebug(7016) << "removing done request" << request->name << "PID" << request->pid;
@@ -622,43 +612,6 @@ static void appendLong(QByteArray &ba, long l)
 void
 KLauncher::requestStart(KLaunchRequest *request)
 {
-#ifdef USE_KPROCESS_FOR_KIOSLAVES
-   requestList.append( request );
-   lastRequest = request;
-
-   KProcess *process  = new KProcess;
-   process->setOutputChannelMode(KProcess::MergedChannels);
-   connect(process ,SIGNAL(readyReadStandardOutput()),this, SLOT(slotGotOutput()) );
-   connect(process ,SIGNAL(finished(int,QProcess::ExitStatus)),this, SLOT(slotFinished(int,QProcess::ExitStatus)) );
-   request->process = process;
-
-// process.setEnvironment(envlist);
-   QStringList args;
-   foreach (const QString &arg, request->arg_list)
-      args << arg;
-
-   QString executable = request->name;
-#ifdef Q_WS_MAC
-   const QString bundlepath = KStandardDirs::findExe(executable);
-   if (!bundlepath.isEmpty())
-      executable = bundlepath;
-#endif
-   process->setProgram(executable,args);
-   process->start();
-
-   if (!process->waitForStarted())
-   {
-       processRequestReturn(LAUNCHER_ERROR,"");
-   }
-   else
-   {
-       request->pid = process->pid();
-       QByteArray data((char *)&request->pid, sizeof(int));
-       processRequestReturn(LAUNCHER_OK,data);
-   }
-   return;
-
-#else
    requestList.append( request );
    // Send request to kdeinit.
    klauncher_header request_header;
@@ -683,9 +636,9 @@ KLauncher::requestStart(KLaunchRequest *request)
        requestData.append(QFile::encodeName(request->cwd)).append('\0');
 
 #ifdef Q_WS_X11
-   request_header.cmd = startup_notify ? LAUNCHER_EXT_EXEC : LAUNCHER_EXEC_NEW;
+   request_header.cmd = startup_notify ? LAUNCHER_EXEC_ASN : LAUNCHER_EXEC;
 #else
-   request_header.cmd = LAUNCHER_EXEC_NEW;
+   request_header.cmd = LAUNCHER_EXEC;
 #endif
    request_header.arg_length = requestData.length();
 
@@ -694,8 +647,8 @@ KLauncher::requestStart(KLaunchRequest *request)
                 << "cmd=" << commandToString(request_header.cmd);
 #endif
 
-   write(kdeinitSocket, &request_header, sizeof(request_header));
-   write(kdeinitSocket, requestData.data(), requestData.length());
+   kde_safe_write(kdeinitSocket, &request_header, sizeof(request_header));
+   kde_safe_write(kdeinitSocket, requestData.data(), requestData.length());
 
    // Wait for pid to return.
    lastRequest = request;
@@ -703,10 +656,9 @@ KLauncher::requestStart(KLaunchRequest *request)
       slotKDEInitData( kdeinitSocket );
    }
    while (lastRequest != 0);
-#endif
 }
 
-void KLauncher::exec_blind(const QString &name, const QStringList &arg_list, const QStringList &envs, const QString &startup_id)
+void KLauncher::exec_blind(const QString &name, const QStringList &arg_list)
 {
    KLaunchRequest *request = new KLaunchRequest;
    request->autoStart = false;
@@ -715,40 +667,13 @@ void KLauncher::exec_blind(const QString &name, const QStringList &arg_list, con
    request->dbus_startup_type = KService::DBusNone;
    request->pid = 0;
    request->status = KLaunchRequest::Launching;
-   request->envs = envs;
-   // Find service, if any - strip path if needed
-   KService::Ptr service = KService::serviceByDesktopName( name.mid( name.lastIndexOf(QLatin1Char('/')) + 1 ));
-   if (service)
-       send_service_startup_info(request, service, startup_id.toLocal8Bit(), QStringList());
-   else // no .desktop file, no startup info
-       cancel_service_startup_info( request, startup_id.toLocal8Bit(), envs );
+   request->envs = QStringList();
 
    requestStart(request);
    // We don't care about this request any longer....
    requestDone(request);
 }
 
-
-// KDE5: remove
-bool
-KLauncher::start_service_by_name(const QString &serviceName, const QStringList &urls,
-    const QStringList &envs, const QString& startup_id, bool blind, const QDBusMessage &msg)
-{
-   KService::Ptr service;
-   // Find service
-#ifndef KDE_NO_DEPRECATED
-   service = KService::serviceByName(serviceName);
-#endif
-   if (!service)
-   {
-      requestResult.result = ENOENT;
-      requestResult.error = i18n("Could not find service '%1'.", serviceName);
-      cancel_service_startup_info( NULL, startup_id.toLocal8Bit(), envs ); // cancel it if any
-      return false;
-   }
-   return start_service(service, urls, envs, startup_id.toLocal8Bit(), blind, false, msg);
-}
-
 bool
 KLauncher::start_service_by_desktop_path(const QString &serviceName, const QStringList &urls,
     const QStringList &envs, const QString& startup_id, bool blind, const QDBusMessage &msg)
@@ -796,7 +721,7 @@ KLauncher::start_service_by_desktop_name(const QString &serviceName, const QStri
 bool
 KLauncher::start_service(KService::Ptr service, const QStringList &_urls,
                          const QStringList &envs, const QByteArray &startup_id,
-                         bool blind, bool autoStart, const QDBusMessage &msg)
+                         bool blind, bool autoStart, QDBusMessage msg)
 {
    QStringList urls = _urls;
    bool runPermitted = KDesktopFile::isAuthorizedDesktopFile(service->entryPath());
@@ -821,14 +746,9 @@ KLauncher::start_service(KService::Ptr service, const QStringList &_urls,
       // For the first file we launch the application in the
       // usual way. The reported result is based on this
       // application.
-      QStringList::ConstIterator it = urls.constBegin();
-      for(++it;
-          it != urls.constEnd();
-          ++it)
-      {
-         QStringList singleUrl;
-         singleUrl.append(*it);
+      foreach(const QString &it, urls) {
          QByteArray startup_id2 = startup_id;
+         const QStringList singleUrl(it);
          if( !startup_id2.isEmpty() && startup_id2 != "0" )
              startup_id2 = "0"; // can't use the same startup_id several times // krazy:exclude=doublequote_chars
          start_service( service, singleUrl, envs, startup_id2, true, false, msg);
@@ -955,17 +875,17 @@ KLauncher::cancel_service_startup_info( KLaunchRequest* request, const QByteArra
         request->startup_id = "0"; // krazy:exclude=doublequote_chars
     if( !startup_id.isEmpty() && startup_id != "0" )
     {
-        QString dpy_str;
+        QByteArray dpy_bytes;
         foreach (const QString &env, envs) {
             if (env.startsWith(QLatin1String("DISPLAY=")))
-                dpy_str = env.mid(8);
+                dpy_bytes = env.mid(8).toLatin1();
         }
         Display* dpy = NULL;
-        if( !dpy_str.isEmpty() && mCached_dpy != NULL
-            && dpy_str != QLatin1String(XDisplayString( mCached_dpy )) )
+        if( !dpy_bytes.isEmpty() && mCached_dpy != NULL
+            && dpy_bytes != XDisplayString( mCached_dpy ) )
             dpy = mCached_dpy;
         if( dpy == NULL )
-            dpy = XOpenDisplay( dpy_str.toLatin1().constData() );
+            dpy = XOpenDisplay( dpy_bytes.constData() );
         if( dpy == NULL )
             return;
         KStartupInfoId id;
@@ -981,7 +901,7 @@ KLauncher::cancel_service_startup_info( KLaunchRequest* request, const QByteArra
 bool
 KLauncher::kdeinit_exec(const QString &app, const QStringList &args,
                         const QString& workdir, const QStringList &envs,
-                        const QString &startup_id, bool wait, const QDBusMessage &msg)
+                        const QString &startup_id, bool wait, QDBusMessage msg)
 {
    KLaunchRequest *request = new KLaunchRequest;
    request->autoStart = false;
@@ -1058,7 +978,16 @@ KLauncher::createArgs( KLaunchRequest *request, const KService::Ptr service ,
   {
      request->arg_list.append(*it);
   }
-  request->cwd = service->path();
+
+  const QString& path = service->path();
+  if (!path.isEmpty()) {
+      request->cwd = path;
+  } else if (!urls.isEmpty()) {
+      const KUrl url(urls.first());
+      if (url.isLocalFile()) {
+          request->cwd = url.directory();
+      }
+  }
 }
 
 ///// IO-Slave functions
@@ -1131,53 +1060,37 @@ KLauncher::requestSlave(const QString &protocol,
     QString name = KProtocolInfo::exec(protocol);
     if (name.isEmpty())
     {
-	error = i18n("Unknown protocol '%1'.\n", protocol);
+        error = i18n("Unknown protocol '%1'.\n", protocol);
         return 0;
     }
 
     QStringList arg_list;
-#ifdef USE_KPROCESS_FOR_KIOSLAVES
-    arg_list << name;
-    arg_list << protocol;
-    arg_list << mConnectionServer.address();
-    arg_list << app_socket;
-    name = KStandardDirs::findExe(QLatin1String("kioslave"));
-#else
-    QString arg1 = protocol;
-    QString arg2 = mConnectionServer.address();
-    QString arg3 = app_socket;
-    arg_list.append(arg1);
-    arg_list.append(arg2);
-    arg_list.append(arg3);
-#endif
+    arg_list.append(protocol);
+    arg_list.append(mConnectionServer.address());
+    arg_list.append(app_socket);
 
     kDebug(7016) << "KLauncher: launching new slave " << name << " with protocol=" << protocol
-     << " args=" << arg_list << endl;
+     << " args=" << arg_list;
 
 #ifdef Q_OS_UNIX
     if (mSlaveDebug == protocol)
     {
-#ifndef USE_KPROCESS_FOR_KIOSLAVES
        klauncher_header request_header;
        request_header.cmd = LAUNCHER_DEBUG_WAIT;
        request_header.arg_length = 0;
-       write(kdeinitSocket, &request_header, sizeof(request_header));
-#else
-      name = QString::fromLatin1("gdb");
-#endif
+       kde_safe_write(kdeinitSocket, &request_header, sizeof(request_header));
     }
     if (mSlaveValgrind == protocol) {
-#ifndef USE_KPROCESS_FOR_KIOSLAVES // otherwise we've already done this
-       KLibrary lib(name, KGlobal::mainComponent());
+       KPluginLoader lib(name, KGlobal::mainComponent());
        arg_list.prepend(lib.fileName());
-       arg_list.prepend(KStandardDirs::locate("exe", QString::fromLatin1("kioslave")));
-#endif
+       arg_list.prepend(KStandardDirs::findExe(QString::fromLatin1("kioslave")));
        name = QString::fromLatin1("valgrind");
 
        if (!mSlaveValgrindSkin.isEmpty()) {
            arg_list.prepend(QLatin1String("--tool=") + mSlaveValgrindSkin);
-       } else
-	   arg_list.prepend(QLatin1String("--tool=memcheck"));
+       } else {
+           arg_list.prepend(QLatin1String("--tool=memcheck"));
+       }
     }
 #endif
     KLaunchRequest *request = new KLaunchRequest;
@@ -1215,17 +1128,17 @@ bool KLauncher::checkForHeldSlave(const QString &url)
 }
 
 void
-KLauncher::waitForSlave(int pid, const QDBusMessage &msg)
+KLauncher::waitForSlave(pid_t pid, QDBusMessage msg)
 {
-    foreach (IdleSlave *slave, mSlaveList)
+    foreach (const IdleSlave *slave, mSlaveList)
     {
-        if (slave->pid() == static_cast<pid_t>(pid))
+        if (slave->pid() == pid)
            return; // Already here.
     }
     SlaveWaitRequest *waitRequest = new SlaveWaitRequest;
     msg.setDelayedReply(true);
     waitRequest->transaction = msg;
-    waitRequest->pid = static_cast<pid_t>(pid);
+    waitRequest->pid = pid;
     mSlaveWaitRequest.append(waitRequest);
 }
 
@@ -1274,13 +1187,10 @@ KLauncher::slotSlaveGone()
 void
 KLauncher::idleTimeout()
 {
-    bool keepOneFileSlave=true;
-    time_t now = time(0);
+    const time_t now = time(0);
     foreach (IdleSlave *slave, mSlaveList)
     {
-        if ((slave->protocol()==QLatin1String("file")) && (keepOneFileSlave))
-           keepOneFileSlave=false;
-        else if (slave->age(now) > SLAVE_MAX_IDLE)
+        if (slave->age(now) > SLAVE_MAX_IDLE)
         {
            // killing idle slave
            delete slave;
@@ -1295,56 +1205,13 @@ void KLauncher::reparseConfiguration()
       slave->reparseConfiguration();
 }
 
-
-void
-KLauncher::slotGotOutput()
-{
-#ifdef USE_KPROCESS_FOR_KIOSLAVES
-  KProcess *p = static_cast<KProcess *>(sender());
-  QByteArray _stdout = p->readAllStandardOutput();
-  kDebug(7016) << _stdout.data();
-#endif
-}
-
-void
-KLauncher::slotFinished(int exitCode, QProcess::ExitStatus exitStatus )
-{
-#ifdef USE_KPROCESS_FOR_KIOSLAVES
-    KProcess *p = static_cast<KProcess *>(sender());
-    kDebug(7016) << "process finished exitcode=" << exitCode << "exitStatus=" << exitStatus;
-
-    foreach (KLaunchRequest *request, requestList)
-    {
-        if (request->process == p)
-        {
-#ifdef KLAUNCHER_VERBOSE_OUTPUT
-            kDebug(7016) << "found KProcess, request done";
-#endif
-            if (exitCode == 0  && exitStatus == QProcess::NormalExit)
-                request->status = KLaunchRequest::Done;
-            else
-                request->status = KLaunchRequest::Error;
-            requestDone(request);
-            request->process = 0;
-        }
-    }
-    delete p;
-#else
-   Q_UNUSED(exitCode);
-   Q_UNUSED(exitStatus);
-#endif
-}
-
-
 void KLauncher::terminate_kdeinit()
 {
     kDebug(7016);
-#ifndef USE_KPROCESS_FOR_KIOSLAVES
     klauncher_header request_header;
     request_header.cmd = LAUNCHER_TERMINATE_KDEINIT;
     request_header.arg_length = 0;
-    write(kdeinitSocket, &request_header, sizeof(request_header));
-#endif
+    kde_safe_write(kdeinitSocket, &request_header, sizeof(request_header));
 }
 
-#include "klauncher.moc"
+#include "moc_klauncher.cpp"
