@@ -35,7 +35,6 @@
 #include "klauncher_cmds.h"
 #include <QtCore/QCoreApplication>
 
-#ifndef Q_WS_WIN
 static int sigpipe[ 2 ];
 static void sig_handler(int sig_num)
 {
@@ -46,15 +45,10 @@ static void sig_handler(int sig_num)
    char tmp = 'x';
    write( sigpipe[ 1 ], &tmp, 1 );
 }
-#endif
 
-#if defined(Q_OS_DARWIN) || defined (Q_OS_MAC)
-#include <kkernel_mac.h>
-#endif
 
-extern "C" KDE_EXPORT int kdemain( int argc, char**argv )
+int main( int argc, char**argv )
 {
-#ifndef Q_WS_WIN
    // Started via kdeinit.
    int launcherFd;
    if (argc != 2 || memcmp(argv[1], "--fd=", 5) || !(launcherFd = atoi(argv[1] + 5)))
@@ -63,11 +57,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char**argv )
                                  "klauncher: It is started automatically by kdeinit4.\n").toLocal8Bit().data());
       return 1;
    }
-#endif
 
-#if defined(Q_OS_DARWIN) || defined (Q_OS_MAC)
-   mac_initialize_dbus();
-#endif
 
    KComponentData componentData("klauncher", "kdelibs4");
    KGlobal::locale();
@@ -110,25 +100,19 @@ extern "C" KDE_EXPORT int kdemain( int argc, char**argv )
       // Try again...
    }
 
-#ifndef Q_WS_WIN
    KLauncher *launcher = new KLauncher(launcherFd);
-#else
-   KLauncher *launcher = new KLauncher();
-#endif
    QDBusConnection::sessionBus().registerObject(QString::fromLatin1("/"), launcher);
 
-#ifndef Q_WS_WIN
    if (pipe(sigpipe) != 0) {
        perror("klauncher: pipe failed.");
        return 1;
    }
    QSocketNotifier* signotif = new QSocketNotifier( sigpipe[ 0 ], QSocketNotifier::Read, launcher );
-   QObject::connect( signotif, SIGNAL( activated( int )), launcher, SLOT( destruct()));
+   QObject::connect( signotif, SIGNAL(activated(int)), launcher, SLOT(destruct()));
    KCrash::setEmergencySaveFunction(sig_handler);
    KDE_signal( SIGHUP, sig_handler);
    KDE_signal( SIGPIPE, SIG_IGN);
    KDE_signal( SIGTERM, sig_handler);
-#endif
 
    return app.exec();
 }
