@@ -137,9 +137,9 @@ int KBookmarkGroup::indexOf(const KBookmark& child) const
 
 QDomElement KBookmarkGroup::nextKnownTag( const QDomElement &start, bool goNext ) const
 {
-    static const QString & bookmark = KGlobal::staticQString("bookmark");
-    static const QString & folder = KGlobal::staticQString("folder");
-    static const QString & separator = KGlobal::staticQString("separator");
+    static const QString bookmark = QString::fromLatin1("bookmark");
+    static const QString folder = QString::fromLatin1("folder");
+    static const QString separator = QString::fromLatin1("separator");
 
     for( QDomElement elem = start; !elem.isNull(); )
     {
@@ -179,12 +179,6 @@ KBookmark KBookmarkGroup::createNewSeparator()
     return KBookmark(sepElem);
 }
 
-#ifndef KDE_NO_DEPRECATED
-bool KBookmarkGroup::moveItem( const KBookmark & bookmark, const KBookmark & after )
-{
-    return moveBookmark(bookmark, after);
-}
-#endif
 
 bool KBookmarkGroup::moveBookmark( const KBookmark & item, const KBookmark & after )
 {
@@ -248,21 +242,12 @@ QDomElement KBookmarkGroup::findToolbar() const
 {
     if ( element.attribute("toolbar") == "yes" )
         return element;
-    for (QDomNode n = element.firstChild(); !n.isNull() ; n = n.nextSibling() )
+    for (QDomElement e = element.firstChildElement("folder"); !e.isNull();
+        e = e.nextSiblingElement("folder") )
     {
-        QDomElement e = n.toElement();
-        // Search among the "folder" children only
-        if ( e.tagName() == "folder" )
-        {
-            if ( e.attribute("toolbar") == "yes" )
-                return e;
-            else
-            {
-                QDomElement result = KBookmarkGroup(e).findToolbar();
-                if (!result.isNull())
-                    return result;
-            }
-        }
+        QDomElement result = KBookmarkGroup(e).findToolbar();
+        if (!result.isNull())
+            return result;
     }
     return QDomElement();
 }
@@ -360,14 +345,6 @@ QString KBookmark::icon() const
     QDomElement iconElement = cd(metaDataNode, "bookmark:icon", false).toElement();
 
     QString icon = iconElement.attribute("name");
-
-    // migration code
-    if (icon.isEmpty())
-      icon = element.attribute("icon");
-    if (icon == "www") // common icon for kde3 bookmarks
-        return "internet-web-browser";
-    // end migration code
-
     if (icon == "bookmark_folder") {
         return "folder-bookmarks";
     }
@@ -705,14 +682,6 @@ QStringList KBookmark::List::mimeDataTypes()
     return QStringList()<<("application/x-xbel")<<KUrl::List::mimeDataTypes();
 }
 
-#ifndef KDE_NO_DEPRECATED
-KBookmark::List KBookmark::List::fromMimeData( const QMimeData *mimeData )
-{
-    QDomDocument doc;
-    kWarning(7043) << "Deprecated method called, with wrong lifetime of QDomDocument, will probably crash";
-    return fromMimeData(mimeData, doc);
-}
-#endif
 
 KBookmark::List KBookmark::List::fromMimeData( const QMimeData *mimeData, QDomDocument& doc )
 {
