@@ -17,14 +17,15 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef __kbookmark_h
-#define __kbookmark_h
+#ifndef KBOOKMARK_H
+#define KBOOKMARK_H
 
 #include <kio/kio_export.h>
 
 #include <QtCore/QString>
 #include <QtCore/QList>
-#include <QtXml/QDomElement>
+#include <QtCore/QMetaType>
+#include <QtXml/qdom.h>
 #include <kurl.h>
 
 class KBookmarkManager;
@@ -66,17 +67,6 @@ public:
          */
         static QStringList mimeDataTypes();
 
-        /**
-         * Extract a list of bookmarks from the contents of @p mimeData.
-         * Decoding will fail if @p mimeData does not contain any bookmarks.
-         * @param mimeData the mime data to extract from; cannot be 0
-         * @return the list of bookmarks
-         * @note those bookmarks are valid QDomElements, but their parent QDomDocument
-         * is already deleted, do not use ownerDocument()
-         * @deprecated use fromMimeData(mimeData, doc), to avoid crashes
-         */
-        static KDE_DEPRECATED KBookmark::List fromMimeData( const QMimeData *mimeData );
-
         /**
          * Extract a list of bookmarks from the contents of @p mimeData.
          * Decoding will fail if @p mimeData does not contain any bookmarks.
@@ -334,10 +324,6 @@ protected:
 
 };
 
-#ifdef MAKE_KIO_LIB
-KDE_DUMMY_QHASH_FUNCTION(KBookmark)
-#endif
-
 /**
  * A group of bookmarks
  */
@@ -418,7 +404,6 @@ public:
      */
     bool moveBookmark( const KBookmark & bookmark, const KBookmark & after);
 
-    KDE_DEPRECATED bool moveItem( const KBookmark & item, const KBookmark & after );
 
     /**
      * Delete a bookmark - it has to be one of our children !
@@ -460,4 +445,7 @@ protected:
     virtual void visitLeave(const KBookmarkGroup &);
 };
 
+#define KIO_KBOOKMARK_METATYPE_DEFINED 1
+Q_DECLARE_METATYPE( KBookmark )
+
 #endif
