@@ -27,6 +27,9 @@
 #include <QtCore/QProcess>
 #include <QtCore/QRegExp>
 #include <QtCore/QTextStream>
+#include <QtCore/QMutex>
+#include <QtCore/QTextCodec>
+#include <QtCore/QThread>
 #include <QtDBus/QtDBus>
 #include <QtGui/QApplication>
 
@@ -37,6 +40,7 @@
 #include <kmessagebox.h>
 #include <ksavefile.h>
 #include <kstandarddirs.h>
+#include <kmimetype.h>
 
 #include "kbookmarkmenu.h"
 #include "kbookmarkmenu_p.h"
@@ -53,7 +57,7 @@ public:
         qDeleteAll( begin() , end() ); // auto-delete functionality
     }
 
-    QReadWriteLock lock;
+    QMutex mutex;
 };
 
 K_GLOBAL_STATIC(KBookmarkManagerList, s_pSelf)
@@ -83,6 +87,15 @@ void KBookmarkMap::update(KBookmarkManager *manager)
         m_bk_map.clear();
         KBookmarkGroup root = manager->root();
         traverse(root);
+
+        QMapIterator<QString, KBookmarkList> iter(m_bk_map);
+        while (iter.hasNext()) {
+            iter.next();
+            foreach (KBookmark it, iter.value()) {
+                kDebug() << "updating favicon for" << it.url();
+                it.setIcon(KMimeType::favIconForUrl(it.url()));
+            }
+        }
     }
 }
 
@@ -149,17 +162,8 @@ static KBookmarkManager* lookupExisting(const QString& bookmarksFile)
 
 KBookmarkManager* KBookmarkManager::managerForFile( const QString& bookmarksFile, const QString& dbusObjectName )
 {
-    KBookmarkManager* mgr(0);
-    {
-        QReadLocker readLock(&s_pSelf->lock);
-        mgr = lookupExisting(bookmarksFile);
-        if (mgr) {
-            return mgr;
-        }
-    }
-
-    QWriteLocker writeLock(&s_pSelf->lock);
-    mgr = lookupExisting(bookmarksFile);
+    QMutexLocker lock(&s_pSelf->mutex);
+    KBookmarkManager* mgr = lookupExisting(bookmarksFile);
     if (mgr) {
         return mgr;
     }
@@ -171,17 +175,8 @@ KBookmarkManager* KBookmarkManager::managerForFile( const QString& bookmarksFile
 
 KBookmarkManager* KBookmarkManager::managerForExternalFile( const QString& bookmarksFile )
 {
-    KBookmarkManager* mgr(0);
-    {
-        QReadLocker readLock(&s_pSelf->lock);
-        mgr = lookupExisting(bookmarksFile);
-        if (mgr) {
-            return mgr;
-        }
-    }
-
-    QWriteLocker writeLock(&s_pSelf->lock);
-    mgr = lookupExisting(bookmarksFile);
+    QMutexLocker lock(&s_pSelf->mutex);
+    KBookmarkManager* mgr = lookupExisting(bookmarksFile);
     if (mgr) {
         return mgr;
     }
@@ -260,10 +255,6 @@ KBookmarkManager::KBookmarkManager(const QString & bookmarksFile)
     d->m_kDirWatch->addFile(d->m_bookmarksFile);
     QObject::connect( d->m_kDirWatch, SIGNAL(dirty(const QString&)),
             this, SLOT(slotFileChanged(const QString&)));
-    QObject::connect( d->m_kDirWatch, SIGNAL(created(const QString&)),
-            this, SLOT(slotFileChanged(const QString&)));
-    QObject::connect( d->m_kDirWatch, SIGNAL(deleted(const QString&)),
-            this, SLOT(slotFileChanged(const QString&)));
     kDebug(7043) << "starting KDirWatch for " << d->m_bookmarksFile;
 }
 
@@ -426,7 +417,6 @@ bool KBookmarkManager::saveAs( const QString & filename, bool toolbarCache ) con
     KSaveFile file( filename );
     if ( file.open() )
     {
-        file.simpleBackupFile( file.fileName(), QString(), ".bak" );
         QTextStream stream(&file);
         stream.setCodec( QTextCodec::codecForName( "UTF-8" ) );
         stream << internalDocument().toString();
@@ -502,9 +492,14 @@ KBookmarkGroup KBookmarkManager::toolbar()
     // is already loaded
     QDomElement elem = root().findToolbar();
     if (elem.isNull())
-        return root(); // Root is the bookmark toolbar if none has been set.
+    {
+        // Root is the bookmark toolbar if none has been set.
+        // Make it explicit to speed up invocations of findToolbar()
+        root().internalElement().setAttribute("toolbar", "yes");
+        return root();
+    }
     else
-        return KBookmarkGroup(root().findToolbar());
+        return KBookmarkGroup(elem);
 }
 
 KBookmark KBookmarkManager::findByAddress( const QString & address )
@@ -514,10 +509,10 @@ KBookmark KBookmarkManager::findByAddress( const QString & address )
     // The address is something like /5/10/2+
     const QStringList addresses = address.split(QRegExp("[/+]"),QString::SkipEmptyParts);
     // kWarning() << addresses.join(",");
-    for ( QStringList::const_iterator it = addresses.begin() ; it != addresses.end() ; )
+    foreach (const QString it, addresses)
     {
-       bool append = ((*it) == "+");
-       uint number = (*it).toUInt();
+       bool append = (it == "+");
+       uint number = it.toUInt();
        Q_ASSERT(result.isGroup());
        KBookmarkGroup group = result.toGroup();
        KBookmark bk = group.first(), lbk = bk; // last non-null bookmark
@@ -526,12 +521,14 @@ KBookmark KBookmarkManager::findByAddress( const QString & address )
            bk = group.next(bk);
          //kWarning() << i;
        }
-       it++;
        //kWarning() << "found section";
        result = bk;
     }
     if (result.isNull()) {
        kWarning() << "KBookmarkManager::findByAddress: couldn't find item " << address;
+    } else {
+        kDebug() << "updating favicon for" << result.url();
+        result.setIcon(KMimeType::favIconForUrl(result.url()));
     }
     //kWarning() << "found " << result.address();
     return result;
@@ -638,26 +635,21 @@ bool KBookmarkManager::updateAccessMetadata( const QString & url )
 {
     d->m_map.update(this);
     QList<KBookmark> list = d->m_map.find(url);
-    if ( list.count() == 0 )
-        return false;
-
-    for ( QList<KBookmark>::iterator it = list.begin();
-          it != list.end(); ++it )
-        (*it).updateAccessMetadata();
+    foreach ( KBookmark it, list ) {
+        it.updateAccessMetadata();
+    }
 
     return true;
 }
 
-void KBookmarkManager::updateFavicon( const QString &url, const QString &/*faviconurl*/ )
+void KBookmarkManager::updateFavicon( const QString &url, const QString &faviconurl )
 {
     d->m_map.update(this);
     QList<KBookmark> list = d->m_map.find(url);
-    for ( QList<KBookmark>::iterator it = list.begin();
-          it != list.end(); ++it )
+    foreach ( KBookmark it, list )
     {
-        // TODO - update favicon data based on faviconurl
-        //        but only when the previously used icon
-        //        isn't a manually set one.
+        KUrl iconurl(faviconurl);
+        it.setIcon(KMimeType::favIconForUrl(iconurl));
     }
 }
 
@@ -714,4 +706,4 @@ void KBookmarkOwner::openFolderinTabs(const KBookmarkGroup &)
 
 }
 
-#include "kbookmarkmanager.moc"
+#include "moc_kbookmarkmanager.cpp"
