@@ -20,10 +20,7 @@
 
 #include "kbookmarkmenu.h"
 #include "kbookmarkmenu_p.h"
-
 #include "kbookmarkdialog.h"
-
-#include <kauthorized.h>
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <klocale.h>
@@ -37,8 +34,6 @@
 
 #include <qclipboard.h>
 #include <qmimedata.h>
-
-
 #include <QtCore/QStack>
 #include <QtGui/QHeaderView>
 #include <QtGui/QApplication>
@@ -54,11 +49,11 @@ public:
         addAddBookmark(0),
         bookmarksToFolder(0)
     {
-    }    
+    }
 
-    QAction *newBookmarkFolder;
-    QAction *addAddBookmark;
-    QAction *bookmarksToFolder;
+    KAction *newBookmarkFolder;
+    KAction *addAddBookmark;
+    KAction *bookmarksToFolder;
 };
 
 
@@ -139,7 +134,7 @@ KBookmarkMenu::~KBookmarkMenu()
 {
     qDeleteAll( m_lstSubMenus );
     qDeleteAll( m_actions );
-    delete d;   
+    delete d;
 }
 
 void KBookmarkMenu::ensureUpToDate()
@@ -170,24 +165,24 @@ void KBookmarkMenu::slotCustomContextMenu( const QPoint & pos)
 }
 
 KMenu * KBookmarkMenu::contextMenu( QAction * action )
-{ 
+{
     KBookmarkActionInterface* act = dynamic_cast<KBookmarkActionInterface *>(action);
     if (!act)
         return 0;
     return new KBookmarkContextMenu(act->bookmark(), m_pManager, m_pOwner);
 }
 
-bool KBookmarkMenu::isRoot() const 
+bool KBookmarkMenu::isRoot() const
 {
     return m_bIsRoot;
 }
 
-bool KBookmarkMenu::isDirty() const 
+bool KBookmarkMenu::isDirty() const
 {
     return m_bDirty;
 }
 
-QString KBookmarkMenu::parentAddress() const 
+QString KBookmarkMenu::parentAddress() const
 {
     return m_parentAddress;
 }
@@ -197,12 +192,12 @@ KBookmarkManager * KBookmarkMenu::manager() const
     return m_pManager;
 }
 
-KBookmarkOwner * KBookmarkMenu::owner() const 
+KBookmarkOwner * KBookmarkMenu::owner() const
 {
     return m_pOwner;
 }
 
-KMenu * KBookmarkMenu::parentMenu() const 
+KMenu * KBookmarkMenu::parentMenu() const
 {
     return m_parentMenu;
 }
@@ -404,58 +399,52 @@ KBookmark KBookmarkContextMenu::bookmark() const
 
 void KBookmarkMenu::slotBookmarksChanged( const QString & groupAddress )
 {
-  kDebug(7043)<<"KBookmarkMenu::slotBookmarksChanged( "<<groupAddress;
-  if ( groupAddress == m_parentAddress )
-  {
-    //kDebug(7043) << "KBookmarkMenu::slotBookmarksChanged -> setting m_bDirty on " << groupAddress;
-    m_bDirty = true;
-  }
-  else
-  {
-    // Iterate recursively into child menus
-    for ( QList<KBookmarkMenu *>::iterator it = m_lstSubMenus.begin(), end = m_lstSubMenus.end() ;
-          it != end ; ++it ) {
-      (*it)->slotBookmarksChanged( groupAddress );
+    kDebug(7043)<<"KBookmarkMenu::slotBookmarksChanged( "<<groupAddress;
+    if ( groupAddress == m_parentAddress ) {
+        //kDebug(7043) << "KBookmarkMenu::slotBookmarksChanged -> setting m_bDirty on " << groupAddress;
+        m_bDirty = true;
+    } else {
+        // Iterate recursively into child menus
+        foreach ( KBookmarkMenu *it, m_lstSubMenus ) {
+            it->slotBookmarksChanged( groupAddress );
+        }
     }
-  }
 }
 
 void KBookmarkMenu::clear()
 {
-  qDeleteAll( m_lstSubMenus );
-  m_lstSubMenus.clear();
+    qDeleteAll( m_lstSubMenus );
+    m_lstSubMenus.clear();
 
-  for ( QList<QAction *>::iterator it = m_actions.begin(), end = m_actions.end() ;
-        it != end ; ++it )
-  {
-        m_parentMenu->removeAction(*it);
-        delete *it;
-  }
+    foreach ( QAction *it, m_actions ) {
+        m_parentMenu->removeAction(it);
+        delete it;
+    }
 
-  m_parentMenu->clear();
-  m_actions.clear();
+    m_parentMenu->clear();
+    m_actions.clear();
 }
 
 void KBookmarkMenu::refill()
 {
-  //kDebug(7043) << "KBookmarkMenu::refill()";
-  if(m_bIsRoot)
-    addActions();
-  fillBookmarks();
-  if(!m_bIsRoot)
-    addActions();
+    //kDebug(7043) << "KBookmarkMenu::refill()";
+    if(m_bIsRoot)
+        addActions();
+    fillBookmarks();
+    if(!m_bIsRoot)
+        addActions();
 }
 
 void KBookmarkMenu::addOpenInTabs()
 {
-    if( !m_pOwner || !m_pOwner->supportsTabs() || !KAuthorized::authorizeKAction("bookmarks") )
+    if( !m_pOwner || !m_pOwner->supportsTabs() )
         return;
 
     QString title = i18n( "Open Folder in Tabs" );
 
     KAction * paOpenFolderInTabs = new KAction( title, this );
     paOpenFolderInTabs->setIcon( KIcon("tab-new") );
-    paOpenFolderInTabs->setToolTip( i18n( "Open all bookmarks in this folder as a new tab." ) );
+    paOpenFolderInTabs->setHelpText( i18n( "Open all bookmarks in this folder as a new tab." ) );
     connect( paOpenFolderInTabs, SIGNAL( triggered( bool ) ), this, SLOT( slotOpenFolderInTabs() ) );
 
     m_parentMenu->addAction(paOpenFolderInTabs);
@@ -464,7 +453,7 @@ void KBookmarkMenu::addOpenInTabs()
 
 void KBookmarkMenu::addAddBookmarksList()
 {
-    if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !m_pOwner->supportsTabs() || !KAuthorized::authorizeKAction("bookmarks") )
+    if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !m_pOwner->supportsTabs() )
         return;
 
     if (d->bookmarksToFolder == 0) {
@@ -472,20 +461,19 @@ void KBookmarkMenu::addAddBookmarksList()
         d->bookmarksToFolder = new KAction( title, this );
         m_actionCollection->addAction( m_bIsRoot ? "add_bookmarks_list" : 0, d->bookmarksToFolder);
         d->bookmarksToFolder->setIcon( KIcon( "bookmark-new-list" ) );
-        d->bookmarksToFolder->setToolTip( i18n( "Add a folder of bookmarks for all open tabs." ) );
+        d->bookmarksToFolder->setHelpText( i18n( "Add a folder of bookmarks for all open tabs." ) );
         connect( d->bookmarksToFolder, SIGNAL( triggered( bool ) ), this, SLOT( slotAddBookmarksList() ) );
     }
-    
+
     m_parentMenu->addAction(d->bookmarksToFolder);
 }
 
 void KBookmarkMenu::addAddBookmark()
 {
-  if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !KAuthorized::authorizeKAction("bookmarks") )
-    return;
+    if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) )
+        return;
 
     if (d->addAddBookmark == 0) {
-        QString title = i18n( "Add Bookmark" );
         d->addAddBookmark = m_actionCollection->addAction(
                 KStandardAction::AddBookmark,
                 m_bIsRoot ? "add_bookmark" : 0,
@@ -500,24 +488,24 @@ void KBookmarkMenu::addAddBookmark()
 
 void KBookmarkMenu::addEditBookmarks()
 {
-  if( ( m_pOwner && !m_pOwner->enableOption(KBookmarkOwner::ShowEditBookmark) ) || !KAuthorized::authorizeKAction("bookmarks") )
-    return;
+    if( ( m_pOwner && !m_pOwner->enableOption(KBookmarkOwner::ShowEditBookmark) ) )
+        return;
 
-  QAction * m_paEditBookmarks = m_actionCollection->addAction( KStandardAction::EditBookmarks, "edit_bookmarks",
-                                                               m_pManager, SLOT( slotEditBookmarks() ) );
-  m_parentMenu->addAction(m_paEditBookmarks);
-  m_paEditBookmarks->setToolTip( i18n( "Edit your bookmark collection in a separate window" ) );
+    KAction * m_paEditBookmarks = m_actionCollection->addAction(KStandardAction::EditBookmarks, "edit_bookmarks",
+                                                              m_pManager, SLOT(slotEditBookmarks()));
+    m_parentMenu->addAction(m_paEditBookmarks);
+    m_paEditBookmarks->setHelpText( i18n( "Edit your bookmark collection in a separate window" ) );
 }
 
 void KBookmarkMenu::addNewFolder()
 {
-    if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !KAuthorized::authorizeKAction("bookmarks"))
+    if( !m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) )
         return;
-    
+
     if (d->newBookmarkFolder == 0) {
         d->newBookmarkFolder = new KAction( i18n( "New Bookmark Folder..." ), this );
         d->newBookmarkFolder->setIcon( KIcon( "folder-new" ) );
-        d->newBookmarkFolder->setToolTip( i18n( "Create a new bookmark folder in this menu" ) );
+        d->newBookmarkFolder->setHelpText( i18n( "Create a new bookmark folder in this menu" ) );
         connect( d->newBookmarkFolder, SIGNAL( triggered( bool ) ), this, SLOT( slotNewFolder() ) );
     }
 
@@ -597,7 +585,7 @@ void KBookmarkMenu::slotAddBookmark()
       parentBookmark.addBookmark(m_pOwner->currentTitle(), KUrl(m_pOwner->currentUrl()));
       m_pManager->emitChanged( parentBookmark );
   }
-      
+
 }
 
 void KBookmarkMenu::slotOpenFolderInTabs()
@@ -726,7 +714,11 @@ KBookmarkAction::KBookmarkAction(const KBookmark &bk, KBookmarkOwner* owner, QOb
     m_pOwner(owner)
 {
   setIcon(KIcon(bookmark().icon()));
-  setToolTip( bookmark().url().pathOrUrl() );
+  setIconText(text());
+  setHelpText( bookmark().url().pathOrUrl() );
+  const QString description = bk.description();
+  if (!description.isEmpty())
+    setToolTip( description );
   connect(this, SIGNAL( triggered(Qt::MouseButtons, Qt::KeyboardModifiers) ),
      SLOT( slotSelected(Qt::MouseButtons, Qt::KeyboardModifiers) ));
 }
@@ -747,6 +739,8 @@ KBookmarkActionMenu::KBookmarkActionMenu(const KBookmark &bm, QObject *parent)
   : KActionMenu(KIcon(bm.icon()), bm.text().replace('&', "&&"), parent),
     KBookmarkActionInterface(bm)
 {
+  setToolTip( bm.description() );
+  setIconText(text());
 }
 
 KBookmarkActionMenu::KBookmarkActionMenu(const KBookmark &bm, const QString & text, QObject *parent)
@@ -759,5 +753,5 @@ KBookmarkActionMenu::~KBookmarkActionMenu()
 {
 }
 
-#include "kbookmarkmenu.moc"
-#include "kbookmarkmenu_p.moc"
+#include "moc_kbookmarkmenu.cpp"
+#include "moc_kbookmarkmenu_p.cpp"
