@@ -34,24 +34,20 @@
 #include <qcheckbox.h>
 #include <qlayout.h>
 #include <QStackedWidget>
-#include <QMouseEvent>
+#include <QtGui/qevent.h>
 #include <QHeaderView>
 
 #include <klocale.h>
 #include <kfileitem.h>
 #include <kdebug.h>
 #include <kdialog.h>
-#include <kvbox.h>
 #include <khbox.h>
+#include <kstandarddirs.h>
+#include <kuser.h>
 
 #ifdef HAVE_ACL_LIBACL_H
 # include <acl/libacl.h>
 #endif
-extern "C" {
-#include <pwd.h>
-#include <grp.h>
-}
-#include <assert.h>
 
 static struct {
     const char* label;
@@ -90,7 +86,7 @@ KACLEditWidget::KACLEditWidget( QWidget *parent )
     d->m_listView = new KACLListView(this);
     hbox->addWidget(d->m_listView);
     connect(d->m_listView->selectionModel(),
-            SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection& )),
+            SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             this,
             SLOT(_k_slotUpdateButtons()));
     QVBoxLayout *vbox = new QVBoxLayout();
@@ -217,37 +213,6 @@ bool KACLListViewItem::operator< ( const QTreeWidgetItem& other ) const
     return key() < static_cast<const KACLListViewItem&>(other).key();
 }
 
-#if 0
-void KACLListViewItem::paintCell( QPainter* p, const QColorGroup &cg,
-                                  int column, int width, int alignment )
-{
-    if ( isDefault ) {
-        setForeground( QColor( 0, 0, 255 ) );
-    }
-    if ( isPartial ) {
-        QFont font = p->font();
-        font.setItalic( true );
-        setForeground( QColor( 100, 100, 100 ) );
-        p->setFont( font );
-    }
-    QTreeWidgetItem::paintCell( p, mycg, column, width, alignment );
-
-    KACLListViewItem *below =0;
-    if ( itemBelow() )
-        below = static_cast<KACLListViewItem*>( itemBelow() );
-    const bool lastUser = type == KACLListView::NamedUser && below && below->type == KACLListView::NamedGroup;
-    const bool lastNonDefault = !isDefault && below && below->isDefault;
-    if ( type == KACLListView::Mask || lastUser || lastNonDefault )
-    {
-        p->setPen( QPen( Qt::gray, 0, Qt::DotLine ) );
-        if ( type == KACLListView::Mask )
-            p->drawLine( 0, 0, width - 1, 0 );
-        p->drawLine( 0, height() - 1, width - 1, height() - 1 );
-    }
-}
-#endif
-
-
 void KACLListViewItem::updatePermPixmaps()
 {
     unsigned int partialPerms = value;
@@ -280,25 +245,25 @@ void KACLListViewItem::repaint()
     switch ( type )
     {
       case KACLListView::User:
-          idx = KACLListView::OWNER_IDX;
+            idx = KACLListView::OWNER_IDX;
             break;
         case KACLListView::Group:
-          idx = KACLListView::GROUP_IDX;
+            idx = KACLListView::GROUP_IDX;
             break;
         case KACLListView::Others:
-          idx = KACLListView::OTHERS_IDX;
+            idx = KACLListView::OTHERS_IDX;
             break;
         case KACLListView::Mask:
-          idx = KACLListView::MASK_IDX;
+            idx = KACLListView::MASK_IDX;
             break;
         case KACLListView::NamedUser:
-          idx = KACLListView::NAMED_USER_IDX;
+            idx = KACLListView::NAMED_USER_IDX;
             break;
         case KACLListView::NamedGroup:
-          idx = KACLListView::NAMED_GROUP_IDX;
+            idx = KACLListView::NAMED_GROUP_IDX;
             break;
         default:
-          idx = KACLListView::OWNER_IDX;
+            idx = KACLListView::OWNER_IDX;
             break;
     }
     setText( 0, i18n(s_itemAttributes[idx].label) );
@@ -445,10 +410,10 @@ EditACLEntryDialog::EditACLEntryDialog( KACLListView *listView, KACLListViewItem
         m_defaultCB = new QCheckBox( i18n("Default for new files in this folder"), page );
         m_defaultCB->setObjectName( QLatin1String( "defaultCB" ) );
         mainLayout->addWidget( m_defaultCB );
-        connect( m_defaultCB, SIGNAL( toggled( bool ) ),
-                 this, SLOT( slotUpdateAllowedUsersAndGroups() ) );
-        connect( m_defaultCB, SIGNAL( toggled( bool ) ),
-                 this, SLOT( slotUpdateAllowedTypes() ) );
+        connect( m_defaultCB, SIGNAL(toggled(bool)),
+                 this, SLOT(slotUpdateAllowedUsersAndGroups()) );
+        connect( m_defaultCB, SIGNAL(toggled(bool)),
+                 this, SLOT(slotUpdateAllowedTypes()) );
     }
 
     QRadioButton *ownerType = new QRadioButton( i18n("Owner"), gb );
@@ -484,8 +449,8 @@ EditACLEntryDialog::EditACLEntryDialog( KACLListView *listView, KACLListViewItem
 
     mainLayout->addWidget( gb );
 
-    connect( m_buttonGroup, SIGNAL( buttonClicked( QAbstractButton* ) ),
-             this, SLOT( slotSelectionChanged( QAbstractButton * ) ) );
+    connect( m_buttonGroup, SIGNAL(buttonClicked(QAbstractButton*)),
+             this, SLOT(slotSelectionChanged(QAbstractButton*)) );
 
     m_widgetStack = new QStackedWidget( page );
     mainLayout->addWidget( m_widgetStack );
@@ -614,6 +579,10 @@ void EditACLEntryDialog::slotSelectionChanged( QAbstractButton *button )
     }
 }
 
+static QString kfileIconPath(const char* const name)
+{
+    return KStandardDirs::locate("data", QString::fromLatin1("kio/pics/%1.png").arg(name));
+}
 
 KACLListView::KACLListView( QWidget* parent )
  : QTreeWidget( parent ),
@@ -637,31 +606,20 @@ KACLListView::KACLListView( QWidget* parent )
 
     // Load the avatars
     for ( int i=0; i < LAST_IDX; ++i ) {
-        s_itemAttributes[i].pixmap = new QPixmap( QString::fromLatin1(":/images/%1").arg(s_itemAttributes[i].pixmapName) );
+        s_itemAttributes[i].pixmap = new QPixmap( kfileIconPath(s_itemAttributes[i].pixmapName) );
     }
-    m_yesPixmap = new QPixmap( ":/images/yes.png" );
-    m_yesPartialPixmap = new QPixmap( ":/images/yespartial.png" );
+    m_yesPixmap = new QPixmap( kfileIconPath("yes") );
+    m_yesPartialPixmap = new QPixmap( kfileIconPath("yespartial") );
 
 
     // fill the lists of all legal users and groups
-    struct passwd *user = 0;
-    setpwent();
-    while ( ( user = getpwent() ) != 0 ) {
-       m_allUsers << QString::fromLatin1( user->pw_name );
-    }
-    endpwent();
-
-    struct group *gr = 0;
-    setgrent();
-    while ( ( gr = getgrent() ) != 0 ) {
-       m_allGroups << QString::fromLatin1( gr->gr_name );
-    }
-    endgrent();
+    m_allUsers = KUser::allUserNames();
+    m_allGroups << KUserGroup::allGroupNames();
     m_allUsers.sort();
     m_allGroups.sort();
 
-    connect( this, SIGNAL( itemClicked( QTreeWidgetItem*, int ) ),
-             this, SLOT( slotItemClicked( QTreeWidgetItem*, int ) ) );
+    connect( this, SIGNAL(itemClicked(QTreeWidgetItem*,int)),
+             this, SLOT(slotItemClicked(QTreeWidgetItem*,int)) );
 }
 
 
@@ -711,17 +669,16 @@ void KACLListView::fillItemsFromACL( const KACL &pACL, bool defaults )
         if ( item->isDefault == defaults )
             delete item;
     }
-    KACLListViewItem *item =
-        new KACLListViewItem( this, User, pACL.ownerPermissions(), defaults );
+    new KACLListViewItem( this, User, pACL.ownerPermissions(), defaults );
 
-    item = new KACLListViewItem( this, Group, pACL.owningGroupPermissions(), defaults );
+    new KACLListViewItem( this, Group, pACL.owningGroupPermissions(), defaults );
 
-    item = new KACLListViewItem( this, Others, pACL.othersPermissions(), defaults );
+    new KACLListViewItem( this, Others, pACL.othersPermissions(), defaults );
 
     bool hasMask = false;
     unsigned short mask = pACL.maskPermissions( hasMask );
     if ( hasMask ) {
-        item = new KACLListViewItem( this, Mask, mask, defaults );
+        new KACLListViewItem( this, Mask, mask, defaults );
     }
 
     // read all named user entries
@@ -815,7 +772,7 @@ KACL KACLListView::getDefaultACL()
     return itemsToACL( true );
 }
 
-void KACLListView::contentsMousePressEvent( QMouseEvent * e )
+void KACLListView::contentsMousePressEvent( QMouseEvent * /*e*/ )
 {
     /*
     QTreeWidgetItem *clickedItem = itemAt( e->pos() );
@@ -1118,7 +1075,7 @@ bool KACLListView::defaultMaskCanBeDeleted() const
     return !findDefaultItemByType( NamedUser ) && !findDefaultItemByType( NamedGroup );
 }
 
-#include "kacleditwidget.moc"
-#include "kacleditwidget_p.moc"
+#include "moc_kacleditwidget.cpp"
+#include "moc_kacleditwidget_p.cpp"
 #endif
 // vim:set ts=8 sw=4:
