@@ -28,15 +28,10 @@
 #include <QtCore/QFile>
 
 #include <kmountpoint.h>
+#include <kdebug.h>
 
-#ifdef Q_OS_WIN
-#include <QtCore/QDir>
-#include <windows.h>
-#else
-#include <QtCore/QFileInfo>
 #include <sys/statvfs.h>
-#endif
-
+#include <errno.h>
 
 class KDiskFreeSpaceInfo::Private : public QSharedData
 {
@@ -117,38 +112,20 @@ KDiskFreeSpaceInfo KDiskFreeSpaceInfo::freeSpaceInfo( const QString& path )
     if (mp)
         info.d->mountPoint = mp->mountPoint();
 
-#ifdef Q_OS_WIN
-    quint64 availUser;
-    QFileInfo fi(info.d->mountPoint);
-    QString dir = QDir::toNativeSeparators(fi.absoluteDir().canonicalPath());
-
-    if(GetDiskFreeSpaceExW((LPCWSTR)dir.utf16(),
-                           (PULARGE_INTEGER)&availUser,
-                           (PULARGE_INTEGER)&info.d->size,
-                           (PULARGE_INTEGER)&info.d->available) != 0) {
-        info.d->valid = true;
-    }
-#else
     struct statvfs statvfs_buf;
 
-    // Ignore autofs mountpoints as statvfs would trigger (expensive) automounting
-    // This also matches "special" filesystems like /proc where free space has no meaning
-    if (mp) {
-        QFileInfo fi(info.d->mountPoint);
-        if (fi.isDir() && fi.size() == 0) {
-            return info;
-        }
-    }
-
     // Prefer mountPoint if available, so that it even works with non-existing files.
     const QString pathArg = info.d->mountPoint.isEmpty() ? path : info.d->mountPoint;
-    if (!statvfs(QFile::encodeName(pathArg).constData(), &statvfs_buf)) {
+    const QByteArray pathArgBytes = QFile::encodeName(pathArg);
+    if (::statvfs(pathArgBytes.constData(), &statvfs_buf) == 0) {
         const quint64 blksize = quint64(statvfs_buf.f_frsize); // cast to avoid overflow
         info.d->available = statvfs_buf.f_bavail * blksize;
         info.d->size = statvfs_buf.f_blocks * blksize;
         info.d->valid = true;
+    } else {
+        const int savederrno = errno;
+        kWarning() << qt_error_string(savederrno);
     }
-#endif
 
     return info;
 }
