@@ -26,8 +26,9 @@
 
 #include "kfiledialog.h"
 
+#include <QtCore/QTextStream>
 #include <QtGui/QCheckBox>
-#include <QtGui/QKeyEvent>
+#include <QtGui/qevent.h>
 #include <QtGui/QFileDialog>
 #include <QtGui/QApplication>
 #include <QtGui/QDesktopWidget>
@@ -37,9 +38,6 @@
 #include <kpushbutton.h>
 #include <config-kfile.h>
 #include <krecentdocument.h>
-#include <kimagefilepreview.h>
-#include <kpluginloader.h>
-#include <kpluginfactory.h>
 #include <kdebug.h>
 #include <kwindowsystem.h>
 #include "kabstractfilewidget.h"
@@ -47,19 +45,12 @@
 #include "krecentdirs.h"
 #include "kservice.h"
 
-/** File dialogs are native by default on Windows. */
-#ifdef Q_WS_WIN
-const bool NATIVE_FILEDIALOGS_BY_DEFAULT = true;
-#else
-const bool NATIVE_FILEDIALOGS_BY_DEFAULT = false;
-#endif
-
 static QStringList mime2KdeFilter( const QStringList &mimeTypes, QString *allExtensions = 0 )
 {
   const KUrl emptyUrl;
   QStringList kdeFilter;
   QStringList allExt;
-  foreach( const QString& mimeType, mimeTypes ) {
+  foreach (const QString& mimeType, mimeTypes) {
     KMimeType::Ptr mime( KMimeType::mimeType(mimeType) );
     if (mime) {
       allExt += mime->patterns();
@@ -95,13 +86,13 @@ static QString qtFilter(const QStringList& _filters)
             new_name = current.mid(p+1);
         }
 	//Qt filters assume anything in () is the file extension list
-	new_name = new_name.replace('(', '[').replace(')',']').trimmed();
+        new_name = new_name.replace('(', '[').replace(')',']').trimmed();
 
         //convert everything to lower case and remove dupes (doesn't matter on win32)
         QStringList allfiltersUnique;
         const QStringList origList( new_f.split(' ', QString::SkipEmptyParts) );
         foreach (const QString& origFilter, origList) {
-	if (!allfiltersUnique.contains(origFilter, Qt::CaseInsensitive))
+        if (!allfiltersUnique.contains(origFilter, Qt::CaseInsensitive))
                 allfiltersUnique += origFilter.toLower();
         }
 
@@ -152,7 +143,7 @@ static const char s_defaultFileModuleName[] = "kfilemodule";
 static KAbstractFileModule* fileModule()
 {
     if(!s_module) {
-        QString moduleName = KConfigGroup(KGlobal::config(), ConfigGroup).readEntry("file module", s_defaultFileModuleName);
+        QString moduleName = KConfig("kdeglobals").group(ConfigGroup).readEntry("file module", s_defaultFileModuleName);
         if(!(s_module = loadFileModule(moduleName))) {
             kDebug() << "Failed to load configured file module" << moduleName;
             if(moduleName != s_defaultFileModuleName) {
@@ -208,7 +199,7 @@ public:
         w(0),
         cfgGroup(KGlobal::config(), ConfigGroup)
     {
-        if (cfgGroup.readEntry("Native", NATIVE_FILEDIALOGS_BY_DEFAULT) &&
+        if (cfgGroup.readEntry("Native", false) &&
             KFileDialogPrivate::Native::s_allowNative)
             native = new Native;
     }
@@ -218,7 +209,7 @@ public:
         if(!KFileDialogPrivate::Native::s_allowNative)
             return false;
         KConfigGroup cfgGroup(KGlobal::config(), ConfigGroup);
-        return cfgGroup.readEntry("Native", NATIVE_FILEDIALOGS_BY_DEFAULT);
+        return cfgGroup.readEntry("Native", false);
     }
     
     static QString getOpenFileName(const KUrl& startDir, const QString& filter,
@@ -255,11 +246,7 @@ bool KFileDialogPrivate::Native::s_allowNative = true;
 
 KFileDialog::KFileDialog( const KUrl& startDir, const QString& filter,
                           QWidget *parent, QWidget* customWidget)
-#ifdef Q_WS_WIN
-    : KDialog( parent , Qt::WindowMinMaxButtonsHint),
-#else
     : KDialog( parent ),
-#endif
       d( new KFileDialogPrivate )
 
 {
@@ -290,7 +277,7 @@ KFileDialog::KFileDialog( const KUrl& startDir, const QString& filter,
     d->w->okButton()->show();
     connect(d->w->okButton(), SIGNAL(clicked()), SLOT(slotOk()));
     d->w->cancelButton()->show();
-    connect(d->w->cancelButton(), SIGNAL( clicked() ), SLOT( slotCancel() ));
+    connect(d->w->cancelButton(), SIGNAL(clicked()), SLOT(slotCancel()));
 
     // Publish signals
     // TODO: Move the relevant signal declarations from KFileWidget to the
@@ -303,10 +290,6 @@ KFileDialog::KFileDialog( const KUrl& startDir, const QString& filter,
                          SIGNAL(fileSelected(KUrl)));
     connect(fileQWidget, SIGNAL(fileHighlighted(KUrl)),
                          SIGNAL(fileHighlighted(KUrl)));
-    connect(fileQWidget, SIGNAL(fileSelected(QString)),
-                         SIGNAL(fileSelected(QString)));
-    connect(fileQWidget, SIGNAL(fileHighlighted(QString)),
-                         SIGNAL(fileHighlighted(QString)));
     connect(fileQWidget, SIGNAL(selectionChanged()),
                          SIGNAL(selectionChanged()));
     connect(fileQWidget, SIGNAL(filterChanged(QString)),
@@ -641,7 +624,7 @@ QString KFileDialog::getExistingDirectory(const KUrl& startDir,
     }
     KUrl url = fileModule()->selectDirectory(startDir, true, parent, caption);
     if ( url.isValid() )
-        return url.path();
+        return url.toLocalFile();
     return QString();
 }
 
@@ -701,15 +684,6 @@ KUrl KFileDialog::baseUrl() const
     return d->w->baseUrl();
 }
 
-QString KFileDialog::getSaveFileName(const KUrl& dir, const QString& filter,
-                                     QWidget *parent,
-                                     const QString& caption)
-{
-    //TODO KDE5: replace this method by the method below (with default parameter values in declaration)
-    // Set no confirm-overwrite mode for backwards compatibility
-    return KFileDialogPrivate::getSaveFileName(dir, filter, parent, caption, Options(0), 0);
-}
-
 QString KFileDialog::getSaveFileName(const KUrl& dir, const QString& filter,
                                      QWidget *parent,
                                      const QString& caption, Options options)
@@ -768,15 +742,6 @@ QString KFileDialogPrivate::getSaveFileName(const KUrl& dir, const QString& filt
     return filename;
 }
 
-QString KFileDialog::getSaveFileNameWId(const KUrl& dir, const QString& filter,
-                                     WId parent_id,
-                                     const QString& caption)
-{
-    //TODO KDE5: replace this method by the method below (with default parameter values in declaration)
-    // Set no confirm-overwrite mode for backwards compatibility
-    return getSaveFileNameWId(dir, filter, parent_id, caption, Options(0));
-}
-
 QString KFileDialog::getSaveFileNameWId(const KUrl& dir, const QString& filter,
                                      WId parent_id,
                                      const QString& caption, Options options)
@@ -805,14 +770,6 @@ QString KFileDialog::getSaveFileNameWId(const KUrl& dir, const QString& filter,
     return filename;
 }
 
-KUrl KFileDialog::getSaveUrl(const KUrl& dir, const QString& filter,
-                             QWidget *parent, const QString& caption)
-{
-    //TODO KDE5: replace this method by the method below (with default parameter values in declaration)
-    // Set no confirm-overwrite mode for backwards compatibility
-    return KFileDialogPrivate::getSaveUrl(dir, filter, parent, caption, Options(0), 0);
-}
-
 KUrl KFileDialog::getSaveUrl(const KUrl& dir, const QString& filter,
                              QWidget *parent, const QString& caption, Options options)
 {
@@ -964,125 +921,31 @@ KAbstractFileWidget* KFileDialog::fileWidget()
     return d->w;
 }
 
-#ifdef Q_WS_WIN
-int KFileDialog::exec()
-{
-    if (!d->native || !KFileDialogPrivate::Native::s_allowNative) {
-        KFileDialogPrivate::Native::s_allowNative = true;
-        return KDialog::exec();
-    }
-
-// not clear here to let KFileDialogPrivate::Native::startDir() return a useful value
-// d->native->selectedUrls.clear();
-    int res = QDialog::Rejected;
-    switch (d->native->operationMode) {
-    case KAbstractFileWidget::Opening:
-    case KAbstractFileWidget::Other:
-        if (d->native->mode & KFile::File) {
-            KUrl url( KFileDialogPrivate::getOpenUrl(
-               d->native->startDir(), d->native->filter, parentWidget(), windowTitle(), &d->native->selectedFilter ) );
-            if (url.isEmpty() || !url.isValid()) {
-                res = QDialog::Rejected;
-                break;
-            }
-            d->native->selectedUrls.clear();
-            d->native->selectedUrls.append(url);
-            res = QDialog::Accepted;
-            break;
-        }
-        else if (d->native->mode & KFile::Files) {
-            KUrl::List urls( KFileDialogPrivate::getOpenUrls(
-                d->native->startDir(), d->native->filter, parentWidget(), windowTitle(), &d->native->selectedFilter ) );
-            if (urls.isEmpty()) {
-                res = QDialog::Rejected;
-                break;
-            }
-            d->native->selectedUrls = urls;
-            res = QDialog::Accepted;
-            break;
-        }
-        else if (d->native->mode & KFile::Directory) {
-            KUrl url( KFileDialog::getExistingDirectoryUrl(
-                d->native->startDir(), parentWidget(), windowTitle()) );
-            if (url.isEmpty() || !url.isValid()) {
-                res = QDialog::Rejected;
-            }
-            d->native->selectedUrls.clear();
-            d->native->selectedUrls.append(url);
-            res = QDialog::Accepted;
-            break;
-        }
-        break;
-    case KAbstractFileWidget::Saving:
-        if (d->native->mode & KFile::File) {
-            KUrl url( KFileDialogPrivate::getSaveUrl(
-                d->native->startDir(), d->native->filter, parentWidget(), windowTitle(), Options(0), &d->native->selectedFilter ) );
-            if (url.isEmpty() || !url.isValid())  {
-                res = QDialog::Rejected;
-                break;
-            }
-            d->native->selectedUrls.clear();
-            d->native->selectedUrls.append(url);
-            res = QDialog::Accepted;
-            break;
-        }
-        else if (d->native->mode & KFile::Directory) {
-            KUrl url( KFileDialog::getExistingDirectoryUrl(
-                d->native->startDir(), parentWidget(), windowTitle()) );
-            if (url.isEmpty() || !url.isValid()) {
-                res = QDialog::Rejected;
-                break;
-            }
-            d->native->selectedUrls.clear();
-            d->native->selectedUrls.append(url);
-            res = QDialog::Accepted;
-            break;
-        }
-        break;
-    default:;
-    }
-
-    setResult(res);
-    emit finished();
-
-    if (res == QDialog::Accepted) {
-        emit accepted();
-    } else {
-        emit rejected();
-    }
-
-    return res;
-}
-#endif // Q_WS_WIN
-
-#ifdef Q_WS_WIN
-#define KF_EXTERN extern __declspec(dllimport)
-#else
-#define KF_EXTERN extern
-#endif
 
+QT_BEGIN_NAMESPACE
 typedef QString (*_qt_filedialog_existing_directory_hook)(QWidget *parent, const QString &caption,
                                                           const QString &dir,
                                                           QFileDialog::Options options);
-KF_EXTERN _qt_filedialog_existing_directory_hook qt_filedialog_existing_directory_hook;
+extern _qt_filedialog_existing_directory_hook qt_filedialog_existing_directory_hook;
 
 typedef QString (*_qt_filedialog_open_filename_hook)(QWidget * parent, const QString &caption,
                                                      const QString &dir, const QString &filter,
                                                      QString *selectedFilter,
                                                      QFileDialog::Options options);
-KF_EXTERN _qt_filedialog_open_filename_hook qt_filedialog_open_filename_hook;
+extern _qt_filedialog_open_filename_hook qt_filedialog_open_filename_hook;
 
 typedef QStringList (*_qt_filedialog_open_filenames_hook)(QWidget * parent, const QString &caption,
                                                           const QString &dir, const QString &filter,
                                                           QString *selectedFilter,
                                                           QFileDialog::Options options);
-KF_EXTERN _qt_filedialog_open_filenames_hook qt_filedialog_open_filenames_hook;
+extern _qt_filedialog_open_filenames_hook qt_filedialog_open_filenames_hook;
 
 typedef QString (*_qt_filedialog_save_filename_hook)(QWidget * parent, const QString &caption,
                                                      const QString &dir, const QString &filter,
                                                      QString *selectedFilter,
                                                      QFileDialog::Options options);
-KF_EXTERN _qt_filedialog_save_filename_hook qt_filedialog_save_filename_hook;
+extern _qt_filedialog_save_filename_hook qt_filedialog_save_filename_hook;
+QT_END_NAMESPACE
 
 /*
  * This class is used to override Qt's QFileDialog calls with KFileDialog ones.
@@ -1178,6 +1041,7 @@ public:
             return QFileDialog::getExistingDirectory(parent, caption, dir, options);
         }
 
+        fileModule(); // make sure i18n is initialized properly, needed for pure Qt applications
         KUrl url(KFileDialog::getExistingDirectory(KUrl(dir), parent, caption));
 
         if(url.isLocalFile())
@@ -1196,6 +1060,7 @@ public:
             return QFileDialog::getOpenFileName(parent, caption, dir, filter, selectedFilter, options);
         }
 
+        fileModule(); // make sure i18n is initialized properly, needed for pure Qt applications
         KFileDialog dlg(KUrl(dir), qt2KdeFilter(filter), parent);
 
         dlg.setOperationMode(KFileDialog::Opening);
@@ -1221,6 +1086,7 @@ public:
             return QFileDialog::getOpenFileNames(parent, caption, dir, filter, selectedFilter, options);
         }
 
+        fileModule(); // make sure i18n is initialized properly, needed for pure Qt applications
         KFileDialog dlg(KUrl(dir), qt2KdeFilter(filter), parent);
 
         dlg.setOperationMode(KFileDialog::Opening);
@@ -1246,6 +1112,7 @@ public:
             return QFileDialog::getSaveFileName(parent, caption, dir, filter, selectedFilter, options);
         }
 
+        fileModule(); // make sure i18n is initialized properly, needed for pure Qt applications
         KFileDialog dlg(KUrl(dir), qt2KdeFilter(filter), parent);
 
         dlg.setOperationMode(KFileDialog::Saving);
@@ -1266,4 +1133,4 @@ public:
 
 static KFileDialogQtOverride qtOverride;
 
-#include "kfiledialog.moc"
+#include "moc_kfiledialog.cpp"
