@@ -6,6 +6,7 @@
                   2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
                   2001 Frerich Raabe <raabe@kde.org>
                   2007 David Faure <faure@kde.org>
+                  2009 David Jarvie <djarvie@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -83,23 +84,28 @@ public:
      */
     enum OperationMode { Other = 0, Opening, Saving };
 
+    /**
+     * Defines the options to use when calling getSave* functions.
+     * @since 4.4
+     */
+    enum Option {
+        ConfirmOverwrite  = 0x01,   /**< Confirm whether to overwrite file to save. */
+        ShowInlinePreview = 0x02    /**< Always show an inline preview. */
+    };
+    Q_DECLARE_FLAGS(Options, Option)
+
     /**
       * Constructs a file dialog.
       *
-      * @param startDir This can either be
-      *         @li The URL of the directory to start in.
-      *         @li A KUrl() to start in the current working
-      *             directory, or the last directory where a file has been
-      *             selected.
-      *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-      *             directory last used by a filedialog in the same application that specified
-      *             the same keyword.
-      *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-      *             in the directory last used by a filedialog in any application that specified the
-      *             same keyword.
+      * @param startDir Specifies the starting directory and/or initially selected
+      *                 file name, or a last used directory and optional file name
+      *                 using the @c kfiledialog:/// syntax.
+      *                 Refer to the KFileWidget documentation for more information
+      *                 on this parameter.
       *
-      * @param filter A shell glob or a mime-type-filter that specifies
-      *               which files to display.
+      * @param filter A shell glob or a mimetype filter that specifies
+      *               which files to display. For better consistency across applications,
+      *               it is recommended to use a mimetype filter.
       * See setFilter() and setMimeFilter() for details on how to use this argument.
       *
       * @param parent The parent widget of this dialog
@@ -109,6 +115,8 @@ public:
       *               display a check box with the caption "Open as read-only".
       *               When creating this widget, you don't need to specify a parent,
       *               since the widget's parent will be set automatically by KFileDialog.
+      *
+      * @see KFileWidget::KFileWidget()
       */
     KFileDialog( const KUrl& startDir, const QString& filter,
                  QWidget *parent, QWidget* widget = 0 );
@@ -211,8 +219,28 @@ public:
     /**
      * Sets the filter to be used to @p filter.
      *
-     * You can set more
-     * filters for the user to select separated by @c '\\n'. Every
+     * The filter can be either set as a space-separated list of
+     * mimetypes, which is recommended, or as a list of shell globs
+     * separated by @c '\\n'.
+     *
+     * If the filter contains an unescaped @c '/', a mimetype filter is assumed.
+     * If you would like a @c '/' visible in your filter it can be escaped with
+     * a @c '\'. You can specify multiple mimetypes like this (separated with
+     * space):
+     *
+     * \code
+     * kfile->setFilter( "image/png text/html text/plain" );
+     * \endcode
+     *
+     * When showing the filter to the user, the mimetypes will be automatically
+     * translated into their description like `PNG image'. Multiple mimetypes
+     * will be automatically summarized to a filter item `All supported files'.
+     * To add a filter item for all files matching @c '*', add @c all/allfiles
+     * as mimetype.
+     *
+     * If the filter contains no unescaped @c '/', it is assumed that
+     * the filter contains conventional shell globs. Several filter items
+     * to select from can be separated by @c '\\n'. Every
      * filter entry is defined through @c namefilter|text to display.
      * If no @c '|' is found in the expression, just the namefilter is
      * shown. Examples:
@@ -229,15 +257,8 @@ public:
      * want to show the suffix to select by a specific filter, you must
      * repeat it.
      *
-     * If the filter contains an unescaped @c '/', a mimetype-filter is assumed.
-     * If you would like a '/' visible in your filter it can be escaped with
-     * a @c '\'. You can specify multiple mimetypes like this (separated with
-     * space):
-     *
-     * \code
-     * kfile->setFilter( "image/png text/html text/plain" );
-     * kfile->setFilter( "*.cue|CUE\\/BIN Files (*.cue)" );
-     * \endcode
+     * For better consistency across applications, it is recommended to use a
+     * mimetype filter.
      *
      * @see filterChanged
      * @see setMimeFilter
@@ -334,23 +355,17 @@ public:
      * Note that with
      * this method the user must select an existing filename.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
+     * @param filter A shell glob or a mimetype filter that specifies which files to display.
      *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     *
+     * @see KFileWidget::KFileWidget()
      */
     static QString getOpenFileName( const KUrl& startDir= KUrl(),
                                     const QString& filter= QString(),
@@ -375,23 +390,17 @@ public:
      * Note that with
      * this method the user must select an existing filename.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
+     * @param filter A shell glob or a mimetype filter that specifies which files to display.
      *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     *
+     * @see KFileWidget::KFileWidget()
      */
     static QStringList getOpenFileNames( const KUrl& startDir= KUrl(),
                                          const QString& filter = QString(),
@@ -407,23 +416,17 @@ public:
      * Note that with
      * this method the user must select an existing URL.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
+     * @param filter A shell glob or a mimetype filter that specifies which files to display.
      *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     *
+     * @see KFileWidget::KFileWidget()
      */
     static KUrl getOpenUrl( const KUrl& startDir = KUrl(),
                             const QString& filter = QString(),
@@ -439,23 +442,17 @@ public:
      * Note that with
      * this method the user must select an existing filename.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
+     * @param filter A shell glob or a mimetype filter that specifies which files to display.
      *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     *
+     * @see KFileWidget::KFileWidget()
      */
     static KUrl::List getOpenUrls( const KUrl& startDir = KUrl(),
                                    const QString& filter = QString(),
@@ -471,37 +468,37 @@ public:
      * Note that with this
      * method the user need not select an existing filename.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
+     * @param filter A shell glob or a mimetype filter that specifies which files to display.
      *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     * @param options Dialog options.
+     *
+     * @see KFileWidget::KFileWidget()
+     *
+     * @since 4.4
      */
     static QString getSaveFileName( const KUrl& startDir = KUrl(),
                                     const QString& filter = QString(),
                                     QWidget *parent = 0,
-                                    const QString& caption = QString() );
-
+                                    const QString& caption = QString(),
+                                    Options options = Options(0));
 
     /**
      * This function accepts the window id of the parent window, instead
      * of QWidget*. It should be used only when necessary.
+     *
+     * @since 4.4
      */
     static QString getSaveFileNameWId( const KUrl &startDir, const QString& filter,
                                        WId parent_id,
-                                       const QString& caption );
+                                       const QString& caption,
+                                       Options options = Options(0));
 
     /**
      * Creates a modal file dialog and returns the selected
@@ -510,48 +507,36 @@ public:
      * Note that with this
      * method the user need not select an existing filename.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
-     * @param filter A shell glob or a mime-type-filter that specifies which files to display.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
+     * @param filter A shell glob or a mimetype filter that specifies which files to display.
      *    The preferred option is to set a list of mimetype names, see setMimeFilter() for details.
      *    Otherwise you can set the text to be displayed for the each glob, and
      *    provide multiple globs, see setFilter() for details.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     *
+     * @see KFileWidget::KFileWidget()
      */
     static KUrl getSaveUrl( const KUrl& startDir = KUrl(),
                             const QString& filter = QString(),
                             QWidget *parent = 0,
-                            const QString& caption = QString() );
-
+                            const QString& caption = QString(),
+                            Options options = Options(0));
 
     /**
      * Creates a modal directory-selection dialog and returns the selected
      * directory (local only) or an empty string if none was chosen.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      * @return the path to an existing local directory.
+     *
+     * @see KFileWidget::KFileWidget()
      */
     static QString getExistingDirectory( const KUrl& startDir = KUrl(),
                                          QWidget * parent = 0,
@@ -562,20 +547,14 @@ public:
      * directory or an empty string if none was chosen.
      * This version supports remote urls.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      * @return the url to an existing directory (local or remote).
+     *
+     * @see KFileWidget::KFileWidget()
      */
     static KUrl getExistingDirectoryUrl( const KUrl& startDir = KUrl(),
                                          QWidget * parent = 0,
@@ -585,19 +564,13 @@ public:
      * Creates a modal file dialog with an image previewer and returns the
      * selected url or an empty string if none was chosen.
      *
-     * @param startDir This can either be
-     *         @li The URL of the directory to start in.
-     *         @li A KUrl() to start in the current working
-     *             directory, or the last directory where a file has been
-     *             selected.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;' to start in the
-     *             directory last used by a filedialog in the same application that specified
-     *             the same keyword.
-     *         @li An URL starting with 'kfiledialog:///&lt;keyword&gt;?global' to start
-     *             in the directory last used by a filedialog in any application that specified the
-     *             same keyword.
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
+     *
+     * @see KFileWidget::KFileWidget()
      */
     static KUrl getImageOpenUrl( const KUrl& startDir = KUrl(),
                                  QWidget *parent = 0,
@@ -694,13 +667,18 @@ public:
      * This method implements the logic to determine the user's default directory
      * to be listed. E.g. the documents directory, home directory or a recently
      * used directory.
-     * @param startDir A url, to be used. May use the 'kfiledialog:///keyword' and
-     *                 'kfiledialog:///keyword?global' syntax
-     *                 as documented in the KFileDialog() constructor.
-     * @param recentDirClass If the 'kfiledialog:///' syntax is used, recentDirClass
-     *        will contain the string to be used later for KRecentDir::dir()
+     *
+     * @param startDir Starting directory or @c kfiledialog:/// URL.
+     *                 Refer to the KFileWidget documentation for more information
+     *                 on this parameter.
+     * @param recentDirClass If the @c kfiledialog:/// syntax is used, this
+     *        will return the string to be passed to KRecentDirs::dir() and
+     *        KRecentDirs::add().
      * @return The URL that should be listed by default (e.g. by KFileDialog or
      *         KDirSelectDialog).
+     *
+     * @see KFileWidget::KFileWidget()
+     * @see KFileWidget::getStartUrl( const KUrl& startDir, QString& recentDirClass );
      */
     static KUrl getStartUrl( const KUrl& startDir, QString& recentDirClass );
 
@@ -710,10 +688,6 @@ public:
      */
     static void setStartDir( const KUrl& directory );
 
-#ifdef Q_WS_WIN
-public Q_SLOTS:
-    int exec();
-#endif
 
 Q_SIGNALS:
     /**
@@ -722,13 +696,17 @@ Q_SIGNALS:
       * is to connect to the okClicked() signal inherited from KDialog
       * and call selectedFile(), selectedFiles(),
       * selectedUrl() or selectedUrls().
+      *
+      * \since 4.4
       */
-    void fileSelected(const QString&);
+    void fileSelected(const KUrl&);
 
     /**
       * Emitted when the user highlights a file.
+      *
+      * \since 4.4
       */
-    void fileHighlighted(const QString&);
+    void fileHighlighted(const KUrl&);
 
     /**
      * Emitted when the user hilights one or more files in multiselection mode.
