@@ -32,19 +32,14 @@ class KUrl;
 /**
  * @brief Shows the meta data of one or more file items.
  *
- * Meta data like name, size, rating, comment, ... are
- * shown as several rows containing a description and
- * the meta data value. It is possible for the user
- * to change specific meta data like rating, tags and
- * comment. The changes are stored automatically by the
- * meta data widget.
+ * Meta data like name, size, ... are shown as several
+ * rows containing a description and the meta data value.
  *
  * @since 4.5
  */
 class KIO_EXPORT KFileMetaDataWidget : public QWidget
 {
     Q_OBJECT
-    Q_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly)
 
 public:
     explicit KFileMetaDataWidget(QWidget* parent = 0);
@@ -58,13 +53,6 @@ public:
     void setItems(const KFileItemList& items);
     KFileItemList items() const;
 
-    /**
-     * If set to true, data such as the comment, tag or rating cannot be
-     * changed by the user. Per default read-only is disabled.
-     */
-    void setReadOnly(bool readOnly);
-    bool isReadOnly() const;
-
     /** @see QWidget::sizeHint() */
     virtual QSize sizeHint() const;
 
@@ -82,9 +70,6 @@ Q_SIGNALS:
      */
     void metaDataRequestFinished(const KFileItemList& items);
 
-protected:
-    virtual bool event(QEvent* event);
-
 private:
     class Private;
     Private* d;
