@@ -24,15 +24,14 @@
 #include "kopenwithdialog.h"
 #include "kopenwithdialog_p.h"
 
-#include <QtCore/QtAlgorithms>
+#include <QtCore/qalgorithms.h>
 #include <QtCore/QList>
 #include <QtGui/QLabel>
 #include <QtGui/QLayout>
 #include <QtGui/QCheckBox>
 #include <QtGui/QStyle>
-#include <QtGui/QStyleOptionButton>
+#include <QtGui/qstyleoption.h>
 
-#include <kauthorized.h>
 #include <khistorycombobox.h>
 #include <kdesktopfile.h>
 #include <klineedit.h>
@@ -47,12 +46,12 @@
 #include <kmimetype.h>
 #include <kservicegroup.h>
 #include <kserviceoffer.h>
+#include <kbuildsycocaprogressdialog.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
 
 #include <assert.h>
 #include <stdlib.h>
-#include <kbuildsycocaprogressdialog.h>
-#include <kconfiggroup.h>
 
 inline void writeEntry( KConfigGroup& group, const char* key,
                         const KGlobalSettings::Completion& aValue,
@@ -556,7 +555,6 @@ void KOpenWithDialogPrivate::setMimeType(const KUrl::List &_urls)
 
 void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
 {
-  bool bReadOnly = !KAuthorized::authorize("shell_access");
   m_terminaldirty = false;
     view = 0;
     m_pService = 0;
@@ -572,30 +570,21 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
   label->setWordWrap(true);
   topLayout->addWidget(label);
 
-  if (!bReadOnly)
-  {
-    // init the history combo and insert it into the URL-Requester
-    KHistoryComboBox *combo = new KHistoryComboBox();
-    KLineEdit *lineEdit = new KLineEdit(q);
-    lineEdit->setClearButtonShown(true);
-    combo->setLineEdit(lineEdit);
-    combo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
-    combo->setDuplicatesEnabled( false );
-    KConfigGroup cg( KGlobal::config(), QString::fromLatin1("Open-with settings") );
-    int max = cg.readEntry( "Maximum history", 15 );
-    combo->setMaxCount( max );
-    int mode = cg.readEntry( "CompletionMode", int(KGlobalSettings::completionMode()));
-    combo->setCompletionMode((KGlobalSettings::Completion)mode);
-    const QStringList list = cg.readEntry( "History", QStringList() );
-    combo->setHistoryItems( list, true );
-    edit = new KUrlRequester( combo, mainWidget );
-  }
-  else
-  {
-    edit = new KUrlRequester( mainWidget );
-    edit->lineEdit()->setReadOnly(true);
-    edit->button()->hide();
-  }
+  // init the history combo and insert it into the URL-Requester
+  KHistoryComboBox *combo = new KHistoryComboBox();
+  KLineEdit *lineEdit = new KLineEdit(q);
+  lineEdit->setClearButtonShown(true);
+  combo->setLineEdit(lineEdit);
+  combo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
+  combo->setDuplicatesEnabled( false );
+  KConfigGroup cg( KGlobal::config(), QString::fromLatin1("Open-with settings") );
+  int max = cg.readEntry( "Maximum history", 15 );
+  combo->setMaxCount( max );
+  int mode = cg.readEntry( "CompletionMode", int(KGlobalSettings::completionMode()));
+  combo->setCompletionMode((KGlobalSettings::Completion)mode);
+  const QStringList list = cg.readEntry( "History", QStringList() );
+  combo->setHistoryItems( list, true );
+  edit = new KUrlRequester( combo, mainWidget );
 
   edit->setText( _value );
   edit->setWhatsThis(i18n(
@@ -635,9 +624,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
                      q, SLOT(_k_slotDbClick()));
 
   terminal = new QCheckBox( i18n("Run in &terminal"), mainWidget );
-  if (bReadOnly)
-     terminal->hide();
-    QObject::connect(terminal, SIGNAL(toggled(bool)), q, SLOT(slotTerminalToggled(bool)));
+  QObject::connect(terminal, SIGNAL(toggled(bool)), q, SLOT(slotTerminalToggled(bool)));
 
   topLayout->addWidget(terminal);
 
@@ -660,7 +647,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
   KConfigGroup confGroup( KGlobal::config(), QString::fromLatin1("General") );
   QString preferredTerminal = confGroup.readPathEntry("TerminalApplication", QString::fromLatin1("konsole"));
 
-  if (bReadOnly || preferredTerminal != "konsole")
+  if (preferredTerminal != "konsole")
      nocloseonexit->hide();
 
   nocloseonexitLayout->addWidget( nocloseonexit );
@@ -713,7 +700,7 @@ void KOpenWithDialog::slotHighlighted(const QString& entryPath, const QString&)
         // ### indicate that default value was restored
         d->terminal->setChecked(d->curService->terminal());
         QString terminalOptions = d->curService->terminalOptions();
-        d->nocloseonexit->setChecked((terminalOptions.contains(QLatin1String("--noclose")) > 0));
+        d->nocloseonexit->setChecked(terminalOptions.contains(QLatin1String("--noclose")));
         d->m_terminaldirty = false; // slotTerminalToggled changed it
     }
 }
@@ -923,11 +910,7 @@ bool KOpenWithDialogPrivate::checkAccept()
             // If we got here, we can't seem to find a service for what they wanted. Create one.
 
             QString menuId;
-#ifdef Q_WS_WIN32
-            // on windows, do not use the complete path, but only the default name.
-            serviceName = QFileInfo(serviceName).fileName();
-#endif
-            QString newPath = KService::newServicePath(false /* ignored argument */, serviceName, &menuId);
+            QString newPath = KService::newServicePath(serviceName, &menuId);
             kDebug(250) << "Creating new service" << serviceName << "(" << newPath << ")" << "menuId=" << menuId;
 
             KDesktopFile desktopFile(newPath);
@@ -1000,5 +983,5 @@ void KOpenWithDialogPrivate::saveComboboxHistory()
     }
 }
 
-#include "kopenwithdialog.moc"
-#include "kopenwithdialog_p.moc"
+#include "moc_kopenwithdialog.cpp"
+#include "moc_kopenwithdialog_p.cpp"
