@@ -22,7 +22,7 @@
 
 #include <QtGui/QLayout>
 
-#include <kfilemetapreview.h>
+#include <kimagefilepreview.h>
 #include <kglobalsettings.h>
 #include <klocale.h>
 
@@ -53,7 +53,7 @@ void KPreviewPropsPlugin::createLayout()
     QVBoxLayout* tmp = new QVBoxLayout(topframe);
     tmp->setMargin(0);
 
-    preview = new KFileMetaPreview(topframe);
+    preview = new KImageFilePreview(topframe);
 
     tmp->addWidget(preview) ;
     connect( properties, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), SLOT(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)) );
@@ -71,11 +71,22 @@ bool KPreviewPropsPlugin::supports( const KFileItemList &_items )
     bool metaDataEnabled = KGlobalSettings::showFilePreview(_items.first().url());
     if (!metaDataEnabled)
         return false;
-    const KMimeType::Ptr mime = _items.first().mimeTypePtr();
-    const QStringList supportedMimeTypes = KIO::PreviewJob::supportedMimeTypes();
-    foreach(const QString& supportedMime, supportedMimeTypes) {
-        if (mime->is(supportedMime))
-    return true;
+    const KMimeType::Ptr itemMime = _items.first().mimeTypePtr();
+    foreach(const QString &it, KIO::PreviewJob::supportedMimeTypes()) {
+        if (itemMime->is(it)) {
+            return true;
+        }
+
+        // glob match for certain thumbnailers, same matching is done in:
+        // kdelibs/kio/kio/previewjob.cpp
+        // kde-workspace/kioslave/thumbnail/thumbnail.cpp
+        if (it.endsWith('*')) {
+            const QString mimeGroup = it.left(it.length()-1);
+            const QString mimeName = itemMime->name();
+            if (mimeName.startsWith(mimeGroup)) {
+                return true;
+            }
+        }
     }
     return false;
 }
@@ -89,4 +100,4 @@ void KPreviewPropsPlugin::currentPageChanged( KPageWidgetItem *current, KPageWid
     preview->showPreview(properties->item().url());
 }
 
-#include "kpreviewprops.moc"
+#include "moc_kpreviewprops.cpp"
