@@ -33,6 +33,7 @@
 #include <QMimeData>
 #include <QAction>
 #include <QApplication>
+#include <QDir>
 
 class KUrlDragPushButton : public KPushButton
 {
@@ -78,6 +79,7 @@ public:
           combo(0),
           fileDialogMode(KFile::File | KFile::ExistingOnly | KFile::LocalOnly)
     {
+        qRegisterMetaType<KUrl>("KUrl");
     }
 
     ~KUrlRequesterPrivate()
@@ -144,12 +146,19 @@ public:
             edit->setCompletionObject( comp );
     }
 
+    void updateCompletionStartDir( const KUrl &newStartDir )
+    {
+        if ( newStartDir.isLocalFile() )
+            myCompletion->setDir(newStartDir.toLocalFile());
+    }
+
     QString text() const {
         return combo ? combo->currentText() : edit->text();
     }
 
     /**
      * replaces ~user or $FOO, if necessary
+     * if text() is a relative path, make it absolute using startDir()
      */
     KUrl url() const {
         const QString txt = text();
@@ -159,10 +168,19 @@ public:
         else
             comp = qobject_cast<KUrlCompletion*>(edit->completionObject());
 
+        KUrl enteredPath;
+        KUrl baseDir(m_startDir);
         if ( comp )
-            return KUrl( comp->replacedPath( txt ) );
+            enteredPath = KUrl( comp->replacedPath( txt ) );
         else
-            return KUrl( txt );
+            enteredPath = KUrl( txt );
+
+        if ( enteredPath.isRelative() && !txt.isEmpty() ) {
+            baseDir.addPath(enteredPath.path());
+            return baseDir;
+        } else {
+            return enteredPath;
+        }
     }
 
     // slots
@@ -171,16 +189,13 @@ public:
     void _k_slotFileDialogFinished();
 
     KUrl m_startDir;
+    bool m_startDirCustomized;
     KUrlRequester *m_parent;
     KLineEdit *edit;
     KComboBox *combo;
     KFile::Modes fileDialogMode;
     QString fileDialogFilter;
-#ifndef KDE_NO_DEPRECATED
-    KEditListBox::CustomEditor editor;
-#else
     KEditListWidget::CustomEditor editor;
-#endif
     KUrlDragPushButton *myButton;
     KFileDialog *myFileDialog;
     KUrlCompletion *myCompletion;
@@ -254,7 +269,11 @@ void KUrlRequester::KUrlRequesterPrivate::init()
     connectSignals( m_parent );
     m_parent->connect(myButton, SIGNAL(clicked()), m_parent, SLOT(_k_slotOpenDialog()));
 
+    m_startDir = KUrl::fromPath(QDir::currentPath());
+    m_startDirCustomized = false;
+
     myCompletion = new KUrlCompletion();
+    updateCompletionStartDir(m_startDir);
     setCompletionObject( myCompletion );
 
     QAction* openAction = new QAction(m_parent);
@@ -267,12 +286,6 @@ void KUrlRequester::setUrl( const KUrl& url )
     d->setText( url.pathOrUrl() );
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KUrlRequester::setPath( const QString& path )
-{
-    d->setText( path );
-}
-#endif
 
 void KUrlRequester::setText(const QString& text)
 {
@@ -282,8 +295,8 @@ void KUrlRequester::setText(const QString& text)
 void KUrlRequester::setStartDir(const KUrl& startDir)
 {
     d->m_startDir = startDir;
-    if (startDir.isLocalFile())
-        d->myCompletion->setDir(startDir.toLocalFile());
+    d->m_startDirCustomized = true;
+    d->updateCompletionStartDir(startDir);
 }
 
 void KUrlRequester::changeEvent(QEvent *e)
@@ -385,6 +398,12 @@ void KUrlRequester::KUrlRequesterPrivate::_k_slotFileDialogFinished()
         {
             m_parent->setUrl( newUrl );
             emit m_parent->urlSelected( url() );
+            // remember url as defaultStartDir and update startdir for autocompletion
+            if ( newUrl.isLocalFile() && !m_startDirCustomized ) {
+                m_startDir = newUrl;
+                m_startDir.setPath(m_startDir.directory());
+                updateCompletionStartDir(m_startDir);
+            }
         }
     }
 }
@@ -499,11 +518,7 @@ void KUrlRequester::setFileDialogModality(Qt::WindowModality modality)
     d->fileDialogModality = modality;
 }
 
-#ifndef KDE_NO_DEPRECATED
-const KEditListBox::CustomEditor &KUrlRequester::customEditor()
-#else
 const KEditListWidget::CustomEditor &KUrlRequester::customEditor()
-#endif
 {
     setSizePolicy(QSizePolicy( QSizePolicy::Preferred,
                                QSizePolicy::Fixed));
@@ -528,4 +543,4 @@ KUrlComboRequester::KUrlComboRequester( QWidget *parent)
 {
 }
 
-#include "kurlrequester.moc"
+#include "moc_kurlrequester.cpp"
