@@ -20,8 +20,8 @@
 #ifndef KIO_CONNECTION_P_H
 #define KIO_CONNECTION_P_H
 
-#include <QObject>
-#include <klocalsocket.h>
+#include <QLocalSocket>
+#include <QLocalServer>
 
 class KUrl;
 
@@ -31,7 +31,7 @@ namespace KIO {
         QByteArray data;
     };
 
-    class AbstractConnectionBackend: public QObject
+    class SocketConnectionBackend: public QObject
     {
         Q_OBJECT
     public:
@@ -39,56 +39,34 @@ namespace KIO {
         QString errorString;
         enum { Idle, Listening, Connected } state;
 
-        explicit AbstractConnectionBackend(QObject *parent = 0);
-        ~AbstractConnectionBackend();
+    private:
+        enum { HeaderSize = 10, StandardBufferSize = 32*1024 };
 
-        virtual void setSuspended(bool enable) = 0;
-        virtual bool connectToRemote(const KUrl &url) = 0;
-        virtual bool listenForRemote() = 0;
-        virtual bool waitForIncomingTask(int ms) = 0;
-        virtual bool sendCommand(const Task &task) = 0;
-        virtual AbstractConnectionBackend *nextPendingConnection() = 0;
+        QLocalSocket *socket;
+        QLocalServer *localServer;
+        long len;
+        int cmd;
+        bool signalEmitted;
+
+    public:
+        explicit SocketConnectionBackend(QObject *parent = 0);
+        ~SocketConnectionBackend();
+
+        void setSuspended(bool enable);
+        bool connectToRemote(const QString &address);
+        bool listenForRemote();
+        bool waitForIncomingTask(int ms);
+        bool sendCommand(const Task &task);
+        SocketConnectionBackend *nextPendingConnection();
+    public slots:
+        void socketReadyRead();
+        void socketDisconnected();
 
     Q_SIGNALS:
         void disconnected();
         void commandReceived(const Task &task);
         void newConnection();
     };
-
-    class SocketConnectionBackend: public AbstractConnectionBackend
-    {
-        Q_OBJECT
-    public:
-        enum Mode { LocalSocketMode, TcpSocketMode };
-
-    private:
-        enum { HeaderSize = 10, StandardBufferSize = 32*1024 };
-
-        QTcpSocket *socket;
-        union {
-            KLocalSocketServer *localServer;
-            QTcpServer *tcpServer;
-        };
-        long len;
-        int cmd;
-        int port;
-        bool signalEmitted;
-        quint8 mode;
-
-    public:
-        explicit SocketConnectionBackend(Mode m, QObject *parent = 0);
-        ~SocketConnectionBackend();
-
-        void setSuspended(bool enable);
-        bool connectToRemote(const KUrl &url);
-        bool listenForRemote();
-        bool waitForIncomingTask(int ms);
-        bool sendCommand(const Task &task);
-        AbstractConnectionBackend *nextPendingConnection();
-    public slots:
-        void socketReadyRead();
-        void socketDisconnected();
-    };
 }
 
 #endif
