@@ -24,6 +24,7 @@
 #include "kdirlister.h"
 #include "kfileitem.h"
 #include "deletejob.h"
+#include "clipboardupdater_p.h"
 
 #include <klocale.h>
 #include <kdesktopfile.h>
@@ -45,14 +46,15 @@
 #endif
 #include <assert.h>
 
+#include <QtCore/QList>
 #include <QtCore/QTimer>
 #include <QtCore/QFile>
 #include <sys/stat.h> // mode_t
 #include <QPointer>
+#include <QtCore/qfileinfo.h>
 
 #include "job_p.h"
 #include <kdiskfreespaceinfo.h>
-#include <kfilesystemtype_p.h>
 
 using namespace KIO;
 
@@ -144,8 +146,8 @@ public:
     bool m_bURLDirty;
     // Used after copying all the files into the dirs, to set mtime (TODO: and permissions?)
     // after the copy is done
-    QLinkedList<CopyInfo> m_directoriesCopied;
-    QLinkedList<CopyInfo>::const_iterator m_directoriesCopiedIterator;
+    QList<CopyInfo> m_directoriesCopied;
+    QList<CopyInfo>::const_iterator m_directoriesCopiedIterator;
 
     CopyJob::CopyMode m_mode;
     bool m_asMethod;
@@ -255,9 +257,9 @@ public:
 CopyJob::CopyJob(CopyJobPrivate &dd)
     : Job(dd)
 {
+    qRegisterMetaType<KIO::UDSEntry>("KIO::UDSEntry");
     setProperty("destUrl", d_func()->m_dest.url());
     QTimer::singleShot(0, this, SLOT(slotStart()));
-    qRegisterMetaType<KIO::UDSEntry>("KIO::UDSEntry");
 }
 
 CopyJob::~CopyJob()
@@ -338,19 +340,20 @@ void CopyJobPrivate::slotResultStating( KJob *job )
 
     if ( destinationState == DEST_NOT_STATED ) {
         if ( m_dest.isLocalFile() ) { //works for dirs as well
-            QString path = m_dest.toLocalFile();
-            if (m_asMethod) {
+            QString path(m_dest.toLocalFile());
+            QFileInfo fileInfo(path);
+            if (m_asMethod || !fileInfo.exists()) {
                 // In copy-as mode, we want to check the directory to which we're
                 // copying. The target file or directory does not exist yet, which
                 // might confuse KDiskFreeSpaceInfo.
-                path = QFileInfo(path).absolutePath();
+                path = fileInfo.absolutePath();
             }
-            KFileSystemType::Type fsType = KFileSystemType::fileSystemType( path );
-            if ( fsType != KFileSystemType::Nfs && fsType != KFileSystemType::Smb  && fsType != KFileSystemType::Ramfs ) {
-                m_freeSpace = KDiskFreeSpaceInfo::freeSpaceInfo( path ).available();
+            KDiskFreeSpaceInfo freeSpaceInfo = KDiskFreeSpaceInfo::freeSpaceInfo(path);
+            if (freeSpaceInfo.isValid()) {
+                m_freeSpace = freeSpaceInfo.available();
+            } else {
+                kDebug(7007) << "Couldn't determine free space information for" << path;
             }
-            //TODO actually preliminary check is even more valuable for slow NFS/SMB mounts,
-            //but we need to find a way to report connection errors to user
         }
 
         const bool isGlobalDest = m_dest == m_globalDest;
@@ -558,10 +561,7 @@ void CopyJobPrivate::slotReport()
 void CopyJobPrivate::slotEntries(KIO::Job* job, const UDSEntryList& list)
 {
     //Q_Q(CopyJob);
-    UDSEntryList::ConstIterator it = list.constBegin();
-    UDSEntryList::ConstIterator end = list.constEnd();
-    for (; it != end; ++it) {
-        const UDSEntry& entry = *it;
+    foreach ( const UDSEntry& entry, list ) {
         addCopyInfoFromUDSEntry(entry, static_cast<SimpleJob *>(job)->url(), m_bCurrentSrcIsDir, m_currentDest);
     }
 }
@@ -829,7 +829,6 @@ void CopyJobPrivate::startRenameJob( const KUrl& slave_url )
     if (m_currentSrcURL.isLocalFile()) {
         const QString parentDir = m_currentSrcURL.directory(KUrl::ObeyTrailingSlash);
         if (!m_parentDirs.contains(parentDir)) {
-            KDirWatch::self()->stopDirScan(parentDir);
             m_parentDirs.insert(parentDir);
         }
     }
@@ -867,7 +866,6 @@ void CopyJobPrivate::startListing( const KUrl & src )
     state = STATE_LISTING;
     m_bURLDirty = true;
     ListJob * newjob = listRecursive(src, KIO::HideProgressInfo);
-    newjob->setUnrestricted(true);
     q->connect(newjob, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
                SLOT(slotEntries(KIO::Job*,KIO::UDSEntryList)));
     q->connect(newjob, SIGNAL(subError(KIO::ListJob*,KIO::ListJob*)),
@@ -1080,15 +1078,16 @@ void CopyJobPrivate::slotResultConflictCreatingDirs( KJob * job )
     if (m_reportTimer)
         m_reportTimer->start(REPORT_TIMEOUT);
     switch ( r ) {
-        case R_CANCEL:
+        case R_CANCEL: {
             q->setError( ERR_USER_CANCELED );
             q->emitResult();
             return;
-        case R_AUTO_RENAME:
+        }
+        case R_AUTO_RENAME: {
             m_bAutoRenameDirs = true;
             // fall through
-        case R_RENAME:
-        {
+        }
+        case R_RENAME: {
             QString oldPath = (*it).uDest.path( KUrl::AddTrailingSlash );
             KUrl newUrl( (*it).uDest );
             newUrl.setPath( newPath );
@@ -1130,34 +1129,40 @@ void CopyJobPrivate::slotResultConflictCreatingDirs( KJob * job )
                 emit q->aboutToCreate( q, dirs );
             if (!files.isEmpty())
                 emit q->aboutToCreate( q, files );
+            break;
         }
-        break;
-        case R_AUTO_SKIP:
+        case R_AUTO_SKIP: {
             m_bAutoSkipDirs = true;
             // fall through
-        case R_SKIP:
+        }
+        case R_SKIP: {
             m_skipList.append( existingDest );
             skip((*it).uSource, true);
             // Move on to next dir
             dirs.erase( it );
             m_processedDirs++;
             break;
-        case R_OVERWRITE:
+        }
+        case R_OVERWRITE: {
             m_overwriteList.insert( existingDest );
             emit q->copyingDone( q, (*it).uSource, (*it).uDest, (*it).mtime, true /* directory */, false /* renamed */ );
             // Move on to next dir
             dirs.erase( it );
             m_processedDirs++;
             break;
-        case R_OVERWRITE_ALL:
+        }
+        case R_OVERWRITE_ALL: {
             m_bOverwriteAllDirs = true;
             emit q->copyingDone( q, (*it).uSource, (*it).uDest, (*it).mtime, true /* directory */, false /* renamed */ );
             // Move on to next dir
             dirs.erase( it );
             m_processedDirs++;
             break;
-        default:
+        }
+        default: {
             assert( 0 );
+            break;
+        }
     }
     state = STATE_CREATING_DIRS;
     //emit processedAmount( this, KJob::Directories, m_processedDirs );
@@ -1203,15 +1208,6 @@ void CopyJobPrivate::createNextDir()
     {
         q->setProcessedAmount( KJob::Directories, m_processedDirs ); // make sure final number appears
 
-        if (m_mode == CopyJob::Move) {
-            // Now we know which dirs hold the files we're going to delete.
-            // To speed things up and prevent double-notification, we disable KDirWatch
-            // on those dirs temporarily (using KDirWatch::self, that's the instanced
-            // used by e.g. kdirlister).
-            for ( QSet<QString>::const_iterator it = m_parentDirs.constBegin() ; it != m_parentDirs.constEnd() ; ++it )
-                KDirWatch::self()->stopDirScan( *it );
-        }
-
         state = STATE_COPYING_FILES;
         m_processedFiles++; // Ralf wants it to start at 1, not 0
         copyNextFile();
@@ -1340,7 +1336,7 @@ void CopyJobPrivate::slotResultCopyingFiles( KJob * job )
     //kDebug(7007) << files.count() << "files remaining";
 
     // Merge metadata from subjob
-    KIO::Job* kiojob = dynamic_cast<KIO::Job*>(job);
+    KIO::Job* kiojob = qobject_cast<KIO::Job*>(job);
     Q_ASSERT(kiojob);
     m_incomingMetaData += kiojob->metaData();
     q->removeSubjob( job );
@@ -1430,15 +1426,16 @@ void CopyJobPrivate::slotResultConflictCopyingFiles( KJob * job )
     q->removeSubjob( job );
     assert ( !q->hasSubjobs() );
     switch ( res ) {
-        case R_CANCEL:
+        case R_CANCEL: {
             q->setError( ERR_USER_CANCELED );
             q->emitResult();
             return;
-        case R_AUTO_RENAME:
+        }
+        case R_AUTO_RENAME: {
             m_bAutoRenameFiles = true;
             // fall through
-        case R_RENAME:
-        {
+        }
+        case R_RENAME: {
             KUrl newUrl( (*it).uDest );
             newUrl.setPath( newPath );
             emit q->renamed( q, (*it).uDest, newUrl ); // for e.g. kpropsdlg
@@ -1447,27 +1444,32 @@ void CopyJobPrivate::slotResultConflictCopyingFiles( KJob * job )
             QList<CopyInfo> files;
             files.append(*it);
             emit q->aboutToCreate( q, files );
+            break;
         }
-        break;
-        case R_AUTO_SKIP:
+        case R_AUTO_SKIP: {
             m_bAutoSkipFiles = true;
             // fall through
-        case R_SKIP:
+        }
+        case R_SKIP: {
             // Move on to next file
             skip((*it).uSource, false);
             m_processedSize += (*it).size;
             files.erase( it );
             m_processedFiles++;
             break;
-       case R_OVERWRITE_ALL:
+        }
+        case R_OVERWRITE_ALL: {
             m_bOverwriteAllFiles = true;
             break;
-        case R_OVERWRITE:
+        }
+        case R_OVERWRITE: {
             // Add to overwrite list, so that copyNextFile knows to overwrite
             m_overwriteList.insert( (*it).uDest.path() );
             break;
-        default:
+        }
+        default: {
             assert( 0 );
+        }
     }
     state = STATE_COPYING_FILES;
     copyNextFile();
@@ -1518,8 +1520,6 @@ KIO::Job* CopyJobPrivate::linkNextFile( const KUrl& uSource, const KUrl& uDest,
                     config.writeEntry( "Icon", QString::fromLatin1("folder-remote") );
                 else if ( protocol == QLatin1String("http") )
                     config.writeEntry( "Icon", QString::fromLatin1("text-html") );
-                else if ( protocol == QLatin1String("info") )
-                    config.writeEntry( "Icon", QString::fromLatin1("text-x-texinfo") );
                 else if ( protocol == QLatin1String("mailto") )   // sven:
                     config.writeEntry( "Icon", QString::fromLatin1("internet-mail") ); // added mailto: support
                 else
@@ -1714,7 +1714,7 @@ void CopyJobPrivate::setNextDirAttribute()
         // TODO: can be removed now. Or reintroduced as a fast path for local files
         // if launching even more jobs as done above is a performance problem.
         //
-        QLinkedList<CopyInfo>::const_iterator it = m_directoriesCopied.constBegin();
+        QList<CopyInfo>::const_iterator it = m_directoriesCopied.constBegin();
         for ( ; it != m_directoriesCopied.constEnd() ; ++it ) {
             const KUrl& url = (*it).uDest;
             if ( url.isLocalFile() && (*it).mtime != (time_t)-1 ) {
@@ -1761,11 +1761,6 @@ void CopyJob::emitResult()
         }
     }
 
-    // Re-enable watching on the dirs that held the deleted/moved files
-    if (d->m_mode == CopyJob::Move) {
-        for (QSet<QString>::const_iterator it = d->m_parentDirs.constBegin() ; it != d->m_parentDirs.constEnd() ; ++it)
-            KDirWatch::self()->restartDirScan( *it );
-    }
     Job::emitResult();
 }
 
@@ -1839,7 +1834,7 @@ void CopyJobPrivate::slotResultRenaming( KJob* job )
     int err = job->error();
     const QString errText = job->errorText();
     // Merge metadata from subjob
-    KIO::Job* kiojob = dynamic_cast<KIO::Job*>(job);
+    KIO::Job* kiojob = qobject_cast<KIO::Job*>(job);
     Q_ASSERT(kiojob);
     m_incomingMetaData += kiojob->metaData();
     q->removeSubjob( job );
@@ -1991,22 +1986,20 @@ void CopyJobPrivate::slotResultRenaming( KJob* job )
 
                 switch ( r )
                 {
-                case R_CANCEL:
-                {
+                case R_CANCEL: {
                     q->setError( ERR_USER_CANCELED );
                     q->emitResult();
                     return;
                 }
-                case R_AUTO_RENAME:
+                case R_AUTO_RENAME: {
                     if (isDir) {
                         m_bAutoRenameDirs = true;
-                    }
-                    else {
+                    } else {
                         m_bAutoRenameFiles = true;
                     }
                     // fall through
-                case R_RENAME:
-                {
+                }
+                case R_RENAME: {
                     // Set m_dest to the chosen destination
                     // This is only for this src url; the next one will revert to m_globalDest
                     m_dest.setPath( newPath );
@@ -2016,23 +2009,26 @@ void CopyJobPrivate::slotResultRenaming( KJob* job )
                     q->addSubjob(job);
                     return;
                 }
-                case R_AUTO_SKIP:
+                case R_AUTO_SKIP: {
                     if (isDir)
                         m_bAutoSkipDirs = true;
                     else
                         m_bAutoSkipFiles = true;
                     // fall through
-                case R_SKIP:
+                }
+                case R_SKIP: {
                     // Move on to next url
                     skipSrc(isDir);
                     return;
-                case R_OVERWRITE_ALL:
+                }
+                case R_OVERWRITE_ALL: {
                     if (destIsDir)
                         m_bOverwriteAllDirs = true;
                     else
                         m_bOverwriteAllFiles = true;
                     break;
-                case R_OVERWRITE:
+                }
+                case R_OVERWRITE: {
                     // Add to overwrite list
                     // Note that we add dest, not m_dest.
                     // This ensures that when moving several urls into a dir (m_dest),
@@ -2041,10 +2037,12 @@ void CopyJobPrivate::slotResultRenaming( KJob* job )
                     kDebug(7007) << "adding to overwrite list: " << dest.path();
                     m_overwriteList.insert( dest.path() );
                     break;
-                default:
+                }
+                default: {
                     //assert( 0 );
                     break;
                 }
+                }
             } else if ( err != KIO::ERR_UNSUPPORTED_ACTION ) {
                 // Dest already exists, and job is not interactive -> abort with error
                 q->setError( err );
@@ -2185,7 +2183,9 @@ CopyJob *KIO::move(const KUrl& src, const KUrl& dest, JobFlags flags)
     //kDebug(7007) << src << dest;
     KUrl::List srcList;
     srcList.append( src );
-    return CopyJobPrivate::newJob(srcList, dest, CopyJob::Move, false, flags);
+    CopyJob* job = CopyJobPrivate::newJob(srcList, dest, CopyJob::Move, false, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::UpdateContent);
+    return job;
 }
 
 CopyJob *KIO::moveAs(const KUrl& src, const KUrl& dest, JobFlags flags)
@@ -2193,13 +2193,17 @@ CopyJob *KIO::moveAs(const KUrl& src, const KUrl& dest, JobFlags flags)
     //kDebug(7007) << src << dest;
     KUrl::List srcList;
     srcList.append( src );
-    return CopyJobPrivate::newJob(srcList, dest, CopyJob::Move, true, flags);
+    CopyJob* job = CopyJobPrivate::newJob(srcList, dest, CopyJob::Move, true, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::UpdateContent);
+    return job;
 }
 
 CopyJob *KIO::move( const KUrl::List& src, const KUrl& dest, JobFlags flags)
 {
     //kDebug(7007) << src << dest;
-    return CopyJobPrivate::newJob(src, dest, CopyJob::Move, false, flags);
+    CopyJob* job = CopyJobPrivate::newJob(src, dest, CopyJob::Move, false, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::UpdateContent);
+    return job;
 }
 
 CopyJob *KIO::link(const KUrl& src, const KUrl& destDir, JobFlags flags)
@@ -2233,4 +2237,4 @@ CopyJob *KIO::trash(const KUrl::List& srcList, JobFlags flags)
     return CopyJobPrivate::newJob(srcList, KUrl( "trash:/" ), CopyJob::Move, false, flags);
 }
 
-#include "copyjob.moc"
+#include "moc_copyjob.cpp"
