@@ -26,6 +26,7 @@
 #include "kdirwatch.h"
 #include "kprotocolmanager.h"
 #include "jobuidelegate.h"
+#include "clipboardupdater_p.h"
 #include <kdirnotify.h>
 
 #include <klocale.h>
@@ -35,17 +36,12 @@
 #include <QtCore/QTimer>
 #include <QtCore/QFile>
 #include <QPointer>
+#include <QtCore/qfileinfo.h>
 
 #include "job_p.h"
 
 extern bool kio_resolve_local_urls; // from copyjob.cpp, abused here to save a symbol.
 
-static bool isHttpProtocol(const QString& protocol)
-{
-    return (protocol.startsWith(QLatin1String("webdav"), Qt::CaseInsensitive) ||
-            protocol.startsWith(QLatin1String("http"), Qt::CaseInsensitive));
-}
-
 namespace KIO
 {
     enum DeleteJobState {
@@ -257,13 +253,6 @@ void DeleteJobPrivate::finishedStatPhase()
 {
     m_totalFilesDirs = files.count() + symlinks.count() + dirs.count();
     slotReport();
-    // Now we know which dirs hold the files we're going to delete.
-    // To speed things up and prevent double-notification, we disable KDirWatch
-    // on those dirs temporarily (using KDirWatch::self, that's the instance
-    // used by e.g. kdirlister).
-    const QSet<QString>::const_iterator itEnd = m_parentDirs.constEnd();
-    for ( QSet<QString>::const_iterator it = m_parentDirs.constBegin() ; it != itEnd ; ++it )
-        KDirWatch::self()->stopDirScan( *it );
     state = DELETEJOB_STATE_DELETING_FILES;
     deleteNextFile();
 }
@@ -286,12 +275,8 @@ void DeleteJobPrivate::deleteNextFile()
             }
             // Normal deletion
             // If local file, try do it directly
-#ifdef Q_WS_WIN
-            if ( (*it).isLocalFile() && DeleteFileW( (LPCWSTR)(*it).toLocalFile().utf16() ) != 0 ) {
-#else
             if ( (*it).isLocalFile() && unlink( QFile::encodeName((*it).toLocalFile()) ) == 0 ) {
-#endif
-                //kdDebug(7007) << "DeleteJob deleted" << (*it).toLocalFile();
+                //kDebug(7007) << "DeleteJob deleted" << (*it).toLocalFile();
                 job = 0;
                 m_processedFiles++;
                 if ( m_processedFiles % 300 == 1 || m_totalFilesDirs < 300) { // update progress info every 300 files
@@ -301,10 +286,7 @@ void DeleteJobPrivate::deleteNextFile()
             } else
             { // if remote - or if unlink() failed (we'll use the job's error handling in that case)
                 //kDebug(7007) << "calling file_delete on" << *it;
-                if (isHttpProtocol(it->protocol()))
-                  job = KIO::http_delete( *it, KIO::HideProgressInfo );
-                else
-                  job = KIO::file_delete( *it, KIO::HideProgressInfo );
+                job = KIO::file_delete( *it, KIO::HideProgressInfo );
                 Scheduler::setJobPriority(job, 1);
                 m_currentURL=(*it);
             }
@@ -332,11 +314,7 @@ void DeleteJobPrivate::deleteNextDir()
             // Take first dir to delete out of list - last ones first !
             KUrl::List::iterator it = --dirs.end();
             // If local dir, try to rmdir it directly
-#ifdef Q_WS_WIN
-            if ( (*it).isLocalFile() && RemoveDirectoryW( (LPCWSTR)(*it).toLocalFile().utf16() ) != 0 ) {
-#else
             if ( (*it).isLocalFile() && ::rmdir( QFile::encodeName((*it).toLocalFile()) ) == 0 ) {
-#endif
                 m_processedDirs++;
                 if ( m_processedDirs % 100 == 1 ) { // update progress info every 100 dirs
                     m_currentURL = *it;
@@ -345,7 +323,7 @@ void DeleteJobPrivate::deleteNextDir()
             } else {
                 // Call rmdir - works for kioslaves with canDeleteRecursive too,
                 // CMD_DEL will trigger the recursive deletion in the slave.
-                SimpleJob* job = KIO::rmdir( *it );
+                SimpleJob* job = KIO::rmdir(*it);
                 job->addMetaData(QString::fromLatin1("recurse"), "true");
                 Scheduler::setJobPriority(job, 1);
                 dirs.erase(it);
@@ -356,12 +334,6 @@ void DeleteJobPrivate::deleteNextDir()
         } while ( !dirs.isEmpty() );
     }
 
-    // Re-enable watching on the dirs that held the deleted files
-    const QSet<QString>::const_iterator itEnd = m_parentDirs.constEnd();
-    for (QSet<QString>::const_iterator it = m_parentDirs.constBegin() ; it != itEnd ; ++it) {
-        KDirWatch::self()->restartDirScan( *it );
-    }
-
     // Finished - tell the world
     if ( !m_srcList.isEmpty() )
     {
@@ -380,17 +352,10 @@ void DeleteJobPrivate::currentSourceStated(bool isDir, bool isLink)
     if (isDir && !isLink) {
         // Add toplevel dir in list of dirs
         dirs.append( url );
-        if (url.isLocalFile()) {
-            // We are about to delete this dir, no need to watch it
-            // Maybe we should ask kdirwatch to remove all watches recursively?
-            // But then there would be no feedback (things disappearing progressively) during huge deletions
-            KDirWatch::self()->stopDirScan(url.toLocalFile(KUrl::RemoveTrailingSlash));
-        }
         if (!KProtocolManager::canDeleteRecursive(url)) {
             //kDebug(7007) << url << "is a directory, let's list it";
             ListJob *newjob = KIO::listRecursive(url, KIO::HideProgressInfo);
             newjob->addMetaData("details", "0");
-            newjob->setUnrestricted(true); // No KIOSK restrictions
             Scheduler::setJobPriority(newjob, 1);
             QObject::connect(newjob, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
                              q, SLOT(slotEntries(KIO::Job*,KIO::UDSEntryList)));
@@ -446,10 +411,10 @@ void DeleteJob::slotResult( KJob *job )
         }
         break;
     case DELETEJOB_STATE_DELETING_FILES:
-	// Propagate the subjob's metadata (a SimpleJob) to the real DeleteJob
-	// FIXME: setMetaData() in the KIO API only allows access to outgoing metadata,
-	// but we need to alter the incoming one
-	d->m_incomingMetaData = dynamic_cast<KIO::Job*>(job)->metaData();
+        // Propagate the subjob's metadata (a SimpleJob) to the real DeleteJob
+        // FIXME: setMetaData() in the KIO API only allows access to outgoing metadata,
+        // but we need to alter the incoming one
+        d->m_incomingMetaData = qobject_cast<KIO::Job*>(job)->metaData();
 
         if ( job->error() )
         {
@@ -485,12 +450,16 @@ DeleteJob *KIO::del( const KUrl& src, JobFlags flags )
 {
     KUrl::List srcList;
     srcList.append( src );
-    return DeleteJobPrivate::newJob(srcList, flags);
+    DeleteJob* job = DeleteJobPrivate::newJob(srcList, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::RemoveContent);
+    return job;
 }
 
 DeleteJob *KIO::del( const KUrl::List& src, JobFlags flags )
 {
-    return DeleteJobPrivate::newJob(src, flags);
+    DeleteJob* job = DeleteJobPrivate::newJob(src, flags);
+    ClipboardUpdater::create(job, ClipboardUpdater::RemoveContent);
+    return job;
 }
 
-#include "deletejob.moc"
+#include "moc_deletejob.cpp"
