@@ -45,6 +45,7 @@ static const char* undoStateToString(UndoState state) {
     return s_undoStateToString[state];
 }
 
+QT_BEGIN_NAMESPACE
 static QDataStream &operator<<(QDataStream &stream, const KIO::BasicOperation &op)
 {
     stream << op.m_valid << (qint8)op.m_type << op.m_renamed
@@ -75,6 +76,7 @@ static QDataStream &operator>>(QDataStream &stream, UndoCommand &cmd)
     cmd.m_type = static_cast<FileUndoManager::CommandType>(type);
     return stream;
 }
+QT_END_NAMESPACE
 
 /**
  * checklist:
@@ -324,6 +326,10 @@ quint64 FileUndoManager::currentCommandSerialNumber() const
 
 void FileUndoManager::undo()
 {
+    if (d->m_commands.isEmpty()) {
+        return;
+    }
+
     // Make a copy of the command to undo before broadcastPop() pops it.
     UndoCommand cmd = d->m_commands.last();
     assert(cmd.m_valid);
@@ -396,7 +402,7 @@ void FileUndoManager::undo()
         d->m_fileCleanupStack.append(d->m_current.m_dst);
     }
 
-    kDebug(1203) << "starting with" << undoStateToString(d->m_undoState);
+    kDebug(7000) << "starting with" << undoStateToString(d->m_undoState);
     d->m_undoJob = new UndoJob(d->m_uiInterface->showProgressInfo());
     d->undoStep();
 }
@@ -430,11 +436,11 @@ void FileUndoManagerPrivate::slotResult(KJob *job)
     else if (m_undoState == STATINGFILE)
     {
         BasicOperation op = m_current.m_opStack.last();
-        //kDebug(1203) << "stat result for " << op.m_dst;
+        //kDebug(7000) << "stat result for " << op.m_dst;
         KIO::StatJob* statJob = static_cast<KIO::StatJob*>(job);
         time_t mtime = statJob->statResult().numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, -1);
         if (mtime != op.m_mtime) {
-            kDebug(1203) << op.m_dst << " was modified after being copied!";
+            kDebug(7000) << op.m_dst << " was modified after being copied!";
             KDateTime srcTime; srcTime.setTime_t(op.m_mtime); srcTime = srcTime.toLocalZone();
             KDateTime destTime; destTime.setTime_t(mtime); destTime = destTime.toLocalZone();
             if (!m_uiInterface->copiedFileWasModified(op.m_src, op.m_dst, srcTime, destTime)) {
@@ -481,7 +487,7 @@ void FileUndoManagerPrivate::stepMakingDirectories()
 {
     if (!m_dirStack.isEmpty()) {
         KUrl dir = m_dirStack.pop();
-        kDebug(1203) << "creatingDir" << dir;
+        kDebug(7000) << "creatingDir" << dir;
         m_currentJob = KIO::mkdir(dir);
         m_undoJob->emitCreatingDir(dir);
     }
@@ -504,7 +510,7 @@ void FileUndoManagerPrivate::stepMovingFiles()
         {
             if (op.m_renamed)
             {
-                kDebug(1203) << "rename" << op.m_dst << op.m_src;
+                kDebug(7000) << "rename" << op.m_dst << op.m_src;
                 m_currentJob = KIO::rename(op.m_dst, op.m_src, KIO::HideProgressInfo);
                 m_undoJob->emitMoving(op.m_dst, op.m_src);
             }
@@ -513,7 +519,7 @@ void FileUndoManagerPrivate::stepMovingFiles()
         }
         else if (type == BasicOperation::Link)
         {
-            kDebug(1203) << "symlink" << op.m_target << op.m_src;
+            kDebug(7000) << "symlink" << op.m_target << op.m_src;
             m_currentJob = KIO::symlink(op.m_target, op.m_src, KIO::Overwrite | KIO::HideProgressInfo);
         }
         else if (m_current.m_type == FileUndoManager::Copy)
@@ -521,7 +527,7 @@ void FileUndoManagerPrivate::stepMovingFiles()
             if (m_undoState == MOVINGFILES) // dest not stat'ed yet
             {
                 // Before we delete op.m_dst, let's check if it was modified (#20532)
-                kDebug(1203) << "stat" << op.m_dst;
+                kDebug(7000) << "stat" << op.m_dst;
                 m_currentJob = KIO::stat(op.m_dst, KIO::HideProgressInfo);
                 m_undoState = STATINGFILE; // temporarily
                 return; // no pop() yet, we'll finish the work in slotResult
@@ -536,7 +542,7 @@ void FileUndoManagerPrivate::stepMovingFiles()
         else if (m_current.isMoveCommand()
                   || m_current.m_type == FileUndoManager::Trash)
         {
-            kDebug(1203) << "file_move" << op.m_dst << op.m_src;
+            kDebug(7000) << "file_move" << op.m_dst << op.m_src;
             m_currentJob = KIO::file_move(op.m_dst, op.m_src, -1, KIO::Overwrite | KIO::HideProgressInfo);
             KIO::ClipboardUpdater::create(m_currentJob, KIO::ClipboardUpdater::UpdateContent);
             m_undoJob->emitMoving(op.m_dst, op.m_src);
@@ -559,11 +565,11 @@ void FileUndoManagerPrivate::stepMovingFiles()
 
 void FileUndoManagerPrivate::stepRemovingLinks()
 {
-    kDebug(1203) << "REMOVINGLINKS";
+    kDebug(7000) << "REMOVINGLINKS";
     if (!m_fileCleanupStack.isEmpty())
     {
         KUrl file = m_fileCleanupStack.pop();
-        kDebug(1203) << "file_delete" << file;
+        kDebug(7000) << "file_delete" << file;
         m_currentJob = KIO::file_delete(file, KIO::HideProgressInfo);
         m_undoJob->emitDeleting(file);
 
@@ -585,7 +591,7 @@ void FileUndoManagerPrivate::stepRemovingDirectories()
     if (!m_dirCleanupStack.isEmpty())
     {
         KUrl dir = m_dirCleanupStack.pop();
-        kDebug(1203) << "rmdir" << dir;
+        kDebug(7000) << "rmdir" << dir;
         m_currentJob = KIO::rmdir(dir);
         m_undoJob->emitDeleting(dir);
         addDirToUpdate(dir);
@@ -596,14 +602,13 @@ void FileUndoManagerPrivate::stepRemovingDirectories()
         m_currentJob = 0;
         if (m_undoJob)
         {
-            kDebug(1203) << "deleting undojob";
+            kDebug(7000) << "deleting undojob";
             m_undoJob->emitResult();
             m_undoJob = 0;
         }
-        QList<KUrl>::ConstIterator it = m_dirsToUpdate.constBegin();
-        for(; it != m_dirsToUpdate.constEnd(); ++it) {
-            kDebug() << "Notifying FilesAdded for " << *it;
-            org::kde::KDirNotify::emitFilesAdded((*it).url());
+        foreach (const KUrl it, m_dirsToUpdate) {
+            kDebug() << "Notifying FilesAdded for " << it;
+            org::kde::KDirNotify::emitFilesAdded(it.url());
         }
         emit q->undoJobFinished();
         broadcastUnlock();
@@ -808,9 +813,5 @@ bool FileUndoManager::UiInterface::showProgressInfo() const
     return d->m_showProgressInfo;
 }
 
-void FileUndoManager::UiInterface::virtual_hook(int, void*)
-{
-}
-
-#include "fileundomanager_p.moc"
-#include "fileundomanager.moc"
+#include "moc_fileundomanager_p.cpp"
+#include "moc_fileundomanager.cpp"
