@@ -22,33 +22,6 @@
 #include "job.h"
 #include "job_p.h"
 #include "clipboardupdater_p.h"
-
-#include <config.h>
-
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/stat.h>
-
-#include <signal.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <time.h>
-#include <unistd.h>
-extern "C" {
-#include <pwd.h>
-#include <grp.h>
-}
-#include <QtCore/QTimer>
-#include <QtCore/QFile>
-
-#include <kauthorized.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kde_file.h>
-
-#include <errno.h>
-
 #include "jobuidelegate.h"
 #include "kmimetype.h"
 #include "slave.h"
@@ -58,8 +31,25 @@ extern "C" {
 #include "kprotocolmanager.h"
 #include "filejob.h"
 
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <sys/stat.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include <time.h>
+#include <unistd.h>
+
+#include <QtCore/QList>
+#include <QtCore/QTimer>
+#include <QtCore/QFile>
+#include <QtCore/qbuffer.h>
+
+#include <klocale.h>
+#include <kconfig.h>
+#include <kdebug.h>
+#include <kde_file.h>
 #include <kdirnotify.h>
-#include <ktemporaryfile.h>
 
 using namespace KIO;
 
@@ -97,7 +87,7 @@ bool Job::addSubjob(KJob *jobBase)
     //kDebug(7007) << "addSubjob(" << jobBase << ") this=" << this;
 
     bool ok = KCompositeJob::addSubjob( jobBase );
-    KIO::Job *job = dynamic_cast<KIO::Job*>( jobBase );
+    KIO::Job *job = qobject_cast<KIO::Job*>( jobBase );
     if (ok && job) {
         // Copy metadata into subjob (e.g. window-id, user-timestamp etc.)
         Q_D(Job);
@@ -212,20 +202,6 @@ void JobPrivate::slotSpeed( KJob*, unsigned long speed )
 
 //Job::errorString is implemented in global.cpp
 
-#ifndef KDE_NO_DEPRECATED
-void Job::showErrorDialog( QWidget *parent )
-{
-    if ( ui() )
-    {
-        ui()->setWindow( parent );
-        ui()->showErrorMessage();
-    }
-    else
-    {
-        kError() << errorString();
-    }
-}
-#endif
 
 bool Job::isInteractive() const
 {
@@ -269,19 +245,23 @@ void Job::addMetaData( const QString &key, const QString &value)
 void Job::addMetaData( const QMap<QString,QString> &values)
 {
     Q_D(Job);
-    QMap<QString,QString>::const_iterator it = values.begin();
-    for(;it != values.end(); ++it)
+    QMapIterator<QString,QString> it(values);
+    while(it.hasNext()) {
+        it.next();
         d->m_outgoingMetaData.insert(it.key(), it.value());
+    }
 }
 
 void Job::mergeMetaData( const QMap<QString,QString> &values)
 {
     Q_D(Job);
-    QMap<QString,QString>::const_iterator it = values.begin();
-    for(;it != values.end(); ++it)
+    QMapIterator<QString,QString> it(values);
+    while(it.hasNext()) {
+        it.next();
         // there's probably a faster way
         if ( !d->m_outgoingMetaData.contains( it.key() ) )
             d->m_outgoingMetaData.insert( it.key(), it.value() );
+    }
 }
 
 MetaData Job::outgoingMetaData() const
@@ -562,14 +542,13 @@ void SimpleJobPrivate::restartAfterRedirection(KUrl *redirectionUrl)
 int SimpleJobPrivate::requestMessageBox(int _type, const QString& text, const QString& caption,
                                        const QString& buttonYes, const QString& buttonNo,
                                        const QString& iconYes, const QString& iconNo,
-                                       const QString& dontAskAgainName,
-                                       const KIO::MetaData& sslMetaData)
+                                       const QString& dontAskAgainName)
 {
     JobUiDelegate* delegate = ui();
     if (delegate) {
       const JobUiDelegate::MessageBoxType type = static_cast<JobUiDelegate::MessageBoxType>(_type);
       return delegate->requestMessageBox(type, text, caption, buttonYes, buttonNo,
-                                         iconYes, iconNo, dontAskAgainName, sslMetaData);
+                                         iconYes, iconNo, dontAskAgainName);
     }
     kWarning(7007) << "JobUiDelegate not set! Returing -1";
     return -1;
@@ -581,26 +560,10 @@ void SimpleJob::slotMetaData( const KIO::MetaData &_metaData )
     QMapIterator<QString,QString> it (_metaData);
     while (it.hasNext()) {
         it.next();
-        if (it.key().startsWith(QLatin1String("{internal~"), Qt::CaseInsensitive))
-            d->m_internalMetaData.insert(it.key(), it.value());
-        else
-            d->m_incomingMetaData.insert(it.key(), it.value());
-    }
-
-    // Update the internal meta-data values as soon as possible. Waiting until
-    // the ioslave is finished has unintended consequences if the client starts
-    // a new connection without waiting for the ioslave to finish.
-    if (!d->m_internalMetaData.isEmpty()) {
-        Scheduler::updateInternalMetaData(this);
+        d->m_incomingMetaData.insert(it.key(), it.value());
     }
 }
 
-void SimpleJob::storeSSLSessionFromJob(const KUrl &redirectionURL)
-{
-    Q_UNUSED(redirectionURL);
-}
-
-
 //////////
 class KIO::MkdirJobPrivate: public SimpleJobPrivate
 {
@@ -652,13 +615,6 @@ void MkdirJobPrivate::slotRedirection( const KUrl &url)
 {
      Q_Q(MkdirJob);
      kDebug(7007) << url;
-     if (!KAuthorized::authorizeUrlAction("redirect", m_url, url))
-     {
-         kWarning(7007) << "Redirection from" << m_url << "to" << url << "REJECTED!";
-         q->setError( ERR_ACCESS_DENIED );
-         q->setErrorText( url.pathOrUrl() );
-         return;
-     }
      m_redirectionURL = url; // We'll remember that when the job finishes
      // Tell the user that we haven't finished yet
      emit q->redirection(q, m_redirectionURL);
@@ -671,9 +627,6 @@ void MkdirJob::slotFinished()
     if ( !d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid() )
     {
         //kDebug(7007) << "MkdirJob: Redirection to " << m_redirectionURL;
-        if (queryMetaData("permanent-redirect")=="true")
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
-
         if ( d->m_redirectionHandlingEnabled )
         {
             KUrl dummyUrl;
@@ -819,12 +772,6 @@ StatJob::~StatJob()
 {
 }
 
-#ifndef KDE_NO_DEPRECATED
-void StatJob::setSide( bool source )
-{
-    d_func()->m_bSource = source;
-}
-#endif
 
 void StatJob::setSide( StatSide side )
 {
@@ -877,13 +824,6 @@ void StatJobPrivate::slotRedirection( const KUrl &url)
 {
      Q_Q(StatJob);
      kDebug(7007) << m_url << "->" << url;
-     if (!KAuthorized::authorizeUrlAction("redirect", m_url, url))
-     {
-       kWarning(7007) << "Redirection from " << m_url << " to " << url << " REJECTED!";
-       q->setError( ERR_ACCESS_DENIED );
-       q->setErrorText( url.pathOrUrl() );
-       return;
-     }
      m_redirectionURL = url; // We'll remember that when the job finishes
      // Tell the user that we haven't finished yet
      emit q->redirection(q, m_redirectionURL);
@@ -896,9 +836,6 @@ void StatJob::slotFinished()
     if ( !d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid() )
     {
         //kDebug(7007) << "StatJob: Redirection to " << m_redirectionURL;
-        if (queryMetaData("permanent-redirect")=="true")
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
-
         if ( d->m_redirectionHandlingEnabled )
         {
             d->m_packedArgs.truncate(0);
@@ -914,13 +851,6 @@ void StatJob::slotFinished()
     SimpleJob::slotFinished();
 }
 
-void StatJob::slotMetaData( const KIO::MetaData &_metaData)
-{
-    Q_D(StatJob);
-    SimpleJob::slotMetaData(_metaData);
-    storeSSLSessionFromJob(d->m_redirectionURL);
-}
-
 StatJob *KIO::stat(const KUrl& url, JobFlags flags)
 {
     // Assume sideIsSource. Gets are more common than puts.
@@ -937,17 +867,6 @@ StatJob *KIO::mostLocalUrl(const KUrl& url, JobFlags flags)
     return job;
 }
 
-#ifndef KDE_NO_DEPRECATED
-StatJob *KIO::stat(const KUrl& url, bool sideIsSource, short int details, JobFlags flags )
-{
-    //kDebug(7007) << "stat" << url;
-    KIO_ARGS << url;
-    StatJob * job = StatJobPrivate::newJob(url, CMD_STAT, packedArgs, flags);
-    job->setSide( sideIsSource ? StatJob::SourceSide : StatJob::DestinationSide );
-    job->setDetails( details );
-    return job;
-}
-#endif
 
 StatJob *KIO::stat(const KUrl& url, KIO::StatJob::StatSide side, short int details, JobFlags flags )
 {
@@ -959,16 +878,6 @@ StatJob *KIO::stat(const KUrl& url, KIO::StatJob::StatSide side, short int detai
     return job;
 }
 
-SimpleJob *KIO::http_update_cache( const KUrl& url, bool no_cache, time_t expireDate)
-{
-    Q_ASSERT(url.protocol() == "http" || url.protocol() == "https");
-    // Send http update_cache command (2)
-    KIO_ARGS << (int)2 << url << no_cache << qlonglong(expireDate);
-    SimpleJob * job = SimpleJobPrivate::newJob(url, CMD_SPECIAL, packedArgs);
-    Scheduler::setJobPriority(job, 1);
-    return job;
-}
-
 //////////
 
 TransferJob::TransferJob(TransferJobPrivate &dd)
@@ -1010,11 +919,6 @@ void TransferJob::slotRedirection( const KUrl &url)
 {
     Q_D(TransferJob);
     kDebug(7007) << url;
-    if (!KAuthorized::authorizeUrlAction("redirect", d->m_url, url))
-    {
-        kWarning(7007) << "Redirection from " << d->m_url << " to " << url << " REJECTED!";
-        return;
-    }
 
     // Some websites keep redirecting to themselves where each redirection
     // acts as the stage in a state-machine. We define "endless redirections"
@@ -1029,12 +933,6 @@ void TransferJob::slotRedirection( const KUrl &url)
     {
        d->m_redirectionURL = url; // We'll remember that when the job finishes
        d->m_redirectionList.append(url);
-       QString sslInUse = queryMetaData(QLatin1String("ssl_in_use"));
-       if (!sslInUse.isNull()) { // the key is present
-           addMetaData(QLatin1String("ssl_was_in_use"), sslInUse);
-       } else {
-           addMetaData(QLatin1String("ssl_was_in_use"), QLatin1String("FALSE"));
-       }
        // Tell the user that we haven't finished yet
        emit redirection(this, d->m_redirectionURL);
     }
@@ -1048,9 +946,6 @@ void TransferJob::slotFinished()
     if (!d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid()) {
 
         //kDebug(7007) << "Redirection to" << m_redirectionURL;
-        if (queryMetaData("permanent-redirect")=="true")
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
-
         if (d->m_redirectionHandlingEnabled) {
             // Honour the redirection
             // We take the approach of "redirecting this same job"
@@ -1059,7 +954,6 @@ void TransferJob::slotFinished()
             const QString redirectToGet = queryMetaData(QLatin1String("redirect-to-get"));
             if (redirectToGet == QLatin1String("true")) {
                 d->m_command = CMD_GET;
-                d->m_outgoingMetaData.remove(QLatin1String("CustomHTTPMethod"));
                 d->m_outgoingMetaData.remove(QLatin1String("content-type"));
             }
             d->staticData.truncate(0);
@@ -1135,23 +1029,7 @@ void TransferJob::sendAsyncData(const QByteArray &dataForSlave)
     d->m_extraFlags &= ~JobPrivate::EF_TransferJobNeedData;
 }
 
-#ifndef KDE_NO_DEPRECATED
-void TransferJob::setReportDataSent(bool enabled)
-{
-    Q_D(TransferJob);
-    if (enabled)
-       d->m_extraFlags |= JobPrivate::EF_TransferJobDataSent;
-    else
-       d->m_extraFlags &= ~JobPrivate::EF_TransferJobDataSent;
-}
-#endif
 
-#ifndef KDE_NO_DEPRECATED
-bool TransferJob::reportDataSent() const
-{
-    return (d_func()->m_extraFlags & JobPrivate::EF_TransferJobDataSent);
-}
-#endif
 
 QString TransferJob::mimetype() const
 {
@@ -1234,11 +1112,6 @@ bool TransferJob::doResume()
     return true;
 }
 
-bool TransferJob::isErrorPage() const
-{
-    return d_func()->m_errorPage;
-}
-
 void TransferJobPrivate::start(Slave *slave)
 {
     Q_Q(TransferJob);
@@ -1260,9 +1133,6 @@ void TransferJobPrivate::start(Slave *slave)
     q->connect( slave, SIGNAL(mimeType(QString)),
              SLOT(slotMimetype(QString)) );
 
-    q->connect( slave, SIGNAL(errorPage()),
-             SLOT(slotErrorPage()) );
-
     q->connect( slave, SIGNAL(needSubUrlData()),
              SLOT(slotNeedSubUrlData()) );
 
@@ -1300,18 +1170,6 @@ void TransferJobPrivate::slotSubUrlData(KIO::Job*, const QByteArray &data)
     internalResume(); // Activate ourselves again.
 }
 
-void TransferJob::slotMetaData( const KIO::MetaData &_metaData)
-{
-    Q_D(TransferJob);
-    SimpleJob::slotMetaData(_metaData);
-    storeSSLSessionFromJob(d->m_redirectionURL);
-}
-
-void TransferJobPrivate::slotErrorPage()
-{
-    m_errorPage = true;
-}
-
 void TransferJobPrivate::slotCanResume( KIO::filesize_t offset )
 {
     Q_Q(TransferJob);
@@ -1426,277 +1284,6 @@ public:
     }
 };
 
-namespace KIO {
-    class PostErrorJob : public StoredTransferJob
-    {
-    public:
-
-        PostErrorJob(int _error, const QString& url, const QByteArray &packedArgs, const QByteArray &postData)
-            : StoredTransferJob(*new StoredTransferJobPrivate(KUrl(), CMD_SPECIAL, packedArgs, postData))
-            {
-                setError( _error );
-                setErrorText( url );
-            }
-
-        PostErrorJob(int _error, const QString& url, const QByteArray &packedArgs, QIODevice* ioDevice)
-            : StoredTransferJob(*new StoredTransferJobPrivate(KUrl(), CMD_SPECIAL, packedArgs, ioDevice))
-            {
-                setError( _error );
-                setErrorText( url );
-            }
-    };
-}
-
-static int isUrlPortBad(const KUrl& url)
-{
-    int _error = 0;
-
-    // filter out some malicious ports
-    static const int bad_ports[] = {
-        1,   // tcpmux
-        7,   // echo
-        9,   // discard
-        11,   // systat
-        13,   // daytime
-        15,   // netstat
-        17,   // qotd
-        19,   // chargen
-        20,   // ftp-data
-        21,   // ftp-cntl
-        22,   // ssh
-        23,   // telnet
-        25,   // smtp
-        37,   // time
-        42,   // name
-        43,   // nicname
-        53,   // domain
-        77,   // priv-rjs
-        79,   // finger
-        87,   // ttylink
-        95,   // supdup
-        101,  // hostriame
-        102,  // iso-tsap
-        103,  // gppitnp
-        104,  // acr-nema
-        109,  // pop2
-        110,  // pop3
-        111,  // sunrpc
-        113,  // auth
-        115,  // sftp
-        117,  // uucp-path
-        119,  // nntp
-        123,  // NTP
-        135,  // loc-srv / epmap
-        139,  // netbios
-        143,  // imap2
-        179,  // BGP
-        389,  // ldap
-        512,  // print / exec
-        513,  // login
-        514,  // shell
-        515,  // printer
-        526,  // tempo
-        530,  // courier
-        531,  // Chat
-        532,  // netnews
-        540,  // uucp
-        556,  // remotefs
-        587,  // sendmail
-        601,  //
-        989,  // ftps data
-        990,  // ftps
-        992,  // telnets
-        993,  // imap/SSL
-        995,  // pop3/SSL
-        1080, // SOCKS
-        2049, // nfs
-        4045, // lockd
-        6000, // x11
-        6667, // irc
-        0};
-    if (url.port() != 80)
-    {
-        const int port = url.port();
-        for (int cnt=0; bad_ports[cnt] && bad_ports[cnt] <= port; ++cnt)
-            if (port == bad_ports[cnt])
-            {
-                _error = KIO::ERR_POST_DENIED;
-                break;
-            }
-    }
-
-    if ( _error )
-    {
-        static bool override_loaded = false;
-        static QList< int >* overriden_ports = NULL;
-        if( !override_loaded ) {
-            KConfig cfg( "kio_httprc" );
-            overriden_ports = new QList< int >;
-            *overriden_ports = cfg.group(QString()).readEntry( "OverriddenPorts", QList<int>() );
-            override_loaded = true;
-        }
-        for( QList< int >::ConstIterator it = overriden_ports->constBegin();
-                it != overriden_ports->constEnd();
-                ++it ) {
-            if( overriden_ports->contains( url.port())) {
-                _error = 0;
-            }
-        }
-    }
-
-    // filter out non https? protocols
-    if ((url.protocol() != "http") && (url.protocol() != "https" ))
-        _error = KIO::ERR_POST_DENIED;
-
-    if (!_error && !KAuthorized::authorizeUrlAction("open", KUrl(), url))
-        _error = KIO::ERR_ACCESS_DENIED;
-
-    return _error;
-}
-
-static KIO::PostErrorJob* precheckHttpPost( const KUrl& url, QIODevice* ioDevice, JobFlags flags )
-{
-    // if request is not valid, return an invalid transfer job
-    const int _error = isUrlPortBad(url);
-
-    if (_error)
-    {
-        KIO_ARGS << (int)1 << url;
-        PostErrorJob * job = new PostErrorJob(_error, url.pathOrUrl(), packedArgs, ioDevice);
-        job->setUiDelegate(new JobUiDelegate());
-        if (!(flags & HideProgressInfo)) {
-            KIO::getJobTracker()->registerJob(job);
-        }
-        return job;
-    }
-
-    // all is ok, return 0
-    return 0;
-}
-
-static KIO::PostErrorJob* precheckHttpPost( const KUrl& url, const QByteArray& postData, JobFlags flags )
-{
-    // if request is not valid, return an invalid transfer job
-    const int _error = isUrlPortBad(url);
-
-    if (_error)
-    {
-        KIO_ARGS << (int)1 << url;
-        PostErrorJob * job = new PostErrorJob(_error, url.pathOrUrl(), packedArgs, postData);
-        job->setUiDelegate(new JobUiDelegate());
-        if (!(flags & HideProgressInfo)) {
-            KIO::getJobTracker()->registerJob(job);
-        }
-        return job;
-    }
-
-    // all is ok, return 0
-    return 0;
-}
-
-TransferJob *KIO::http_post( const KUrl& url, const QByteArray &postData, JobFlags flags )
-{
-    QBuffer* device = new QBuffer;
-    device->setData(postData);
-    device->open(QIODevice::ReadOnly);
-    TransferJob* job = http_post(url, device, device->size(), flags);
-    device->setParent(job);
-    return job;
-}
-
-TransferJob *KIO::http_post( const KUrl& url, QIODevice* ioDevice, qint64 size, JobFlags flags )
-{
-    bool redirection = false;
-    KUrl _url(url);
-    if (_url.path().isEmpty())
-    {
-      redirection = true;
-      _url.setPath("/");
-    }
-
-    TransferJob* job = precheckHttpPost(_url, ioDevice, flags);
-    if (job)
-        return job;
-
-    // If no size is specified and the QIODevice is not a sequential one,
-    // attempt to obtain the size information from it.
-    Q_ASSERT(ioDevice);
-    if (size < 0)
-        size = ((ioDevice && !ioDevice->isSequential()) ? ioDevice->size() : -1);
-
-    // Send http post command (1), decoded path and encoded query
-    KIO_ARGS << (int)1 << _url << size;
-    job = TransferJobPrivate::newJob(_url, CMD_SPECIAL, packedArgs, ioDevice, flags);
-
-    if (redirection)
-      QTimer::singleShot(0, job, SLOT(slotPostRedirection()));
-
-    return job;
-}
-
-TransferJob* KIO::http_delete(const KUrl& url, JobFlags flags)
-{
-    // Send decoded path and encoded query
-    KIO_ARGS << url;
-    TransferJob * job = TransferJobPrivate::newJob(url, CMD_DEL, packedArgs,
-                                                   QByteArray(), flags);
-    return job;
-}
-
-StoredTransferJob *KIO::storedHttpPost( const QByteArray& postData, const KUrl& url, JobFlags flags )
-{
-    KUrl _url(url);
-    if (_url.path().isEmpty())
-    {
-      _url.setPath("/");
-    }
-
-    StoredTransferJob* job = precheckHttpPost(_url, postData, flags);
-    if (job)
-        return job;
-
-    // Send http post command (1), decoded path and encoded query
-    KIO_ARGS << (int)1 << _url << static_cast<qint64>(postData.size());
-    job = StoredTransferJobPrivate::newJob(_url, CMD_SPECIAL, packedArgs, postData, flags );
-    return job;
-}
-
-StoredTransferJob *KIO::storedHttpPost( QIODevice* ioDevice, const KUrl& url, qint64 size, JobFlags flags )
-{
-    KUrl _url(url);
-    if (_url.path().isEmpty())
-    {
-      _url.setPath("/");
-    }
-
-    StoredTransferJob* job = precheckHttpPost(_url, ioDevice, flags);
-    if (job)
-        return job;
-
-    // If no size is specified and the QIODevice is not a sequential one,
-    // attempt to obtain the size information from it.
-    Q_ASSERT(ioDevice);
-    if (size < 0)
-        size = ((ioDevice && !ioDevice->isSequential()) ? ioDevice->size() : -1);
-
-    // Send http post command (1), decoded path and encoded query
-    KIO_ARGS << (int)1 << _url << size;
-    job = StoredTransferJobPrivate::newJob(_url, CMD_SPECIAL, packedArgs, ioDevice, flags );
-    return job;
-}
-
-// http post got redirected from http://host to http://host/ by TransferJob
-// We must do this redirection ourselves because redirections by the
-// slave change post jobs into get jobs.
-void TransferJobPrivate::slotPostRedirection()
-{
-    Q_Q(TransferJob);
-    kDebug(7007) << "TransferJob::slotPostRedirection(" << m_url << ")";
-    // Tell the user about the new url.
-    emit q->redirection(q, m_url);
-}
-
-
 TransferJob *KIO::put( const KUrl& url, int permissions, JobFlags flags )
 {
     KIO_ARGS << url << qint8( (flags & Overwrite) ? 1 : 0 ) << qint8( (flags & Resume) ? 1 : 0 ) << permissions;
@@ -1833,9 +1420,6 @@ void MimetypeJob::slotFinished( )
     if ( !d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid() && !error() )
     {
         //kDebug(7007) << "Redirection to " << m_redirectionURL;
-        if (queryMetaData("permanent-redirect")=="true")
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
-
         if (d->m_redirectionHandlingEnabled)
         {
             d->staticData.truncate(0);
@@ -2268,8 +1852,6 @@ void FileCopyJobPrivate::slotCanResume( KIO::Job* job, KIO::filesize_t offset )
         {
             m_getJob = KIO::get( m_src, NoReload, HideProgressInfo /* no GUI */ );
             //kDebug(7007) << "m_getJob=" << m_getJob << m_src;
-            m_getJob->addMetaData( "errorPage", "false" );
-            m_getJob->addMetaData( "AllowCompressedPage", "false" );
             // Set size in subjob. This helps if the slave doesn't emit totalSize.
             if ( m_sourceSize != (KIO::filesize_t)-1 )
                 m_getJob->setTotalAmount(KJob::Bytes, m_sourceSize);
@@ -2522,7 +2104,6 @@ public:
     void slotListEntries( const KIO::UDSEntryList& list );
     void slotRedirection( const KUrl &url );
     void gotEntries( KIO::Job * subjob, const KIO::UDSEntryList& list );
-    void slotSubError( ListJob* job, ListJob* subJob);
 
     Q_DECLARE_PUBLIC(ListJob)
 
@@ -2602,8 +2183,6 @@ void ListJobPrivate::slotListEntries( const KIO::UDSEntryList& list )
                     Scheduler::setJobPriority(job, 1);
                     q->connect(job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
                                SLOT(gotEntries(KIO::Job*,KIO::UDSEntryList)));
-                    q->connect(job, SIGNAL(subError(KIO::ListJob*,KIO::ListJob*)),
-                               SLOT(slotSubError(KIO::ListJob*,KIO::ListJob*)));
                     q->addSubjob(job);
                 }
             }
@@ -2619,14 +2198,9 @@ void ListJobPrivate::slotListEntries( const KIO::UDSEntryList& list )
         // cull the unwanted hidden dirs and/or parent dir references from the listing, then emit that
         UDSEntryList newlist;
 
-        UDSEntryList::const_iterator it = list.begin();
-        const UDSEntryList::const_iterator end = list.end();
-        for (; it != end; ++it) {
-
-            // Modify the name in the UDSEntry
-            UDSEntry newone = *it;
-            const QString filename = newone.stringValue( KIO::UDSEntry::UDS_NAME );
-            QString displayName = newone.stringValue(KIO::UDSEntry::UDS_DISPLAY_NAME);
+        foreach (KIO::UDSEntry entry, list) {
+            const QString filename = entry.stringValue( KIO::UDSEntry::UDS_NAME );
+            QString displayName = entry.stringValue(KIO::UDSEntry::UDS_DISPLAY_NAME);
             if (displayName.isEmpty())
                 displayName = filename;
             // Avoid returning entries like subdir/. and subdir/.., but include . and .. for
@@ -2635,9 +2209,9 @@ void ListJobPrivate::slotListEntries( const KIO::UDSEntryList& list )
                   && (includeHidden || (filename[0] != '.') )  )
             {
                 // ## Didn't find a way to use the iterator instead of re-doing a key lookup
-                newone.insert( KIO::UDSEntry::UDS_NAME, m_prefix + filename );
-                newone.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, m_displayPrefix + displayName);
-                newlist.append(newone);
+                entry.insert( KIO::UDSEntry::UDS_NAME, m_prefix + filename );
+                entry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, m_displayPrefix + displayName);
+                newlist.append(entry);
             }
         }
 
@@ -2652,17 +2226,8 @@ void ListJobPrivate::gotEntries(KIO::Job *, const KIO::UDSEntryList& list )
     emit q->entries(q, list);
 }
 
-void ListJobPrivate::slotSubError(KIO::ListJob* /*job*/, KIO::ListJob* subJob)
-{
-    Q_Q(ListJob);
-
-    emit q->subError(q, subJob); /*Let the signal of subError go up */
-}
-
 void ListJob::slotResult( KJob * job )
 {
-    Q_D(ListJob);
-
     if (job->error()) {
 	// If we can't list a subdir, the result is still ok
 	// This is why we override KCompositeJob::slotResult - to not set
@@ -2671,18 +2236,13 @@ void ListJob::slotResult( KJob * job )
 	emit subError(this, static_cast<KIO::ListJob*>(job));
     }
     removeSubjob(job);
-    if (!hasSubjobs() && !d->m_slave) // if the main directory listing is still running, it will emit result in SimpleJob::slotFinished()
+    if (!hasSubjobs())
         emitResult();
 }
 
 void ListJobPrivate::slotRedirection( const KUrl & url )
 {
     Q_Q(ListJob);
-    if (!KAuthorized::authorizeUrlAction("redirect", m_url, url))
-    {
-        kWarning(7007) << "ListJob: Redirection from " << m_url << " to " << url << " REJECTED!";
-        return;
-    }
     m_redirectionURL = url; // We'll remember that when the job finishes
     emit q->redirection( q, m_redirectionURL );
 }
@@ -2691,26 +2251,9 @@ void ListJob::slotFinished()
 {
     Q_D(ListJob);
 
-    // Support for listing archives as directories
-    if ( error() == KIO::ERR_IS_FILE && d->m_url.isLocalFile() ) {
-        KMimeType::Ptr ptr = KMimeType::findByUrl( d->m_url, 0, true, true );
-        if ( ptr ) {
-            QString proto = ptr->property("X-KDE-LocalProtocol").toString();
-            if ( !proto.isEmpty() && KProtocolInfo::isKnownProtocol( proto) ) {
-                d->m_redirectionURL = d->m_url;
-                d->m_redirectionURL.setProtocol( proto );
-                setError( 0 );
-                emit redirection(this,d->m_redirectionURL);
-            }
-        }
-    }
-
     if ( !d->m_redirectionURL.isEmpty() && d->m_redirectionURL.isValid() && !error() ) {
 
         //kDebug(7007) << "Redirection to " << d->m_redirectionURL;
-        if (queryMetaData("permanent-redirect")=="true")
-            emit permanentRedirection(this, d->m_url, d->m_redirectionURL);
-
         if ( d->m_redirectionHandlingEnabled ) {
             d->m_packedArgs.truncate(0);
             QDataStream stream( &d->m_packedArgs, QIODevice::WriteOnly );
@@ -2725,13 +2268,6 @@ void ListJob::slotFinished()
     SimpleJob::slotFinished();
 }
 
-void ListJob::slotMetaData( const KIO::MetaData &_metaData)
-{
-    Q_D(ListJob);
-    SimpleJob::slotMetaData(_metaData);
-    storeSSLSessionFromJob(d->m_redirectionURL);
-}
-
 ListJob *KIO::listDir( const KUrl& url, JobFlags flags, bool includeHidden )
 {
     return ListJobPrivate::newJob(url, false, QString(), QString(), includeHidden, flags);
@@ -2742,26 +2278,9 @@ ListJob *KIO::listRecursive( const KUrl& url, JobFlags flags, bool includeHidden
     return ListJobPrivate::newJob(url, true, QString(), QString(), includeHidden, flags);
 }
 
-void ListJob::setUnrestricted(bool unrestricted)
-{
-    Q_D(ListJob);
-    if (unrestricted)
-        d->m_extraFlags |= JobPrivate::EF_ListJobUnrestricted;
-    else
-        d->m_extraFlags &= ~JobPrivate::EF_ListJobUnrestricted;
-}
-
 void ListJobPrivate::start(Slave *slave)
 {
     Q_Q(ListJob);
-    if (!KAuthorized::authorizeUrlAction("list", m_url, m_url) &&
-        !(m_extraFlags & EF_ListJobUnrestricted))
-    {
-        q->setError( ERR_ACCESS_DENIED );
-        q->setErrorText( m_url.url() );
-        QTimer::singleShot(0, q, SLOT(slotFinished()) );
-        return;
-    }
     q->connect( slave, SIGNAL(listEntries(KIO::UDSEntryList)),
              SLOT(slotListEntries(KIO::UDSEntryList)));
     q->connect( slave, SIGNAL(totalSize(KIO::filesize_t)),
@@ -2777,237 +2296,7 @@ const KUrl& ListJob::redirectionUrl() const
     return d_func()->m_redirectionURL;
 }
 
-////
-
-class KIO::MultiGetJobPrivate: public KIO::TransferJobPrivate
-{
-public:
-    MultiGetJobPrivate(const KUrl& url)
-        : TransferJobPrivate(url, 0, QByteArray(), QByteArray()),
-          m_currentEntry( 0, KUrl(), MetaData() )
-    {}
-    struct GetRequest {
-        GetRequest(long _id, const KUrl &_url, const MetaData &_metaData)
-            : id(_id), url(_url), metaData(_metaData) { }
-        long id;
-        KUrl url;
-        MetaData metaData;
-
-        inline bool operator==( const GetRequest& req ) const
-            { return req.id == id; }
-    };
-    typedef QLinkedList<GetRequest> RequestQueue;
-
-    RequestQueue m_waitQueue;
-    RequestQueue m_activeQueue;
-    GetRequest m_currentEntry;
-    bool b_multiGetActive;
-
-    /**
-     * @internal
-     * Called by the scheduler when a @p slave gets to
-     * work on this job.
-     * @param slave the slave that starts working on this job
-     */
-    virtual void start(Slave *slave);
-
-    bool findCurrentEntry();
-    void flushQueue(QLinkedList<GetRequest> &queue);
-
-    Q_DECLARE_PUBLIC(MultiGetJob)
-
-    static inline MultiGetJob *newJob(const KUrl &url)
-    {
-        MultiGetJob *job = new MultiGetJob(*new MultiGetJobPrivate(url));
-        job->setUiDelegate(new JobUiDelegate);
-        return job;
-    }
-};
-
-MultiGetJob::MultiGetJob(MultiGetJobPrivate &dd)
-    : TransferJob(dd)
-{
-}
-
-MultiGetJob::~MultiGetJob()
-{
-}
-
-void MultiGetJob::get(long id, const KUrl &url, const MetaData &metaData)
-{
-   Q_D(MultiGetJob);
-   MultiGetJobPrivate::GetRequest entry(id, url, metaData);
-   entry.metaData["request-id"] = QString::number(id);
-   d->m_waitQueue.append(entry);
-}
-
-void MultiGetJobPrivate::flushQueue(RequestQueue &queue)
-{
-   // Use multi-get
-   // Scan all jobs in m_waitQueue
-   RequestQueue::iterator wqit = m_waitQueue.begin();
-   const RequestQueue::iterator wqend = m_waitQueue.end();
-   while ( wqit != wqend )
-   {
-      const GetRequest& entry = *wqit;
-      if ((m_url.protocol() == entry.url.protocol()) &&
-          (m_url.host() == entry.url.host()) &&
-          (m_url.port() == entry.url.port()) &&
-          (m_url.user() == entry.url.user()))
-      {
-         queue.append( entry );
-         wqit = m_waitQueue.erase( wqit );
-      }
-      else
-      {
-         ++wqit;
-      }
-   }
-   // Send number of URLs, (URL, metadata)*
-   KIO_ARGS << (qint32) queue.count();
-   RequestQueue::const_iterator qit = queue.begin();
-   const RequestQueue::const_iterator qend = queue.end();
-   for( ; qit != qend; ++qit )
-   {
-      stream << (*qit).url << (*qit).metaData;
-   }
-   m_packedArgs = packedArgs;
-   m_command = CMD_MULTI_GET;
-   m_outgoingMetaData.clear();
-}
-
-void MultiGetJobPrivate::start(Slave *slave)
-{
-   // Add first job from m_waitQueue and add it to m_activeQueue
-   GetRequest entry = m_waitQueue.takeFirst();
-   m_activeQueue.append(entry);
-
-   m_url = entry.url;
-
-   if (!entry.url.protocol().startsWith(QLatin1String("http")))
-   {
-      // Use normal get
-      KIO_ARGS << entry.url;
-      m_packedArgs = packedArgs;
-      m_outgoingMetaData = entry.metaData;
-      m_command = CMD_GET;
-      b_multiGetActive = false;
-   }
-   else
-   {
-      flushQueue(m_activeQueue);
-      b_multiGetActive = true;
-   }
-
-   TransferJobPrivate::start(slave); // Anything else to do??
-}
-
-bool MultiGetJobPrivate::findCurrentEntry()
-{
-   if (b_multiGetActive)
-   {
-      long id = m_incomingMetaData["request-id"].toLong();
-      RequestQueue::const_iterator qit = m_activeQueue.begin();
-      const RequestQueue::const_iterator qend = m_activeQueue.end();
-      for( ; qit != qend; ++qit )
-      {
-         if ((*qit).id == id)
-         {
-            m_currentEntry = *qit;
-            return true;
-         }
-      }
-      m_currentEntry.id = 0;
-      return false;
-   }
-   else
-   {
-      if ( m_activeQueue.isEmpty() )
-        return false;
-      m_currentEntry = m_activeQueue.first();
-      return true;
-   }
-}
-
-void MultiGetJob::slotRedirection( const KUrl &url)
-{
-  Q_D(MultiGetJob);
-  if (!d->findCurrentEntry()) return; // Error
-  if (!KAuthorized::authorizeUrlAction("redirect", d->m_url, url))
-  {
-     kWarning(7007) << "MultiGetJob: Redirection from " << d->m_currentEntry.url << " to " << url << " REJECTED!";
-     return;
-  }
-  d->m_redirectionURL = url;
-  get(d->m_currentEntry.id, d->m_redirectionURL, d->m_currentEntry.metaData); // Try again
-}
-
-
-void MultiGetJob::slotFinished()
-{
-  Q_D(MultiGetJob);
-  if (!d->findCurrentEntry()) return;
-  if (d->m_redirectionURL.isEmpty())
-  {
-     // No redirection, tell the world that we are finished.
-     emit result(d->m_currentEntry.id);
-  }
-  d->m_redirectionURL = KUrl();
-  setError( 0 );
-  d->m_incomingMetaData.clear();
-  d->m_activeQueue.removeAll(d->m_currentEntry);
-  if (d->m_activeQueue.count() == 0)
-  {
-     if (d->m_waitQueue.count() == 0)
-     {
-        // All done
-        TransferJob::slotFinished();
-     }
-     else
-     {
-        // return slave to pool
-        // fetch new slave for first entry in d->m_waitQueue and call start
-        // again.
-        d->slaveDone();
-
-        d->m_url = d->m_waitQueue.first().url;
-        if ((d->m_extraFlags & JobPrivate::EF_KillCalled) == 0) {
-            Scheduler::doJob(this);
-        }
-     }
-  }
-}
-
-void MultiGetJob::slotData( const QByteArray &_data)
-{
-    Q_D(MultiGetJob);
-    if(d->m_redirectionURL.isEmpty() || !d->m_redirectionURL.isValid() || error())
-        emit data(d->m_currentEntry.id, _data);
-}
-
-void MultiGetJob::slotMimetype( const QString &_mimetype )
-{
-  Q_D(MultiGetJob);
-  if (d->b_multiGetActive)
-  {
-     MultiGetJobPrivate::RequestQueue newQueue;
-     d->flushQueue(newQueue);
-     if (!newQueue.isEmpty())
-     {
-        d->m_activeQueue += newQueue;
-        d->m_slave->send( d->m_command, d->m_packedArgs );
-     }
-  }
-  if (!d->findCurrentEntry()) return; // Error, unknown request!
-  emit mimetype(d->m_currentEntry.id, _mimetype);
-}
-
-MultiGetJob *KIO::multi_get(long id, const KUrl &url, const MetaData &metaData)
-{
-    MultiGetJob * job = MultiGetJobPrivate::newJob(url);
-    job->get(id, url, metaData);
-    return job;
-}
+//
 
 class KIO::SpecialJobPrivate: public TransferJobPrivate
 {
@@ -3038,173 +2327,5 @@ QByteArray SpecialJob::arguments() const
     return d_func()->m_packedArgs;
 }
 
-// Never defined, never used - what's this code about?
-#ifdef CACHE_INFO
-CacheInfo::CacheInfo(const KUrl &url)
-{
-    m_url = url;
-}
-
-QString CacheInfo::cachedFileName()
-{
-   const QChar separator = '_';
-
-   QString CEF = m_url.path();
-
-   int p = CEF.find('/');
-
-   while(p != -1)
-   {
-      CEF[p] = separator;
-      p = CEF.find('/', p);
-   }
-
-   QString host = m_url.host().toLower();
-   CEF = host + CEF + '_';
-
-   QString dir = KProtocolManager::cacheDir();
-   if (dir[dir.length()-1] != '/')
-      dir += '/';
-
-   int l = m_url.host().length();
-   for(int i = 0; i < l; i++)
-   {
-      if (host[i].isLetter() && (host[i] != 'w'))
-      {
-         dir += host[i];
-         break;
-      }
-   }
-   if (dir[dir.length()-1] == '/')
-      dir += '0';
-
-   unsigned long hash = 0x00000000;
-   QString u = m_url.url().toLatin1();
-   for(int i = u.length(); i--;)
-   {
-      hash = (hash * 12211 + u[i]) % 2147483563;
-   }
-
-   QString hashString;
-   hashString.sprintf("%08lx", hash);
-
-   CEF = CEF + hashString;
-
-   CEF = dir + '/' + CEF;
-
-   return CEF;
-}
-
-QFile *CacheInfo::cachedFile()
-{
-#ifdef Q_WS_WIN
-   const char *mode = (readWrite ? "rb+" : "rb");
-#else
-   const char *mode = (readWrite ? "r+" : "r");
-#endif
-
-   FILE *fs = KDE::fopen(CEF, mode); // Open for reading and writing
-   if (!fs)
-      return 0;
-
-   char buffer[401];
-   bool ok = true;
-
-  // CacheRevision
-  if (ok && (!fgets(buffer, 400, fs)))
-      ok = false;
-   if (ok && (strcmp(buffer, CACHE_REVISION) != 0))
-      ok = false;
-
-   time_t date;
-   time_t currentDate = time(0);
-
-   // URL
-   if (ok && (!fgets(buffer, 400, fs)))
-      ok = false;
-   if (ok)
-   {
-      int l = strlen(buffer);
-      if (l>0)
-         buffer[l-1] = 0; // Strip newline
-      if (m_.url.url() != buffer)
-      {
-         ok = false; // Hash collision
-      }
-   }
-
-   // Creation Date
-   if (ok && (!fgets(buffer, 400, fs)))
-      ok = false;
-   if (ok)
-   {
-      date = (time_t) strtoul(buffer, 0, 10);
-      if (m_maxCacheAge && (difftime(currentDate, date) > m_maxCacheAge))
-      {
-         m_bMustRevalidate = true;
-         m_expireDate = currentDate;
-      }
-   }
-
-   // Expiration Date
-   m_cacheExpireDateOffset = KDE_ftell(fs);
-   if (ok && (!fgets(buffer, 400, fs)))
-      ok = false;
-   if (ok)
-   {
-      if (m_request.cache == CC_Verify)
-      {
-         date = (time_t) strtoul(buffer, 0, 10);
-         // After the expire date we need to revalidate.
-         if (!date || difftime(currentDate, date) >= 0)
-            m_bMustRevalidate = true;
-         m_expireDate = date;
-      }
-   }
-
-   // ETag
-   if (ok && (!fgets(buffer, 400, fs)))
-      ok = false;
-   if (ok)
-   {
-      m_etag = QString(buffer).trimmed();
-   }
-
-   // Last-Modified
-   if (ok && (!fgets(buffer, 400, fs)))
-      ok = false;
-   if (ok)
-   {
-      m_lastModified = QString(buffer).trimmed();
-   }
-
-   fclose(fs);
-
-   if (ok)
-      return fs;
-
-   unlink( QFile::encodeName(CEF) );
-   return 0;
-
-}
-
-void CacheInfo::flush()
-{
-    cachedFile().remove();
-}
-
-void CacheInfo::touch()
-{
-
-}
-void CacheInfo::setExpireDate(int);
-void CacheInfo::setExpireTimeout(int);
-
-
-int CacheInfo::creationDate();
-int CacheInfo::expireDate();
-int CacheInfo::expireTimeout();
-#endif
-
-#include "jobclasses.moc"
-#include "job_p.moc"
+#include "moc_jobclasses.cpp"
+#include "moc_job_p.cpp"
