@@ -114,7 +114,7 @@ namespace KIO {
     /**
      * Execute any command that is specific to one slave (protocol).
      *
-     * Examples are : HTTP POST, mount and unmount (kio_file)
+     * Examples are : mount and unmount (kio_file)
      *
      * @param url The URL isn't passed to the slave, but is used to know
      *        which slave to send it to :-)
@@ -150,17 +150,6 @@ namespace KIO {
      */
     KIO_EXPORT SimpleJob *unmount( const QString & point, JobFlags flags = DefaultFlags );
 
-    /**
-     * HTTP cache update
-     *
-     * @param url Url to update, protocol must be "http".
-     * @param no_cache If true, cache entry for @p url is deleted.
-     * @param expireDate Local machine time indicating when the entry is
-     * supposed to expire.
-     * @return the job handling the operation.
-     */
-    KIO_EXPORT SimpleJob *http_update_cache( const KUrl& url, bool no_cache, time_t expireDate);
-
     /**
      * Find all details for one file or directory.
      *
@@ -198,38 +187,6 @@ namespace KIO {
      */
     KIO_EXPORT StatJob * stat( const KUrl& url, KIO::StatJob::StatSide side,
                                short int details, JobFlags flags = DefaultFlags );
-    /**
-     * Find all details for one file or directory.
-     * This version of the call includes two additional booleans, @p sideIsSource and @p details.
-     *
-     * @param url the URL of the file
-     * @param sideIsSource is true when stating a source file (we will do a get on it if
-     * the stat works) and false when stating a destination file (target of a copy).
-     * The reason for this parameter is that in some cases the kioslave might not
-     * be able to determine a file's existence (e.g. HTTP doesn't allow it, FTP
-     * has issues with case-sensitivity on some systems).
-     * When the slave can't reliably determine the existence of a file, it will:
-     * @li be optimistic if sideIsSource=true, i.e. it will assume the file exists,
-     * and if it doesn't this will appear when actually trying to download it
-     * @li be pessimistic if sideIsSource=false, i.e. it will assume the file
-     * doesn't exist, to prevent showing "about to overwrite" errors to the user.
-     * If you simply want to check for existence without downloading/uploading afterwards,
-     * then you should use sideIsSource=false.
-     *
-     * @param details selects the level of details we want.
-     * By default this is 2 (all details wanted, including modification time, size, etc.),
-     * setDetails(1) is used when deleting: we don't need all the information if it takes
-     * too much time, no need to follow symlinks etc.
-     * setDetails(0) is used for very simple probing: we'll only get the answer
-     * "it's a file or a directory, or it doesn't exist". This is used by KRun.
-     * @param flags Can be HideProgressInfo here
-     * @return the job handling the operation.
-     */
-#ifndef KDE_NO_DEPRECATED
-    KIO_EXPORT_DEPRECATED StatJob * stat( const KUrl& url, bool sideIsSource,
-                                          short int details, JobFlags flags = DefaultFlags );
-#endif
-
     /**
      * Get (a.k.a. read).
      * This is the job to use in order to "download" a file into memory.
@@ -274,75 +231,11 @@ namespace KIO {
      * @param flags Can be HideProgressInfo, Overwrite and Resume here. WARNING:
      * Setting Resume means that the data will be appended to @p dest if @p dest exists.
      * @return the job handling the operation.
-     * @see multi_get()
+     * @see get()
      */
     KIO_EXPORT TransferJob *put( const KUrl& url, int permissions,
                                  JobFlags flags = DefaultFlags );
 
-    /**
-     * HTTP POST (for form data).
-     *
-     * Example:
-     * \code
-     *    job = KIO::http_post( url, postData, KIO::HideProgressInfo );
-     *    job->addMetaData("content-type", contentType );
-     *    job->addMetaData("referrer", referrerURL);
-     * \endcode
-     *
-     * @p postData is the data that you want to send and
-     * @p contentType is the complete HTTP header line that
-     * specifies the content's MIME type, for example
-     * "Content-Type: text/xml".
-     *
-     * You MUST specify content-type!
-     *
-     * Often @p contentType is
-     * "Content-Type: application/x-www-form-urlencoded" and
-     * the @p postData is then an ASCII string (without null-termination!)
-     * with characters like space, linefeed and percent escaped like %20,
-     * %0A and %25.
-     *
-     * @param url Where to write the data.
-     * @param postData Encoded data to post.
-     * @param flags Can be HideProgressInfo here
-     * @return the job handling the operation.
-     */
-    KIO_EXPORT TransferJob *http_post( const KUrl& url, const QByteArray &postData,
-                                       JobFlags flags = DefaultFlags );
-
-    /**
-     * HTTP POST.
-     *
-     * This function, unlike the one that accepts a QByteArray, accepts an IO device
-     * from which to read the encoded data to be posted to the server in order to
-     * to avoid holding the content of very large post requests, e.g. multimedia file
-     * uploads, in memory.
-     *
-     * @param url Where to write the data.
-     * @param postData Encoded data to post.
-     * @param size Size of the encoded post data.
-     * @param flags Can be HideProgressInfo here
-     * @return the job handling the operation.
-     *
-     * @since 4.7
-     */
-    KIO_EXPORT TransferJob *http_post( const KUrl& url, QIODevice* device,
-                                       qint64 size = -1, JobFlags flags = DefaultFlags );
-
-    /**
-     * HTTP DELETE.
-     *
-     * Though this function servers the same purpose as KIO::file_delete, unlike
-     * file_delete it accomodates HTTP sepecific actions such as redirections.
-     *
-     * @param src url resource to delete.
-     * @param flags Can be HideProgressInfo here
-     * @return the job handling the operation.
-     *
-     * @since 4.7.3
-     */
-    KIO_EXPORT TransferJob *http_delete( const KUrl& url, JobFlags flags = DefaultFlags );
-
     /**
      * Get (a.k.a. read), into a single QByteArray.
      * @see StoredTransferJob
@@ -368,45 +261,6 @@ namespace KIO {
     KIO_EXPORT StoredTransferJob *storedPut( const QByteArray& arr, const KUrl& url, int permissions,
                                              JobFlags flags = DefaultFlags );
 
-    /**
-     * HTTP POST (a.k.a. write) data from a single QByteArray.
-     * @see StoredTransferJob
-     *
-     * @param arr The data to write
-     * @param url Where to write data.
-     * @param flags Can be HideProgressInfo here.
-     * @return the job handling the operation.
-     * @since 4.2
-     */
-    KIO_EXPORT StoredTransferJob *storedHttpPost( const QByteArray& arr, const KUrl& url,
-                                                  JobFlags flags = DefaultFlags );
-    /**
-     * HTTP POST (a.k.a. write) data from the given IO device.
-     * @see StoredTransferJob
-     *
-     * @param device Device from which the encoded data to be posted is read.
-     * @param url Where to write data.
-     * @param size Size of the encoded data to be posted.
-     * @param flags Can be HideProgressInfo here.
-     * @return the job handling the operation.
-     *
-     * @since 4.7
-     */
-    KIO_EXPORT StoredTransferJob *storedHttpPost( QIODevice* device, const KUrl& url,
-                                                  qint64 size = -1, JobFlags flags = DefaultFlags );
-
-    /**
-     * Creates a new multiple get job.
-     *
-     * @param id the id of the get operation
-     * @param url the URL of the file
-     * @param metaData the MetaData associated with the file
-     *
-     * @return the job handling the operation.
-     * @see get()
-     */
-    KIO_EXPORT MultiGetJob *multi_get( long id, const KUrl &url, const MetaData &metaData);
-
     /**
      * Find mimetype for one file or directory.
      *
