@@ -29,6 +29,8 @@
 #include "jobuidelegate.h"
 #include "kjobtrackerinterface.h"
 
+#include <QtCore/qpointer.h>
+
 #define KIO_ARGS QByteArray packedArgs; QDataStream stream( &packedArgs, QIODevice::WriteOnly ); stream
 
 namespace KIO {
@@ -48,15 +50,13 @@ namespace KIO {
         enum { EF_TransferJobAsync    = (1 << 0),
                EF_TransferJobNeedData = (1 << 1),
                EF_TransferJobDataSent = (1 << 2),
-               EF_ListJobUnrestricted = (1 << 3),
-               EF_KillCalled          = (1 << 4) };
+               EF_KillCalled          = (1 << 3) };
 
         // Maybe we could use the QObject parent/child mechanism instead
         // (requires a new ctor, and moving the ctor code to some init()).
         Job* m_parentJob;
         int m_extraFlags;
         MetaData m_incomingMetaData;
-        MetaData m_internalMetaData;
         MetaData m_outgoingMetaData;
 
         inline KIO::JobUiDelegate *ui() const
@@ -189,8 +189,7 @@ namespace KIO {
                               const QString& buttonNo,
                               const QString& iconYes = QString(),
                               const QString& iconNo = QString(),
-                              const QString& dontAskAgainName = QString(),
-                              const KIO::MetaData& sslMetaData = KIO::MetaData());
+                              const QString& dontAskAgainName = QString());
 
         Q_DECLARE_PUBLIC(SimpleJob)
 
@@ -234,15 +233,6 @@ namespace KIO {
          */
         void redirection( KIO::Job *job, const KUrl &url );
 
-        /**
-         * Signals a permanent redirection.
-         * The redirection itself is handled internally.
-         * @param job the job that is redirected
-         * @param fromUrl the original URL
-         * @param toUrl the new URL
-         */
-        void permanentRedirection( KIO::Job *job, const KUrl &fromUrl, const KUrl &toUrl );
-
     protected Q_SLOTS:
         virtual void slotFinished();
 
@@ -260,27 +250,26 @@ namespace KIO {
         inline TransferJobPrivate(const KUrl& url, int command, const QByteArray &packedArgs,
                                   const QByteArray &_staticData)
             : SimpleJobPrivate(url, command, packedArgs),
-              m_internalSuspended(false), m_errorPage(false),
+              m_internalSuspended(false),
               staticData(_staticData), m_isMimetypeEmitted(false), m_subJob(0)
             { }
 
         inline TransferJobPrivate(const KUrl& url, int command, const QByteArray &packedArgs,
                                   QIODevice* ioDevice)
             : SimpleJobPrivate(url, command, packedArgs),
-              m_internalSuspended(false), m_errorPage(false),
+              m_internalSuspended(false),
               m_isMimetypeEmitted(false), m_subJob(0),
-              m_outgoingDataSource(QWeakPointer<QIODevice>(ioDevice))
+              m_outgoingDataSource(ioDevice)
             { }
 
         bool m_internalSuspended;
-        bool m_errorPage;
         QByteArray staticData;
         KUrl m_redirectionURL;
         KUrl::List m_redirectionList;
         QString m_mimetype;
         bool m_isMimetypeEmitted;
         TransferJob *m_subJob;
-        QWeakPointer<QIODevice> m_outgoingDataSource;
+        QPointer<QIODevice> m_outgoingDataSource;
 
         /**
          * Flow control. Suspend data processing from the slave.
@@ -305,9 +294,7 @@ namespace KIO {
          */
         virtual void slotDataReqFromDevice();
 
-        void slotErrorPage();
         void slotCanResume( KIO::filesize_t offset );
-        void slotPostRedirection();
         void slotNeedSubUrlData();
         void slotSubUrlData(KIO::Job*, const QByteArray &);
 
