@@ -23,13 +23,9 @@
 #define KIO_JOBCLASSES_H
 
 #include <QtCore/QObject>
-#include <QtCore/QLinkedList> // KDE5: remove
-#include <QtCore/QStringList>
-
 #include <kurl.h>
 #include <kio/global.h>
 #include <kio/udsentry.h>
-
 #include <kcompositejob.h>
 
 namespace KIO {
@@ -164,20 +160,6 @@ namespace KIO {
         QStringList detailedErrorStrings(const KUrl *reqUrl = 0L,
                                          int method = -1) const;
 
-        /**
-         * Display a dialog box to inform the user of the error given by
-         * this job.
-         * Only call if error is not 0, and only in the slot connected
-         * to result.
-         * @param parent the parent widget for the dialog box, can be 0 for
-         *        top-level
-         * @deprecated you should use job->ui()->setWindow(parent)
-         *             and job->ui()->showErrorMessage() instead
-         */
-#ifndef KDE_NO_DEPRECATED
-        KDE_DEPRECATED void showErrorDialog( QWidget *parent = 0 );
-#endif
-
         /**
          * Returns whether the user should be asked about things when the job
          * is unsure, like whether to overwrite existing files etc.
@@ -408,15 +390,6 @@ namespace KIO {
         virtual void slotMetaData( const KIO::MetaData &_metaData);
 
     protected:
-        /*
-         * Allow jobs that inherit SimpleJob and are aware
-         * of redirections to store the SSL session used.
-         * Retrieval is handled by SimpleJob::start
-         * @param m_redirectionURL Reference to redirection URL,
-         * used instead of m_url if not empty
-         */
-        void storeSSLSessionFromJob(const KUrl &m_redirectionURL);
-
         /**
          * Creates a new simple job. You don't need to use this constructor,
          * unless you create a new job that inherits from SimpleJob.
@@ -465,9 +438,6 @@ namespace KIO {
          * (e.g. with FTP).
          * @param source true for "source" mode, false for "dest" mode
          */
-#ifndef KDE_NO_DEPRECATED
-        KDE_DEPRECATED void setSide( bool source );
-#endif
 
         /**
          * Selects the level of @p details we want.
@@ -523,18 +493,8 @@ namespace KIO {
          */
         void redirection( KIO::Job *job, const KUrl &url );
 
-        /**
-         * Signals a permanent redirection.
-         * The redirection itself is handled internally.
-         * @param job the job that is redirected
-         * @param fromUrl the original URL
-         * @param toUrl the new URL
-         */
-        void permanentRedirection( KIO::Job *job, const KUrl &fromUrl, const KUrl &toUrl );
-
     protected Q_SLOTS:
         virtual void slotFinished();
-        virtual void slotMetaData( const KIO::MetaData &_metaData);
     protected:
         StatJob(StatJobPrivate &dd);
 
@@ -564,15 +524,6 @@ namespace KIO {
          */
         void setModificationTime( const QDateTime& mtime );
 
-        /**
-         * Checks whether we got an error page. This currently only happens
-         * with HTTP urls. Call this from your slot connected to result().
-         *
-         * @return true if we got an (HTML) error page from the server
-         * instead of what we asked for.
-         */
-        bool isErrorPage() const;
-
         /**
          * Enable the async data mode.
          * When async data is enabled, data should be provided to the job by
@@ -588,29 +539,6 @@ namespace KIO {
          */
         void sendAsyncData(const QByteArray &data);
 
-        /**
-         * When enabled, the job reports the amount of data that has been sent,
-         * instead of the amount of data that that has been received.
-         * @see slotProcessedSize
-         * @see slotSpeed
-         * @deprecated not needed, this is false for KIO::get and true for KIO::put,
-         *             automatically since KDE-4.2.1
-         */
-#ifndef KDE_NO_DEPRECATED
-        KDE_DEPRECATED void setReportDataSent(bool enabled);
-#endif
-
-        /**
-         *  Returns whether the job reports the amount of data that has been
-         *  sent (true), or whether the job reports the amount of data that
-         * has been received (false)
-         * @deprecated not needed, this is false for KIO::get and true for KIO::put,
-         *             automatically since KDE-4.2.1 (and not useful as public API)
-         */
-#ifndef KDE_NO_DEPRECATED
-        KDE_DEPRECATED bool reportDataSent() const;
-#endif
-
         /**
          * Call this in the slot connected to result,
          * and only after making sure no error happened.
@@ -671,15 +599,6 @@ namespace KIO {
          */
         void redirection( KIO::Job *job, const KUrl &url );
 
-        /**
-         * Signals a permanent redirection.
-         * The redirection itself is handled internally.
-         * @param job the job that emitted this signal
-         * @param fromUrl the original URL
-         * @param toUrl the new URL
-         */
-        void permanentRedirection( KIO::Job *job, const KUrl &fromUrl, const KUrl &toUrl );
-
         /**
          * Mimetype determined.
          * @param job the job that emitted this signal
@@ -703,14 +622,11 @@ namespace KIO {
         virtual void slotData( const QByteArray &data);
         virtual void slotDataReq();
         virtual void slotMimetype( const QString &mimetype );
-        virtual void slotMetaData( const KIO::MetaData &_metaData);
 
     protected:
         TransferJob(TransferJobPrivate &dd);
     private:
-        Q_PRIVATE_SLOT(d_func(), void slotErrorPage())
         Q_PRIVATE_SLOT(d_func(), void slotCanResume( KIO::filesize_t offset ))
-        Q_PRIVATE_SLOT(d_func(), void slotPostRedirection())
         Q_PRIVATE_SLOT(d_func(), void slotNeedSubUrlData())
         Q_PRIVATE_SLOT(d_func(), void slotSubUrlData(KIO::Job*, const QByteArray &))
         Q_PRIVATE_SLOT(d_func(), void slotDataReqFromDevice())
@@ -768,65 +684,6 @@ namespace KIO {
         Q_DECLARE_PRIVATE(StoredTransferJob)
     };
 
-    class MultiGetJobPrivate;
-    /**
-     * The MultiGetJob is a TransferJob that allows you to get
-     * several files from a single server. Don't create directly,
-     * but use KIO::multi_get() instead.
-     * @see KIO::multi_get()
-     */
-    class KIO_EXPORT MultiGetJob : public TransferJob {
-    Q_OBJECT
-
-    public:
-        virtual ~MultiGetJob();
-
-        /**
-         * Get an additional file.
-         *
-         * @param id the id of the file
-         * @param url the url of the file to get
-         * @param metaData the meta data for this request
-         */
-        void get(long id, const KUrl &url, const MetaData &metaData);
-
-    Q_SIGNALS:
-        /**
-         * Data from the slave has arrived.
-         * @param id the id of the request
-         * @param data data received from the slave.
-         * End of data (EOD) has been reached if data.size() == 0
-         */
-        void data( long id, const QByteArray &data);
-
-        /**
-         * Mimetype determined
-         * @param id the id of the request
-         * @param type the mime type
-         */
-        void mimetype( long id, const QString &type );
-
-        /**
-         * File transfer completed.
-         *
-         * When all files have been processed, result(KJob *) gets
-         * emitted.
-         * @param id the id of the request
-         */
-        void result( long id);
-
-    protected Q_SLOTS:
-        virtual void slotRedirection( const KUrl &url);
-        virtual void slotFinished();
-        virtual void slotData( const QByteArray &data);
-        virtual void slotMimetype( const QString &mimetype );
-
-    protected:
-        MultiGetJob(MultiGetJobPrivate &dd);
-    private:
-        Q_DECLARE_PRIVATE(MultiGetJob)
-    };
-
     class MimetypeJobPrivate;
     /**
      * A MimetypeJob is a TransferJob that  allows you to get
@@ -946,11 +803,6 @@ namespace KIO {
          */
         const KUrl& redirectionUrl() const;
 
-        /**
-         * Do not apply any KIOSK restrictions to this job.
-         */
-        void setUnrestricted(bool unrestricted);
-
     Q_SIGNALS:
         /**
          * This signal emits the entry found by the job while listing.
@@ -963,6 +815,15 @@ namespace KIO {
          */
         void entries( KIO::Job *job, const KIO::UDSEntryList& list); // TODO KDE5: use KIO::ListJob* argument to avoid casting
 
+        /**
+        * This signal is emitted when a sub-directory could not be listed.
+        * The job keeps going, thus doesn't result in an overall error.
+        * @param job the job that emitted the signal
+        * @param subJob the job listing a sub-directory, which failed. Use
+        * url(), error() and errorText() on that job to find out more.
+        */
+        void subError( KIO::ListJob *job, KIO::ListJob *subJob );
+
         /**
          * Signals a redirection.
          * Use to update the URL shown to the user.
@@ -972,18 +833,8 @@ namespace KIO {
          */
         void redirection( KIO::Job *job, const KUrl &url );
 
-        /**
-         * Signals a permanent redirection.
-         * The redirection itself is handled internally.
-         * @param job the job that emitted this signal
-         * @param fromUrl the original URL
-         * @param toUrl the new URL
-         */
-        void permanentRedirection( KIO::Job *job, const KUrl &fromUrl, const KUrl &toUrl );
-
     protected Q_SLOTS:
         virtual void slotFinished( );
-        virtual void slotMetaData( const KIO::MetaData &_metaData);
         virtual void slotResult( KJob *job );
 
     protected:
