@@ -2,6 +2,7 @@
     Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
                        David Faure <faure@kde.org>
     Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
+    Copyright (C) 2013 Dawit Alemayehu <adawit@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -25,6 +26,7 @@
 #include <kdialogjobuidelegate.h>
 #include <kio/skipdialog.h>
 #include <kio/renamedialog.h>
+#include <kio/global.h>
 
 class KJob;
 namespace KIO
@@ -127,6 +129,45 @@ public:
     bool askDeleteConfirmation(const KUrl::List& urls, DeletionType deletionType,
                                ConfirmationType confirmationType);
 
+    /**
+    * Message box types.
+    *
+    * Should be kept in sync with SlaveBase::MessageBoxType.
+    *
+    * @since 4.11
+    *
+    * @internal
+    */
+    enum MessageBoxType {
+        QuestionYesNo = 1,
+        WarningYesNo = 2,
+        WarningContinueCancel = 3,
+        WarningYesNoCancel = 4,
+        Information = 5
+    };
+    /**
+    * This function allows for the delegation user prompts from the ioslaves.
+    *
+    * @param type the desired type of message box.
+    * @param text the message shown to the user.
+    * @param caption the caption of the message dialog box.
+    * @param buttonYes the text for the YES button.
+    * @param buttonNo the text for the NO button.
+    * @param iconYes the icon shown on the YES button.
+    * @param iconNo the icon shown on the NO button.
+    * @param dontAskAgainName the name used to store result from 'Do not ask again' checkbox.
+    *
+    * @since 4.11
+    *
+    * @internal
+    */
+    int requestMessageBox(MessageBoxType type, const QString& text,
+                          const QString& caption,
+                          const QString& buttonYes,
+                          const QString& buttonNo,
+                          const QString& iconYes = QString(),
+                          const QString& iconNo = QString(),
+                          const QString& dontAskAgainName = QString());
 private:
     class Private;
     Private * const d;
