@@ -23,7 +23,9 @@
 #include "kdirlister.h"
 #include "kdirlister_p.h"
 
+#include <QtCore/QList>
 #include <QtCore/QRegExp>
+#include <QtCore/qcoreapplication.h>
 
 #include <kdebug.h>
 #include <kde_file.h>
@@ -56,10 +58,6 @@ KDirListerCache::KDirListerCache()
 
   connect( KDirWatch::self(), SIGNAL(dirty(QString)),
            this, SLOT(slotFileDirty(QString)) );
-  connect( KDirWatch::self(), SIGNAL(created(QString)),
-           this, SLOT(slotFileCreated(QString)) );
-  connect( KDirWatch::self(), SIGNAL(deleted(QString)),
-           this, SLOT(slotFileDeleted(QString)) );
 
   kdirnotify = new org::kde::KDirNotify(QString(), QString(), QDBusConnection::sessionBus(), this);
   connect(kdirnotify, SIGNAL(FileRenamed(QString,QString)), SLOT(slotFileRenamed(QString,QString)));
@@ -82,8 +80,7 @@ KDirListerCache::~KDirListerCache()
     itemsCached.clear();
     directoryData.clear();
 
-    if ( KDirWatch::exists() )
-        KDirWatch::self()->disconnect( this );
+    KDirWatch::self()->disconnect( this );
 }
 
 // setting _reload to true will emit the old files and
@@ -496,10 +493,8 @@ void KDirListerCache::stopListJob(const QString& url, bool silent)
 void KDirListerCache::setAutoUpdate( KDirLister *lister, bool enable )
 {
     // IMPORTANT: this method does not check for the current autoUpdate state!
-
-    for ( KUrl::List::const_iterator it = lister->d->lstDirs.constBegin();
-          it != lister->d->lstDirs.constEnd(); ++it ) {
-        DirItem* dirItem = itemsInUse.value((*it).url());
+    foreach(const KUrl it, lister->d->lstDirs) {
+        DirItem* dirItem = itemsInUse.value(it.url());
         Q_ASSERT(dirItem);
         if ( enable )
             dirItem->incAutoUpdate();
@@ -521,9 +516,8 @@ void KDirListerCache::forgetDirs( KDirLister *lister )
     lister->d->lstDirs.clear();
 
     //kDebug() << "Iterating over dirs" << lstDirsCopy;
-    for ( KUrl::List::const_iterator it = lstDirsCopy.begin();
-          it != lstDirsCopy.end(); ++it ) {
-        forgetDirs( lister, *it, false );
+    foreach ( const KUrl it, lstDirsCopy ) {
+        forgetDirs( lister, it, false );
     }
 }
 
@@ -806,9 +800,8 @@ KFileItem KDirListerCache::findByName( const KDirLister *lister, const QString&
 {
     Q_ASSERT(lister);
 
-    for (KUrl::List::const_iterator it = lister->d->lstDirs.constBegin();
-         it != lister->d->lstDirs.constEnd(); ++it) {
-        DirItem* dirItem = itemsInUse.value((*it).url());
+    foreach(const KUrl it, lister->d->lstDirs) {
+        DirItem* dirItem = itemsInUse.value(it.url());
         Q_ASSERT(dirItem);
         const KFileItem item = dirItem->lstItems.findByName(_name);
         if (!item.isNull())
@@ -910,8 +903,9 @@ void KDirListerCache::slotFilesRemoved(const KUrl::List& fileList)
         }
     }
 
-    QMap<QString, KFileItemList>::const_iterator rit = removedItemsByDir.constBegin();
-    for(; rit != removedItemsByDir.constEnd(); ++rit) {
+    QMapIterator<QString, KFileItemList> rit(removedItemsByDir);
+    while(rit.hasNext()) {
+        rit.next();
         // Tell the views about it before calling deleteDir.
         // They might need the subdirs' file items (see the dirtree).
         DirectoryDataHash::const_iterator dit = directoryData.constFind(rit.key());
@@ -1082,7 +1076,7 @@ QStringList KDirListerCache::directoriesForCanonicalPath(const QString& dir) con
 // but it can also be called for a file.
 void KDirListerCache::slotFileDirty( const QString& path )
 {
-    kDebug(7004) << path;
+    // kDebug(7004) << path;
 
     KUrl url(path);
     url.adjustPath(KUrl::RemoveTrailingSlash);
@@ -1159,27 +1153,6 @@ void KDirListerCache::handleFileDirty(const KUrl& url)
     }
 }
 
-void KDirListerCache::slotFileCreated( const QString& path ) // from KDirWatch
-{
-    kDebug(7004) << path;
-    // XXX: how to avoid a complete rescan here?
-    // We'd need to stat that one file separately and refresh the item(s) for it.
-    KUrl fileUrl(path);
-    slotFilesAdded(fileUrl.directory());
-}
-
-void KDirListerCache::slotFileDeleted( const QString& path ) // from KDirWatch
-{
-    kDebug(7004) << path;
-    KUrl u( path );
-    QStringList fileUrls;
-    Q_FOREACH(KUrl url, directoriesForCanonicalPath(u.directory())) {
-        url.addPath(u.fileName());
-        fileUrls << url.url();
-    }
-    slotFilesRemoved(fileUrls);
-}
-
 void KDirListerCache::slotEntries( KIO::Job *job, const KIO::UDSEntryList &entries )
 {
     KUrl url(joburl( static_cast<KIO::ListJob *>(job) ));
@@ -1548,7 +1521,7 @@ void KDirListerCache::renameDir( const KUrl &oldUrl, const KUrl &newUrl )
     //DirItem *dir = itemsInUse.take( oldUrlStr );
     //emitRedirections( oldUrl, url );
 
-    QLinkedList<ItemInUseChange> itemsToChange;
+    QList<ItemInUseChange> itemsToChange;
     QSet<KDirLister *> listers;
 
     // Look at all dirs being listed/shown
@@ -1591,7 +1564,6 @@ void KDirListerCache::renameDir( const KUrl &oldUrl, const KUrl &newUrl )
 
                 listers |= emitRefreshItem(oldItem, *kit);
             }
-            emitRedirections( oldDirUrl, newDirUrl );
         }
     }
 
@@ -1605,6 +1577,10 @@ void KDirListerCache::renameDir( const KUrl &oldUrl, const KUrl &newUrl )
         itemsInUse.remove(i.oldUrl);
         itemsInUse.insert(i.newUrl, i.dirItem);
     }
+    //Now that all the caches are updated and consistent, emit the redirection.
+    foreach(const ItemInUseChange& i, itemsToChange) {
+        emitRedirections(i.oldUrl, i.newUrl);
+    }
 
     // Is oldUrl a directory in the cache?
     // Remove any child of oldUrl from the cache - even if the renamed dir itself isn't in it!
@@ -1733,6 +1709,7 @@ void KDirListerCache::slotUpdateResult( KJob * j )
         printDebug();
 #endif
         Q_ASSERT(dir);
+        return;
     } else {
         dir->complete = true;
     }
@@ -1938,7 +1915,6 @@ void KDirListerCache::deleteDir( const KUrl& dirUrl )
                 {
                     // tell the view first. It might need the subdirs' items (which forgetDirs will delete)
                     if ( !kdl->d->rootFileItem.isNull() ) {
-                        emit kdl->deleteItem( kdl->d->rootFileItem );
                         emit kdl->itemsDeleted(KFileItemList() << kdl->d->rootFileItem);
                     }
                     forgetDirs( kdl );
@@ -2223,9 +2199,6 @@ void KDirLister::Private::emitChanges()
         }
         if (!deletedItems.isEmpty()) {
             emit m_parent->itemsDeleted(deletedItems);
-            // for compat
-            Q_FOREACH(const KFileItem& item, deletedItems)
-                emit m_parent->deleteItem(item);
         }
         emitItems();
     }
@@ -2542,10 +2515,7 @@ void KDirLister::Private::emitItemsDeleted(const KFileItemList &_items)
     QMutableListIterator<KFileItem> it(items);
     while (it.hasNext()) {
         const KFileItem& item = it.next();
-        if (isItemVisible(item) && m_parent->matchesMimeFilter(item)) {
-            // for compat
-            emit m_parent->deleteItem(item);
-        } else {
+        if (!(isItemVisible(item) && m_parent->matchesMimeFilter(item))) {
             it.remove();
         }
     }
@@ -2785,5 +2755,5 @@ KFileItem KDirLister::cachedItemForUrl(const KUrl& url)
     return kDirListerCache->itemForUrl(url);
 }
 
-#include "kdirlister.moc"
-#include "kdirlister_p.moc"
+#include "moc_kdirlister.cpp"
+#include "moc_kdirlister_p.cpp"
