@@ -20,6 +20,7 @@
 #include "kdirmodel.h"
 #include "kdirlister.h"
 #include "kfileitem.h"
+#include "kuiserver_interface.h"
 #include <kdatetime.h>
 #include <kicon.h>
 #include <klocale.h>
@@ -27,23 +28,26 @@
 #include <kio/copyjob.h>
 #include <kio/fileundomanager.h>
 #include <kio/jobuidelegate.h>
-#include <kio/joburlcache_p.h>
 #include <kurl.h>
 #include <kdebug.h>
 #include <QMimeData>
 #include <QFile>
 #include <QFileInfo>
+#include <QBitArray>
 #include <QDir>
+#include <QApplication>
+
 #include <sys/types.h>
 #include <dirent.h>
 
-#ifdef Q_WS_WIN
-#include <windows.h>
-#endif
-
 class KDirModelNode;
 class KDirModelDirNode;
 
+K_GLOBAL_STATIC_WITH_ARGS(
+    org::kde::kuiserver, globalJobViewServer,
+    ("org.kde.kuiserver", "/JobViewServer", QDBusConnection::sessionBus(), qApp)
+);
+
 static KUrl cleanupUrl(const KUrl& url) {
     KUrl u = url;
     u.cleanPath(); // remove double slashes in the path, simplify "foo/." to "foo/", etc.
@@ -100,6 +104,7 @@ public:
     void setChildCount(int count) { m_childCount = count; }
     bool isPopulated() const { return m_populated; }
     void setPopulated( bool populated ) { m_populated = populated; }
+    bool isSlow() const { return item().isSlow(); }
 
     // For removing all child urls from the global hash.
     void collectAllChildUrls(KUrl::List &urls) const {
@@ -346,12 +351,12 @@ void KDirModel::setDirLister(KDirLister* dirLister)
              this, SLOT(_k_slotNewItems(KUrl,KFileItemList)) );
     connect( d->m_dirLister, SIGNAL(itemsDeleted(KFileItemList)),
              this, SLOT(_k_slotDeleteItems(KFileItemList)) );
-    connect( d->m_dirLister, SIGNAL(refreshItems(QList<QPair<KFileItem, KFileItem> >)),
-             this, SLOT(_k_slotRefreshItems(QList<QPair<KFileItem, KFileItem> >)) );
+    connect( d->m_dirLister, SIGNAL(refreshItems(QList<QPair<KFileItem,KFileItem> >)),
+             this, SLOT(_k_slotRefreshItems(QList<QPair<KFileItem,KFileItem> >)) );
     connect( d->m_dirLister, SIGNAL(clear()),
              this, SLOT(_k_slotClear()) );
-    connect(d->m_dirLister, SIGNAL(redirection(KUrl, KUrl)),
-            this, SLOT(_k_slotRedirection(KUrl, KUrl)));
+    connect(d->m_dirLister, SIGNAL(redirection(KUrl,KUrl)),
+            this, SLOT(_k_slotRedirection(KUrl,KUrl)));
 }
 
 KDirLister* KDirModel::dirLister() const
@@ -398,13 +403,11 @@ void KDirModelPrivate::_k_slotNewItems(const KUrl& directoryUrl, const KFileItem
 
     QList<QModelIndex> emitExpandFor;
 
-    KFileItemList::const_iterator it = items.begin();
-    KFileItemList::const_iterator end = items.end();
-    for ( ; it != end ; ++it ) {
-        const bool isDir = it->isDir();
+    foreach (const KFileItem it, items) {
+        const bool isDir = it.isDir();
         KDirModelNode* node = isDir
-                              ? new KDirModelDirNode( dirNode, *it )
-                              : new KDirModelNode( dirNode, *it );
+                              ? new KDirModelDirNode( dirNode, it )
+                              : new KDirModelNode( dirNode, it );
 #ifndef NDEBUG
         // Test code for possible duplication of items in the childnodes list,
         // not sure if/how it ever happened.
@@ -414,7 +417,7 @@ void KDirModelPrivate::_k_slotNewItems(const KUrl& directoryUrl, const KFileItem
         //             << "url=" << dirNode->m_childNodes.last()->item().url();
 #endif
         dirNode->m_childNodes.append(node);
-        const KUrl url = it->url();
+        const KUrl url = it.url();
         m_nodeHash.insert(cleanupUrl(url), node);
         //kDebug(7008) << url;
 
@@ -489,6 +492,11 @@ void KDirModelPrivate::_k_slotDeleteItems(const KFileItemList& items)
                 kWarning(7008) << "No node found for item that was just removed:" << url;
                 continue;
             }
+            if (!node->parent()) {
+                // The root node has been deleted, but it was not first in the list 'items'.
+                // see https://bugs.kde.org/show_bug.cgi?id=196695
+                return;
+            }
         }
         rowNumbers.setBit(node->rowNumber(), 1); // O(n)
         removeFromNodeHash(node, url);
@@ -703,30 +711,12 @@ QVariant KDirModel::data( const QModelIndex & index, int role ) const
             else {
                 KDirModelDirNode* dirNode = static_cast<KDirModelDirNode *>(node);
                 int count = dirNode->childCount();
-                if (count == ChildCountUnknown && item.isReadable()) {
+                if (count == ChildCountUnknown && item.isReadable() && !dirNode->isSlow()) {
                     const QString path = item.localPath();
                     if (!path.isEmpty()) {
 //                        slow
 //                        QDir dir(path);
 //                        count = dir.entryList(QDir::AllEntries|QDir::NoDotAndDotDot|QDir::System).count();
-#ifdef Q_WS_WIN
-                        QString s = path + QLatin1String( "\\*.*" );
-                        s.replace('/', '\\');
-                        count = 0;
-                        WIN32_FIND_DATA findData;
-                        HANDLE hFile = FindFirstFile( (LPWSTR)s.utf16(), &findData );
-                        if( hFile != INVALID_HANDLE_VALUE ) {
-                            do {
-                                if (!( findData.cFileName[0] == '.' &&
-                                       findData.cFileName[1] == '\0' ) &&
-                                    !( findData.cFileName[0] == '.' &&
-                                       findData.cFileName[1] == '.' &&
-                                       findData.cFileName[2] == '\0' ) )
-                                    ++count;
-                            } while( FindNextFile( hFile, &findData ) != 0 );
-                            FindClose( hFile );
-                        }
-#else
                         DIR* dir = ::opendir(QFile::encodeName(path));
                         if (dir) {
                             count = 0;
@@ -742,7 +732,6 @@ QVariant KDirModel::data( const QModelIndex & index, int role ) const
                             }
                             ::closedir(dir);
                         }
-#endif
                         //kDebug(7008) << "child count for " << path << ":" << count;
                         dirNode->setChildCount(count);
                     }
@@ -776,10 +765,10 @@ bool KDirModel::setData( const QModelIndex & index, const QVariant & value, int
             KDirModelNode* node = static_cast<KDirModelNode*>(index.internalPointer());
             const KFileItem& item = node->item();
             const QString newName = value.toString();
-            if (newName.isEmpty() || newName == item.text())
+            if (newName.isEmpty() || newName == item.text() || (newName == QLatin1String(".")) || (newName == QLatin1String("..")))
                 return true;
             KUrl newurl(item.url());
-            newurl.setPath(newurl.directory(KUrl::AppendTrailingSlash) + newName);
+            newurl.setPath(newurl.directory(KUrl::AppendTrailingSlash) + KIO::encodeFileName(newName));
             KIO::Job * job = KIO::moveAs(item.url(), newurl, newurl.isLocalFile() ? KIO::HideProgressInfo : KIO::DefaultFlags);
             job->ui()->setAutoErrorHandlingEnabled(true);
             // undo handling
@@ -853,11 +842,14 @@ void KDirModel::requestSequenceIcon(const QModelIndex& index, int sequenceIndex)
 
 void KDirModel::setJobTransfersVisible(bool value)
 {
-    if(value) {
+    if (value) {
         d->m_jobTransfersVisible = true;
-        connect(&JobUrlCache::instance(), SIGNAL(jobUrlsChanged(QStringList)), this, SLOT(_k_slotJobUrlsChanged(QStringList)), Qt::UniqueConnection);
-
-        JobUrlCache::instance().requestJobUrlsChanged();
+        connect(
+            globalJobViewServer, SIGNAL(jobUrlsChanged(QStringList)),
+            this, SLOT(_k_slotJobUrlsChanged(QStringList)),
+            Qt::UniqueConnection
+        );
+        globalJobViewServer->emitJobUrlsChanged();
     } else {
         disconnect(this, SLOT(_k_slotJobUrlsChanged(QStringList)));
     }
@@ -924,9 +916,9 @@ QMimeData * KDirModel::mimeData( const QModelIndexList & indexes ) const
     QString application_x_qiconlist;
     const int items = urls.count();
     for (int i = 0; i < items; i++) {
-	const int offset = i*16;
-	QString tmp("%1$@@$%2$@@$32$@@$32$@@$%3$@@$%4$@@$32$@@$16$@@$no data$@@$");
-	application_x_qiconlist += tmp.arg(offset).arg(offset).arg(offset).arg(offset+40);
+        const int offset = i*16;
+        QString tmp("%1$@@$%2$@@$32$@@$32$@@$%3$@@$%4$@@$32$@@$16$@@$no data$@@$");
+        application_x_qiconlist += tmp.arg(offset).arg(offset).arg(offset).arg(offset+40);
     }
     data->setData("application/x-qiconlist", application_x_qiconlist.toLatin1());
 
@@ -943,12 +935,6 @@ KFileItem KDirModel::itemForIndex( const QModelIndex& index ) const
     }
 }
 
-QModelIndex KDirModel::indexForItem( const KFileItem* item ) const
-{
-    // Note that we can only use the URL here, not the pointer.
-    // KFileItems can be copied.
-    return indexForUrl(item->url()); // O(n)
-}
 
 QModelIndex KDirModel::indexForItem( const KFileItem& item ) const
 {
@@ -1032,7 +1018,7 @@ Qt::ItemFlags KDirModel::flags( const QModelIndex & index ) const
         } else {
             KFileItem item = itemForIndex(index);
             if (item.isNull()) {
-                kWarning(7007) << "Invalid item returned for index";
+                kWarning(7008) << "Invalid item returned for index";
             } else if (item.isDir()) {
                 if (d->m_dropsAllowed & DropOnDirectory) {
                     f |= Qt::ItemIsDropEnabled;
@@ -1139,24 +1125,4 @@ void KDirModel::expandToUrl(const KUrl& url)
     fetchMore(parentIndex);
 }
 
-bool KDirModel::insertRows(int , int, const QModelIndex&)
-{
-    return false;
-}
-
-bool KDirModel::insertColumns(int, int, const QModelIndex&)
-{
-    return false;
-}
-
-bool KDirModel::removeRows(int, int, const QModelIndex&)
-{
-    return false;
-}
-
-bool KDirModel::removeColumns(int, int, const QModelIndex&)
-{
-    return false;
-}
-
-#include "kdirmodel.moc"
+#include "moc_kdirmodel.cpp"
