@@ -21,24 +21,20 @@
 #include "kfileitem.h"
 
 #include <config.h>
-#include <config-kio.h>
 
 #include <sys/time.h>
-#include <pwd.h>
-#include <grp.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-
-#include <assert.h>
 #include <unistd.h>
 
-#include <QtCore/QDate>
+#include <QtCore/qdatetime.h>
 #include <QtCore/QDir>
 #include <QtCore/QFile>
 #include <QtCore/QMap>
 #include <QtGui/QApplication>
 #include <QtGui/QPalette>
-#include <QTextDocument>
+#include <QtDBus/QDBusInterface>
+#include <QtDBus/QDBusReply>
 
 #include <kdebug.h>
 #include <kfilemetainfo.h>
@@ -51,12 +47,23 @@
 #include <kdesktopfile.h>
 #include <kmountpoint.h>
 #include <kconfiggroup.h>
-#ifndef Q_OS_WIN
-#include <knfsshare.h>
-#include <ksambashare.h>
-#endif
+#include <kuser.h>
 #include <kfilesystemtype_p.h>
 
+static bool isKDirShare(const QString &dirpath)
+{
+    static QDBusInterface kdirshareiface(
+        QString::fromLatin1("org.kde.kded"),
+        QString::fromLatin1("/modules/kdirshare"),
+        QString::fromLatin1("org.kde.kdirshare")
+    );
+    QDBusReply<bool> kdirsharereply = kdirshareiface.call("isShared", dirpath);
+    if (!kdirsharereply.isValid()) {
+        return false;
+    }
+    return kdirsharereply.value();
+}
+
 class KFileItemPrivate : public QSharedData
 {
 public:
@@ -197,9 +204,6 @@ public:
     // For special case like link to dirs over FTP
     QString m_guessedMimeType;
     mutable QString m_access;
-#ifndef KDE_NO_DEPRECATED
-    QMap<const void*, void*> m_extra; // DEPRECATED
-#endif
     mutable KFileMetaInfo m_metaInfo;
 
     enum { NumFlags = KFileItem::CreationTime + 1 };
@@ -256,8 +260,8 @@ void KFileItemPrivate::readUDSEntry( bool _urlIsDirectory )
 {
     // extract fields from the KIO::UDS Entry
 
-    m_fileMode = m_entry.numberValue( KIO::UDSEntry::UDS_FILE_TYPE, KFileItem::Unknown );
-    m_permissions = m_entry.numberValue( KIO::UDSEntry::UDS_ACCESS, KFileItem::Unknown );
+    m_fileMode = m_entry.numberValue( KIO::UDSEntry::UDS_FILE_TYPE );
+    m_permissions = m_entry.numberValue( KIO::UDSEntry::UDS_ACCESS );
     m_strName = m_entry.stringValue( KIO::UDSEntry::UDS_NAME );
 
     const QString displayName = m_entry.stringValue( KIO::UDSEntry::UDS_DISPLAY_NAME );
@@ -285,7 +289,7 @@ void KFileItemPrivate::readUDSEntry( bool _urlIsDirectory )
     m_hidden = hiddenVal == 1 ? Hidden : ( hiddenVal == 0 ? Shown : Auto );
 
     // avoid creating these QStrings again and again
-    static const QString& dot = KGlobal::staticQString(".");
+    static const QString dot = QString::fromLatin1(".");
     if ( _urlIsDirectory && !UDS_URL_seen && !m_strName.isEmpty() && m_strName != dot )
         m_url.addPath( m_strName );
 
@@ -397,7 +401,7 @@ bool KFileItemPrivate::cmp( const KFileItemPrivate & item ) const
 inline //because it is used only in one place
 QString KFileItemPrivate::parsePermissions(mode_t perm) const
 {
-    static char buffer[ 12 ];
+    char buffer[ 12 ];
 
     char uxbit,gxbit,oxbit;
 
@@ -660,23 +664,6 @@ KDateTime KFileItem::time( FileTimes which ) const
     return d->time(which);
 }
 
-#ifndef KDE_NO_DEPRECATED
-time_t KFileItem::time( unsigned int which ) const
-{
-    if (!d)
-        return 0;
-
-    switch (which) {
-    case KIO::UDSEntry::UDS_ACCESS_TIME:
-        return d->time(AccessTime).toTime_t();
-    case KIO::UDSEntry::UDS_CREATION_TIME:
-        return d->time(CreationTime).toTime_t();
-    case KIO::UDSEntry::UDS_MODIFICATION_TIME:
-    default:
-        return d->time(ModificationTime).toTime_t();
-    }
-}
-#endif
 
 QString KFileItem::user() const
 {
@@ -690,21 +677,15 @@ QString KFileItemPrivate::user() const
 {
     QString userName = m_entry.stringValue(KIO::UDSEntry::UDS_USER);
     if (userName.isEmpty() && m_bIsLocalUrl) {
-#ifdef Q_WS_WIN
-        QFileInfo a(m_url.toLocalFile( KUrl::RemoveTrailingSlash ));
-        userName = a.owner();
-        m_entry.insert( KIO::UDSEntry::UDS_USER, userName );
-#else
         KDE_struct_stat buff;
         if ( KDE::lstat( m_url.toLocalFile( KUrl::RemoveTrailingSlash ), &buff ) == 0) // get uid/gid of the link, if it's a link
         {
-            struct passwd *pwuser = getpwuid( buff.st_uid );
-            if ( pwuser != 0 ) {
-                userName = QString::fromLocal8Bit(pwuser->pw_name);
+            const KUser kuser( buff.st_uid );
+            if ( kuser.isValid() ) {
+                userName = kuser.loginName();
                 m_entry.insert( KIO::UDSEntry::UDS_USER, userName );
             }
         }
-#endif
     }
     return userName;
 }
@@ -722,25 +703,17 @@ QString KFileItemPrivate::group() const
     QString groupName = m_entry.stringValue( KIO::UDSEntry::UDS_GROUP );
     if (groupName.isEmpty() && m_bIsLocalUrl )
     {
-#ifdef Q_WS_WIN
-        QFileInfo a(m_url.toLocalFile( KUrl::RemoveTrailingSlash ));
-        groupName = a.group();
-        m_entry.insert( KIO::UDSEntry::UDS_GROUP, groupName );
-#else
         KDE_struct_stat buff;
         if ( KDE::lstat( m_url.toLocalFile( KUrl::RemoveTrailingSlash ), &buff ) == 0) // get uid/gid of the link, if it's a link
         {
-            struct group *ge = getgrgid( buff.st_gid );
-            if ( ge != 0 ) {
-                groupName = QString::fromLocal8Bit(ge->gr_name);
-                if (groupName.isEmpty())
-                    groupName.sprintf("%d",ge->gr_gid);
+            const KUserGroup kusergroup( buff.st_gid );
+            if ( kusergroup.isValid() ) {
+                groupName = kusergroup.name();
             }
-            else
-                groupName.sprintf("%d",buff.st_gid);
+            if (groupName.isEmpty())
+                groupName = QString::number(buff.st_gid);
             m_entry.insert( KIO::UDSEntry::UDS_GROUP, groupName );
         }
-#endif
     }
     return groupName;
 }
@@ -783,7 +756,7 @@ KMimeType::Ptr KFileItem::determineMimeType() const
 
     if ( !d->m_pMimeType || !d->m_bMimeTypeKnown )
     {
-        bool isLocalUrl;
+        bool isLocalUrl = false;
         KUrl url = mostLocalUrl(isLocalUrl);
 
         d->m_pMimeType = KMimeType::findByUrl( url, d->m_fileMode, isLocalUrl );
@@ -831,7 +804,7 @@ QString KFileItem::mimeComment() const
 
     KMimeType::Ptr mType = determineMimeType();
 
-    bool isLocalUrl;
+    bool isLocalUrl = false;
     KUrl url = mostLocalUrl(isLocalUrl);
 
     KMimeType::Ptr mime = mimeTypePtr();
@@ -891,7 +864,7 @@ QString KFileItem::iconName() const
         return d->m_iconName;
     }
 
-    bool isLocalUrl;
+    bool isLocalUrl = false;
     KUrl url = mostLocalUrl(isLocalUrl);
 
     KMimeType::Ptr mime;
@@ -931,7 +904,7 @@ QString KFileItem::iconName() const
 static bool checkDesktopFile(const KFileItem& item, bool _determineMimeType)
 {
     // only local files
-    bool isLocal;
+    bool isLocal = false;
     const KUrl url = item.mostLocalUrl(isLocal);
     if (!isLocal)
         return false;
@@ -959,7 +932,8 @@ QStringList KFileItem::overlays() const
         names.append("emblem-symbolic-link");
     }
 
-    if (!isReadable()) {
+    if ( !S_ISDIR( d->m_fileMode ) // Locked dirs have a special icon, use the overlay for files only
+         && !isReadable()) {
         names.append("object-locked");
     }
 
@@ -987,17 +961,19 @@ QStringList KFileItem::overlays() const
         names.append("hidden");
     }
 
-#ifndef Q_OS_WIN
     if( S_ISDIR( d->m_fileMode ) && d->m_bIsLocalUrl)
     {
-        if (KSambaShare::instance()->isDirectoryShared( d->m_url.toLocalFile() ) ||
-            KNFSShare::instance()->isDirectoryShared( d->m_url.toLocalFile() ))
+        if (isKDirShare( d->m_url.toLocalFile() ))
         {
             //kDebug() << d->m_url.path();
             names.append("network-workgroup");
         }
     }
-#endif  // Q_OS_WIN
+
+    if ( d->m_pMimeType && d->m_url.fileName().endsWith( QLatin1String( ".gz" ) ) &&
+         d->m_pMimeType->is("application/x-gzip") ) {
+        names.append("application-zip");
+    }
 
     return names;
 }
@@ -1023,17 +999,11 @@ QPixmap KFileItem::pixmap( int _size, int _state ) const
     if (!d->m_pMimeType) {
         // No mimetype determined yet, go for a fast default icon
         if (S_ISDIR(d->m_fileMode)) {
-            static const QString * defaultFolderIcon = 0;
-            if ( !defaultFolderIcon ) {
-                const KMimeType::Ptr mimeType = KMimeType::mimeType( "inode/directory" );
-                if ( mimeType )
-                    defaultFolderIcon = &KGlobal::staticQString( mimeType->iconName() );
-               else
-                    kWarning(7000) << "No mimetype for inode/directory could be found. Check your installation.";
-            }
-            if ( defaultFolderIcon )
-                return DesktopIcon( *defaultFolderIcon, _size, _state );
-
+            const KMimeType::Ptr mimeType = KMimeType::mimeType( "inode/directory" );
+            if ( mimeType )
+                return DesktopIcon( mimeType->iconName(), _size, _state );
+            else
+                kWarning(7000) << "No mimetype for inode/directory could be found. Check your installation.";
         }
         return DesktopIcon( "unknown", _size, _state );
     }
@@ -1055,8 +1025,7 @@ QPixmap KFileItem::pixmap( int _size, int _state ) const
         mime = KMimeType::findByUrl( sf, 0, d->m_bIsLocalUrl );
     }
 
-    bool isLocalUrl;
-    KUrl url = mostLocalUrl(isLocalUrl);
+    KUrl url = mostLocalUrl();
 
     QPixmap p = KIconLoader::global()->loadMimeTypeIcon( mime->iconName( url ), KIconLoader::Desktop, _size, _state );
     //kDebug() << "finding pixmap for " << url.url() << " : " << mime->name();
@@ -1072,8 +1041,7 @@ bool KFileItem::isReadable() const
         return false;
 
     /*
-      struct passwd * user = getpwuid( geteuid() );
-      bool isMyFile = (QString::fromLocal8Bit(user->pw_name) == d->m_user);
+      bool isMyFile = (KUser(KUser::UseEffectiveUID).loginName() == d->m_user);
       // This gets ugly for the group....
       // Maybe we want a static QString for the user and a static QStringList
       // for the groups... then we need to handle the deletion properly...
@@ -1102,8 +1070,7 @@ bool KFileItem::isWritable() const
         return false;
 
     /*
-      struct passwd * user = getpwuid( geteuid() );
-      bool isMyFile = (QString::fromLocal8Bit(user->pw_name) == d->m_user);
+      bool isMyFile = (KUser(KUser::UseEffectiveUID).loginName() == d->m_user);
       // This gets ugly for the group....
       // Maybe we want a static QString for the user and a static QStringList
       // for the groups... then we need to handle the deletion properly...
@@ -1159,28 +1126,6 @@ bool KFileItem::isFile() const
     return !isDir();
 }
 
-#ifndef KDE_NO_DEPRECATED
-bool KFileItem::acceptsDrops() const
-{
-    // A directory ?
-    if ( S_ISDIR( mode() ) ) {
-        return isWritable();
-    }
-
-    // But only local .desktop files and executables
-    if ( !d->m_bIsLocalUrl )
-        return false;
-
-    if ( mimetype() == "application/x-desktop")
-        return true;
-
-    // Executable, shell script ... ?
-    if ( QFileInfo(d->m_url.toLocalFile()).isExecutable() )
-        return true;
-
-    return false;
-}
-#endif
 
 QString KFileItem::getStatusBarInfo() const
 {
@@ -1213,86 +1158,6 @@ QString KFileItem::getStatusBarInfo() const
     return text;
 }
 
-#ifndef KDE_NO_DEPRECATED
-QString KFileItem::getToolTipText(int maxcount) const
-{
-    if (!d)
-        return QString();
-
-    // we can return QString() if no tool tip should be shown
-    QString tip;
-    KFileMetaInfo info = metaInfo();
-
-    // the font tags are a workaround for the fact that the tool tip gets
-    // screwed if the color scheme uses white as default text color
-    const QString colorName = QApplication::palette().color(QPalette::ToolTipText).name();
-    const QString start = "<tr><td align=\"right\"><nobr><font color=\"" + colorName + "\"><b>";
-    const QString mid = "&nbsp;</b></font></nobr></td><td><nobr><font color=\"" + colorName + "\">";
-    const char* end = "</font></nobr></td></tr>";
-
-    tip = "<table cellspacing=0 cellpadding=0>";
-
-    tip += start + i18n("Name:") + mid + text() + end;
-    tip += start + i18n("Type:") + mid;
-
-    QString type = Qt::escape(mimeComment());
-    if ( d->m_bLink ) {
-        tip += i18n("Link to %1 (%2)", linkDest(), type) + end;
-    } else
-        tip += type + end;
-
-    if ( !S_ISDIR ( d->m_fileMode ) )
-        tip += start + i18n("Size:") + mid +
-               QString("%1").arg(KIO::convertSize(size())) +
-               end;
-
-    tip += start + i18n("Modified:") + mid +
-           timeString( KFileItem::ModificationTime ) + end
-#ifndef Q_WS_WIN //TODO: show win32-specific permissions
-           +start + i18n("Owner:") + mid + user() + " - " + group() + end +
-           start + i18n("Permissions:") + mid +
-           permissionsString() + end
-#endif
-           ;
-
-    if (info.isValid())
-    {
-        const QStringList keys = info.preferredKeys();
-
-        // now the rest
-        QStringList::ConstIterator it = keys.begin();
-        for (int count = 0; count<maxcount && it!=keys.end() ; ++it)
-        {
-            if ( count == 0 )
-            {
-                tip += "<tr><td colspan=2><center><s>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</s></center></td></tr>";
-            }
-
-            KFileMetaInfoItem item = info.item( *it );
-            if ( item.isValid() )
-            {
-                QString s = item.value().toString();
-                if ( !s.isEmpty() )
-                {
-                    count++;
-                    tip += start +
-                           Qt::escape( item.name() ) + ':' +
-                           mid +
-                           Qt::escape( s ) +
-                           end;
-                }
-
-            }
-        }
-    }
-    tip += "</table>";
-
-    //kDebug() << "making this the tool tip rich text:\n";
-    //kDebug() << tip;
-
-    return tip;
-}
-#endif
 
 void KFileItem::run( QWidget* parentWidget ) const
 {
@@ -1331,74 +1196,14 @@ bool KFileItem::operator!=(const KFileItem& other) const
     return !operator==(other);
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KFileItem::setUDSEntry( const KIO::UDSEntry& _entry, const KUrl& _url,
-                             bool _delayedMimeTypes, bool _urlIsDirectory )
-{
-    if (!d)
-        return;
-
-    d->m_entry = _entry;
-    d->m_url = _url;
-    d->m_strName.clear();
-    d->m_strText.clear();
-    d->m_iconName.clear();
-    d->m_strLowerCaseName.clear();
-    d->m_pMimeType = 0;
-    d->m_fileMode = KFileItem::Unknown;
-    d->m_permissions = KFileItem::Unknown;
-    d->m_bMarked = false;
-    d->m_bLink = false;
-    d->m_bIsLocalUrl = _url.isLocalFile();
-    d->m_bMimeTypeKnown = false;
-    d->m_hidden = KFileItemPrivate::Auto;
-    d->m_guessedMimeType.clear();
-    d->m_metaInfo = KFileMetaInfo();
-    d->m_delayedMimeTypes = _delayedMimeTypes;
-    d->m_useIconNameCache = false;
-
-    d->readUDSEntry( _urlIsDirectory );
-    d->init();
-}
-#endif
 
 KFileItem::operator QVariant() const
 {
     return qVariantFromValue(*this);
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KFileItem::setExtraData( const void *key, void *value )
-{
-    if (!d)
-        return;
 
-    if ( !key )
-        return;
 
-    d->m_extra.insert( key, value ); // replaces the value of key if already there
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-const void * KFileItem::extraData( const void *key ) const
-{
-    if (!d)
-        return 0;
-
-    return d->m_extra.value( key, 0 );
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-void KFileItem::removeExtraData( const void *key )
-{
-    if (!d)
-        return;
-
-    d->m_extra.remove( key );
-}
-#endif
 
 QString KFileItem::permissionsString() const
 {
@@ -1420,23 +1225,6 @@ QString KFileItem::timeString( FileTimes which ) const
     return KGlobal::locale()->formatDateTime( d->time(which) );
 }
 
-#ifndef KDE_NO_DEPRECATED
-QString KFileItem::timeString( unsigned int which ) const
-{
-    if (!d)
-        return QString();
-
-    switch (which) {
-    case KIO::UDSEntry::UDS_ACCESS_TIME:
-        return timeString(AccessTime);
-    case KIO::UDSEntry::UDS_CREATION_TIME:
-        return timeString(CreationTime);
-    case KIO::UDSEntry::UDS_MODIFICATION_TIME:
-    default:
-        return timeString(ModificationTime);
-    }
-}
-#endif
 
 void KFileItem::setMetaInfo( const KFileMetaInfo & info ) const
 {
@@ -1451,21 +1239,14 @@ KFileMetaInfo KFileItem::metaInfo(bool autoget, int what) const
     if (!d)
         return KFileMetaInfo();
 
-    if ((isRegularFile() || isDir()) && autoget && !d->m_metaInfo.isValid())
+    if (isFile() && autoget && !d->m_metaInfo.isValid())
     {
-        bool isLocalUrl;
-        KUrl url(mostLocalUrl(isLocalUrl));
-        d->m_metaInfo = KFileMetaInfo(url.toLocalFile(), mimetype(), (KFileMetaInfo::What)what);
+        KUrl url(mostLocalUrl());
+        d->m_metaInfo = KFileMetaInfo(url.toLocalFile(), (KFileMetaInfo::What)what);
     }
     return d->m_metaInfo;
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KFileItem::assign( const KFileItem & item )
-{
-    *this = item;
-}
-#endif
 
 KUrl KFileItem::mostLocalUrl(bool &local) const
 {
@@ -1613,27 +1394,6 @@ KUrl KFileItem::targetUrl() const
       return url();
 }
 
-KUrl KFileItem::nepomukUri() const
-{
-#ifndef KIO_NO_NEPOMUK
-    if (!d)
-        return KUrl();
-
-    const QString nepomukUriStr = d->m_entry.stringValue( KIO::UDSEntry::UDS_NEPOMUK_URI );
-    if(!nepomukUriStr.isEmpty()) {
-        return KUrl(nepomukUriStr);
-    }
-    else if(targetUrl().isLocalFile()) {
-        return targetUrl();
-    }
-    else {
-        return KUrl();
-    }
-#else
-    return KUrl();
-#endif
-}
-
 /*
  * Mimetype handling.
  *
@@ -1654,15 +1414,15 @@ KMimeType::Ptr KFileItem::mimeTypePtr() const
     if (!d->m_pMimeType) {
         // On-demand fast (but not always accurate) mimetype determination
         Q_ASSERT(!d->m_url.isEmpty());
-        bool isLocalUrl;
+        bool isLocalUrl = false;
         KUrl url = mostLocalUrl(isLocalUrl);
         int accuracy;
         d->m_pMimeType = KMimeType::findByUrl( url, d->m_fileMode, isLocalUrl,
                                                // use fast mode if delayed mimetype determination can refine it later
                                                d->m_delayedMimeTypes, &accuracy );
-        // If we used the "fast mode" (no sniffing), and we didn't get a perfect (extension-based) match,
-        // then determineMimeType will be able to do better.
-        const bool canDoBetter = d->m_delayedMimeTypes && accuracy < 100;
+        // If we didn't get a perfect (glob and content-based) match,
+        // then determineMimeType will be able to do better for readable URLs.
+        const bool canDoBetter = d->m_delayedMimeTypes;
         //kDebug() << "finding mimetype for" << url << ":" << d->m_pMimeType->name() << "canDoBetter=" << canDoBetter;
         d->m_bMimeTypeKnown = !canDoBetter;
     }
