@@ -21,13 +21,10 @@
 */
 
 #include "kfileitemdelegate.h"
-#include "imagefilter_p.h"
-
-#include <config.h> // for HAVE_XRENDER
 
 #include <QApplication>
 #include <QStyle>
-#include <QModelIndex>
+#include <QtCore/qabstractitemmodel.h>
 #include <QPainter>
 #include <QCache>
 #include <QImage>
@@ -49,17 +46,6 @@
 #include <ktextedit.h>
 #include <kstringhandler.h>
 
-#include "delegateanimationhandler_p.h"
-
-#if defined(Q_WS_X11) && defined(HAVE_XRENDER)
-#  include <X11/Xlib.h>
-#  include <X11/extensions/Xrender.h>
-#  include <QX11Info>
-#  undef KeyPress
-#  undef FocusOut
-#endif
-
-
 struct Margin
 {
     int left, right, top, bottom;
@@ -71,7 +57,7 @@ class KFileItemDelegate::Private
     public:
         enum MarginType { ItemMargin = 0, TextMargin, IconMargin, NMargins };
 
-        Private(KFileItemDelegate *parent);
+        Private();
         ~Private() {}
 
         QSize decorationSizeHint(const QStyleOptionViewItemV4 &option, const QModelIndex &index) const;
@@ -106,18 +92,11 @@ class KFileItemDelegate::Private
                              QTextLayout *labelLayout, QTextLayout *infoLayout, QRect *textBoundingRect) const;
         void drawTextItems(QPainter *painter, const QTextLayout &labelLayout, const QTextLayout &infoLayout,
                            const QRect &textBoundingRect) const;
-        KIO::AnimationState *animationState(const QStyleOptionViewItemV4 &option, const QModelIndex &index,
-                                            const QAbstractItemView *view) const;
-        void restartAnimation(KIO::AnimationState* state);
         QPixmap applyHoverEffect(const QPixmap &icon) const;
         QPixmap transition(const QPixmap &from, const QPixmap &to, qreal amount) const;
         void initStyleOption(QStyleOptionViewItemV4 *option, const QModelIndex &index) const;
         void drawFocusRect(QPainter *painter, const QStyleOptionViewItemV4 &option, const QRect &rect) const;
 
-        void gotNewIcon(const QModelIndex& index);
-
-        void paintJobTransfers(QPainter* painter, const qreal& jobAnimationAngle, const QPoint& iconPos, const QStyleOptionViewItemV4& opt);
-
     public:
         KFileItemDelegate::InformationList informationList;
         QColor shadowColor;
@@ -130,18 +109,16 @@ class KFileItemDelegate::Private
         KIcon downArrowIcon;
 
     private:
-        KFileItemDelegate * const q;
-        KIO::DelegateAnimationHandler *animationHandler;
         Margin verticalMargin[NMargins];
         Margin horizontalMargin[NMargins];
         Margin *activeMargins;
 };
 
 
-KFileItemDelegate::Private::Private(KFileItemDelegate *parent)
+KFileItemDelegate::Private::Private()
      : shadowColor(Qt::transparent), shadowOffset(1, 1), shadowBlur(2), maximumSize(0, 0),
        showToolTipWhenElided(true), wrapMode( QTextOption::WrapAtWordBoundaryOrAnywhere ), jobTransfersVisible(false),
-       q(parent), animationHandler(new KIO::DelegateAnimationHandler(parent)), activeMargins(0)
+       activeMargins(0)
 {
 }
 
@@ -579,31 +556,6 @@ QPixmap KFileItemDelegate::Private::applyHoverEffect(const QPixmap &icon) const
     return icon;
 }
 
-void KFileItemDelegate::Private::gotNewIcon(const QModelIndex& index)
-{
-    animationHandler->gotNewIcon(index);
-}
-
-void KFileItemDelegate::Private::restartAnimation(KIO::AnimationState* state)
-{
-    animationHandler->restartAnimation(state);
-}
-
-KIO::AnimationState *KFileItemDelegate::Private::animationState(const QStyleOptionViewItemV4 &option,
-                                                                const QModelIndex &index,
-                                                                const QAbstractItemView *view) const
-{
-    if (!(KGlobalSettings::graphicEffectsLevel() & KGlobalSettings::SimpleAnimationEffects)) {
-        return NULL;
-    }
-
-    if (index.column() == KDirModel::Name)
-        return animationHandler->animationState(option, index, view);
-
-    return NULL;
-}
-
-
 QPixmap KFileItemDelegate::Private::transition(const QPixmap &from, const QPixmap &to, qreal amount) const
 {
     int value = int(0xff * amount);
@@ -617,16 +569,9 @@ QPixmap KFileItemDelegate::Private::transition(const QPixmap &from, const QPixma
     QColor color;
     color.setAlphaF(amount);
 
-// FIXME: Somehow this doesn't work on Mac OS..
-#if defined(Q_OS_MAC)
-    const bool usePixmap = false;
-#else
-    const bool usePixmap = from.paintEngine()->hasFeature(QPaintEngine::PorterDuff) &&
-                           from.paintEngine()->hasFeature(QPaintEngine::BlendModes);
-#endif
-
     // If the native paint engine supports Porter/Duff compositing and CompositionMode_Plus
-    if (usePixmap)
+    if (from.paintEngine()->hasFeature(QPaintEngine::PorterDuff) &&
+        from.paintEngine()->hasFeature(QPaintEngine::BlendModes))
     {
         QPixmap under = from;
         QPixmap over  = to;
@@ -645,57 +590,7 @@ QPixmap KFileItemDelegate::Private::transition(const QPixmap &from, const QPixma
         p.end();
 
         return under;
-    }
-#if defined(Q_WS_X11) && defined(HAVE_XRENDER)
-    else if (from.paintEngine()->hasFeature(QPaintEngine::PorterDuff)) // We have Xrender support
-    {
-        // QX11PaintEngine doesn't implement CompositionMode_Plus in Qt 4.3,
-        // which we need to be able to do a transition from one pixmap to
-        // another.
-        //
-        // In order to avoid the overhead of converting the pixmaps to images
-        // and doing the operation entirely in software, this function has a
-        // specialized path for X11 that uses Xrender directly to do the
-        // transition. This operation can be fully accelerated in HW.
-        //
-        // This specialization can be removed when QX11PaintEngine supports
-        // CompositionMode_Plus.
-        QPixmap source(to), destination(from);
-
-        source.detach();
-        destination.detach();
-
-        Display *dpy = QX11Info::display();
-
-        XRenderPictFormat *format = XRenderFindStandardFormat(dpy, PictStandardA8);
-        XRenderPictureAttributes pa;
-        pa.repeat = 1; // RepeatNormal
-
-        // Create a 1x1 8 bit repeating alpha picture
-        Pixmap pixmap = XCreatePixmap(dpy, destination.handle(), 1, 1, 8);
-        Picture alpha = XRenderCreatePicture(dpy, pixmap, format, CPRepeat, &pa);
-        XFreePixmap(dpy, pixmap);
-
-        // Fill the alpha picture with the opacity value
-        XRenderColor xcolor;
-        xcolor.alpha = quint16(0xffff * amount);
-        XRenderFillRectangle(dpy, PictOpSrc, alpha, &xcolor, 0, 0, 1, 1);
-
-        // Reduce the alpha of the destination with 1 - opacity
-        XRenderComposite(dpy, PictOpOutReverse, alpha, None, destination.x11PictureHandle(),
-                         0, 0, 0, 0, 0, 0, destination.width(), destination.height());
-
-        // Add source * opacity to the destination
-        XRenderComposite(dpy, PictOpAdd, source.x11PictureHandle(), alpha,
-                         destination.x11PictureHandle(),
-                         0, 0, 0, 0, 0, 0, destination.width(), destination.height());
-
-        XRenderFreePicture(dpy, alpha);
-        return destination;
-    }
-#endif
-    else
-    {
+    } else {
         // Fall back to using QRasterPaintEngine to do the transition.
         QImage under = from.toImage();
         QImage over  = to.toImage();
@@ -800,7 +695,7 @@ void KFileItemDelegate::Private::drawTextItems(QPainter *painter, const QTextLay
         p.drawImage(padding, padding, pixmap.toImage());
         p.end();
 
-        KIO::ImageFilter::shadowBlur(image, blurFactor, shadowColor);
+        KIconEffect::shadowBlur(image, blurFactor, shadowColor);
 
         painter->drawImage(boundingRect.topLeft() - QPoint(padding, padding) + shadowOffset.toPoint(), image);
         painter->drawPixmap(boundingRect.topLeft(), pixmap);
@@ -866,49 +761,11 @@ void KFileItemDelegate::Private::initStyleOption(QStyleOptionViewItemV4 *option,
     option->showDecorationSelected = true;
 }
 
-void KFileItemDelegate::Private::paintJobTransfers(QPainter *painter, const qreal &jobAnimationAngle, const QPoint &iconPos, const QStyleOptionViewItemV4& opt)
-{
-    painter->save();
-    QSize iconSize = opt.icon.actualSize(opt.decorationSize);
-    QPixmap downArrow = downArrowIcon.pixmap(iconSize * 0.30);
-    //corner (less x and y than bottom-right corner) that we will center the painter around
-    QPoint bottomRightCorner = QPoint(iconPos.x() + iconSize.width() * 0.75, iconPos.y() + iconSize.height() * 0.60);
-
-    QPainter pixmapPainter(&downArrow);
-    //make the icon transparent and such
-    pixmapPainter.setCompositionMode(QPainter::CompositionMode_DestinationIn);
-    pixmapPainter.fillRect(downArrow.rect(), QColor(255, 255, 255, 110));
-
-
-    painter->translate(bottomRightCorner);
-
-    painter->drawPixmap(-downArrow.size().width() * .50, -downArrow.size().height() * .50, downArrow);
-
-    //animate the circles by rotating the painter around the center point..
-    painter->rotate(jobAnimationAngle);
-    painter->setPen(QColor(20, 20, 20, 80));
-    painter->setBrush(QColor(250, 250, 250, 90));
-
-    int radius = iconSize.width() * 0.04;
-    int spacing = radius * 4.5;
-
-    //left
-    painter->drawEllipse(QPoint(-spacing, 0), radius, radius);
-    //right
-    painter->drawEllipse(QPoint(spacing, 0), radius, radius);
-    //up
-    painter->drawEllipse(QPoint(0, -spacing), radius, radius);
-    //down
-    painter->drawEllipse(QPoint(0, spacing), radius, radius);
-    painter->restore();
-}
-
-
 // ---------------------------------------------------------------------------
 
 
 KFileItemDelegate::KFileItemDelegate(QObject *parent)
-    : QAbstractItemDelegate(parent), d(new Private(this))
+    : QAbstractItemDelegate(parent), d(new Private())
 {
     int focusHMargin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameHMargin);
     int focusVMargin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameVMargin);
@@ -1263,13 +1120,6 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     else
         opt.viewItemPosition = QStyleOptionViewItemV4::OnlyOne;
 
-    const QAbstractItemView *view = qobject_cast<const QAbstractItemView*>(opt.widget);
-
-
-    // Check if the item is being animated
-    // ========================================================================
-    KIO::AnimationState *state = d->animationState(opt, index, view);
-    KIO::CachedRendering *cache = 0;
     qreal progress = ((opt.state & QStyle::State_MouseOver) &&
     index.column() == KDirModel::Name) ? 1.0 : 0.0;
     const QPoint iconPos   = d->iconPosition(opt);
@@ -1277,61 +1127,6 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     QIcon::State iconState = option.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
     QPixmap icon           = opt.icon.pixmap(opt.decorationSize, iconMode, iconState);
 
-    if (state && !state->hasJobAnimation())
-    {
-        cache    = state->cachedRendering();
-        progress = state->hoverProgress();
-        // Clear the mouse over bit temporarily
-        opt.state &= ~QStyle::State_MouseOver;
-
-
-        // If we have a cached rendering, draw the item from the cache
-        if (cache)
-        {
-            if (cache->checkValidity(opt.state) && cache->regular.size() == opt.rect.size())
-            {
-                QPixmap pixmap = d->transition(cache->regular, cache->hover, progress);
-
-                if (state->cachedRenderingFadeFrom() && state->fadeProgress() != 1.0)
-                {
-                    // Apply icon fading animation
-                    KIO::CachedRendering* fadeFromCache = state->cachedRenderingFadeFrom();
-                    const QPixmap fadeFromPixmap = d->transition(fadeFromCache->regular, fadeFromCache->hover, progress);
-
-                    pixmap = d->transition(fadeFromPixmap, pixmap, state->fadeProgress());
-                }
-                painter->drawPixmap(option.rect.topLeft(), pixmap);
-                if (d->jobTransfersVisible && index.column() == 0) {
-                    if (index.data(KDirModel::HasJobRole).toBool()) {
-                        d->paintJobTransfers(painter, state->jobAnimationAngle(), iconPos, opt);
-                    }
-                }
-                return;
-            }
-
-            if (!cache->checkValidity(opt.state))
-            {
-                if ((KGlobalSettings::graphicEffectsLevel() & KGlobalSettings::SimpleAnimationEffects))
-                {
-                    // Fade over from the old icon to the new one
-                    // Only start a new fade if the previous one is ready
-                    // Else we may start racing when checkValidity() always returns false
-                    if (state->fadeProgress() == 1)
-                        state->setCachedRenderingFadeFrom(state->takeCachedRendering());
-                }
-                d->gotNewIcon(index);
-            }
-            // If it wasn't valid, delete it
-            state->setCachedRendering(0);
-        }
-        else
-        {
-            // The cache may have been discarded, but the animation handler still needs to know about new icons
-            d->gotNewIcon(index);
-        }
-    }
-
-
     // Compute the metrics, and lay out the text items
     // ========================================================================
     const QPen pen         = QPen(d->foregroundBrush(opt, index), 0);
@@ -1351,64 +1146,6 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     QRect focusRect = textBoundingRect.adjusted(-focusHMargin, -focusVMargin,
                                                 +focusHMargin, +focusVMargin);
 
-    // Create a new cached rendering of a hovered and an unhovered item.
-    // We don't create a new cache for a fully hovered item, since we don't
-    // know yet if a hover out animation will be run.
-    // ========================================================================
-    if (state && (state->hoverProgress() < 1 || state->fadeProgress() < 1))
-    {
-        cache = new KIO::CachedRendering(opt.state, option.rect.size(), index);
-
-        QPainter p;
-        p.begin(&cache->regular);
-        p.translate(-option.rect.topLeft());
-        p.setRenderHint(QPainter::Antialiasing);
-        p.setPen(pen);
-        style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, &p, opt.widget);
-        p.drawPixmap(iconPos, icon);
-        d->drawTextItems(&p, labelLayout, infoLayout, textBoundingRect);
-        d->drawFocusRect(&p, opt, focusRect);
-        p.end();
-
-        opt.state |= QStyle::State_MouseOver;
-        icon = d->applyHoverEffect(icon);
-
-        p.begin(&cache->hover);
-        p.translate(-option.rect.topLeft());
-        p.setRenderHint(QPainter::Antialiasing);
-        p.setPen(pen);
-        style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, &p, opt.widget);
-        p.drawPixmap(iconPos, icon);
-        d->drawTextItems(&p, labelLayout, infoLayout, textBoundingRect);
-        d->drawFocusRect(&p, opt, focusRect);
-        p.end();
-
-        state->setCachedRendering(cache);
-
-        QPixmap pixmap = d->transition(cache->regular, cache->hover, progress);
-
-        if (state->cachedRenderingFadeFrom() && state->fadeProgress() == 0)
-        {
-            // Apply icon fading animation
-            KIO::CachedRendering* fadeFromCache = state->cachedRenderingFadeFrom();
-            const QPixmap fadeFromPixmap = d->transition(fadeFromCache->regular, fadeFromCache->hover, progress);
-
-            pixmap = d->transition(fadeFromPixmap, pixmap, state->fadeProgress());
-
-            d->restartAnimation(state);
-        }
-
-        painter->drawPixmap(option.rect.topLeft(), pixmap);
-        painter->setRenderHint(QPainter::Antialiasing);
-        if (d->jobTransfersVisible && index.column() == 0) {
-            if (index.data(KDirModel::HasJobRole).toBool()) {
-                d->paintJobTransfers(painter, state->jobAnimationAngle(), iconPos, opt);
-            }
-        }
-        return;
-    }
-
-
     // Render the item directly if we're not using a cached rendering
     // ========================================================================
     painter->save();
@@ -1427,11 +1164,6 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     d->drawTextItems(painter, labelLayout, infoLayout, textBoundingRect);
     d->drawFocusRect(painter, opt, focusRect);
 
-    if (d->jobTransfersVisible && index.column() == 0 && state) {
-        if (index.data(KDirModel::HasJobRole).toBool()) {
-            d->paintJobTransfers(painter, state->jobAnimationAngle(), iconPos, opt);
-        }
-    }
     painter->restore();
 }
 
@@ -1686,7 +1418,7 @@ bool KFileItemDelegate::eventFilter(QObject *object, QEvent *event)
 
 
 
-#include "kfileitemdelegate.moc"
+#include "moc_kfileitemdelegate.cpp"
 
 
 // kate: space-indent on; indent-width 4; replace-tabs on;
