@@ -21,24 +21,16 @@
 
 #include "kprotocolmanager.h"
 
-#include "hostinfo_p.h"
-
 #include <string.h>
 #include <unistd.h>
 #include <sys/utsname.h>
 
 #include <QtCore/QCoreApplication>
-#include <QtNetwork/QSslSocket>
 #include <QtNetwork/QHostAddress>
 #include <QtNetwork/QHostInfo>
 #include <QtDBus/QtDBus>
 #include <QtCore/QCache>
 
-#if !defined(QT_NO_NETWORKPROXY) && (defined (Q_OS_WIN32) || defined(Q_OS_MAC))
-#include <QtNetwork/QNetworkProxyFactory>
-#include <QtNetwork/QNetworkProxyQuery>
-#endif
-
 #include <kdeversion.h>
 #include <kdebug.h>
 #include <kglobal.h>
@@ -52,7 +44,6 @@
 
 #include <kio/slaveconfig.h>
 #include <kio/ioslave_defaults.h>
-#include <kio/http_slave_defaults.h>
 
 #define QL1S(x)   QLatin1String(x)
 #define QL1C(x)   QLatin1Char(x)
@@ -126,14 +117,11 @@ public:
     bool shouldIgnoreProxyFor(const KUrl& url);
 
    KSharedConfig::Ptr config;
-   KSharedConfig::Ptr http_config;
    QString modifiers;
    QString useragent;
    QString noProxyFor;
    QList<SubnetPair> noProxySubnets;
    QCache<QString, KProxyData> cachedProxyData;
-
-   QMap<QString /*mimetype*/, QString /*protocol*/> protocolForArchiveMimetypes;
 };
 
 K_GLOBAL_STATIC(KProtocolManagerPrivate, kProtocolManagerPrivate)
@@ -206,7 +194,7 @@ bool KProtocolManagerPrivate::shouldIgnoreProxyFor(const KUrl& url)
     // TODO: Perhaps we should make configurable ?
     if (address.isNull()) {
       kDebug() << "Performing DNS lookup for" << host;
-      QHostInfo info = KIO::HostInfo::lookupHost(host, 2000);
+      QHostInfo info = QHostInfo::fromName(host);
       const QList<QHostAddress> addresses = info.addresses();
       if (!addresses.isEmpty())
         address = addresses.first();
@@ -232,9 +220,6 @@ KProtocolManagerPrivate *d = kProtocolManagerPrivate
 void KProtocolManager::reparseConfiguration()
 {
     PRIVATE_DATA;
-    if (d->http_config) {
-        d->http_config->reparseConfiguration();
-    }
     if (d->config) {
         d->config->reparseConfiguration();
     }
@@ -257,15 +242,6 @@ KSharedConfig::Ptr KProtocolManager::config()
   return d->config;
 }
 
-static KConfigGroup http_config()
-{
-  PRIVATE_DATA;
-  if (!d->http_config) {
-     d->http_config = KSharedConfig::openConfig("kio_httprc", KConfig::NoGlobals);
-  }
-  return KConfigGroup(d->http_config, QString());
-}
-
 /*=============================== TIMEOUT SETTINGS ==========================*/
 
 int KProtocolManager::readTimeout()
@@ -321,36 +297,6 @@ KProtocolManager::ProxyAuthMode KProtocolManager::proxyAuthMode()
   return static_cast<ProxyAuthMode>(cg.readEntry( "AuthMode" , 0));
 }
 
-/*========================== CACHING =====================================*/
-
-bool KProtocolManager::useCache()
-{
-  return http_config().readEntry( "UseCache", true );
-}
-
-KIO::CacheControl KProtocolManager::cacheControl()
-{
-  QString tmp = http_config().readEntry("cache");
-  if (tmp.isEmpty())
-    return DEFAULT_CACHE_CONTROL;
-  return KIO::parseCacheControl(tmp);
-}
-
-QString KProtocolManager::cacheDir()
-{
-  return http_config().readPathEntry("CacheDir", KGlobal::dirs()->saveLocation("cache","http"));
-}
-
-int KProtocolManager::maxCacheAge()
-{
-  return http_config().readEntry( "MaxCacheAge", DEFAULT_MAX_CACHE_AGE ); // 14 days
-}
-
-int KProtocolManager::maxCacheSize()
-{
-  return http_config().readEntry( "MaxCacheSize", DEFAULT_MAX_CACHE_SIZE ); // 5 MB
-}
-
 QString KProtocolManager::noProxyFor()
 {
   QString noProxy = config()->group("Proxy Settings").readEntry( "NoProxyFor" );
@@ -360,20 +306,9 @@ QString KProtocolManager::noProxyFor()
   return noProxy;
 }
 
-static QString adjustProtocol(const QString& scheme)
-{
-  if (scheme.compare(QL1S("webdav"), Qt::CaseInsensitive) == 0)
-    return QL1S("http");
-
-  if (scheme.compare(QL1S("webdavs"), Qt::CaseInsensitive) == 0)
-    return QL1S("https");
-
-  return scheme.toLower();
-}
-
 QString KProtocolManager::proxyFor( const QString& protocol )
 {
-  const QString key = adjustProtocol(protocol) + QL1S("Proxy");
+  const QString key = protocol.toLower() + QL1S("Proxy");
   QString proxyStr (config()->group("Proxy Settings").readEntry(key));
   const int index = proxyStr.lastIndexOf(QL1C(' '));
 
@@ -405,32 +340,6 @@ static QStringList getSystemProxyFor( const KUrl& url )
 {
   QStringList proxies;
 
-#if !defined(QT_NO_NETWORKPROXY) && (defined(Q_OS_WIN32) || defined(Q_OS_MAC))
-  QNetworkProxyQuery query ( url );
-  const QList<QNetworkProxy> proxyList = QNetworkProxyFactory::systemProxyForQuery(query);
-  Q_FOREACH(const QNetworkProxy& proxy, proxyList)
-  {
-    KUrl url;
-    const QNetworkProxy::ProxyType type = proxy.type();
-    if (type == QNetworkProxy::NoProxy || type == QNetworkProxy::DefaultProxy)
-    {
-      proxies << QL1S("DIRECT");
-      continue;
-    }
-
-    if (type == QNetworkProxy::HttpProxy || type == QNetworkProxy::HttpCachingProxy)
-      url.setProtocol(QL1S("http"));
-    else if (type == QNetworkProxy::Socks5Proxy)
-      url.setProtocol(QL1S("socks"));
-    else if (type == QNetworkProxy::FtpCachingProxy)
-      url.setProtocol(QL1S("ftp"));
-
-    url.setHost(proxy.hostName());
-    url.setPort(proxy.port());
-    url.setUser(proxy.user());
-    proxies << url.url();
-  }
-#else
   // On Unix/Linux use system environment variables if any are set.
   QString proxyVar (KProtocolManager::proxyFor(url.protocol()));
   // Check for SOCKS proxy, if not proxy is found for given url.
@@ -451,7 +360,6 @@ static QStringList getSystemProxyFor( const KUrl& url )
       proxies << proxy;
     }
   }
-#endif
   return proxies;
 }
 
@@ -463,23 +371,6 @@ QStringList KProtocolManager::proxiesForUrl( const KUrl &url )
   if (!d->shouldIgnoreProxyFor(url)) {
     switch (proxyType())
     {
-      case PACProxy:
-      case WPADProxy:
-      {
-        KUrl u (url);
-        const QString protocol = adjustProtocol(u.protocol());
-        u.setProtocol(protocol);
-
-        if (protocol.startsWith(QL1S("http"), Qt::CaseInsensitive) ||
-            protocol.startsWith(QL1S("ftp"), Qt::CaseInsensitive)) {
-          QDBusReply<QStringList> reply = QDBusInterface(QL1S("org.kde.kded"),
-                                                         QL1S("/modules/proxyscout"),
-                                                         QL1S("org.kde.KPAC.ProxyScout"))
-                                          .call(QL1S("proxiesForUrl"), u.url());
-          proxyList = reply;
-        }
-        break;
-      }
       case EnvVarProxy:
         proxyList = getSystemProxyFor( url );
         break;
@@ -496,8 +387,8 @@ QStringList KProtocolManager::proxiesForUrl( const KUrl &url )
           proxy = QL1S("socks://") + (index == -1 ? proxy : proxy.mid(index+3));
           proxyList << proxy;
         }
+        break;
       }
-      break;
       case NoProxy:
       default:
         break;
@@ -513,9 +404,6 @@ QStringList KProtocolManager::proxiesForUrl( const KUrl &url )
 
 void KProtocolManager::badProxy( const QString &proxy )
 {
-  QDBusInterface( QL1S("org.kde.kded"), QL1S("/modules/proxyscout"))
-      .asyncCall(QL1S("blackListProxy"), proxy);
-
   PRIVATE_DATA;
   const QStringList keys (d->cachedProxyData.keys());
   Q_FOREACH(const QString& key, keys) {
@@ -592,10 +480,9 @@ QString KProtocolManager::slaveProtocol(const KUrl &url, QStringList &proxyList)
   }
 
   // The idea behind slave protocols is not applicable to http
-  // and webdav protocols as well as protocols unknown to KDE.
+  // protocol as well as protocols unknown to KDE.
   if (!proxyList.isEmpty()
       && !protocol.startsWith(QL1S("http"))
-      && !protocol.startsWith(QL1S("webdav"))
       && KProtocolInfo::isKnownProtocol(protocol)) {
       Q_FOREACH(const QString& proxy, proxyList) {
           KUrl u (proxy);
@@ -613,52 +500,14 @@ QString KProtocolManager::slaveProtocol(const KUrl &url, QStringList &proxyList)
 
 /*================================= USER-AGENT SETTINGS =====================*/
 
-QString KProtocolManager::userAgentForHost( const QString& hostname )
-{
-  const QString sendUserAgent = KIO::SlaveConfig::self()->configData("http", hostname.toLower(), "SendUserAgent").toLower();
-  if (sendUserAgent == QL1S("false"))
-     return QString();
-
-  const QString useragent = KIO::SlaveConfig::self()->configData("http", hostname.toLower(), "UserAgent");
-
-  // Return the default user-agent if none is specified
-  // for the requested host.
-  if (useragent.isEmpty())
-    return defaultUserAgent();
-
-  return useragent;
-}
-
 QString KProtocolManager::defaultUserAgent( )
 {
-  const QString modifiers = KIO::SlaveConfig::self()->configData("http", QString(), "UserAgentKeys");
-  return defaultUserAgent(modifiers);
-}
-
-static QString defaultUserAgentFromPreferredService()
-{
-  QString agentStr;
-
-  // Check if the default COMPONENT contains a custom default UA string...
-  KService::Ptr service = KMimeTypeTrader::self()->preferredService(QL1S("text/html"),
-                                                      QL1S("KParts/ReadOnlyPart"));
-  if (service && service->showInKDE())
-    agentStr = service->property(QL1S("X-KDE-Default-UserAgent"),
-                                 QVariant::String).toString();
-  return agentStr;
+  return defaultUserAgent(DEFAULT_USER_AGENT_KEYS);
 }
 
 static QString platform()
 {
-#if defined(Q_WS_X11)
     return QL1S("X11");
-#elif defined(Q_WS_MAC)
-    return QL1S("Macintosh");
-#elif defined(Q_WS_WIN)
-     return QL1S("Windows");
-#elif defined(Q_WS_S60)
-     return QL1S("Symbian");
-#endif
 }
 
 QString KProtocolManager::defaultUserAgent( const QString &_modifiers )
@@ -698,201 +547,68 @@ QString KProtocolManager::defaultUserAgent( const QString &_modifiers )
 
   QString systemName, systemVersion, machine, supp;
   const bool sysInfoFound = getSystemNameVersionAndMachine( systemName, systemVersion, machine );
-  QString agentStr = defaultUserAgentFromPreferredService();
 
-  if (agentStr.isEmpty())
+  supp += platform();
+
+  if (sysInfoFound)
   {
-    supp += platform();
-
-    if (sysInfoFound)
+    if (modifiers.contains('o'))
     {
-      if (modifiers.contains('o'))
+      supp += QL1S("; ");
+      supp += systemName;
+      if (modifiers.contains('v'))
       {
-        supp += QL1S("; ");
-        supp += systemName;
-        if (modifiers.contains('v'))
-        {
-          supp += QL1C(' ');
-          supp += systemVersion;
-        }
-
-        if (modifiers.contains('m'))
-        {
-          supp += QL1C(' ');
-          supp += machine;
-        }
+        supp += QL1C(' ');
+        supp += systemVersion;
       }
 
-      if (modifiers.contains('l'))
+      if (modifiers.contains('m'))
       {
-        supp += QL1S("; ");
-        supp += KGlobal::locale()->language();
+        supp += QL1C(' ');
+        supp += machine;
       }
     }
 
-    // Full format: Mozilla/5.0 (Linux
-    d->useragent = QL1S("Mozilla/5.0 (");
-    d->useragent += supp;
-    d->useragent += QL1S(") KHTML/");
-    d->useragent += QString::number(KDE::versionMajor());
-    d->useragent += QL1C('.');
-    d->useragent += QString::number(KDE::versionMinor());
-    d->useragent += QL1C('.');
-    d->useragent += QString::number(KDE::versionRelease());
-    d->useragent += QL1S(" (like Gecko) Konqueror/");
-    d->useragent += QString::number(KDE::versionMajor());
-    d->useragent += QL1C('.');
-    d->useragent += QString::number(KDE::versionMinor());
+    if (modifiers.contains('l'))
+    {
+      supp += QL1S("; ");
+      supp += KGlobal::locale()->language();
+    }
   }
-  else
-  {
-    QString appName = QCoreApplication::applicationName();
-    if (appName.isEmpty() || appName.startsWith(QL1S("kcmshell"), Qt::CaseInsensitive))
-      appName = QL1S ("KDE");
 
-    QString appVersion = QCoreApplication::applicationVersion();
-    if (appVersion.isEmpty()) {
-      appVersion += QString::number(KDE::versionMajor());
-      appVersion += QL1C('.');
-      appVersion += QString::number(KDE::versionMinor());
-      appVersion += QL1C('.');
-      appVersion += QString::number(KDE::versionRelease());
-    }
-
-    appName += QL1C('/');
-    appName += appVersion;
-
-    agentStr.replace(QL1S("%appversion%"), appName, Qt::CaseInsensitive);
-
-    if (!QSslSocket::supportsSsl())
-      agentStr.replace(QL1S("%security%"), QL1S("N"), Qt::CaseInsensitive);
-    else
-      agentStr.remove(QL1S("%security%"), Qt::CaseInsensitive);
-
-    if (sysInfoFound)
-    {
-      // Platform (e.g. X11). It is no longer configurable from UI.
-      agentStr.replace(QL1S("%platform%"), platform(), Qt::CaseInsensitive);
-
-      // Operating system (e.g. Linux)
-      if (modifiers.contains('o'))
-      {
-        agentStr.replace(QL1S("%osname%"), systemName, Qt::CaseInsensitive);
-
-        // OS version (e.g. 2.6.36)
-        if (modifiers.contains('v'))
-          agentStr.replace(QL1S("%osversion%"), systemVersion, Qt::CaseInsensitive);
-        else
-          agentStr.remove(QL1S("%osversion%"), Qt::CaseInsensitive);
-
-        // Machine type (i686, x86-64, etc.)
-        if (modifiers.contains('m'))
-          agentStr.replace(QL1S("%systype%"), machine, Qt::CaseInsensitive);
-        else
-          agentStr.remove(QL1S("%systype%"), Qt::CaseInsensitive);
-      }
-      else
-      {
-         agentStr.remove(QL1S("%osname%"), Qt::CaseInsensitive);
-         agentStr.remove(QL1S("%osversion%"), Qt::CaseInsensitive);
-         agentStr.remove(QL1S("%systype%"), Qt::CaseInsensitive);
-      }
-
-      // Language (e.g. en_US)
-      if (modifiers.contains('l'))
-        agentStr.replace(QL1S("%language%"), KGlobal::locale()->language(), Qt::CaseInsensitive);
-      else
-        agentStr.remove(QL1S("%language%"), Qt::CaseInsensitive);
-
-      // Clean up unnecessary separators that could be left over from the
-      // possible keyword removal above...
-      agentStr.replace(QRegExp("[(]\\s*[;]\\s*"), QL1S("("));
-      agentStr.replace(QRegExp("[;]\\s*[;]\\s*"), QL1S("; "));
-      agentStr.replace(QRegExp("\\s*[;]\\s*[)]"), QL1S(")"));
-    }
-    else
-    {
-      agentStr.remove(QL1S("%osname%"));
-      agentStr.remove(QL1S("%osversion%"));
-      agentStr.remove(QL1S("%platform%"));
-      agentStr.remove(QL1S("%systype%"));
-      agentStr.remove(QL1S("%language%"));
-    }
-
-    d->useragent = agentStr.simplified();
-  }
+  // Full format: Mozilla/5.0 (Linux
+  d->useragent = QL1S("Mozilla/5.0 (");
+  d->useragent += supp;
+  d->useragent += QL1S(") KHTML/");
+  d->useragent += QString::number(KDE::versionMajor());
+  d->useragent += QL1C('.');
+  d->useragent += QString::number(KDE::versionMinor());
+  d->useragent += QL1C('.');
+  d->useragent += QString::number(KDE::versionRelease());
+  d->useragent += QL1S(" (like Gecko) Konqueror/");
+  d->useragent += QString::number(KDE::versionMajor());
+  d->useragent += QL1C('.');
+  d->useragent += QString::number(KDE::versionMinor());
 
   //kDebug() << "USERAGENT STRING:" << d->useragent;
   return d->useragent;
 }
 
-QString KProtocolManager::userAgentForApplication( const QString &appName, const QString& appVersion,
-  const QStringList& extraInfo )
-{
-  QString systemName, systemVersion, machine, info;
-
-  if (getSystemNameVersionAndMachine( systemName, systemVersion, machine ))
-  {
-    info +=  systemName;
-    info += QL1C('/');
-    info += systemVersion;
-    info += QL1S("; ");
-  }
-
-  info += QL1S("KDE/");
-  info += QString::number(KDE::versionMajor());
-  info += QL1C('.');
-  info += QString::number(KDE::versionMinor());
-  info += QL1C('.');
-  info += QString::number(KDE::versionRelease());
-
-  if (!machine.isEmpty())
-  {
-    info += QL1S("; ");
-    info += machine;
-  }
-
-  info += QL1S("; ");
-  info += extraInfo.join(QL1S("; "));
-
-  return (appName + QL1C('/') + appVersion + QL1S(" (") + info + QL1C(')'));
-}
-
 bool KProtocolManager::getSystemNameVersionAndMachine(
   QString& systemName, QString& systemVersion, QString& machine )
 {
   struct utsname unameBuf;
   if ( 0 != uname( &unameBuf ) )
     return false;
-#if defined(Q_WS_WIN) && !defined(_WIN32_WCE)
-  // we do not use unameBuf.sysname information constructed in kdewin32
-  // because we want to get separate name and version
-  systemName = QL1S( "Windows" );
-  OSVERSIONINFOEX versioninfo;
-  ZeroMemory(&versioninfo, sizeof(OSVERSIONINFOEX));
-  // try calling GetVersionEx using the OSVERSIONINFOEX, if that fails, try using the OSVERSIONINFO
-  versioninfo.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-  bool ok = GetVersionEx( (OSVERSIONINFO *) &versioninfo );
-  if ( !ok ) {
-    versioninfo.dwOSVersionInfoSize = sizeof (OSVERSIONINFO);
-    ok = GetVersionEx( (OSVERSIONINFO *) &versioninfo );
-  }
-  if ( ok ) {
-    systemVersion = QString::number(versioninfo.dwMajorVersion);
-    systemVersion +=  QL1C('.');
-    systemVersion += QString::number(versioninfo.dwMinorVersion);
-  }
-#else
   systemName = unameBuf.sysname;
   systemVersion = unameBuf.release;
-#endif
   machine = unameBuf.machine;
   return true;
 }
 
 QString KProtocolManager::acceptLanguagesHeader()
 {
-  static const QString &english = KGlobal::staticQString("en");
+  static const QString english = QString::fromLatin1("en");
 
   // User's desktop language preference.
   QStringList languageList = KGlobal::locale()->languageList();
@@ -971,21 +687,6 @@ bool KProtocolManager::autoResume()
   return config()->group(QByteArray()).readEntry( "AutoResume", false );
 }
 
-bool KProtocolManager::persistentConnections()
-{
-  return config()->group(QByteArray()).readEntry( "PersistentConnections", true );
-}
-
-bool KProtocolManager::persistentProxyConnection()
-{
-  return config()->group(QByteArray()).readEntry( "PersistentProxyConnection", false );
-}
-
-QString KProtocolManager::proxyConfigScript()
-{
-  return config()->group("Proxy Settings").readEntry( "Proxy Config Script" );
-}
-
 /* =========================== PROTOCOL CAPABILITIES ============== */
 
 static KProtocolInfo::Ptr findProtocol(const KUrl &url)
@@ -1176,22 +877,6 @@ QString KProtocolManager::defaultMimetype( const KUrl &url )
   return prot->m_defaultMimetype;
 }
 
-QString KProtocolManager::protocolForArchiveMimetype( const QString& mimeType )
-{
-    PRIVATE_DATA;
-    if (d->protocolForArchiveMimetypes.isEmpty()) {
-        const KProtocolInfo::List allProtocols = KProtocolInfoFactory::self()->allProtocols();
-        for (KProtocolInfo::List::const_iterator it = allProtocols.begin();
-             it != allProtocols.end(); ++it) {
-            const QStringList archiveMimetypes = (*it)->archiveMimeTypes();
-            Q_FOREACH(const QString& mime, archiveMimetypes) {
-                d->protocolForArchiveMimetypes.insert(mime, (*it)->name());
-            }
-        }
-    }
-    return d->protocolForArchiveMimetypes.value(mimeType);
-}
-
 QString KProtocolManager::charsetFor(const KUrl& url)
 {
     return KIO::SlaveConfig::self()->configData(url.scheme(), url.host(), QLatin1String("Charset"));
