@@ -31,6 +31,8 @@
 #include <typeinfo>
 #include <sys/stat.h>
 
+#include <QtCore/QFileInfo>
+#include <QtCore/QDir>
 #include <QtGui/QWidget>
 #include <QtGui/QLabel>
 #include <QtGui/QVBoxLayout>
@@ -50,8 +52,6 @@
 #include "kfile/kopenwithdialog.h"
 #include "kfile/krecentdocument.h"
 #include "kdesktopfileactions.h"
-
-#include <kauthorized.h>
 #include <kmessageboxwrapper.h>
 #include <kurl.h>
 #include <kglobal.h>
@@ -61,16 +61,9 @@
 #include <kprotocolmanager.h>
 #include <kstandarddirs.h>
 #include <kprocess.h>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QTextIStream>
-#include <QtCore/QDate>
-#include <QtCore/QRegExp>
-#include <QDir>
 #include <kdesktopfile.h>
 #include <kmacroexpander.h>
 #include <kshell.h>
-#include <QTextDocument>
 #include <kde_file.h>
 #include <kconfiggroup.h>
 #include <kdialog.h>
@@ -80,8 +73,6 @@
 
 #ifdef Q_WS_X11
 #include <kwindowsystem.h>
-#elif defined(Q_WS_WIN)
-#include <QDesktopServices>
 #endif
 
 KRun::KRunPrivate::KRunPrivate(KRun *parent)
@@ -106,9 +97,6 @@ bool KRun::isExecutableFile(const KUrl& url, const QString &mimetype)
     if (file.isExecutable()) {    // Got a prospective file to run
         KMimeType::Ptr mimeType = KMimeType::mimeType(mimetype, KMimeType::ResolveAliases);
         if (mimeType && (mimeType->is(QLatin1String("application/x-executable")) ||
-#ifdef Q_WS_WIN
-                         mimeType->is(QLatin1String("application/x-ms-dos-executable")) ||
-#endif
                          mimeType->is(QLatin1String("application/x-executable-script")))
            )
         {
@@ -122,26 +110,15 @@ bool KRun::isExecutableFile(const KUrl& url, const QString &mimetype)
 bool KRun::runUrl(const KUrl& u, const QString& _mimetype, QWidget* window, bool tempFile, bool runExecutables, const QString& suggestedFileName, const QByteArray& asn)
 {
     bool noRun = false;
-    bool noAuth = false;
-    if (_mimetype == QLatin1String("inode/directory-locked")) {
-        KMessageBoxWrapper::error(window,
-                                  i18n("<qt>Unable to enter <b>%1</b>.\nYou do not have access rights to this location.</qt>", Qt::escape(u.prettyUrl())));
-        return false;
-    }
-    else if (_mimetype == QLatin1String("application/x-desktop")) {
+    if (_mimetype == QLatin1String("application/x-desktop")) {
         if (u.isLocalFile() && runExecutables) {
             return KDesktopFileActions::run(u, true);
         }
     }
     else if (isExecutableFile(u, _mimetype)) {
         if (u.isLocalFile() && runExecutables) {
-            if (KAuthorized::authorize("shell_access")) {
-                return (KRun::runCommand(KShell::quoteArg(u.toLocalFile()), QString(), QString(), window, asn, u.directory())); // just execute the url as a command
-                // ## TODO implement deleting the file if tempFile==true
-            }
-            else {
-                noAuth = true;
-            }
+            return (KRun::runCommand(KShell::quoteArg(u.toLocalFile()), QString(), QString(), window, asn, u.directory())); // just execute the url as a command
+            // ## TODO implement deleting the file if tempFile==true
         }
         else if (_mimetype == QLatin1String("application/x-executable")) {
             noRun = true;
@@ -151,10 +128,6 @@ bool KRun::runUrl(const KUrl& u, const QString& _mimetype, QWidget* window, bool
         if (!runExecutables) {
             noRun = true;
         }
-
-        if (!KAuthorized::authorize("shell_access")) {
-            noAuth = true;
-        }
     }
 
     if (noRun) {
@@ -163,11 +136,6 @@ bool KRun::runUrl(const KUrl& u, const QString& _mimetype, QWidget* window, bool
                                 "For safety it will not be started.</qt>", Qt::escape(u.prettyUrl())));
         return false;
     }
-    if (noAuth) {
-        KMessageBoxWrapper::error(window,
-                                  i18n("<qt>You do not have permission to run <b>%1</b>.</qt>", Qt::escape(u.prettyUrl())));
-        return false;
-    }
 
     KUrl::List lst;
     lst.append(u);
@@ -175,16 +143,10 @@ bool KRun::runUrl(const KUrl& u, const QString& _mimetype, QWidget* window, bool
     KService::Ptr offer = KMimeTypeTrader::self()->preferredService(_mimetype);
 
     if (!offer) {
-#ifdef Q_WS_WIN
-        // As KDE on windows doesnt know about the windows default applications offers will be empty in nearly all cases.
-        // So we use QDesktopServices::openUrl to let windows decide how to open the file
-        return QDesktopServices::openUrl(u);
-#else
         // Open-with dialog
         // TODO : pass the mimetype as a parameter, to show it (comment field) in the dialog !
         // Hmm, in fact KOpenWithDialog::setServiceType already guesses the mimetype from the first URL of the list...
         return displayOpenWithDialog(lst, window, tempFile, suggestedFileName, asn);
-#endif
     }
 
     return KRun::run(*offer, lst, window, tempFile, suggestedFileName, asn);
@@ -193,19 +155,6 @@ bool KRun::runUrl(const KUrl& u, const QString& _mimetype, QWidget* window, bool
 bool KRun::displayOpenWithDialog(const KUrl::List& lst, QWidget* window, bool tempFiles,
                                  const QString& suggestedFileName, const QByteArray& asn)
 {
-    if (!KAuthorized::authorizeKAction("openwith")) {
-        KMessageBox::sorry(window,
-                           i18n("You are not authorized to select an application to open this file."));
-        return false;
-    }
-
-#ifdef Q_WS_WIN
-    KConfigGroup cfgGroup(KGlobal::config(), "KOpenWithDialog Settings");
-    if (cfgGroup.readEntry("Native", true)) {
-        return KRun::KRunPrivate::displayNativeOpenWithDialog(lst, window, tempFiles,
-                suggestedFileName, asn);
-    }
-#endif
     KOpenWithDialog l(lst, i18n("Open with:"), QString(), window);
     l.setWindowModality(Qt::WindowModal);
     if (l.exec()) {
@@ -219,17 +168,6 @@ bool KRun::displayOpenWithDialog(const KUrl::List& lst, QWidget* window, bool te
     return false;
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KRun::shellQuote(QString &_str)
-{
-    // Credits to Walter, says Bernd G. :)
-    if (_str.isEmpty()) { // Don't create an explicit empty parameter
-        return;
-    }
-    QChar q('\'');
-    _str.replace(q, "'\\''").prepend(q).append(q);
-}
-#endif
 
 
 class KRunMX1 : public KMacroExpanderBase
@@ -241,7 +179,7 @@ public:
     bool hasUrls: 1, hasSpec: 1;
 
 protected:
-    virtual int expandEscapedMacro(const QString &str, int pos, QStringList &ret);
+    int expandEscapedMacro(const QString &str, int pos, QStringList &ret) final;
 
 private:
     const KService &service;
@@ -259,7 +197,7 @@ KRunMX1::expandEscapedMacro(const QString &str, int pos, QStringList &ret)
         ret << service.entryPath().replace('%', "%%");
         break;
     case 'i':
-        ret << "--icon" << service.icon().replace('%', "%%");
+        ret << service.icon().replace('%', "%%");
         break;
     case 'm':
 //       ret << "-miniicon" << service.icon().replace( '%', "%%" );
@@ -294,7 +232,7 @@ public:
     bool ignFile: 1;
 
 protected:
-    virtual int expandEscapedMacro(const QString &str, int pos, QStringList &ret);
+    int expandEscapedMacro(const QString &str, int pos, QStringList &ret) final;
 
 private:
     void subst(int option, const KUrl &url, QStringList &ret);
@@ -376,8 +314,7 @@ static QStringList supportedProtocols(const KService& _service)
     QString exec = _service.exec();
     if (mx1.expandMacrosShellQuote(exec) && !mx1.hasUrls) {
         Q_ASSERT(supportedProtocols.isEmpty());   // huh? If you support protocols you need %u or %U...
-    }
-    else {
+    } else {
         if (supportedProtocols.isEmpty()) {
             // compat mode: assume KIO if not set and it's a KDE app (or a KDE service)
             const QStringList categories = _service.property("Categories").toStringList();
@@ -423,13 +360,14 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
         return QStringList();
     }
 
+    const QString kioexec = KStandardDirs::findExe("kioexec");
+    Q_ASSERT(!kioexec.isEmpty());
+
     // FIXME: the current way of invoking kioexec disables term and su use
 
     // Check if we need "tempexec" (kioexec in fact)
     appHasTempFileOption = tempFiles && _service.property("X-KDE-HasTempFileOption").toBool();
     if (tempFiles && !appHasTempFileOption && _urls.size()) {
-        const QString kioexec = KStandardDirs::findExe("kioexec");
-        Q_ASSERT(!kioexec.isEmpty());
         result << kioexec << "--tempfiles" << exec;
         if (!suggestedFileName.isEmpty()) {
             result << "--suggestedfilename";
@@ -459,8 +397,6 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
     }
     if (useKioexec) {
         // We need to run the app through kioexec
-        const QString kioexec = KStandardDirs::findExe("kioexec");
-        Q_ASSERT(!kioexec.isEmpty());
         result << kioexec;
         if (tempFiles) {
             result << "--tempfiles";
@@ -496,8 +432,8 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
      2 << split(term) << "-e"                                    << split(cmd)
      3 << split(term) << "-e"                                    << "sh" << "-c" << cmd
 
-     4                        << "kdesu" << "-u" << user << "-c" << cmd
-     5                        << "kdesu" << "-u" << user << "-c" << ("sh -c " + quote(cmd))
+     4                        << "kdesudo" << "-u" << user << "-c" << cmd
+     5                        << "kdesudo" << "-u" << user << "-c" << ("sh -c " + quote(cmd))
      6 << split(term) << "-e" << "su"            << user << "-c" << cmd
      7 << split(term) << "-e" << "su"            << user << "-c" << ("sh -c " + quote(cmd))
 
@@ -512,7 +448,7 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
             if (!_service.path().isEmpty()) {
                 terminal += " --workdir " + KShell::quoteArg(_service.path());
             }
-            terminal += " -caption=%c %i %m";
+            terminal += " --icon '%i' --caption '%c'";
         }
         terminal += ' ';
         terminal += _service.terminalOptions();
@@ -540,7 +476,7 @@ QStringList KRun::processDesktopExec(const KService &_service, const KUrl::List&
             result << "su";
         }
         else {
-            result << KStandardDirs::findExe("kdesu") << "-u";
+            result << KStandardDirs::findExe("kdesudo") << "-u";
         }
 
         result << _service.username() << "-c";
@@ -582,7 +518,7 @@ static bool runCommandInternal(KProcess* proc, const KService* service, const QS
                                const QByteArray& asn)
 {
     if (window != NULL) {
-        window = window->topLevelWidget();
+        window = window->window();
     }
     if (service && !service->entryPath().isEmpty()
             && !KDesktopFile::isAuthorizedDesktopFile(service->entryPath()))
@@ -632,7 +568,7 @@ static bool runCommandInternal(KProcess* proc, const KService* service, const QS
             data.setApplicationId(service->entryPath());
         KStartupInfo::sendStartup(id, data);
     }
-    int pid = KProcessRunner::run(proc, executable, id);
+    qint64 pid = KProcessRunner::run(proc, executable, id);
     if (startup_notify && pid) {
         KStartupInfoData data;
         data.addPid(pid);
@@ -727,8 +663,14 @@ static bool runTempService(const KService& _service, const KUrl::List& _urls, QW
     KProcess * proc = new KProcess;
     *proc << args;
 
-    if (!_service.path().isEmpty()) {
-        proc->setWorkingDirectory(_service.path());
+    const QString& path = _service.path();
+    if (!path.isEmpty()) {
+        proc->setWorkingDirectory(path);
+    } else if (!_urls.isEmpty()) {
+        const KUrl& url = _urls.first();
+        if (url.isLocalFile()) {
+            proc->setWorkingDirectory(url.directory());
+        }
     }
 
     return runCommandInternal(proc, &_service, KRun::binaryName(_service.exec(), false),
@@ -891,12 +833,6 @@ static bool makeFileExecutable(const QString &fileName)
 // to make the file executable or we failed to make it executable.
 static bool makeServiceExecutable(const KService& service, QWidget* window)
 {
-    if (!KAuthorized::authorize("run_desktop_files")) {
-        kWarning() << "No authorization to execute " << service.entryPath();
-        KMessageBox::sorry(window, i18n("You are not authorized to execute this service."));
-        return false; // Don't circumvent the Kiosk
-    }
-
     KGuiItem continueItem = KStandardGuiItem::cont();
 
     SecureMessageDialog *baseDialog = new SecureMessageDialog(window);
@@ -1008,7 +944,7 @@ bool KRun::run(const KService& _service, const KUrl::List& _urls, QWidget* windo
     const KUrl::List urls = resolveURLs(_urls, _service);
 
     QString error;
-    int pid = 0;
+    qint64 pid = 0;
 
     QByteArray myasn = asn;
     // startServiceByDesktopPath() doesn't take QWidget*, add it to the startup info now
@@ -1048,11 +984,6 @@ bool KRun::run(const QString& _exec, const KUrl::List& _urls, QWidget* window, c
     return run(*service, _urls, window, false, QString(), asn);
 }
 
-bool KRun::runCommand(const QString &cmd, QWidget* window)
-{
-    return runCommand(cmd, window, QString());
-}
-
 bool KRun::runCommand(const QString& cmd, QWidget* window, const QString& workingDirectory)
 {
     if (cmd.isEmpty()) {
@@ -1070,11 +1001,6 @@ bool KRun::runCommand(const QString& cmd, QWidget* window, const QString& workin
     return KRun::runCommand(cmd, bin, bin /*iconName*/, window, QByteArray(), workingDirectory);
 }
 
-bool KRun::runCommand(const QString& cmd, const QString &execName, const QString & iconName, QWidget* window, const QByteArray& asn)
-{
-    return runCommand(cmd, execName, iconName, window, asn, QString());
-}
-
 bool KRun::runCommand(const QString& cmd, const QString &execName, const QString & iconName,
                       QWidget* window, const QByteArray& asn, const QString& workingDirectory)
 {
@@ -1134,19 +1060,8 @@ void KRun::init()
 {
     kDebug(7010) << "INIT called";
     if (!d->m_strURL.isValid()) {
-        // TODO KDE5: call virtual method on error (see BrowserRun::init)
         d->m_showingDialog = true;
-        KMessageBoxWrapper::error(d->m_window, i18n("Malformed URL\n%1", d->m_strURL.url()));
-        d->m_showingDialog = false;
-        d->m_bFault = true;
-        d->m_bFinished = true;
-        d->startTimer();
-        return;
-    }
-    if (!KAuthorized::authorizeUrlAction("open", KUrl(), d->m_strURL)) {
-        QString msg = KIO::buildErrorString(KIO::ERR_ACCESS_DENIED, d->m_strURL.prettyUrl());
-        d->m_showingDialog = true;
-        KMessageBoxWrapper::error(d->m_window, msg);
+        error(i18n("Malformed URL\n%1", d->m_strURL.url()));
         d->m_showingDialog = false;
         d->m_bFault = true;
         d->m_bFinished = true;
@@ -1167,10 +1082,11 @@ void KRun::init()
             KDE_struct_stat buff;
             if (KDE::stat(d->m_strURL.toLocalFile(), &buff) == -1) {
                 d->m_showingDialog = true;
-                KMessageBoxWrapper::error(d->m_window,
-                                          i18n("<qt>Unable to run the command specified. "
-                                          "The file or folder <b>%1</b> does not exist.</qt>" ,
-                                          Qt::escape(d->m_strURL.prettyUrl())));
+                error(
+                    i18n("<qt>Unable to run the command specified. "
+                    "The file or folder <b>%1</b> does not exist.</qt>" ,
+                    Qt::escape(d->m_strURL.prettyUrl()))
+                );
                 d->m_showingDialog = false;
                 d->m_bFault = true;
                 d->m_bFinished = true;
@@ -1191,9 +1107,8 @@ void KRun::init()
             }
         } else if (mime->isDefault() && !QFileInfo(d->m_strURL.toLocalFile()).isReadable()) {
             // Unknown mimetype because the file is unreadable, no point in showing an open-with dialog (#261002)
-            const QString msg = KIO::buildErrorString(KIO::ERR_ACCESS_DENIED, d->m_strURL.prettyUrl());
             d->m_showingDialog = true;
-            KMessageBoxWrapper::error(d->m_window, msg);
+            error(KIO::buildErrorString(KIO::ERR_ACCESS_DENIED, d->m_strURL.prettyUrl()));
             d->m_showingDialog = false;
             d->m_bFault = true;
             d->m_bFinished = true;
@@ -1375,8 +1290,7 @@ void KRun::slotStatResult(KJob * job)
 
         // will emit the error and autodelete this
         d->startTimer();
-    }
-    else {
+    } else {
         kDebug(7010) << "Finished";
 
         KIO::StatJob* statJob = qobject_cast<KIO::StatJob*>(job);
@@ -1513,6 +1427,11 @@ void KRun::foundMimeType(const QString& type)
     setFinished(true);
 }
 
+void KRun::error(const QString& message)
+{
+    KMessageBoxWrapper::error(window(), message);
+}
+
 void KRun::killJob()
 {
     if (d->m_job) {
@@ -1648,53 +1567,11 @@ KIO::Job* KRun::job()
     return d->m_job;
 }
 
-#ifndef KDE_NO_DEPRECATED
-QTimer& KRun::timer()
-{
-    return d->m_timer;
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-void KRun::setDoScanFile(bool scanFile)
-{
-    d->m_bScanFile = scanFile;
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-bool KRun::doScanFile() const
-{
-    return d->m_bScanFile;
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-void KRun::setIsDirecory(bool isDirectory)
-{
-    d->m_bIsDirectory = isDirectory;
-}
-#endif
-
 bool KRun::isDirectory() const
 {
     return d->m_bIsDirectory;
 }
 
-#ifndef KDE_NO_DEPRECATED
-void KRun::setInitializeNextAction(bool initialize)
-{
-    d->m_bInit = initialize;
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-bool KRun::initializeNextAction() const
-{
-    return d->m_bInit;
-}
-#endif
-
 void KRun::setIsLocalFile(bool isLocalFile)
 {
     d->m_bIsLocalFile = isLocalFile;
@@ -1718,12 +1595,12 @@ mode_t KRun::mode() const
 /****************/
 
 #ifndef Q_WS_X11
-int KProcessRunner::run(KProcess * p, const QString & executable)
+qint64 KProcessRunner::run(KProcess * p, const QString & executable)
 {
     return (new KProcessRunner(p, executable))->pid();
 }
 #else
-int KProcessRunner::run(KProcess * p, const QString & executable, const KStartupInfoId& id)
+qint64 KProcessRunner::run(KProcess * p, const QString & executable, const KStartupInfoId& id)
 {
     return (new KProcessRunner(p, executable, id))->pid();
 }
@@ -1732,36 +1609,37 @@ int KProcessRunner::run(KProcess * p, const QString & executable, const KStartup
 #ifndef Q_WS_X11
 KProcessRunner::KProcessRunner(KProcess * p, const QString & executable)
 #else
-KProcessRunner::KProcessRunner(KProcess * p, const QString & executable, const KStartupInfoId& _id) :
-        id(_id)
+KProcessRunner::KProcessRunner(KProcess * p, const QString & executable, const KStartupInfoId& id)
 #endif
+    : m_process(p),
+    m_executable(executable),
+#ifdef Q_WS_X11
+    m_id(id),
+#endif
+    m_pid(0)
 {
-    m_pid = 0;
-    process = p;
-    m_executable = executable;
-    connect(process, SIGNAL(finished(int,QProcess::ExitStatus)),
+    connect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)),
             this, SLOT(slotProcessExited(int,QProcess::ExitStatus)));
 
-    process->start();
-    if (!process->waitForStarted()) {
+    m_process->start();
+    if (!m_process->waitForStarted()) {
         //kDebug() << "wait for started failed, exitCode=" << process->exitCode()
         //         << "exitStatus=" << process->exitStatus();
         // Note that exitCode is 255 here (the first time), and 0 later on (bug?).
-        slotProcessExited(255, process->exitStatus());
-    }
-    else {
+        slotProcessExited(255, m_process->exitStatus());
+    } else {
 #ifdef Q_WS_X11
-        m_pid = process->pid();
+        m_pid = m_process->pid();
 #endif
     }
 }
 
 KProcessRunner::~KProcessRunner()
 {
-    delete process;
+    delete m_process;
 }
 
-int KProcessRunner::pid() const
+qint64 KProcessRunner::pid() const
 {
     return m_pid;
 }
@@ -1769,11 +1647,11 @@ int KProcessRunner::pid() const
 void KProcessRunner::terminateStartupNotification()
 {
 #ifdef Q_WS_X11
-    if (!id.none()) {
+    if (!m_id.none()) {
         KStartupInfoData data;
         data.addPid(m_pid); // announce this pid for the startup notification has finished
         data.setHostname();
-        KStartupInfo::sendFinish(id, data);
+        KStartupInfo::sendFinish(m_id, data);
     }
 #endif
 
@@ -1797,13 +1675,12 @@ KProcessRunner::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
             KGlobal::ref();
             KMessageBox::sorry(0L, i18n("Could not find the program '%1'", m_executable));
             KGlobal::deref();
-        }
-        else {
-            kDebug() << process->readAllStandardError();
+        } else {
+            kDebug() << m_process->readAllStandardError();
         }
     }
     deleteLater();
 }
 
-#include "krun.moc"
-#include "krun_p.moc"
+#include "moc_krun.cpp"
+#include "moc_krun_p.cpp"
