@@ -142,8 +142,7 @@ public:
      * its mimetype will have been found by KRun. IMPORTANT: the service is
      * only used if its configuration says it can handle this mimetype.
      * This is used for instance for the X-KDE-LastOpenedWith key in
-     * the recent documents list, or for the app selection in
-     * KParts::BrowserOpenOrSaveQuestion.
+     * the recent documents list.
      * @param desktopEntryName the desktopEntryName of the service, e.g. "kate".
      */
     void setPreferredService(const QString& desktopEntryName);
@@ -178,6 +177,12 @@ public:
      */
     QString suggestedFileName() const;
 
+    /**
+     * Associated window, as passed to the constructor
+     * @since 4.9.3
+     */
+    QWidget* window() const;
+
 
     /**
      * Open a list of URLs with a certain service (application).
@@ -250,18 +255,12 @@ public:
      * @p cmd must be a shell command. You must not append "&"
      * to it, since the function will do that for you.
      * @param window The top-level widget of the app that invoked this object.
+     * @param workingDirectory a working directory, so that a command like
+     *                         "kwrite file.txt" finds file.txt from the right place.
      *
      * @return @c true on success, @c false on error
      */
-    static bool runCommand(const QString &cmd, QWidget* window);
-
-    /**
-     * Overload that also takes a working directory, so that a command like
-     * "kwrite file.txt" finds file.txt from the right place.
-     * @since 4.4
-     */
-    static bool runCommand(const QString &cmd, QWidget* window, const QString& workingDirectory);
-    // TODO KDE5: merge the above with 2-args runCommand, using QString()
+    static bool runCommand(const QString &cmd, QWidget* window, const QString& workingDirectory = QString());
 
     /**
      * Same as the other runCommand(), but it also takes the name of the
@@ -273,22 +272,13 @@ public:
      * @param icon icon for app starting notification
      * @param window The top-level widget of the app that invoked this object.
      * @param asn Application startup notification id, if any (otherwise "").
-     * @return @c true on success, @c false on error
-     */
-    static bool runCommand(const QString& cmd, const QString & execName,
-                           const QString & icon, QWidget* window, const QByteArray& asn = QByteArray());
-
-    /**
-     * Overload that also takes a working directory, so that a command like
-     * "kwrite file.txt" finds file.txt from the right place.
      * @param workingDirectory the working directory for the started process. The default
      *                         (if passing an empty string) is the user's document path.
-     * @since 4.4
+     * @return @c true on success, @c false on error
      */
-    static bool runCommand(const QString& cmd, const QString & execName,
-                           const QString & icon, QWidget* window,
-                           const QByteArray& asn, const QString& workingDirectory);
-    // TODO KDE5: merge the above with 5-args runCommand, using QString()
+    static bool runCommand(const QString& cmd, const QString& execName,
+                           const QString& icon, QWidget* window, const QByteArray& asn = QByteArray(),
+                           const QString& workingDirectory = QString());
 
     /**
      * Display the Open-With dialog for those URLs, and run the chosen application.
@@ -304,20 +294,6 @@ public:
                                       bool tempFiles = false, const QString& suggestedFileName = QString(),
                                       const QByteArray& asn = QByteArray());
 
-    /**
-     * Quotes a string for the shell.
-     * An empty string will @em not be quoted.
-     *
-     * @deprecated Use KShell::quoteArg() instead. @em Note that this function
-     *  behaves differently for empty arguments and returns the result
-     *  differently.
-     *
-     * @param str the string to quote. The quoted string will be written here
-     */
-#ifndef KDE_NO_DEPRECATED
-    static KDE_DEPRECATED void shellQuote(QString &str);
-#endif
-
     /**
      * Processes a Exec= line as found in .desktop files.
      * @param _service the service to extract information from.
@@ -442,6 +418,11 @@ protected:
      */
     virtual void foundMimeType(const QString& type);
 
+    /**
+     * Called if error occurres.
+     */
+    virtual void error(const QString& message);
+
     /**
      * Kills the file scanning job.
      */
@@ -487,58 +468,11 @@ protected:
      */
     KIO::Job* job();
 
-    /**
-     * Returns the timer object.
-     * @deprecated setFinished(true) now takes care of the timer().start(0),
-     * so this can be removed.
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED QTimer& timer();
-#endif
-
-    /**
-     * Indicate that the next action is to scan the file.
-     * @deprecated not useful in public API
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED void setDoScanFile(bool scanFile);
-#endif
-
-    /**
-     * Returns whether the file shall be scanned.
-     * @deprecated not useful in public API
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED bool doScanFile() const;
-#endif
-
-    /**
-     * Sets whether it is a directory.
-     * @deprecated typo in the name, and not useful as a public method
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED void setIsDirecory(bool isDirectory);
-#endif
-
     /**
      * Returns whether it is a directory.
      */
     bool isDirectory() const;
 
-    /**
-     * @deprecated not useful in public API
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED void setInitializeNextAction(bool initialize);
-#endif
-
-    /**
-     * @deprecated not useful in public API
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED bool initializeNextAction() const;
-#endif
-
     /**
      * Sets whether it is a local file.
      */
