@@ -20,20 +20,19 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef KIO_NETACCESS_h
-#define KIO_NETACCESS_h
+#ifndef KIO_NETACCESS_H
+#define KIO_NETACCESS_H
 
 #include <QtCore/QObject>
-#include <QtCore/QString>
 #include <kio/global.h>
 #include <kio/udsentry.h>
 #include <kurl.h>
 #include <kio/jobclasses.h> // for KIO::JobFlags
 
-class QStringList;
-class QWidget;
+#include <QStringList>
+#include <QWidget>
 
-template<typename T, typename K> class QMap;
+#include <QMap>
 
 class KJob;
 namespace KIO {
@@ -190,11 +189,6 @@ public:
      * @return true if successful, false for failure
      */
     static bool file_copy( const KUrl& src, const KUrl& target, QWidget* window = 0 );
-    /// @deprecated, use file_copy instead
-#ifndef KDE_NO_DEPRECATED
-    static KDE_DEPRECATED bool copy( const KUrl& src, const KUrl& target,
-                                     QWidget* window = 0 );
-#endif
 
     /**
      * Alternative method for copying over the network.
@@ -223,45 +217,6 @@ public:
      */
     static bool dircopy( const KUrl::List& src, const KUrl& target, QWidget* window = 0L ); // TODO deprecate in favor of KIO::copy + synchronousRun (or job->exec())
 
-    /**
-     * Full-fledged equivalent of KIO::move.
-     * Moves or renames one file or directory.
-     * @deprecated use KIO::move and then KIO::NetAccess::synchronousRun (or job->exec())
-     */
-#ifndef KDE_NO_DEPRECATED
-    static KDE_DEPRECATED bool move( const KUrl& src, const KUrl& target, QWidget* window = 0L );
-#endif
-
-    /**
-     * Full-fledged equivalent of KIO::move.
-     * Moves or renames a list of files or directories.
-     * @deprecated use KIO::move and then KIO::NetAccess::synchronousRun (or job->exec())
-     */
-#ifndef KDE_NO_DEPRECATED
-    static KDE_DEPRECATED bool move( const KUrl::List& src, const KUrl& target, QWidget* window = 0L );
-#endif
-
-    /**
-     * Tests whether a URL exists.
-     *
-     * @param url the URL we are testing
-     * @param source if true, we want to read from that URL.
-     *               If false, we want to write to it.
-     * IMPORTANT: see documentation for KIO::stat for more details about this.
-     * @param window main window associated with this job. This is used to
-     *               automatically cache and discard authentication information
-     *               as needed. If NULL, authentication information will be
-     *               cached only for a short duration after which the user will
-     *               again be prompted for passwords as needed.
-     * @return true if the URL exists and we can do the operation specified by
-     *              @p source, false otherwise
-     *
-     * @deprecated use the StatSide enum instead of the bool source
-     */
-#ifndef KDE_NO_DEPRECATED
-    static KDE_DEPRECATED bool exists(const KUrl& url, bool source, QWidget* window);
-#endif
-
     /**
      * Tests whether a URL exists.
      *
@@ -347,26 +302,6 @@ public:
      */
     static bool mkdir( const KUrl & url, QWidget* window, int permissions = -1 );
 
-    /**
-     * Executes a remote process via the fish ioslave in a synchronous way.
-     *
-     * @param url The remote machine where the command should be executed.
-     *            e.g. fish://someuser\@somehost:sshport/
-     *            some special cases exist.
-     *            fish://someuser\@localhost/
-     *            will use su instead of ssh to connect and execute the command.
-     *            fish://someuser\@localhost:port/
-     *            will use ssh to connect and execute the command.
-     * @param command The command to be executed.
-     * @param window main window associated with this job. This is used to
-     *               automatically cache and discard authentication information
-     *               as needed. If NULL, authentication information will be
-     *               cached only for a short duration after which the user will
-     *               again be prompted for passwords as needed.
-     * @return The resulting output of the @p command that is executed.
-     */
-    static QString fish_execute( const KUrl & url, const QString &command, QWidget* window );
-
     /**
      * This function executes a job in a synchronous way.
      * If a job fetches some data, pass a QByteArray pointer as data parameter to this function
@@ -375,10 +310,9 @@ public:
      * @code
      * KIO::Job *job = KIO::get( url );
      * QMap<QString, QString> metaData;
-     * metaData.insert( "PropagateHttpHeader", "true" );
+     * metaData.insert( "no-auth", "yes" );
      * if ( NetAccess::synchronousRun( job, 0, &data, &url, &metaData ) ) {
-     *   QString responseHeaders = metaData[ "HTTP-Headers" ];
-     *   kDebug()<<"Response header = "<< responseHeaders;
+     *   kDebug()<<"Success";
      * }
      * @endcode
      *
@@ -460,15 +394,12 @@ private:
 
     bool delInternal(const KUrl & url, QWidget* window = 0);
     bool mkdirInternal(const KUrl & url, int permissions, QWidget* window = 0);
-    QString fish_executeInternal(const KUrl & url, const QString &command, QWidget* window = 0);
     bool synchronousRunInternal( Job* job, QWidget* window, QByteArray* data,
                                  KUrl* finalURL, QMap<QString,QString>* metaData );
 
     QString mimetypeInternal(const KUrl & url, QWidget* window = 0);
     void enter_loop();
 
-    friend class I_like_this_class;
-
 private Q_SLOTS:
     void slotResult( KJob * job );
     void slotMimetype( KIO::Job * job, const QString & type );
