@@ -22,19 +22,20 @@
 #ifndef KIO_RENAMEDIALOG_H
 #define KIO_RENAMEDIALOG_H
 
+#include <ksqueezedtextlabel.h>
 #include <kurl.h>
 #include <QtGui/QDialog>
-#include <QtCore/QString>
 #include <sys/types.h>
 
 #include <kio/global.h>
 
-class QScrollArea;
-class QLabel;
-class QPixmap;
+#include <QScrollArea>
+#include <QLabel>
+#include <QPixmap>
 class KFileItem;
 
-namespace KIO {
+namespace KIO
+{
 
 // KDE5: get rid of M_OVERWRITE_ITSELF, trigger it internally if src==dest
 // KDE5: get rid of M_SINGLE. If not multi, then single ;)
@@ -67,80 +68,82 @@ enum RenameDialog_Result {R_RESUME = 6, R_RESUME_ALL = 7, R_OVERWRITE = 4, R_OVE
  */
 class KIO_EXPORT RenameDialog : public QDialog
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
-  /**
-   * Construct a "rename" dialog to let the user know that @p src is about to overwrite @p dest.
-   *
-   * @param parent parent widget (often 0)
-   * @param caption the caption for the dialog box
-   * @param src the url to the file/dir we're trying to copy, as it's part of the text message
-   * @param dest the path to destination file/dir, i.e. the one that already exists
-   * @param mode parameters for the dialog (which buttons to show...),
-   * @param sizeSrc size of source file
-   * @param sizeDest size of destination file
-   * @param ctimeSrc creation time of source file
-   * @param ctimeDest creation time of destination file
-   * @param mtimeSrc modification time of source file
-   * @param mtimeDest modification time of destination file
-   * @see RenameDialog_Mode
-   */
-  RenameDialog( QWidget *parent, const QString & caption,
-             const KUrl & src, const KUrl & dest,
-             RenameDialog_Mode mode,
-             KIO::filesize_t sizeSrc = KIO::filesize_t(-1),
-             KIO::filesize_t sizeDest = KIO::filesize_t(-1),
-             time_t ctimeSrc = time_t(-1),
-             time_t ctimeDest = time_t(-1),
-             time_t mtimeSrc = time_t(-1),
-             time_t mtimeDest = time_t(-1) );
-  ~RenameDialog();
+    /**
+     * Construct a "rename" dialog to let the user know that @p src is about to overwrite @p dest.
+     *
+     * @param parent parent widget (often 0)
+     * @param caption the caption for the dialog box
+     * @param src the url to the file/dir we're trying to copy, as it's part of the text message
+     * @param dest the path to destination file/dir, i.e. the one that already exists
+     * @param mode parameters for the dialog (which buttons to show...),
+     * @param sizeSrc size of source file
+     * @param sizeDest size of destination file
+     * @param ctimeSrc creation time of source file
+     * @param ctimeDest creation time of destination file
+     * @param mtimeSrc modification time of source file
+     * @param mtimeDest modification time of destination file
+     * @see RenameDialog_Mode
+     */
+    RenameDialog(QWidget *parent, const QString & caption,
+                 const KUrl & src, const KUrl & dest,
+                 RenameDialog_Mode mode,
+                 KIO::filesize_t sizeSrc = KIO::filesize_t(-1),
+                 KIO::filesize_t sizeDest = KIO::filesize_t(-1),
+                 time_t ctimeSrc = time_t(-1),
+                 time_t ctimeDest = time_t(-1),
+                 time_t mtimeSrc = time_t(-1),
+                 time_t mtimeDest = time_t(-1));
+    ~RenameDialog();
 
-  /**
-   * @return the new destination
-   * valid only if RENAME was chosen
-   */
-  KUrl newDestUrl();
+    /**
+     * @return the new destination
+     * valid only if RENAME was chosen
+     */
+    KUrl newDestUrl();
 
 
-  /**
-   * @return an automatically renamed destination
-   * @since 4.5
-   * valid always
-   */
-  KUrl autoDestUrl() const;
+    /**
+     * @return an automatically renamed destination
+     * @since 4.5
+     * valid always
+     */
+    KUrl autoDestUrl() const;
 
-  /**
-   * Given a directory path and a filename (which usually exists already),
-   * this function returns a suggested name for a file that doesn't exist
-   * in that directory. The existence is only checked for local urls though.
-   * The suggested file name is of the form foo_1 foo_2 etc.
-   */
-  static QString suggestName(const KUrl& baseURL, const QString& oldName);
+    /**
+     * Given a directory path and a filename (which usually exists already),
+     * this function returns a suggested name for a file that doesn't exist
+     * in that directory. The existence is only checked for local urls though.
+     * The suggested file name is of the form "foo 1", "foo 2" etc.
+     */
+    static QString suggestName(const KUrl& baseURL, const QString& oldName);
 
 public Q_SLOTS:
-  void cancelPressed();
-  void renamePressed();
-  void skipPressed();
-  void autoSkipPressed();
-  void overwritePressed();
-  void overwriteAllPressed();
-  void resumePressed();
-  void resumeAllPressed();
-  void suggestNewNamePressed();
+    void cancelPressed();
+    void renamePressed();
+    void skipPressed();
+    void autoSkipPressed();
+    void overwritePressed();
+    void overwriteAllPressed();
+    void resumePressed();
+    void resumeAllPressed();
+    void suggestNewNamePressed();
 
 protected Q_SLOTS:
-  void enableRenameButton(const QString &);
+    void enableRenameButton(const QString &);
 private Q_SLOTS:
     void applyAllPressed();
     void showSrcIcon(const KFileItem &);
     void showDestIcon(const KFileItem &);
     void showSrcPreview(const KFileItem &, const QPixmap &);
     void showDestPreview(const KFileItem &, const QPixmap &);
+    void resizePanels();
 
 private:
     QScrollArea* createContainerLayout(QWidget* parent, const KFileItem& item, QLabel* preview);
-    QLabel* createLabel(QWidget* parent, const QString& text);
+    QLabel* createLabel(QWidget* parent, const QString& text, const bool containerTitle);
+    KSqueezedTextLabel* createSqueezedLabel(QWidget* parent, const QString& text);
     class RenameDialogPrivate;
     RenameDialogPrivate* const d;
 };
