@@ -21,7 +21,6 @@
 #include "scheduler.h"
 #include "scheduler_p.h"
 
-#include "sessiondata.h"
 #include "slaveconfig.h"
 #include "authinfo.h"
 #include "slave.h"
@@ -31,11 +30,16 @@
 #include <kdebug.h>
 #include <kprotocolmanager.h>
 #include <kprotocolinfo.h>
-#include <assert.h>
 
-#include <QtCore/QHash>
-#include <QtGui/QWidget>
-#include <QtDBus/QtDBus>
+
+#include <QtCore/qhash.h>
+#include <QtCore/qcoreapplication.h>
+#include <QtCore/qthread.h>
+#include <QtDBus/QDBusConnection>
+#include <QtDBus/QDBusInterface>
+#include <QtGui/qwidget.h>
+
+#include <assert.h>
 
 // Slaves may be idle for a certain time (3 minutes) before they are killed.
 static const int s_idleSlaveLifetime = 3 * 60;
@@ -43,12 +47,10 @@ static const int s_idleSlaveLifetime = 3 * 60;
 
 using namespace KIO;
 
-#ifndef KDE_USE_FINAL // already defined in job.cpp
 static inline Slave *jobSlave(SimpleJob *job)
 {
     return SimpleJobPrivate::get(job)->m_slave;
 }
-#endif
 
 static inline int jobCommand(SimpleJob *job)
 {
@@ -63,11 +65,49 @@ static inline void startJob(SimpleJob *job, Slave *slave)
 // here be uglies
 // forward declaration to break cross-dependency of SlaveKeeper and SchedulerPrivate
 static void setupSlave(KIO::Slave *slave, const KUrl &url, const QString &protocol,
-                       const QStringList &proxyList, bool newSlave, const KIO::MetaData *config = 0);
+                       const QStringList &proxyList, bool newSlave);
 // same reason as above
 static Scheduler *scheduler();
 static Slave *heldSlaveForJob(SimpleJob *job);
 
+/********************************* SessionData ****************************/
+
+SessionData::SessionData()
+{
+    initDone = false;
+}
+
+SessionData::~SessionData()
+{
+}
+
+void SessionData::configDataFor( MetaData &configData, const QString &proto)
+{
+  if ( (proto.startsWith(QLatin1String("http"), Qt::CaseInsensitive)) )
+  {
+    if (!initDone)
+        reset();
+
+    // These might have already been set so check first
+    // to make sure that we do not trumpt settings sent
+    // by apps or end-user.
+    if ( configData["Languages"].isEmpty() )
+        configData["Languages"] = language;
+    if ( configData["Charsets"].isEmpty() )
+        configData["Charsets"] = charsets;
+    if ( configData["UserAgent"].isEmpty() )
+        configData["UserAgent"] = KProtocolManager::defaultUserAgent();
+  }
+}
+
+void SessionData::reset()
+{
+    initDone = true;
+
+    language = KProtocolManager::acceptLanguagesHeader();
+    charsets = QString::fromLatin1(QTextCodec::codecForLocale()->name()).toLower();
+    KProtocolManager::reparseConfiguration();
+}
 
 int SerialPicker::changedPrioritySerial(int oldSerial, int newPriority) const
 {
@@ -81,7 +121,7 @@ int SerialPicker::changedPrioritySerial(int oldSerial, int newPriority) const
 SlaveKeeper::SlaveKeeper()
 {
     m_grimTimer.setSingleShot(true);
-    connect (&m_grimTimer, SIGNAL(timeout()), SLOT(grimReaper()));
+    connect(&m_grimTimer, SIGNAL(timeout()), this, SLOT(grimReaper()));
 }
 
 void SlaveKeeper::returnSlave(Slave *slave)
@@ -214,147 +254,6 @@ QList<Slave *> HostQueue::allSlaves() const
     return ret;
 }
 
-
-
-ConnectedSlaveQueue::ConnectedSlaveQueue()
-{
-    m_startJobsTimer.setSingleShot(true);
-    connect (&m_startJobsTimer, SIGNAL(timeout()), SLOT(startRunnableJobs()));
-}
-
-bool ConnectedSlaveQueue::queueJob(SimpleJob *job, Slave *slave)
-{
-    QHash<Slave *, PerSlaveQueue>::Iterator it = m_connectedSlaves.find(slave);
-    if (it == m_connectedSlaves.end()) {
-        return false;
-    }
-    SimpleJobPrivate::get(job)->m_slave = slave;
-
-    PerSlaveQueue &jobs = it.value();
-    jobs.waitingList.append(job);
-    if (!jobs.runningJob) {
-        // idle slave now has a job to run
-        m_runnableSlaves.insert(slave);
-        m_startJobsTimer.start();
-    }
-    return true;
-}
-
-bool ConnectedSlaveQueue::removeJob(SimpleJob *job)
-{
-    Slave *slave = jobSlave(job);
-    Q_ASSERT(slave);
-    QHash<Slave *, PerSlaveQueue>::Iterator it = m_connectedSlaves.find(slave);
-    if (it == m_connectedSlaves.end()) {
-        return false;
-    }
-    PerSlaveQueue &jobs = it.value();
-    if (jobs.runningJob || jobs.waitingList.isEmpty()) {
-        // a slave that was busy running a job was not runnable.
-        // a slave that has no waiting job(s) was not runnable either.
-        Q_ASSERT(!m_runnableSlaves.contains(slave));
-    }
-
-    const bool removedRunning = jobs.runningJob == job;
-    const bool removedWaiting = jobs.waitingList.removeAll(job) != 0;
-    if (removedRunning) {
-        jobs.runningJob = 0;
-        Q_ASSERT(!removedWaiting);
-    }
-    const bool removedTheJob = removedRunning || removedWaiting;
-
-    if (!slave->isAlive()) {
-        removeSlave(slave);
-        return removedTheJob;
-    }
-
-    if (removedRunning && jobs.waitingList.count()) {
-        m_runnableSlaves.insert(slave);
-        m_startJobsTimer.start();
-    }
-    if (removedWaiting && jobs.waitingList.isEmpty()) {
-        m_runnableSlaves.remove(slave);
-    }
-    return removedTheJob;
-}
-
-void ConnectedSlaveQueue::addSlave(Slave *slave)
-{
-    Q_ASSERT(slave);
-    if (!m_connectedSlaves.contains(slave)) {
-        m_connectedSlaves.insert(slave, PerSlaveQueue());
-    }
-}
-
-bool ConnectedSlaveQueue::removeSlave(Slave *slave)
-{
-    QHash<Slave *, PerSlaveQueue>::Iterator it = m_connectedSlaves.find(slave);
-    if (it == m_connectedSlaves.end()) {
-        return false;
-    }
-    PerSlaveQueue &jobs = it.value();
-    Q_FOREACH (SimpleJob *job, jobs.waitingList) {
-        // ### for compatibility with the old scheduler we don't touch the running job, if any.
-        // make sure that the job doesn't call back into Scheduler::cancelJob(); this would
-        // a) crash and b) be unnecessary because we clean up just fine.
-        SimpleJobPrivate::get(job)->m_schedSerial = 0;
-        job->kill();
-    }
-    m_connectedSlaves.erase(it);
-    m_runnableSlaves.remove(slave);
-
-    slave->kill();
-    return true;
-}
-
-// KDE5: only one caller, for doubtful reasons. remove this if possible.
-bool ConnectedSlaveQueue::isIdle(Slave *slave)
-{
-    QHash<Slave *, PerSlaveQueue>::Iterator it = m_connectedSlaves.find(slave);
-    if (it == m_connectedSlaves.end()) {
-        return false;
-    }
-    return it.value().runningJob == 0;
-}
-
-
-//private slot
-void ConnectedSlaveQueue::startRunnableJobs()
-{
-    QSet<Slave *>::Iterator it = m_runnableSlaves.begin();
-    while (it != m_runnableSlaves.end()) {
-        Slave *slave = *it;
-        if (!slave->isConnected()) {
-            // this polling is somewhat inefficient...
-            m_startJobsTimer.start();
-            ++it;
-            continue;
-        }
-        it = m_runnableSlaves.erase(it);
-        PerSlaveQueue &jobs = m_connectedSlaves[slave];
-        SimpleJob *job = jobs.waitingList.takeFirst();
-        Q_ASSERT(!jobs.runningJob);
-        jobs.runningJob = job;
-
-        const KUrl url = job->url();
-        // no port is -1 in QUrl, but in kde3 we used 0 and the kioslaves assume that.
-        const int port = url.port() == -1 ? 0 : url.port();
-
-        if (slave->host() == "<reset>") {
-            MetaData configData = SlaveConfig::self()->configData(url.protocol(), url.host());
-            slave->setConfig(configData);
-            slave->setProtocol(url.protocol());
-            slave->setHost(url.host(), port, url.user(), url.pass());
-        }
-
-        Q_ASSERT(slave->protocol() == url.protocol());
-        Q_ASSERT(slave->host() == url.host());
-        Q_ASSERT(slave->port() == port);
-        startJob(job, slave);
-    }
-}
-
-
 static void ensureNoDuplicates(QMap<int, HostQueue *> *queuesBySerial)
 {
     Q_UNUSED(queuesBySerial);
@@ -391,9 +290,8 @@ static void verifyRunningJobsCount(QHash<QString, HostQueue> *queues, int runnin
 }
 
 
-ProtoQueue::ProtoQueue(SchedulerPrivate *sp, int maxSlaves, int maxSlavesPerHost)
- : m_schedPrivate(sp),
-   m_maxConnectionsPerHost(maxSlavesPerHost ? maxSlavesPerHost : maxSlaves),
+ProtoQueue::ProtoQueue(int maxSlaves, int maxSlavesPerHost)
+ : m_maxConnectionsPerHost(maxSlavesPerHost ? maxSlavesPerHost : maxSlaves),
    m_maxConnectionsTotal(qMax(maxSlaves, maxSlavesPerHost)),
    m_runningJobsCount(0)
 
@@ -522,9 +420,7 @@ void ProtoQueue::removeJob(SimpleJob *job)
         // should be a connected slave
         // if the assertion fails the job has probably changed the host part of its URL while
         // running, so we can't find it by hostname. don't do this.
-        const bool removed = m_connectedSlaveQueue.removeJob(job);
-        Q_UNUSED(removed);
-        Q_ASSERT(removed);
+        Q_ASSERT(false);
     }
 
     ensureNoDuplicates(&m_queuesBySerial);
@@ -536,14 +432,10 @@ Slave *ProtoQueue::createSlave(const QString &protocol, SimpleJob *job, const KU
     QString errortext;
     Slave *slave = Slave::createSlave(protocol, url, error, errortext);
     if (slave) {
-        // Set the parent widget the slave should use to display message boxes.
-        if (job && job->ui()) {
-            slave->setWindow(job->ui()->window());
-        }
-        scheduler()->connect(slave, SIGNAL(slaveDied(KIO::Slave*)),
-                             SLOT(slotSlaveDied(KIO::Slave*)));
-        scheduler()->connect(slave, SIGNAL(slaveStatus(pid_t,QByteArray,QString,bool)),
-                             SLOT(slotSlaveStatus(pid_t,QByteArray,QString,bool)));
+        connect(
+            slave, SIGNAL(slaveDied(KIO::Slave*)),
+            scheduler(), SLOT(slotSlaveDied(KIO::Slave*))
+        );
     } else {
         kError() << "couldn't create slave:" << errortext;
         if (job) {
@@ -555,10 +447,9 @@ Slave *ProtoQueue::createSlave(const QString &protocol, SimpleJob *job, const KU
 
 bool ProtoQueue::removeSlave (KIO::Slave *slave)
 {
-    const bool removedConnected = m_connectedSlaveQueue.removeSlave(slave);
     const bool removedUnconnected = m_slaveKeeper.removeSlave(slave);
-    Q_ASSERT(!(removedConnected && removedUnconnected));
-    return removedConnected || removedUnconnected;
+    Q_ASSERT(!removedUnconnected);
+    return removedUnconnected;
 }
 
 QList<Slave *> ProtoQueue::allSlaves() const
@@ -567,7 +458,6 @@ QList<Slave *> ProtoQueue::allSlaves() const
     Q_FOREACH (const HostQueue &hq, m_queuesByHostname) {
         ret.append(hq.allSlaves());
     }
-    ret.append(m_connectedSlaveQueue.allSlaves());
     return ret;
 }
 
@@ -688,27 +578,20 @@ public:
     QMap<QObject *,WId> m_windowList;
 
     void doJob(SimpleJob *job);
-#ifndef KDE_NO_DEPRECATED
-    void scheduleJob(SimpleJob *job);
-#endif
     void setJobPriority(SimpleJob *job, int priority);
     void cancelJob(SimpleJob *job);
     void jobFinished(KIO::SimpleJob *job, KIO::Slave *slave);
     void putSlaveOnHold(KIO::SimpleJob *job, const KUrl &url);
     void removeSlaveOnHold();
-    Slave *getConnectedSlave(const KUrl &url, const KIO::MetaData &metaData);
-    bool assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job);
-    bool disconnectSlave(KIO::Slave *slave);
     void checkSlaveOnHold(bool b);
     void publishSlaveOnHold();
     Slave *heldSlaveForJob(KIO::SimpleJob *job);
     bool isSlaveOnHoldFor(const KUrl& url);
     void registerWindow(QWidget *wid);
-    void updateInternalMetaData(SimpleJob* job);
 
     MetaData metaDataFor(const QString &protocol, const QStringList &proxyList, const KUrl &url);
     void setupSlave(KIO::Slave *slave, const KUrl &url, const QString &protocol,
-                    const QStringList &proxyList, bool newSlave, const KIO::MetaData *config = 0);
+                    const QStringList &proxyList, bool newSlave);
 
     void slotSlaveDied(KIO::Slave *slave);
     void slotSlaveStatus(pid_t pid, const QByteArray &protocol,
@@ -717,8 +600,6 @@ public:
     void slotReparseSlaveConfiguration(const QString &, const QDBusMessage&);
     void slotSlaveOnHoldListChanged();
 
-    void slotSlaveConnected();
-    void slotSlaveError(int error, const QString &errorMsg);
     void slotUnregisterWindow(QObject *);
 
     ProtoQueue *protoQ(const QString& protocol, const QString& host)
@@ -739,7 +620,7 @@ public:
                 maxSlavesPerHost = KProtocolInfo::maxSlavesPerHost(protocol);
             }
             // Never allow maxSlavesPerHost to exceed maxSlaves.
-            pq = new ProtoQueue(this, maxSlaves, qMin(maxSlaves, maxSlavesPerHost));
+            pq = new ProtoQueue(maxSlaves, qMin(maxSlaves, maxSlavesPerHost));
             m_protocols.insert(protocol, pq);
         }
         return pq;
@@ -775,7 +656,6 @@ Slave *heldSlaveForJob(SimpleJob *job)
 
 
 Scheduler::Scheduler()
- : removeMe(0)
 {
     setObjectName( "scheduler" );
 
@@ -799,12 +679,6 @@ void Scheduler::doJob(SimpleJob *job)
     schedulerPrivate->doJob(job);
 }
 
-#ifndef KDE_NO_DEPRECATED
-void Scheduler::scheduleJob(SimpleJob *job)
-{
-    schedulerPrivate->scheduleJob(job);
-}
-#endif
 
 void Scheduler::setJobPriority(SimpleJob *job, int priority)
 {
@@ -841,27 +715,6 @@ bool Scheduler::isSlaveOnHoldFor(const KUrl& url)
     return schedulerPrivate->isSlaveOnHoldFor(url);
 }
 
-void Scheduler::updateInternalMetaData(SimpleJob* job)
-{
-    schedulerPrivate->updateInternalMetaData(job);
-}
-
-KIO::Slave *Scheduler::getConnectedSlave(const KUrl &url,
-        const KIO::MetaData &config )
-{
-    return schedulerPrivate->getConnectedSlave(url, config);
-}
-
-bool Scheduler::assignJobToSlave(KIO::Slave *slave, KIO::SimpleJob *job)
-{
-    return schedulerPrivate->assignJobToSlave(slave, job);
-}
-
-bool Scheduler::disconnectSlave(KIO::Slave *slave)
-{
-    return schedulerPrivate->disconnectSlave(slave);
-}
-
 void Scheduler::registerWindow(QWidget *wid)
 {
     schedulerPrivate->registerWindow(wid);
@@ -872,30 +725,6 @@ void Scheduler::unregisterWindow(QObject *wid)
     schedulerPrivate->slotUnregisterWindow(wid);
 }
 
-bool Scheduler::connect( const char *signal, const QObject *receiver,
-                         const char *member)
-{
-    return QObject::connect(self(), signal, receiver, member);
-}
-
-bool Scheduler::connect( const QObject* sender, const char* signal,
-                         const QObject* receiver, const char* member )
-{
-    return QObject::connect(sender, signal, receiver, member);
-}
-
-bool Scheduler::disconnect( const QObject* sender, const char* signal,
-                            const QObject* receiver, const char* member )
-{
-    return QObject::disconnect(sender, signal, receiver, member);
-}
-
-bool Scheduler::connect( const QObject *sender, const char *signal,
-                         const char *member )
-{
-    return QObject::connect(sender, signal, member);
-}
-
 void Scheduler::checkSlaveOnHold(bool b)
 {
     schedulerPrivate->checkSlaveOnHold(b);
@@ -952,9 +781,6 @@ static bool mayReturnContent(int cmd, const QString& protocol)
     if (cmd == CMD_GET)
         return true;
 
-    if (cmd == CMD_MULTI_GET)
-        return true;
-
     if (cmd == CMD_SPECIAL && protocol.startsWith(QLatin1String("http"), Qt::CaseInsensitive))
         return true;
 
@@ -981,13 +807,6 @@ void SchedulerPrivate::doJob(SimpleJob *job)
     proto->queueJob(job);
 }
 
-#ifndef KDE_NO_DEPRECATED
-void SchedulerPrivate::scheduleJob(SimpleJob *job)
-{
-    kDebug(7006) << job;
-    setJobPriority(job, 1);
-}
-#endif
 
 void SchedulerPrivate::setJobPriority(SimpleJob *job, int priority)
 {
@@ -1031,45 +850,25 @@ void SchedulerPrivate::jobFinished(SimpleJob *job, Slave *slave)
     }
 
     if (slave) {
-        // If we have internal meta-data, tell existing ioslaves to reload
-        // their configuration.
-        if (jobPriv->m_internalMetaData.count()) {
-            kDebug(7006) << "Updating ioslaves with new internal metadata information";
-            ProtoQueue * queue = m_protocols.value(slave->protocol());
-            if (queue) {
-                QListIterator<Slave*> it (queue->allSlaves());
-                while (it.hasNext()) {
-                    Slave* runningSlave = it.next();
-                    if (slave->host() == runningSlave->host()) {
-                        slave->setConfig(metaDataFor(slave->protocol(), jobPriv->m_proxyList, job->url()));
-                        kDebug(7006) << "Updated configuration of" << slave->protocol()
-                                     << "ioslave, pid=" << slave->slave_pid();
-                    }
-                }
-            }
-        }
         slave->setJob(0);
         slave->disconnect(job);
     }
     jobPriv->m_schedSerial = 0; // this marks the job as unscheduled again
     jobPriv->m_slave = 0;
-    // Clear the values in the internal metadata container since they have
-    // already been taken care of above...
-    jobPriv->m_internalMetaData.clear();
 }
 
 // static
 void setupSlave(KIO::Slave *slave, const KUrl &url, const QString &protocol,
-                const QStringList &proxyList , bool newSlave, const KIO::MetaData *config)
+                const QStringList &proxyList , bool newSlave)
 {
-    schedulerPrivate->setupSlave(slave, url, protocol, proxyList, newSlave, config);
+    schedulerPrivate->setupSlave(slave, url, protocol, proxyList, newSlave);
 }
 
 MetaData SchedulerPrivate::metaDataFor(const QString &protocol, const QStringList &proxyList, const KUrl &url)
 {
     const QString host = url.host();
     MetaData configData = SlaveConfig::self()->configData(protocol, host);
-    sessionData.configDataFor( configData, protocol, host );
+    sessionData.configDataFor( configData, protocol );
     if (proxyList.isEmpty()) {
         configData.remove(QLatin1String("UseProxy"));
         configData.remove(QLatin1String("ProxyUrls"));
@@ -1103,7 +902,7 @@ MetaData SchedulerPrivate::metaDataFor(const QString &protocol, const QStringLis
 }
 
 void SchedulerPrivate::setupSlave(KIO::Slave *slave, const KUrl &url, const QString &protocol,
-                                  const QStringList &proxyList, bool newSlave, const KIO::MetaData *config)
+                                  const QStringList &proxyList, bool newSlave)
 {
     int port = url.port();
     if ( port == -1 ) // no port is -1 in QUrl, but in kde3 we used 0 and the kioslaves assume that.
@@ -1116,21 +915,12 @@ void SchedulerPrivate::setupSlave(KIO::Slave *slave, const KUrl &url, const QStr
         slave->user() != user || slave->passwd() != passwd) {
 
         MetaData configData = metaDataFor(protocol, proxyList, url);
-        if (config)
-           configData += *config;
-
         slave->setConfig(configData);
         slave->setProtocol(url.protocol());
         slave->setHost(host, port, user, passwd);
     }
 }
 
-
-void SchedulerPrivate::slotSlaveStatus(pid_t, const QByteArray&, const QString &, bool)
-{
-}
-
-
 void SchedulerPrivate::slotSlaveDied(KIO::Slave *slave)
 {
     kDebug(7006) << slave;
@@ -1199,7 +989,7 @@ Slave *SchedulerPrivate::heldSlaveForJob(SimpleJob *job)
     if (!slave && m_slaveOnHold) {
         // Make sure that the job wants to do a GET or a POST, and with no offset
         const int cmd = jobPriv->m_command;
-        bool canJobReuse = (cmd == CMD_GET || cmd == CMD_MULTI_GET);
+        bool canJobReuse = (cmd == CMD_GET);
 
         if (KIO::TransferJob *tJob = qobject_cast<KIO::TransferJob *>(job)) {
             canJobReuse = ( canJobReuse || cmd == CMD_SPECIAL );
@@ -1226,12 +1016,6 @@ Slave *SchedulerPrivate::heldSlaveForJob(SimpleJob *job)
         kDebug(7006) << "HOLD: Reusing klauncher held slave (" << slave << ")";
     }
 
-    // Reset the parent widget the ioslave should use when displaying message
-    // boxes after being put on hold.
-    if (slave && job->ui()) {
-        slave->setWindow(job->ui()->window());
-    }
-
     return slave;
 }
 
@@ -1245,68 +1029,6 @@ void SchedulerPrivate::removeSlaveOnHold()
     m_urlOnHold.clear();
 }
 
-Slave *SchedulerPrivate::getConnectedSlave(const KUrl &url, const KIO::MetaData &config)
-{
-    QStringList proxyList;
-    const QString protocol = KProtocolManager::slaveProtocol(url, proxyList);
-    ProtoQueue *pq = protoQ(protocol, url.host());
-
-    Slave *slave = pq->createSlave(protocol, /* job */0, url);
-    if (slave) {
-        setupSlave(slave, url, protocol, proxyList, true, &config);
-        pq->m_connectedSlaveQueue.addSlave(slave);
-
-        slave->send( CMD_CONNECT );
-        q->connect(slave, SIGNAL(connected()),
-                   SLOT(slotSlaveConnected()));
-        q->connect(slave, SIGNAL(error(int,QString)),
-                   SLOT(slotSlaveError(int,QString)));
-    }
-    kDebug(7006) << url << slave;
-    return slave;
-}
-
-
-void SchedulerPrivate::slotSlaveConnected()
-{
-    kDebug(7006);
-    Slave *slave = static_cast<Slave *>(q->sender());
-    slave->setConnected(true);
-    q->disconnect(slave, SIGNAL(connected()), q, SLOT(slotSlaveConnected()));
-    emit q->slaveConnected(slave);
-}
-
-void SchedulerPrivate::slotSlaveError(int errorNr, const QString &errorMsg)
-{
-    Slave *slave = static_cast<Slave *>(q->sender());
-    kDebug(7006) << slave << errorNr << errorMsg;
-    ProtoQueue *pq = protoQ(slave->protocol(), slave->host());
-    if (!slave->isConnected() || pq->m_connectedSlaveQueue.isIdle(slave)) {
-        // Only forward to application if slave is idle or still connecting.
-        // ### KDE5: can we remove this apparently arbitrary behavior and just always emit SlaveError?
-        emit q->slaveError(slave, errorNr, errorMsg);
-    }
-}
-
-bool SchedulerPrivate::assignJobToSlave(KIO::Slave *slave, SimpleJob *job)
-{
-    kDebug(7006) << slave << job;
-    // KDE5: queueing of jobs can probably be removed, it provides very little benefit
-    ProtoQueue *pq = m_protocols.value(slave->protocol());
-    if (pq) {
-        pq->removeJob(job);
-        return pq->m_connectedSlaveQueue.queueJob(job, slave);
-    }
-    return false;
-}
-
-bool SchedulerPrivate::disconnectSlave(KIO::Slave *slave)
-{
-    kDebug(7006) << slave;
-    ProtoQueue *pq = m_protocols.value(slave->protocol());
-    return (pq ? pq->m_connectedSlaveQueue.removeSlave(slave) : false);
-}
-
 void SchedulerPrivate::checkSlaveOnHold(bool b)
 {
     kDebug(7006) << b;
@@ -1373,24 +1095,5 @@ void SchedulerPrivate::slotUnregisterWindow(QObject *obj)
        call(QDBus::NoBlock, "unregisterWindowId", qlonglong(windowId));
 }
 
-void SchedulerPrivate::updateInternalMetaData(SimpleJob* job)
-{
-    KIO::SimpleJobPrivate *const jobPriv = SimpleJobPrivate::get(job);
-    // Preserve all internal meta-data so they can be sent back to the
-    // ioslaves as needed...
-    const KUrl jobUrl = job->url();
-    kDebug(7006) << job << jobPriv->m_internalMetaData;
-    QMapIterator<QString, QString> it (jobPriv->m_internalMetaData);
-    while (it.hasNext()) {
-        it.next();
-        if (it.key().startsWith(QLatin1String("{internal~currenthost}"), Qt::CaseInsensitive)) {
-            SlaveConfig::self()->setConfigData(jobUrl.protocol(), jobUrl.host(), it.key().mid(22), it.value());
-        } else if (it.key().startsWith(QLatin1String("{internal~allhosts}"), Qt::CaseInsensitive)) {
-            SlaveConfig::self()->setConfigData(jobUrl.protocol(), QString(), it.key().mid(19), it.value());
-        }
-    }
-}
-
-
-#include "scheduler.moc"
-#include "scheduler_p.moc"
+#include "moc_scheduler.cpp"
+#include "moc_scheduler_p.cpp"
