@@ -34,6 +34,7 @@
 #include <signal.h>
 #include <time.h>
 
+#include <QtCore/QBuffer>
 #include <QtCore/QFile>
 #include <QtCore/QList>
 #include <QtCore/QDateTime>
@@ -44,13 +45,15 @@
 #include <kconfiggroup.h>
 #include <kde_file.h>
 #include <klocale.h>
+#include <kpassworddialog.h>
+#include <kwindowsystem.h>
 
 #include "kremoteencoding.h"
 
 #include "connection.h"
 #include "ioslave_defaults.h"
 #include "slaveinterface.h"
-#include "kpasswdserver_p.h"
+#include "kpasswdstore.h"
 
 #ifndef NDEBUG
 #ifdef HAVE_BACKTRACE
@@ -58,6 +61,11 @@
 #endif
 #endif
 
+#define AUTHINFO_EXTRAFIELD_DOMAIN QLatin1String("domain")
+#define AUTHINFO_EXTRAFIELD_ANONYMOUS QLatin1String("anonymous")
+#define AUTHINFO_EXTRAFIELD_SKIP_CACHING_ON_QUERY QLatin1String("skip-caching-on-query")
+#define AUTHINFO_EXTRAFIELD_HIDE_USERNAME_INPUT QLatin1String("hide-username-line")
+
 extern "C" {
     static void sigsegv_handler(int sig);
     static void sigpipe_handler(int sig);
@@ -72,21 +80,42 @@ typedef QMap<QString,QByteArray> AuthKeysMap;
 
 namespace KIO {
 
+static QByteArray authInfoKey(const AuthInfo &authinfo)
+{
+    return KPasswdStore::makeKey(authinfo.url.prettyUrl());
+}
+
+static QString authInfoToData(const AuthInfo &authinfo)
+{
+    QByteArray authdata;
+    QDataStream authstream(&authdata, QIODevice::WriteOnly);
+    authstream << authinfo;
+    return QString::fromLatin1(authdata.toHex());
+}
+
+static AuthInfo authInfoFromData(const QByteArray &authdata)
+{
+    QBuffer authbuffer;
+    authbuffer.setData(QByteArray::fromHex(authdata));
+    authbuffer.open(QBuffer::ReadOnly);
+    AuthInfo authinfo;
+    QDataStream authstream(&authbuffer);
+    authstream >> authinfo;
+    return authinfo;
+}
+
 class SlaveBasePrivate {
 public:
     SlaveBase* q;
-    SlaveBasePrivate(SlaveBase* owner): q(owner), m_passwdServer(0) {}
-    ~SlaveBasePrivate() { delete m_passwdServer; }
+    SlaveBasePrivate(SlaveBase* owner): q(owner), m_passwdStore(nullptr) {}
+    ~SlaveBasePrivate() { delete m_passwdStore; }
 
     UDSEntryList pendingListEntries;
-    int listEntryCurrentSize;
-    long listEntry_sec, listEntry_usec;
+    QTime m_timeSinceLastBatch;
     Connection appConnection;
     QString poolSocket;
     bool isConnectedToApp;
-    static qlonglong s_seqNr;
 
-    QString slaveid;
     bool resume:1;
     bool needSendCanResume:1;
     bool onHold:1;
@@ -100,13 +129,12 @@ public:
 
     struct timeval last_tv;
     KIO::filesize_t totalSize;
-    KIO::filesize_t sentListEntries;
     KRemoteEncoding *remotefile;
     time_t timeout;
     enum { Idle, InsideMethod, FinishedCalled, ErrorCalled } m_state;
     QByteArray timeoutData;
 
-    KPasswdServer* m_passwdServer;
+    KPasswdStore* m_passwdStore;
 
     // Reconstructs configGroup from configData and mIncomingMetaData
     void rebuildConfig()
@@ -138,38 +166,38 @@ public:
         }
     }
 
-    KPasswdServer* passwdServer()
+    KPasswdStore* passwdStore()
     {
-        if (!m_passwdServer) {
-            m_passwdServer = new KPasswdServer;
+        if (!m_passwdStore) {
+            m_passwdStore = new KPasswdStore();
+            m_passwdStore->setStoreID("KIO");
         }
 
-        return m_passwdServer;
+        return m_passwdStore;
     }
 };
 
 }
 
-static SlaveBase *globalSlave;
-qlonglong SlaveBasePrivate::s_seqNr;
+static SlaveBase *globalSlave = nullptr;
 
 static volatile bool slaveWriteError = false;
 
-static const char *s_protocol;
+static const char *s_protocol = nullptr;
 
 #ifdef Q_OS_UNIX
 extern "C" {
 static void genericsig_handler(int sigNumber)
 {
-   KDE_signal(sigNumber,SIG_IGN);
+   KDE_signal(sigNumber, SIG_IGN);
    //WABA: Don't do anything that requires malloc, we can deadlock on it since
    //a SIGTERM signal can come in while we are in malloc/free.
    //kDebug()<<"kioslave : exiting due to signal "<<sigNumber;
    //set the flag which will be checked in dispatchLoop() and which *should* be checked
    //in lengthy operations in the various slaves
-   if (globalSlave!=0)
+   if (globalSlave != 0)
       globalSlave->setKillFlag();
-   KDE_signal(SIGALRM,SIG_DFL);
+   KDE_signal(SIGALRM, SIG_DFL);
    alarm(5);  //generate an alarm signal in 5 seconds, in this time the slave has to exit
 }
 }
@@ -189,13 +217,9 @@ SlaveBase::SlaveBase( const QByteArray &protocol,
 #ifdef Q_OS_UNIX
     if (qgetenv("KDE_DEBUG").isEmpty())
     {
-        KCrash::setCrashHandler( sigsegv_handler );
-        KDE_signal(SIGILL,&sigsegv_handler);
-        KDE_signal(SIGTRAP,&sigsegv_handler);
-        KDE_signal(SIGABRT,&sigsegv_handler);
-        KDE_signal(SIGBUS,&sigsegv_handler);
-        KDE_signal(SIGALRM,&sigsegv_handler);
-        KDE_signal(SIGFPE,&sigsegv_handler);
+        KCrash::setCrashHandler(sigsegv_handler);
+        KDE_signal(SIGTRAP, &sigsegv_handler);
+        KDE_signal(SIGALRM, &sigsegv_handler);
 #ifdef SIGPOLL
         KDE_signal(SIGPOLL, &sigsegv_handler);
 #endif
@@ -215,27 +239,19 @@ SlaveBase::SlaveBase( const QByteArray &protocol,
 
     struct sigaction act;
     act.sa_handler = sigpipe_handler;
-    sigemptyset( &act.sa_mask );
+    sigemptyset(&act.sa_mask);
     act.sa_flags = 0;
-    sigaction( SIGPIPE, &act, 0 );
+    sigaction(SIGPIPE, &act, 0);
 
-    KDE_signal(SIGINT,&genericsig_handler);
-    KDE_signal(SIGQUIT,&genericsig_handler);
-    KDE_signal(SIGTERM,&genericsig_handler);
+    KDE_signal(SIGINT, &genericsig_handler);
+    KDE_signal(SIGQUIT, &genericsig_handler);
+    KDE_signal(SIGTERM, &genericsig_handler);
 #endif
 
-    globalSlave=this;
+    globalSlave = this;
 
-    d->listEntryCurrentSize = 100;
-    struct timeval tp;
-    gettimeofday(&tp, 0);
-    d->listEntry_sec = tp.tv_sec;
-    d->listEntry_usec = tp.tv_usec;
     d->isConnectedToApp = true;
 
-    // by kahl for netmgr (need a way to identify slaves)
-    d->slaveid = protocol;
-    d->slaveid += QString::number(getpid());
     d->resume = false;
     d->needSendCanResume = false;
     d->config = new KConfig(QString(), KConfig::SimpleConfig);
@@ -245,9 +261,7 @@ SlaveBase::SlaveBase( const QByteArray &protocol,
     d->wasKilled=false;
     d->last_tv.tv_sec = 0;
     d->last_tv.tv_usec = 0;
-//    d->processed_size = 0;
     d->totalSize=0;
-    d->sentListEntries=0;
     d->timeout = 0;
     connectSlave(QFile::decodeName(app_socket));
 
@@ -330,7 +344,7 @@ void SlaveBase::connectSlave(const QString &address)
 
     if (!d->appConnection.inited())
     {
-        kDebug(7019) << "failed to connect to" << address << endl
+        kDebug(7019) << "failed to connect to" << address << '\n'
 		      << "Reason:" << d->appConnection.errorString();
         exit();
         return;
@@ -440,8 +454,6 @@ void SlaveBase::error( int _errid, const QString &_text )
 
     send( MSG_ERROR, data );
     //reset
-    d->listEntryCurrentSize = 100;
-    d->sentListEntries=0;
     d->totalSize=0;
     d->inOpenLoop=false;
 }
@@ -468,8 +480,6 @@ void SlaveBase::finished()
     send( MSG_FINISHED );
 
     // reset
-    d->listEntryCurrentSize = 100;
-    d->sentListEntries=0;
     d->totalSize=0;
     d->inOpenLoop=false;
 }
@@ -479,19 +489,11 @@ void SlaveBase::needSubUrlData()
     send( MSG_NEED_SUBURL_DATA );
 }
 
-/*
- * Map pid_t to a signed integer type that makes sense for QByteArray;
- * only the most common sizes 16 bit and 32 bit are special-cased.
- */
-template<int T> struct PIDType { typedef pid_t PID_t; } ;
-template<> struct PIDType<2> { typedef qint16 PID_t; } ;
-template<> struct PIDType<4> { typedef qint32 PID_t; } ;
-
 void SlaveBase::slaveStatus( const QString &host, bool connected )
 {
-    pid_t pid = getpid();
+    qint64 pid = static_cast<qint64>(::getpid());
     qint8 b = connected ? 1 : 0;
-    KIO_DATA << (PIDType<sizeof(pid_t)>::PID_t)pid << mProtocol << host << b;
+    KIO_DATA << pid << mProtocol << host << b;
     if (d->onHold)
        stream << d->onHoldUrl;
     send( MSG_SLAVE_STATUS, data );
@@ -508,12 +510,7 @@ void SlaveBase::totalSize( KIO::filesize_t _bytes )
     send( INF_TOTAL_SIZE, data );
 
     //this one is usually called before the first item is listed in listDir()
-    struct timeval tp;
-    gettimeofday(&tp, 0);
-    d->listEntry_sec = tp.tv_sec;
-    d->listEntry_usec = tp.tv_usec;
     d->totalSize=_bytes;
-    d->sentListEntries=0;
 }
 
 void SlaveBase::processedSize( KIO::filesize_t _bytes )
@@ -547,7 +544,6 @@ void SlaveBase::processedSize( KIO::filesize_t _bytes )
             d->last_tv.tv_usec = tv.tv_usec;
         }
     }
-//    d->processed_size = _bytes;
 }
 
 void SlaveBase::written( KIO::filesize_t _bytes )
@@ -562,12 +558,6 @@ void SlaveBase::position( KIO::filesize_t _pos )
     send( INF_POSITION, data );
 }
 
-void SlaveBase::processedPercent( float /* percent */ )
-{
-  kDebug(7019) << "STUB";
-}
-
-
 void SlaveBase::speed( unsigned long _bytes_per_second )
 {
     KIO_DATA << (quint32) _bytes_per_second;
@@ -580,11 +570,6 @@ void SlaveBase::redirection( const KUrl& _url )
     send( INF_REDIRECTION, data );
 }
 
-void SlaveBase::errorPage()
-{
-    send( INF_ERROR_PAGE );
-}
-
 static bool isSubCommand(int cmd)
 {
    return ( (cmd == CMD_REPARSECONFIGURATION) ||
@@ -593,8 +578,7 @@ static bool isSubCommand(int cmd)
             (cmd == CMD_SUBURL) ||
             (cmd == CMD_SLAVE_STATUS) ||
             (cmd == CMD_SLAVE_CONNECT) ||
-            (cmd == CMD_SLAVE_HOLD) ||
-            (cmd == CMD_MULTI_GET));
+            (cmd == CMD_SLAVE_HOLD));
 }
 
 void SlaveBase::mimeType( const QString &_type)
@@ -659,27 +643,6 @@ void SlaveBase::infoMessage( const QString &_msg)
     send( INF_INFOMESSAGE, data );
 }
 
-bool SlaveBase::requestNetwork(const QString& host)
-{
-    KIO_DATA << host << d->slaveid;
-    send( MSG_NET_REQUEST, data );
-
-    if ( waitForAnswer( INF_NETWORK_STATUS, 0, data ) != -1 )
-    {
-        bool status;
-        QDataStream stream( data );
-        stream >> status;
-        return status;
-    } else
-        return false;
-}
-
-void SlaveBase::dropNetwork(const QString& host)
-{
-    KIO_DATA << host << d->slaveid;
-    send( MSG_NET_DROP, data );
-}
-
 void SlaveBase::statEntry( const UDSEntry& entry )
 {
     KIO_DATA << entry;
@@ -688,44 +651,29 @@ void SlaveBase::statEntry( const UDSEntry& entry )
 
 void SlaveBase::listEntry( const UDSEntry& entry, bool _ready )
 {
-   static struct timeval tp;
-   static const int maximum_updatetime = 300;
-   static const int minimum_updatetime = 100;
+    static const int maximum_updatetime = 300;
 
-   if (!_ready) {
-      d->pendingListEntries.append(entry);
+    // We start measuring the time from the point we start filling the list
+    if (d->pendingListEntries.isEmpty()) {
+        d->m_timeSinceLastBatch.restart();
+    }
 
-      if (d->pendingListEntries.count() > d->listEntryCurrentSize) {
-         gettimeofday(&tp, 0);
+    if (!_ready) {
+        d->pendingListEntries.append(entry);
 
-         long diff = ((tp.tv_sec - d->listEntry_sec) * 1000000 +
-                      tp.tv_usec - d->listEntry_usec) / 1000;
-         if (diff==0) diff=1;
-
-         if (diff > maximum_updatetime) {
-            d->listEntryCurrentSize = d->listEntryCurrentSize * 3 / 4;
+        // If more then maximum_updatetime time is passed, emit the current batch
+        if (d->m_timeSinceLastBatch.elapsed() > maximum_updatetime) {
             _ready = true;
-         }
-//if we can send all list entries of this dir which have not yet been sent
-//within maximum_updatetime, then make d->listEntryCurrentSize big enough for all of them
-         else if (((d->pendingListEntries.count()*maximum_updatetime)/diff) > static_cast<long>(d->totalSize-d->sentListEntries))
-            d->listEntryCurrentSize=d->totalSize-d->sentListEntries+1;
-//if we are below minimum_updatetime, estimate how much we will get within
-//maximum_updatetime
-         else if (diff < minimum_updatetime)
-            d->listEntryCurrentSize = (d->pendingListEntries.count() * maximum_updatetime) / diff;
-         else
-            _ready=true;
-      }
-   }
-   if (_ready) { // may happen when we started with !ready
-      listEntries( d->pendingListEntries );
-      d->pendingListEntries.clear();
+        }
+    }
 
-      gettimeofday(&tp, 0);
-      d->listEntry_sec = tp.tv_sec;
-      d->listEntry_usec = tp.tv_usec;
-   }
+    if (_ready) { // may happen when we started with !ready
+        listEntries( d->pendingListEntries );
+        d->pendingListEntries.clear();
+
+        // Restart time
+        d->m_timeSinceLastBatch.restart();
+    }
 }
 
 void SlaveBase::listEntries( const UDSEntryList& list )
@@ -736,7 +684,6 @@ void SlaveBase::listEntries( const UDSEntryList& list )
     for (; it != end; ++it)
       stream << *it;
     send( MSG_LIST_ENTRIES, data);
-    d->sentListEntries+=(uint)list.count();
 }
 
 static void sigsegv_handler(int sig)
@@ -751,8 +698,9 @@ static void sigsegv_handler(int sig)
     // Debug and printf should be avoided because they might
     // call malloc.. and get in a nice recursive malloc loop
     char buffer[120];
-    qsnprintf(buffer, sizeof(buffer), "kioslave: ####### CRASH ###### protocol = %s pid = %d signal = %d\n", s_protocol, getpid(), sig);
-    write(2, buffer, strlen(buffer));
+    memset(buffer, '\0', sizeof(buffer) * sizeof(char));
+    snprintf(buffer, sizeof(buffer), "kioslave: ####### CRASH ###### protocol = %s pid = %d signal = %d\n", s_protocol, getpid(), sig);
+    write(STDERR_FILENO, buffer, strlen(buffer));
 #ifndef NDEBUG
 #ifdef HAVE_BACKTRACE
     void* trace[256];
@@ -826,8 +774,6 @@ void SlaveBase::chown(KUrl const &, const QString &, const QString &)
 { error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_CHOWN)); }
 void SlaveBase::setSubUrl(KUrl const &)
 { error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_SUBURL)); }
-void SlaveBase::multiGet(const QByteArray &)
-{ error(  ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(mProtocol, CMD_MULTI_GET)); }
 
 
 void SlaveBase::slave_status()
@@ -841,34 +787,86 @@ void SlaveBase::reparseConfiguration()
 
 bool SlaveBase::openPasswordDialog( AuthInfo& info, const QString &errorMsg )
 {
-    const long windowId = metaData(QLatin1String("window-id")).toLong();
-    const unsigned long userTimestamp = metaData(QLatin1String("user-timestamp")).toULong();
-    QString errorMessage;
     if (metaData(QLatin1String("no-auth-prompt")).compare(QLatin1String("true"), Qt::CaseInsensitive) == 0) {
-        errorMessage = QLatin1String("<NoAuthPrompt>");
-    } else {
-        errorMessage = errorMsg;
+        return false;
     }
 
-    AuthInfo dlgInfo (info);
-    // Make sure the modified flag is not set.
-    dlgInfo.setModified(false);
+    const qlonglong windowId = metaData(QLatin1String("window-id")).toLongLong();
+    QWidget *windowWidget = QWidget::find(windowId);
+
+    AuthInfo dlgInfo(info);
     // Prevent queryAuthInfo from caching the user supplied password since
     // we need the ioslaves to first authenticate against the server with
     // it to ensure it is valid.
-    dlgInfo.setExtraField(QLatin1String("skip-caching-on-query"), true);
+    dlgInfo.setExtraField(AUTHINFO_EXTRAFIELD_SKIP_CACHING_ON_QUERY, true);
 
-    KPasswdServer* passwdServer = d->passwdServer();
+    KPasswdStore* passwdstore = d->passwdStore();
 
-    if (passwdServer) {
-        qlonglong seqNr = passwdServer->queryAuthInfo(dlgInfo, errorMessage, windowId,
-                                                      SlaveBasePrivate::s_seqNr, userTimestamp);
-        if (seqNr > 0) {
-            SlaveBasePrivate::s_seqNr = seqNr;
-            if (dlgInfo.isModified()) {
-                info = dlgInfo;
-                return true;
-            }
+    if (passwdstore) {
+        // assemble dialog-flags
+        KPasswordDialog::KPasswordDialogFlags dialogFlags;
+
+        if (dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_DOMAIN).isValid()) {
+            dialogFlags |= KPasswordDialog::ShowDomainLine;
+        }
+
+        if (dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_ANONYMOUS).isValid()) {
+            dialogFlags |= KPasswordDialog::ShowAnonymousLoginCheckBox;
+        }
+
+        if (!dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_HIDE_USERNAME_INPUT).toBool()) {
+            dialogFlags |= KPasswordDialog::ShowUsernameLine;
+        }
+
+        // If store is not enabled and the caller explicitly requested for it,
+        // do not show the keep password checkbox.
+        if (dlgInfo.keepPassword && !passwdstore->cacheOnly())
+            dialogFlags |= KPasswordDialog::ShowKeepPassword;
+
+        KPasswordDialog* dlg = new KPasswordDialog(windowWidget, dialogFlags);
+
+        QString username = dlgInfo.username;
+        QString password = dlgInfo.password;
+
+        dlg->setPrompt(dlgInfo.prompt);
+        dlg->setUsername(username);
+        if (dlgInfo.caption.isEmpty())
+            dlg->setWindowTitle(i18n("Authentication Dialog"));
+        else
+            dlg->setWindowTitle(dlgInfo.caption);
+
+        if (!dlgInfo.comment.isEmpty() )
+            dlg->addCommentLine(dlgInfo.commentLabel, dlgInfo.comment);
+
+        if (!password.isEmpty())
+            dlg->setPassword(password);
+
+        if (dlgInfo.readOnly)
+            dlg->setUsernameReadOnly(true);
+
+        if (!passwdstore->cacheOnly())
+            dlg->setKeepPassword(true);
+
+        if (dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_DOMAIN).isValid ())
+            dlg->setDomain(dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_DOMAIN).toString());
+
+        if (dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_ANONYMOUS).isValid () && password.isEmpty() && username.isEmpty())
+            dlg->setAnonymousMode(dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_ANONYMOUS).toBool());
+
+        KWindowSystem::setMainWindow(dlg, windowId);
+
+        if (dlg->exec() == KPasswordDialog::Accepted) {
+            dlgInfo.username = dlg->username();
+            dlgInfo.password = dlg->password();
+            dlgInfo.keepPassword = dlg->keepPassword();
+
+            if (dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_DOMAIN).isValid())
+                dlgInfo.setExtraField(AUTHINFO_EXTRAFIELD_DOMAIN, dlg->domain());
+            if (dlgInfo.getExtraField(AUTHINFO_EXTRAFIELD_ANONYMOUS).isValid())
+                dlgInfo.setExtraField(AUTHINFO_EXTRAFIELD_ANONYMOUS, dlg->anonymousMode());
+
+            info = dlgInfo;
+            return true;
         }
     }
 
@@ -974,237 +972,275 @@ void SlaveBase::dispatch( int command, const QByteArray &data )
 {
     QDataStream stream( data );
 
-    KUrl url;
-    int i;
-
     switch( command ) {
-    case CMD_HOST: {
-        // Reset s_seqNr, see kpasswdserver/DESIGN
-        SlaveBasePrivate::s_seqNr = 0;
-        QString passwd;
-        QString host, user;
-        quint16 port;
-        stream >> host >> port >> user >> passwd;
-        d->m_state = d->InsideMethod;
-        setHost( host, port, user, passwd );
-        d->verifyErrorFinishedNotCalled("setHost()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_CONNECT: {
-        openConnection( );
-    } break;
-    case CMD_DISCONNECT: {
-        closeConnection( );
-    } break;
-    case CMD_SLAVE_STATUS: {
-        d->m_state = d->InsideMethod;
-        slave_status();
-        // TODO verify that the slave has called slaveStatus()?
-        d->verifyErrorFinishedNotCalled("slave_status()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_SLAVE_CONNECT: {
-        d->onHold = false;
-        QString app_socket;
-        QDataStream stream( data );
-        stream >> app_socket;
-        d->appConnection.send( MSG_SLAVE_ACK );
-        disconnectSlave();
-        d->isConnectedToApp = true;
-        connectSlave(app_socket);
-        virtual_hook(AppConnectionMade, 0);
-    } break;
-    case CMD_SLAVE_HOLD: {
-        KUrl url;
-        QDataStream stream( data );
-        stream >> url;
-        d->onHoldUrl = url;
-        d->onHold = true;
-        disconnectSlave();
-        d->isConnectedToApp = false;
-        // Do not close connection!
-        connectSlave(d->poolSocket);
-    } break;
-    case CMD_REPARSECONFIGURATION: {
-        d->m_state = d->InsideMethod;
-        reparseConfiguration();
-        d->verifyErrorFinishedNotCalled("reparseConfiguration()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_CONFIG: {
-        stream >> d->configData;
-        d->rebuildConfig();
-#if 0 //TODO: decide what to do in KDE 4.1
-        KSocks::setConfig(d->configGroup);
-#endif
-        delete d->remotefile;
-        d->remotefile = 0;
-    } break;
-    case CMD_GET: {
-        stream >> url;
-        d->m_state = d->InsideMethod;
-        get( url );
-        d->verifyState("get()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_OPEN: {
-        stream >> url >> i;
-        QIODevice::OpenMode mode = QFlag(i);
-        d->m_state = d->InsideMethod;
-        open(url, mode); //krazy:exclude=syscalls
-        d->m_state = d->Idle;
-    } break;
-    case CMD_PUT: {
-        int permissions;
-        qint8 iOverwrite, iResume;
-        stream >> url >> iOverwrite >> iResume >> permissions;
-        JobFlags flags;
-        if ( iOverwrite != 0 ) flags |= Overwrite;
-        if ( iResume != 0 ) flags |= Resume;
+        case CMD_HOST: {
+            QString passwd;
+            QString host, user;
+            quint16 port;
+            stream >> host >> port >> user >> passwd;
+            d->m_state = d->InsideMethod;
+            setHost( host, port, user, passwd );
+            d->verifyErrorFinishedNotCalled("setHost()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_CONNECT: {
+            openConnection( );
+            break;
+        }
+        case CMD_DISCONNECT: {
+            closeConnection( );
+            break;
+        }
+        case CMD_SLAVE_STATUS: {
+            d->m_state = d->InsideMethod;
+            slave_status();
+            // TODO verify that the slave has called slaveStatus()?
+            d->verifyErrorFinishedNotCalled("slave_status()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_SLAVE_CONNECT: {
+            d->onHold = false;
+            QString app_socket;
+            QDataStream stream( data );
+            stream >> app_socket;
+            d->appConnection.send( MSG_SLAVE_ACK );
+            disconnectSlave();
+            d->isConnectedToApp = true;
+            connectSlave(app_socket);
+            break;
+        }
+        case CMD_SLAVE_HOLD: {
+            KUrl url;
+            QDataStream stream( data );
+            stream >> url;
+            d->onHoldUrl = url;
+            d->onHold = true;
+            disconnectSlave();
+            d->isConnectedToApp = false;
+            // Do not close connection!
+            connectSlave(d->poolSocket);
+            break;
+        }
+        case CMD_REPARSECONFIGURATION: {
+            d->m_state = d->InsideMethod;
+            reparseConfiguration();
+            d->verifyErrorFinishedNotCalled("reparseConfiguration()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_CONFIG: {
+            stream >> d->configData;
+            d->rebuildConfig();
+            delete d->remotefile;
+            d->remotefile = 0;
+            break;
+        }
+        case CMD_GET: {
+            KUrl url;
+            stream >> url;
+            d->m_state = d->InsideMethod;
+            get( url );
+            d->verifyState("get()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_OPEN: {
+            KUrl url;
+            int i;
+            stream >> url >> i;
+            QIODevice::OpenMode mode = QFlag(i);
+            d->m_state = d->InsideMethod;
+            open(url, mode); //krazy:exclude=syscalls
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_PUT: {
+            KUrl url;
+            int permissions;
+            qint8 iOverwrite, iResume;
+            stream >> url >> iOverwrite >> iResume >> permissions;
+            JobFlags flags;
+            if ( iOverwrite != 0 ) flags |= Overwrite;
+            if ( iResume != 0 ) flags |= Resume;
 
-        // Remember that we need to send canResume(), TransferJob is expecting
-        // it. Well, in theory this shouldn't be done if resume is true.
-        //   (the resume bool is currently unused)
-        d->needSendCanResume = true   /* !resume */;
+            // Remember that we need to send canResume(), TransferJob is expecting
+            // it. Well, in theory this shouldn't be done if resume is true.
+            //   (the resume bool is currently unused)
+            d->needSendCanResume = true   /* !resume */;
 
-        d->m_state = d->InsideMethod;
-        put( url, permissions, flags);
-        d->verifyState("put()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_STAT: {
-        stream >> url;
-        d->m_state = d->InsideMethod;
-        stat( url ); //krazy:exclude=syscalls
-        d->verifyState("stat()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_MIMETYPE: {
-        stream >> url;
-        d->m_state = d->InsideMethod;
-        mimetype( url );
-        d->verifyState("mimetype()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_LISTDIR: {
-        stream >> url;
-        d->m_state = d->InsideMethod;
-        listDir( url );
-        d->verifyState("listDir()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_MKDIR: {
-        stream >> url >> i;
-        d->m_state = d->InsideMethod;
-        mkdir( url, i ); //krazy:exclude=syscalls
-        d->verifyState("mkdir()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_RENAME: {
-        qint8 iOverwrite;
-        KUrl url2;
-        stream >> url >> url2 >> iOverwrite;
-        JobFlags flags;
-        if ( iOverwrite != 0 ) flags |= Overwrite;
-        d->m_state = d->InsideMethod;
-        rename( url, url2, flags ); //krazy:exclude=syscalls
-        d->verifyState("rename()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_SYMLINK: {
-        qint8 iOverwrite;
-        QString target;
-        stream >> target >> url >> iOverwrite;
-        JobFlags flags;
-        if ( iOverwrite != 0 ) flags |= Overwrite;
-        d->m_state = d->InsideMethod;
-        symlink( target, url, flags );
-        d->verifyState("symlink()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_COPY: {
-        int permissions;
-        qint8 iOverwrite;
-        KUrl url2;
-        stream >> url >> url2 >> permissions >> iOverwrite;
-        JobFlags flags;
-        if ( iOverwrite != 0 ) flags |= Overwrite;
-        d->m_state = d->InsideMethod;
-        copy( url, url2, permissions, flags );
-        d->verifyState("copy()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_DEL: {
-        qint8 isFile;
-        stream >> url >> isFile;
-        d->m_state = d->InsideMethod;
-        del( url, isFile != 0);
-        d->verifyState("del()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_CHMOD: {
-        stream >> url >> i;
-        d->m_state = d->InsideMethod;
-        chmod( url, i);
-        d->verifyState("chmod()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_CHOWN: {
-        QString owner, group;
-        stream >> url >> owner >> group;
-        d->m_state = d->InsideMethod;
-        chown(url, owner, group);
-        d->verifyState("chown()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_SETMODIFICATIONTIME: {
-        QDateTime dt;
-        stream >> url >> dt;
-        d->m_state = d->InsideMethod;
-        setModificationTime(url, dt);
-        d->verifyState("setModificationTime()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_SPECIAL: {
-        d->m_state = d->InsideMethod;
-        special( data );
-        d->verifyState("special()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_META_DATA: {
-        //kDebug(7019) << "(" << getpid() << ") Incoming meta-data...";
-        stream >> mIncomingMetaData;
-        d->rebuildConfig();
-    } break;
-    case CMD_SUBURL: {
-        stream >> url;
-        d->m_state = d->InsideMethod;
-        setSubUrl(url);
-        d->verifyErrorFinishedNotCalled("setSubUrl()");
-        d->m_state = d->Idle;
-    } break;
-    case CMD_NONE: {
-        kWarning(7019) << "Got unexpected CMD_NONE!";
-    } break;
-    case CMD_MULTI_GET: {
-        d->m_state = d->InsideMethod;
-        multiGet( data );
-        d->verifyState("multiGet()");
-        d->m_state = d->Idle;
-    } break;
-    default: {
-        // Some command we don't understand.
-        // Just ignore it, it may come from some future version of KDE.
-    } break;
+            d->m_state = d->InsideMethod;
+            put( url, permissions, flags);
+            d->verifyState("put()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_STAT: {
+            KUrl url;
+            stream >> url;
+            d->m_state = d->InsideMethod;
+            stat( url ); //krazy:exclude=syscalls
+            d->verifyState("stat()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_MIMETYPE: {
+            KUrl url;
+            stream >> url;
+            d->m_state = d->InsideMethod;
+            mimetype( url );
+            d->verifyState("mimetype()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_LISTDIR: {
+            KUrl url;
+            stream >> url;
+            d->m_state = d->InsideMethod;
+            listDir( url );
+            d->verifyState("listDir()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_MKDIR: {
+            KUrl url;
+            int i;
+            stream >> url >> i;
+            d->m_state = d->InsideMethod;
+            mkdir( url, i ); //krazy:exclude=syscalls
+            d->verifyState("mkdir()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_RENAME: {
+            KUrl url;
+            KUrl url2;
+            qint8 iOverwrite;
+            stream >> url >> url2 >> iOverwrite;
+            JobFlags flags;
+            if ( iOverwrite != 0 ) flags |= Overwrite;
+            d->m_state = d->InsideMethod;
+            rename( url, url2, flags ); //krazy:exclude=syscalls
+            d->verifyState("rename()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_SYMLINK: {
+            KUrl url;
+            QString target;
+            qint8 iOverwrite;
+            stream >> target >> url >> iOverwrite;
+            JobFlags flags;
+            if ( iOverwrite != 0 ) flags |= Overwrite;
+            d->m_state = d->InsideMethod;
+            symlink( target, url, flags );
+            d->verifyState("symlink()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_COPY: {
+            KUrl url;
+            KUrl url2;
+            int permissions;
+            qint8 iOverwrite;
+            stream >> url >> url2 >> permissions >> iOverwrite;
+            JobFlags flags;
+            if ( iOverwrite != 0 ) flags |= Overwrite;
+            d->m_state = d->InsideMethod;
+            copy( url, url2, permissions, flags );
+            d->verifyState("copy()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_DEL: {
+            KUrl url;
+            qint8 isFile;
+            stream >> url >> isFile;
+            d->m_state = d->InsideMethod;
+            del( url, isFile != 0);
+            d->verifyState("del()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_CHMOD: {
+            KUrl url;
+            int i;
+            stream >> url >> i;
+            d->m_state = d->InsideMethod;
+            chmod( url, i);
+            d->verifyState("chmod()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_CHOWN: {
+            KUrl url;
+            QString owner, group;
+            stream >> url >> owner >> group;
+            d->m_state = d->InsideMethod;
+            chown(url, owner, group);
+            d->verifyState("chown()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_SETMODIFICATIONTIME: {
+            KUrl url;
+            QDateTime dt;
+            stream >> url >> dt;
+            d->m_state = d->InsideMethod;
+            setModificationTime(url, dt);
+            d->verifyState("setModificationTime()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_SPECIAL: {
+            d->m_state = d->InsideMethod;
+            special( data );
+            d->verifyState("special()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_META_DATA: {
+            //kDebug(7019) << "(" << getpid() << ") Incoming meta-data...";
+            stream >> mIncomingMetaData;
+            d->rebuildConfig();
+            break;
+        }
+        case CMD_SUBURL: {
+            KUrl url;
+            stream >> url;
+            d->m_state = d->InsideMethod;
+            setSubUrl(url);
+            d->verifyErrorFinishedNotCalled("setSubUrl()");
+            d->m_state = d->Idle;
+            break;
+        }
+        case CMD_NONE: {
+            kWarning(7019) << "Got unexpected CMD_NONE!";
+            break;
+        }
+        default: {
+            // Some command we don't understand.
+            // Just ignore it, it may come from some future version of KDE.
+            break;
+        }
     }
 }
 
 bool SlaveBase::checkCachedAuthentication( AuthInfo& info )
 {
-    KPasswdServer* passwdServer = d->passwdServer();
-    return (passwdServer &&
-            passwdServer->checkAuthInfo(info, metaData(QLatin1String("window-id")).toLong(),
-                                        metaData(QLatin1String("user-timestamp")).toULong()));
+    KPasswdStore* passwdstore = d->passwdStore();
+    if (!passwdstore) {
+        return false;
+    }
+    const qlonglong windowId = metaData(QLatin1String("window-id")).toLongLong();
+    const QByteArray authkey = authInfoKey(info);
+    if (passwdstore->hasPasswd(authkey, windowId)) {
+        const QString passwd = passwdstore->getPasswd(authkey, windowId);
+        info = authInfoFromData(passwd.toLatin1());
+        return true;
+    }
+    return false;
 }
 
 void SlaveBase::dispatchOpenCommand( int command, const QByteArray &data )
@@ -1212,42 +1248,46 @@ void SlaveBase::dispatchOpenCommand( int command, const QByteArray &data )
     QDataStream stream( data );
 
     switch( command ) {
-    case CMD_READ: {
-        KIO::filesize_t bytes;
-        stream >> bytes;
-        read(bytes);
-        break;
-    }
-    case CMD_WRITE: {
-        write(data);
-        break;
-    }
-    case CMD_SEEK: {
-        KIO::filesize_t offset;
-        stream >> offset;
-        seek(offset);
-    }
-    case CMD_NONE:
-        break;
-    case CMD_CLOSE:
-        close();                // must call finish(), which will set d->inOpenLoop=false
-        break;
-    default:
-        // Some command we don't understand.
-        // Just ignore it, it may come from some future version of KDE.
-        break;
+        case CMD_READ: {
+            KIO::filesize_t bytes;
+            stream >> bytes;
+            read(bytes);
+            break;
+        }
+        case CMD_WRITE: {
+            write(data);
+            break;
+        }
+        case CMD_SEEK: {
+            KIO::filesize_t offset;
+            stream >> offset;
+            seek(offset);
+            break;
+        }
+        case CMD_NONE: {
+            break;
+        }
+        case CMD_CLOSE: {
+            close();                // must call finish(), which will set d->inOpenLoop=false
+            break;
+        }
+        default: {
+            // Some command we don't understand.
+            // Just ignore it, it may come from some future version of KDE.
+            break;
+        }
     }
 }
 
 bool SlaveBase::cacheAuthentication( const AuthInfo& info )
 {
-    KPasswdServer* passwdServer = d->passwdServer();
+    KPasswdStore* passwdstore = d->passwdStore();
 
-    if (!passwdServer) {
+    if (!passwdstore) {
         return false;
     }
 
-    passwdServer->addAuthInfo(info, metaData(QLatin1String("window-id")).toLongLong());
+    passwdstore->storePasswd(authInfoKey(info), authInfoToData(info), metaData(QLatin1String("window-id")).toLongLong());
     return true;
 }
 
@@ -1282,7 +1322,6 @@ int SlaveBase::responseTimeout()
     return DEFAULT_RESPONSE_TIMEOUT;
 }
 
-
 int SlaveBase::readTimeout()
 {
     bool ok;
@@ -1311,39 +1350,3 @@ void SlaveBase::send(int cmd, const QByteArray& arr )
        slaveWriteError = true;
    if (slaveWriteError) exit();
 }
-
-void SlaveBase::virtual_hook( int, void* )
-{ /*BASE::virtual_hook( id, data );*/ }
-
-void SlaveBase::lookupHost(const QString& host)
-{
-    KIO_DATA << host;
-    send(MSG_HOST_INFO_REQ, data);
-}
-
-int SlaveBase::waitForHostInfo(QHostInfo& info)
-{
-    QByteArray data;
-    int result = waitForAnswer(CMD_HOST_INFO, 0, data);
-
-    if (result  == -1) {
-        info.setError(QHostInfo::UnknownError);
-        info.setErrorString(i18n("Unknown Error"));
-        return result;
-    }
-
-    QDataStream stream(data);
-    QString hostName;
-    QList<QHostAddress> addresses;
-    int error;
-    QString errorString;
-
-    stream >> hostName >> addresses >> error >> errorString;
-
-    info.setHostName(hostName);
-    info.setAddresses(addresses);
-    info.setError(QHostInfo::HostInfoError(error));
-    info.setErrorString(errorString);
-
-    return result;
-}
