@@ -17,14 +17,13 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef __kio_slaveinterface_h
-#define __kio_slaveinterface_h
+#ifndef KIO_SLAVEINTERFACE_H
+#define KIO_SLAVEINTERFACE_H
 
 #include <unistd.h>
 #include <sys/types.h>
 
 #include <QtCore/QObject>
-#include <QtNetwork/QHostInfo>
 
 #include <kio/global.h>
 #include <kio/udsentry.h>
@@ -49,13 +48,9 @@ class SlaveInterfacePrivate;
    INF_SPEED,
    INF_REDIRECTION = 20,
    INF_MIME_TYPE = 21,
-   INF_ERROR_PAGE = 22,
    INF_WARNING = 23,
-   INF_GETTING_FILE, // Deprecated
-   INF_UNUSED = 25, // now unused
    INF_INFOMESSAGE,
    INF_META_DATA,
-   INF_NETWORK_STATUS,
    INF_MESSAGEBOX,
    INF_POSITION
    // add new ones here once a release is done, to avoid breaking binary compatibility
@@ -72,19 +67,13 @@ class SlaveInterfacePrivate;
    MSG_FINISHED,
    MSG_STAT_ENTRY, // 105
    MSG_LIST_ENTRIES,
-   MSG_RENAMED, // unused
    MSG_RESUME,
    MSG_SLAVE_STATUS,
    MSG_SLAVE_ACK, // 110
-   MSG_NET_REQUEST,
-   MSG_NET_DROP,
    MSG_NEED_SUBURL_DATA,
    MSG_CANRESUME,
-   MSG_AUTH_KEY, // 115 // deprecated.
-   MSG_DEL_AUTH_KEY, // deprecated.
    MSG_OPENED,
    MSG_WRITTEN,
-   MSG_HOST_INFO_REQ
    // add new ones here once a release is done, to avoid breaking binary compatibility
  };
 
@@ -130,7 +119,7 @@ public:
      * @since 4.8.2
      * @deprecated
      */
-    KDE_DEPRECATED QWidget* window() const;
+    KIO_DEPRECATED QWidget* window() const;
 
     /**
      * Sets the top level window used as a parent when displaying
@@ -139,7 +128,7 @@ public:
      * @since 4.8.2
      * @deprecated
      */
-    KDE_DEPRECATED void setWindow(QWidget* window);
+    KIO_DEPRECATED void setWindow(QWidget* window);
 
 Q_SIGNALS:
     ///////////
@@ -171,7 +160,6 @@ Q_SIGNALS:
     void position( KIO::filesize_t );
 
     void speed( unsigned long );
-    void errorPage();
     void mimeType( const QString & );
     void warning( const QString & );
     void infoMessage( const QString & );
@@ -183,7 +171,7 @@ protected:
     ////////////////
 
     virtual bool dispatch();
-    virtual bool dispatch( int _cmd, const QByteArray &data );
+    virtual bool dispatch( int cmd, const QByteArray &data );
 
     void messageBox( int type, const QString &text, const QString &caption,
                      const QString &buttonYes, const QString &buttonNo );
@@ -192,17 +180,11 @@ protected:
                      const QString &buttonYes, const QString &buttonNo,
                      const QString &dontAskAgainName );
 
-    // I need to identify the slaves
-    void requestNetwork( const QString &, const QString &);
-    void dropNetwork( const QString &, const QString &);
-
 protected Q_SLOTS:
     void calcSpeed();
 protected:
     SlaveInterfacePrivate* const d_ptr;
     Q_DECLARE_PRIVATE(SlaveInterface)
-private:
-    Q_PRIVATE_SLOT(d_func(), void slotHostInfo(QHostInfo))
 };
 
 }
