@@ -19,6 +19,8 @@
 
 #include "thumbcreator.h"
 
+#include <qglobal.h>
+
 ThumbCreator::~ThumbCreator()
 {
 }
@@ -28,16 +30,12 @@ ThumbCreator::Flags ThumbCreator::flags() const
     return None;
 }
 
-ThumbCreatorV2::~ThumbCreatorV2()
-{
-}
-
-QWidget *ThumbCreatorV2::createConfigurationWidget()
+QWidget *ThumbCreator::createConfigurationWidget()
 {
     return 0;
 }
 
-void ThumbCreatorV2::writeConfiguration(const QWidget *configurationWidget)
+void ThumbCreator::writeConfiguration(const QWidget *configurationWidget)
 {
     Q_UNUSED(configurationWidget);
 }
