@@ -55,30 +55,10 @@ QTEST_KDEMAIN( JobTest, NoGUI )
 
 static QString otherTmpDir()
 {
-#ifdef Q_WS_WIN
-    return QDir::tempPath() + "/jobtest/";
-#else
     // This one needs to be on another partition
     return "/tmp/jobtest/";
-#endif
 }
 
-#if 0
-static KUrl systemTmpDir()
-{
-#ifdef Q_WS_WIN
-    return KUrl( "system:" + QDir::homePath() + "/.kde-unit-test/jobtest-system/" );
-#else
-    return KUrl( "system:/home/.kde-unit-test/jobtest-system/" );
-#endif
-}
-
-static QString realSystemPath()
-{
-    return QFile::decodeName( getenv( "KDEHOME" ) ) + "/jobtest-system/";
-}
-#endif
-
 Q_DECLARE_METATYPE(KIO::Job*)
 
 void JobTest::initTestCase()
@@ -93,15 +73,6 @@ void JobTest::initTestCase()
         if ( !ok )
             kFatal() << "Couldn't create " << otherTmpDir();
     }
-#if 0
-    if ( KProtocolInfo::isKnownProtocol( "system" ) ) {
-        if ( !QFile::exists( realSystemPath() ) ) {
-            bool ok = dir.mkdir( realSystemPath() );
-            if ( !ok )
-                kFatal() << "Couldn't create " << realSystemPath();
-        }
-    }
-#endif
 
     qRegisterMetaType<KJob*>("KJob*");
     qRegisterMetaType<KIO::Job*>("KIO::Job*");
@@ -120,11 +91,6 @@ void JobTest::cleanupTestCase()
 {
     delDir( homeTmpDir() );
     delDir( otherTmpDir() );
-#if 0
-    if ( KProtocolInfo::isKnownProtocol( "system" ) ) {
-        delDir(systemTmpDir());
-    }
-#endif
 }
 
 void JobTest::enterLoop()
@@ -252,13 +218,7 @@ void JobTest::copyLocalFile( const QString& src, const QString& dest )
         // The datapump solution ignores mtime, the app has to call FileCopyJob::setModificationTime()
         QFileInfo srcInfo( src );
         QFileInfo destInfo( dest );
-#ifdef Q_WS_WIN
-        // win32 time may differs in msec part
-        QCOMPARE( srcInfo.lastModified().toString("dd.MM.yyyy hh:mm"),
-                  destInfo.lastModified().toString("dd.MM.yyyy hh:mm") );
-#else
         QCOMPARE( srcInfo.lastModified(), destInfo.lastModified() );
-#endif
     }
 
     // cleanup and retry with KIO::copy()
@@ -274,13 +234,7 @@ void JobTest::copyLocalFile( const QString& src, const QString& dest )
         // check that the timestamp is the same (#24443)
         QFileInfo srcInfo( src );
         QFileInfo destInfo( dest );
-#ifdef Q_WS_WIN
-        // win32 time may differs in msec part
-        QCOMPARE( srcInfo.lastModified().toString("dd.MM.yyyy hh:mm"),
-                  destInfo.lastModified().toString("dd.MM.yyyy hh:mm") );
-#else
         QCOMPARE( srcInfo.lastModified(), destInfo.lastModified() );
-#endif
     }
     QCOMPARE(spyCopyingDone.count(), 1);
 }
@@ -295,18 +249,18 @@ void JobTest::copyLocalDirectory( const QString& src, const QString& _dest, int
     KUrl d;
     d.setPath( dest );
     if ( flags & AlreadyExists )
-        QVERIFY( QFile::exists( dest ) );
+        QVERIFY( QDir( dest ).exists() );
     else
-        QVERIFY( !QFile::exists( dest ) );
+        QVERIFY( !QDir( dest ).exists() );
 
     KIO::Job* job = KIO::copy(u, d, KIO::HideProgressInfo);
     job->setUiDelegate(0);
     bool ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY( ok );
-    QVERIFY( QFile::exists( dest ) );
+    QVERIFY( QDir( dest ).exists() );
     QVERIFY( QFileInfo( dest ).isDir() );
     QVERIFY( QFileInfo( dest + "/testfile" ).isFile() );
-    QVERIFY( QFile::exists( src ) ); // still there
+    QVERIFY( QDir( src ).exists() ); // still there
 
     if ( flags & AlreadyExists ) {
         dest += '/' + u.fileName();
@@ -314,14 +268,12 @@ void JobTest::copyLocalDirectory( const QString& src, const QString& _dest, int
     }
 
     // CopyJob::setNextDirAttribute isn't implemented for Windows currently.
-#ifndef Q_WS_WIN
     {
         // Check that the timestamp is the same (#24443)
         QFileInfo srcInfo( src );
         QFileInfo destInfo( dest );
         QCOMPARE( srcInfo.lastModified(), destInfo.lastModified() );
     }
-#endif
 
     // Do it again, with Overwrite.
     // Use copyAs, we don't want a subdir inside d.
@@ -441,12 +393,10 @@ static void moveLocalSymlink( const QString& src, const QString& dest )
 void JobTest::moveLocalDirectory( const QString& src, const QString& dest )
 {
     kDebug() << src << " " << dest;
-    QVERIFY( QFile::exists( src ) );
+    QVERIFY( QDir( src ).exists() );
     QVERIFY( QFileInfo( src ).isDir() );
     QVERIFY( QFileInfo( src + "/testfile" ).isFile() );
-#ifndef Q_WS_WIN
     QVERIFY( QFileInfo( src + "/testlink" ).isSymLink() );
-#endif
     KUrl u;
     u.setPath( src );
     KUrl d;
@@ -456,13 +406,11 @@ void JobTest::moveLocalDirectory( const QString& src, const QString& dest )
     job->setUiDelegate( 0 );
     bool ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY( ok );
-    QVERIFY( QFile::exists( dest ) );
+    QVERIFY( QDir( dest).exists() );
     QVERIFY( QFileInfo( dest ).isDir() );
     QVERIFY( QFileInfo( dest + "/testfile" ).isFile() );
-    QVERIFY( !QFile::exists( src ) ); // not there anymore
-#ifndef Q_WS_WIN
+    QVERIFY( !QDir( src ).exists() ); // not there anymore
     QVERIFY( QFileInfo( dest + "/testlink" ).isSymLink() );
-#endif
 }
 
 void JobTest::moveFileToSamePartition()
@@ -494,32 +442,25 @@ void JobTest::moveFileToOtherPartition()
 
 void JobTest::moveSymlinkToOtherPartition()
 {
-#ifndef Q_WS_WIN
     kDebug() ;
     const QString filePath = homeTmpDir() + "testlink";
     const QString dest = otherTmpDir() + "testlink_moved";
     createTestSymlink( filePath );
     moveLocalSymlink( filePath, dest );
-#endif
 }
 
 void JobTest::moveDirectoryToOtherPartition()
 {
     kDebug() ;
-#ifndef Q_WS_WIN
     const QString src = homeTmpDir() + "dirFromHome";
     const QString dest = otherTmpDir() + "dirFromHome_moved";
     createTestDirectory( src );
     moveLocalDirectory( src, dest );
-#endif
 }
 
 void JobTest::moveFileNoPermissions()
 {
     kDebug() ;
-#ifdef Q_WS_WIN
-    kDebug() << "port to win32";
-#else
     const QString src = "/etc/passwd";
     const QString dest = homeTmpDir() + "passwd";
     QVERIFY( QFile::exists( src ) );
@@ -541,23 +482,19 @@ void JobTest::moveFileNoPermissions()
     // destination file remains.
     //QVERIFY( QFile::exists( dest ) );
     QVERIFY( QFile::exists( src ) );
-#endif
 }
 
 void JobTest::moveDirectoryNoPermissions()
 {
     kDebug() ;
-#ifdef Q_WS_WIN
-    kDebug() << "port to win32";
-#else
 
     // All of /etc is a bit much, so try to find something smaller:
     QString src = "/etc/fonts";
-    if ( !QFile::exists( src ) )
+    if ( !QDir( src ).exists() )
         src = "/etc";
 
     const QString dest = homeTmpDir() + "mdnp";
-    QVERIFY( QFile::exists( src ) );
+    QVERIFY( QDir( src ).exists() );
     QVERIFY( QFileInfo( src ).isDir() );
     KUrl u;
     u.setPath( src );
@@ -570,9 +507,8 @@ void JobTest::moveDirectoryNoPermissions()
     bool ok = KIO::NetAccess::synchronousRun( job, 0, 0, 0, &metaData );
     QVERIFY( !ok );
     QCOMPARE( KIO::NetAccess::lastError(), (int)KIO::ERR_ACCESS_DENIED );
-    //QVERIFY( QFile::exists( dest ) ); // see moveFileNoPermissions
-    QVERIFY( QFile::exists( src ) );
-#endif
+    //QVERIFY( QDir( dest ).exists() ); // see moveFileNoPermissions
+    QVERIFY( QDir( src ).exists() );
 }
 
 void JobTest::listRecursive()
@@ -580,11 +516,9 @@ void JobTest::listRecursive()
     // Note: many other tests must have been run before since we rely on the files they created
 
     const QString src = homeTmpDir();
-#ifndef Q_WS_WIN
     // Add a symlink to a dir, to make sure we don't recurse into those
     bool symlinkOk = symlink( "dirFromHome", QFile::encodeName( src + "/dirFromHome_link" ) ) == 0;
     QVERIFY( symlinkOk );
-#endif
     KIO::ListJob* job = KIO::listRecursive( KUrl(src), KIO::HideProgressInfo );
     job->setUiDelegate( 0 );
     connect( job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
@@ -594,18 +528,12 @@ void JobTest::listRecursive()
     m_names.sort();
     QByteArray ref_names = QByteArray( ".,..,"
             "dirFromHome,dirFromHome/testfile,"
-#ifndef Q_WS_WIN
             "dirFromHome/testlink,"
-#endif
             "dirFromHome_copied,"
             "dirFromHome_copied/dirFromHome,dirFromHome_copied/dirFromHome/testfile,"
-#ifndef Q_WS_WIN
             "dirFromHome_copied/dirFromHome/testlink,"
-#endif
             "dirFromHome_copied/testfile,"
-#ifndef Q_WS_WIN
             "dirFromHome_copied/testlink,dirFromHome_link,"
-#endif
             "fileFromHome,fileFromHome_copied");
 
     const QString joinedNames = m_names.join( "," );
@@ -682,15 +610,9 @@ void JobTest::directorySize()
     kDebug() << "totalSize: " << job->totalSize();
     kDebug() << "totalFiles: " << job->totalFiles();
     kDebug() << "totalSubdirs: " << job->totalSubdirs();
-#ifdef Q_WS_WIN
-    QCOMPARE(job->totalFiles(), 5ULL); // see expected result in listRecursive() above
-    QCOMPARE(job->totalSubdirs(), 3ULL); // see expected result in listRecursive() above
-    QVERIFY(job->totalSize() > 54);
-#else
     QCOMPARE(job->totalFiles(), 8ULL); // see expected result in listRecursive() above
     QCOMPARE(job->totalSubdirs(), 4ULL); // see expected result in listRecursive() above
     QVERIFY(job->totalSize() >= 325);
-#endif
 
     qApp->sendPostedEvents(0, QEvent::DeferredDelete);
 }
@@ -859,8 +781,8 @@ void JobTest::newApiPerformance()
 
 
         for (int i = 0; i < lookupIterations; ++i) {
-            OldUDSEntry::ConstIterator it2 = entry.begin();
-            for( ; it2 != entry.end(); it2++ ) {
+            OldUDSEntry::ConstIterator it2 = entry.constBegin();
+            for( ; it2 != entry.constEnd(); it2++ ) {
                 switch ((*it2).m_uds) {
                 case KIO::UDSEntry::UDS_NAME:
                     displayName = (*it2).m_str;
@@ -924,12 +846,12 @@ void JobTest::newApiPerformance()
             displayName = entry.value( KIO::UDSEntry::UDS_NAME ).toString();
 
             // For a field that might not be there
-            UDSEntryHV::const_iterator it = entry.find( KIO::UDSEntry::UDS_URL );
-            const UDSEntryHV::const_iterator end = entry.end();
+            UDSEntryHV::const_iterator it = entry.constFind( KIO::UDSEntry::UDS_URL );
+            const UDSEntryHV::const_iterator end = entry.constEnd();
             if ( it != end )
                  url = it.value().toString();
 
-            it = entry.find( KIO::UDSEntry::UDS_SIZE );
+            it = entry.constFind( KIO::UDSEntry::UDS_SIZE );
             if ( it != end )
                 size = it.value().toULongLong();
         }
@@ -972,12 +894,12 @@ void JobTest::newApiPerformance()
             displayName = entry.value( KIO::UDSEntry::UDS_NAME ).m_str;
 
             // For a field that might not be there
-            UDSEntryHS::const_iterator it = entry.find( KIO::UDSEntry::UDS_URL );
-            const UDSEntryHS::const_iterator end = entry.end();
+            UDSEntryHS::const_iterator it = entry.constFind( KIO::UDSEntry::UDS_URL );
+            const UDSEntryHS::const_iterator end = entry.constEnd();
             if ( it != end )
                  url = it.value().m_str;
 
-            it = entry.find( KIO::UDSEntry::UDS_SIZE );
+            it = entry.constFind( KIO::UDSEntry::UDS_SIZE );
             if ( it != end )
                 size = it.value().m_long;
         }
@@ -1019,12 +941,12 @@ void JobTest::newApiPerformance()
             displayName = entry.value( KIO::UDSEntry::UDS_NAME ).m_str;
 
             // For a field that might not be there
-            UDSEntryMS::const_iterator it = entry.find( KIO::UDSEntry::UDS_URL );
-            const UDSEntryMS::const_iterator end = entry.end();
+            UDSEntryMS::const_iterator it = entry.constFind( KIO::UDSEntry::UDS_URL );
+            const UDSEntryMS::const_iterator end = entry.constEnd();
             if ( it != end )
                  url = it.value().m_str;
 
-            it = entry.find( KIO::UDSEntry::UDS_SIZE );
+            it = entry.constFind( KIO::UDSEntry::UDS_SIZE );
             if ( it != end )
                 size = it.value().m_long;
         }
@@ -1051,86 +973,9 @@ void JobTest::calculateRemainingSeconds()
     QCOMPARE( text, i18n( "00:00:50" ) );
 }
 
-#if 0
-void JobTest::copyFileToSystem()
-{
-    if ( !KProtocolInfo::isKnownProtocol( "system" ) ) {
-        kDebug() << "no kio_system, skipping test";
-        return;
-    }
-
-    // First test with support for UDS_LOCAL_PATH
-    copyFileToSystem( true );
-
-    QString dest = realSystemPath() + "fileFromHome_copied";
-    QFile::remove( dest );
-
-    // Then disable support for UDS_LOCAL_PATH, i.e. test what would
-    // happen for ftp, smb, http etc.
-    copyFileToSystem( false );
-}
-
-void JobTest::copyFileToSystem( bool resolve_local_urls )
-{
-    kDebug() << resolve_local_urls;
-    extern KIO_EXPORT bool kio_resolve_local_urls;
-    kio_resolve_local_urls = resolve_local_urls;
-
-    const QString src = homeTmpDir() + "fileFromHome";
-    createTestFile( src );
-    KUrl u;
-    u.setPath( src );
-    KUrl d = systemTmpDir();
-    d.addPath( "fileFromHome_copied" );
-
-    kDebug() << "copying " << u << " to " << d;
-
-    // copy the file with file_copy
-    m_mimetype.clear();
-    KIO::FileCopyJob* job = KIO::file_copy(u, d, -1, KIO::HideProgressInfo);
-    job->setUiDelegate( 0 );
-    connect( job, SIGNAL(mimetype(KIO::Job*,QString)),
-             this, SLOT(slotMimetype(KIO::Job*,QString)) );
-    bool ok = KIO::NetAccess::synchronousRun( job, 0 );
-    QVERIFY( ok );
-
-    QString dest = realSystemPath() + "fileFromHome_copied";
-
-    QVERIFY( QFile::exists( dest ) );
-    QVERIFY( QFile::exists( src ) ); // still there
-
-    {
-        // do NOT check that the timestamp is the same.
-        // It can't work with file_copy when it uses the datapump,
-        // unless we use setModificationTime in the app code.
-    }
-
-    // Check mimetype
-    QCOMPARE(m_mimetype, QString("text/plain"));
-
-    // cleanup and retry with KIO::copy()
-    QFile::remove( dest );
-    job = KIO::copy(u, d, KIO::HideProgressInfo);
-    job->setUiDelegate(0);
-    ok = KIO::NetAccess::synchronousRun(job, 0);
-    QVERIFY( ok );
-    QVERIFY( QFile::exists( dest ) );
-    QVERIFY( QFile::exists( src ) ); // still there
-    {
-        // check that the timestamp is the same (#79937)
-        QFileInfo srcInfo( src );
-        QFileInfo destInfo( dest );
-        QCOMPARE( srcInfo.lastModified(), destInfo.lastModified() );
-    }
-
-    // restore normal behavior
-    kio_resolve_local_urls = true;
-}
-#endif
-
 void JobTest::getInvalidUrl()
 {
-    KUrl url("http://strange<hostname>/");
+    KUrl url("http:/strange<hostname>/");
     QVERIFY(!url.isValid());
 
     KIO::SimpleJob* job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
@@ -1168,14 +1013,12 @@ void JobTest::deleteDirectory()
     // Let's put a few things in there to see if the recursive deletion works correctly
     // A hidden file:
     createTestFile(dest + "/.hidden");
-#ifndef Q_WS_WIN
     // A broken symlink:
     createTestSymlink(dest+"/broken_symlink");
     // A symlink to a dir:
     bool symlink_ok = symlink( KDESRCDIR, QFile::encodeName( dest + "/symlink_to_dir" ) ) == 0;
     if ( !symlink_ok )
         kFatal() << "couldn't create symlink: " << strerror( errno ) ;
-#endif
 
     KIO::Job* job = KIO::del(KUrl(dest), KIO::HideProgressInfo);
     job->setUiDelegate(0);
@@ -1189,24 +1032,22 @@ void JobTest::deleteSymlink(bool using_fast_path)
     extern KIO_EXPORT bool kio_resolve_local_urls;
     kio_resolve_local_urls = !using_fast_path;
 
-#ifndef Q_WS_WIN
     const QString src = homeTmpDir() + "dirFromHome";
     createTestDirectory(src);
-    QVERIFY(QFile::exists(src));
+    QVERIFY(QDir(src).exists());
     const QString dest = homeTmpDir() + "/dirFromHome_link";
-    if (!QFile::exists(dest)) {
+    if (!QDir(dest).exists()) {
         // Add a symlink to a dir, to make sure we don't recurse into those
         bool symlinkOk = symlink(QFile::encodeName(src), QFile::encodeName(dest)) == 0;
         QVERIFY( symlinkOk );
-        QVERIFY(QFile::exists(dest));
+        QVERIFY(QDir(dest).exists());
     }
     KIO::Job* job = KIO::del(KUrl(dest), KIO::HideProgressInfo);
     job->setUiDelegate(0);
     bool ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY(ok);
-    QVERIFY(!QFile::exists(dest));
-    QVERIFY(QFile::exists(src));
-#endif
+    QVERIFY(!QDir(dest).exists());
+    QVERIFY(QDir(src).exists());
 
     kio_resolve_local_urls = true;
 }
@@ -1214,10 +1055,8 @@ void JobTest::deleteSymlink(bool using_fast_path)
 
 void JobTest::deleteSymlink()
 {
-#ifndef Q_WS_WIN
     deleteSymlink(true);
     deleteSymlink(false);
-#endif
 }
 
 void JobTest::deleteManyDirs(bool using_fast_path)
@@ -1239,7 +1078,7 @@ void JobTest::deleteManyDirs(bool using_fast_path)
     bool ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY(ok);
     Q_FOREACH(const KUrl& dir, dirs) {
-        QVERIFY(!QFile::exists(dir.path()));
+        QVERIFY(!QDir(dir.path()).exists());
     }
 
     kDebug() << "Deleted" << numDirs << "dirs in" << dt.elapsed() << "milliseconds";
@@ -1319,10 +1158,10 @@ void JobTest::rmdirEmpty()
 {
     const QString dir = homeTmpDir() + "dir";
     QDir().mkdir(dir);
-    QVERIFY(QFile::exists(dir));
+    QVERIFY(QDir(dir).exists());
     KIO::Job* job = KIO::rmdir(dir);
     QVERIFY(job->exec());
-    QVERIFY(!QFile::exists(dir));
+    QVERIFY(!QDir(dir).exists());
 }
 
 void JobTest::rmdirNotEmpty()
@@ -1332,7 +1171,7 @@ void JobTest::rmdirNotEmpty()
     createTestDirectory(dir + "/subdir");
     KIO::Job* job = KIO::rmdir(dir);
     QVERIFY(!job->exec());
-    QVERIFY(QFile::exists(dir));
+    QVERIFY(QDir(dir).exists());
 }
 
 void JobTest::stat()
@@ -1369,7 +1208,8 @@ void JobTest::mostLocalUrl()
     createTestFile( filePath );
     KIO::StatJob* job = KIO::mostLocalUrl(filePath, KIO::HideProgressInfo);
     QVERIFY(job);
-    bool ok = job->exec();
+    job->setUiDelegate(0);
+    bool ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY(ok);
     QCOMPARE(job->mostLocalUrl().toLocalFile(), filePath);
 }
@@ -1462,7 +1302,7 @@ void JobTest::moveDestAlreadyExistsAutoRename()
         // cleanup
         KIO::Job* job = KIO::del(dir, KIO::HideProgressInfo);
         QVERIFY(job->exec());
-        QVERIFY(!QFile::exists(dir));
+        QVERIFY(!QDir(dir).exists());
     }
 }
 
@@ -1493,14 +1333,14 @@ void JobTest::moveDestAlreadyExistsAutoRename(const QString& destDir, bool moveD
 
     kDebug() << QDir(destDir).entryList();
     QVERIFY(ok);
-    QVERIFY(!QFile::exists(file1)); // it was moved
-    QVERIFY(!QFile::exists(file2)); // it was moved
-    QVERIFY(QFile::exists(existingDest1));
-    QVERIFY(QFile::exists(existingDest2));
+    QVERIFY(!QFileInfo(file1).exists()); // it was moved
+    QVERIFY(!QFileInfo(file2).exists()); // it was moved
+    QVERIFY(QFileInfo(existingDest1).exists());
+    QVERIFY(QFileInfo(existingDest2).exists());
     const QString file3 = destDir + prefix + "3";
     const QString file4 = destDir + prefix + "4";
-    QVERIFY(QFile::exists(file3));
-    QVERIFY(QFile::exists(file4));
+    QVERIFY(QFileInfo(file3).exists());
+    QVERIFY(QFileInfo(file4).exists());
     if (moveDirs) {
         QDir().rmdir(file1);
         QDir().rmdir(file2);
@@ -1527,7 +1367,6 @@ void JobTest::moveAndOverwrite()
     QVERIFY(ok);
     QVERIFY(!QFile::exists(sourceFile)); // it was moved
 
-#ifndef Q_WS_WIN
     // Now same thing when the target is a symlink to the source
     createTestFile( sourceFile );
     createTestSymlink( existingDest, QFile::encodeName(sourceFile) );
@@ -1558,12 +1397,10 @@ void JobTest::moveAndOverwrite()
     ok = KIO::NetAccess::synchronousRun(job, 0);
     QVERIFY(ok);
     QVERIFY(!QFile::exists(sourceFile)); // it was moved
-#endif
 }
 
 void JobTest::moveOverSymlinkToSelf() // #169547
 {
-#ifndef Q_WS_WIN
     const QString sourceFile = homeTmpDir() + "fileFromHome";
     createTestFile( sourceFile );
     const QString existingDest = homeTmpDir() + "testlink";
@@ -1576,7 +1413,6 @@ void JobTest::moveOverSymlinkToSelf() // #169547
     QVERIFY(!ok);
     QCOMPARE(job->error(), (int)KIO::ERR_FILE_ALREADY_EXIST); // and not ERR_IDENTICAL_FILES!
     QVERIFY(QFile::exists(sourceFile)); // it not moved
-#endif
 }
 
-#include "jobtest.moc"
+#include "moc_jobtest.cpp"
