@@ -19,7 +19,7 @@
 
 #include "kdirlistertest.h"
 #include <ktemporaryfile.h>
-#include "kdirlistertest.moc"
+#include "moc_kdirlistertest.cpp"
 #include <kdirlister.h>
 #include <qtest_kde.h>
 
@@ -32,8 +32,6 @@ QTEST_KDEMAIN( KDirListerTest, NoGUI )
 #include <kio/job.h>
 #include <kio/copyjob.h>
 
-#define WORKAROUND_BROKEN_INOTIFY 0
-
 void MyDirLister::handleError(KIO::Job* job)
 {
     // Currently we don't expect any errors.
@@ -259,7 +257,7 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     const QString symPath = tempFile.fileName() + "_link";
     tempFile.close();
     bool symlinkOk = ::symlink(QFile::encodeName(path), QFile::encodeName(symPath)) == 0;
-    QVERIFY2(symlinkOk, qPrintable(QString("Failed to symlink(%1, %2): %3").arg(path, symPath, strerror(errno))));
+    QVERIFY(symlinkOk);
     MyDirLister dirLister2;
     m_items2.clear();
     connect(&dirLister2, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems2(KFileItemList)));
@@ -278,9 +276,6 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     const QString fileName = "toplevelfile_newinlink";
     createSimpleFile(path + fileName);
 
-#if WORKAROUND_BROKEN_INOTIFY
-    org::kde::KDirNotify::emitFilesAdded(path);
-#endif
     int numTries = 0;
     // Give time for KDirWatch to notify us
     while (m_items2.count() == origItemCount) {
@@ -312,19 +307,17 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
         qDebug() << "Deleting" << (path+fileName);
         QTest::qWait(1000); // for timestamp difference
         QFile::remove(path + fileName);
-        while (dirLister2.spyDeleteItem.count() == 0) {
+        while (dirLister2.spyItemsDeleted.count() == 0) {
             QVERIFY(++numTries < 10);
             QTest::qWait(200);
         }
-        QCOMPARE(dirLister2.spyDeleteItem.count(), 1);
-        const KFileItem item = dirLister2.spyDeleteItem[0][0].value<KFileItem>();
+        QCOMPARE(dirLister2.spyItemsDeleted.count(), 1);
+        const KFileItem item = dirLister2.spyItemsDeleted[0][0].value<KFileItem>();
         QCOMPARE(item.url().toLocalFile(), QString(symPath + '/' + fileName));
     }
 
     // TODO: test file update.
     disconnect(&m_dirLister, 0, this, 0);
-
-    QFile::remove(symPath);
 }
 
 // This test assumes testOpenUrl was run before. So m_dirLister is holding the items already.
@@ -443,18 +436,15 @@ void KDirListerTest::testDeleteItem()
     const int origItemCount = m_items.count();
     QCOMPARE(fileCount(), origItemCount);
     const QString path = m_tempDir.name();
-    connect(&m_dirLister, SIGNAL(deleteItem(KFileItem)), this, SLOT(exitLoop()));
+    connect(&m_dirLister, SIGNAL(itemsDeleted(KFileItemList)), this, SLOT(exitLoop()));
 
     //kDebug() << "Removing " << path+"toplevelfile_1";
     QFile::remove(path+"toplevelfile_1");
-    // the remove() doesn't always trigger kdirwatch in stat mode, if this all happens in the same second
-    KDirWatch::self()->setDirty(path);
-    if (m_dirLister.spyDeleteItem.count() == 0) {
-        qDebug("waiting for deleteItem");
+    if (m_dirLister.spyItemsDeleted.count() == 0) {
+        qDebug("waiting for itemsDeleted");
         enterLoop();
     }
 
-    QCOMPARE(m_dirLister.spyDeleteItem.count(), 1);
     QCOMPARE(m_dirLister.spyItemsDeleted.count(), 1);
 
     // OK now kdirlister told us the file was deleted, let's try a re-listing
@@ -508,11 +498,10 @@ void KDirListerTest::testRenameAndOverwrite() // has to be run after testRenameI
     const QString dirPath = m_tempDir.name();
     const QString path = dirPath+"toplevelfile_2";
     createTestFile(path);
-#if WORKAROUND_BROKEN_INOTIFY
-    org::kde::KDirNotify::emitFilesAdded(dirPath);
-#endif
     KFileItem existingItem;
+    int numTries = 0;
     while (existingItem.isNull()) {
+        QVERIFY(++numTries < 20);
         QTest::qWait(100);
         existingItem = m_dirLister.findByUrl(KUrl(path));
     };
@@ -956,38 +945,7 @@ void KDirListerTest::testRenameCurrentDir() // #294445
     QCOMPARE(secondDirLister.rootItem().url().toLocalFile(), newPath);
 
     disconnect(&secondDirLister, 0, this, 0);
-    QDir().rmdir(newPath);
-}
-
-void KDirListerTest::slotOpenUrlOnRename(const KUrl & newUrl)
-{
-  QVERIFY(m_dirLister.openUrl(newUrl));
-}
-
-//This tests for a crash if you connect redirects to openUrl, due
-//to internal data being inconsistently exposed.
-//Matches usage in gwenview.
-void KDirListerTest::testRenameCurrentDirOpenUrl()
-{
-    m_items.clear();
-    const QString path = m_tempDir.name() + "newsubdir-1";
-    QVERIFY(QDir().mkdir(path));
-    connect(&m_dirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
-
-    m_dirLister.openUrl(KUrl(path));
-    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
-    QVERIFY(m_dirLister.isFinished());
-
-    const QString newPath = m_tempDir.name() + "newsubdir-2";
-    QVERIFY(QDir().rename(path, newPath));
-
-    //Connect the redirection to openURL, so that on a rename the new location is opened.
-    //This matches usage in gwenview, and crashes without a fix
-    connect(&m_dirLister, SIGNAL(redirection(KUrl)), this, SLOT(slotOpenUrlOnRename(KUrl)));
-    org::kde::KDirNotify::emitFileRenamed(KUrl(path).url(), KUrl(newPath).url());
-    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(redirection(KUrl,KUrl)), 1000));
-    disconnect(&m_dirLister, 0, this, 0);
-    QDir().rmdir(newPath);
+    QDir().remove(newPath);
 }
 
 void KDirListerTest::testRedirection()
@@ -1027,38 +985,7 @@ void KDirListerTest::testRedirection()
     m_dirLister.stop(url);
     QVERIFY(!m_dirLister.isFinished());
     disconnect(&m_dirLister, 0, this, 0);
-}
 
-void KDirListerTest::testListEmptyDirFromCache() // #278431
-{
-    m_items.clear();
-
-    KTempDir newDir;
-    const QString path = newDir.name();
-
-    // List and watch an empty dir
-    connect(&m_dirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
-    m_dirLister.openUrl(QUrl::fromLocalFile(path));
-    QVERIFY(QTest::kWaitForSignal(&m_dirLister, SIGNAL(completed()), 1000));
-    QVERIFY(m_dirLister.isFinished());
-    QVERIFY(m_items.isEmpty());
-
-    // List it with two more dirlisters (one will create a cached items job, the second should also benefit from it)
-    MyDirLister secondDirLister;
-    connect(&secondDirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
-    secondDirLister.openUrl(KUrl(path), KDirLister::NoFlags);
-    MyDirLister thirdDirLister;
-    connect(&thirdDirLister, SIGNAL(newItems(KFileItemList)), this, SLOT(slotNewItems(KFileItemList)));
-    thirdDirLister.openUrl(KUrl(path), KDirLister::NoFlags);
-
-    // The point of this test is that (with DEBUG_CACHE enabled) it used to assert here
-    // with "HUH? Lister KDirLister(0x7ffd1f044260) is supposed to be listing, but has no job!"
-    // due to the if (!itemU->lstItems.isEmpty()) check which is now removed.
-
-    QVERIFY(!secondDirLister.isFinished()); // we didn't go to the event loop yet
-    QVERIFY(QTest::kWaitForSignal(&secondDirLister, SIGNAL(completed()), 1000));
-    if (!thirdDirLister.isFinished())
-        QVERIFY(QTest::kWaitForSignal(&thirdDirLister, SIGNAL(completed()), 1000));
 }
 
 void KDirListerTest::testWatchingAfterCopyJob() // #331582
@@ -1142,7 +1069,6 @@ void KDirListerTest::testRemoveWatchedDirectory()
 
     // Watch the subfolder for changes, independently.
     // This is what triggers the bug.
-    // (Technically, this could become a KDirWatch unittest, but if one day we use QFSW, good to have the tests here)
     KDirWatch watcher;
     watcher.addDir(subDirPath);
 
@@ -1191,6 +1117,8 @@ void KDirListerTest::testDirPermissionChange()
 void KDirListerTest::enterLoop(int exitCount)
 {
     //qDebug("enterLoop");
+    connect(&m_eventTimer, SIGNAL(timeout()), &m_eventLoop, SLOT(quit()));
+    m_eventTimer.start(10000);
     m_exitCount = exitCount;
     m_eventLoop.exec(QEventLoop::ExcludeUserInputEvents);
 }
@@ -1198,6 +1126,8 @@ void KDirListerTest::enterLoop(int exitCount)
 void KDirListerTest::exitLoop()
 {
     //qDebug("exitLoop");
+    disconnect(&m_eventTimer, SIGNAL(timeout()), &m_eventLoop, SLOT(quit()));
+    m_eventTimer.stop();
     --m_exitCount;
     if (m_exitCount <= 0) {
         m_eventLoop.quit();
