@@ -22,7 +22,7 @@
 #include <kio/copyjob.h>
 #include <kio/chmodjob.h>
 #include <kprotocolinfo.h>
-#include "kdirmodeltest.moc"
+#include "moc_kdirmodeltest.cpp"
 #include <kdirmodel.h>
 #include <kdirlister.h>
 //TODO #include "../../kdeui/tests/proxymodeltestsuite/modelspy.h"
@@ -47,11 +47,7 @@ QTEST_KDEMAIN( KDirModelTest, NoGUI )
 
 #define connect(a,b,c,d) QVERIFY(QObject::connect(a,b,c,d))
 
-#ifndef Q_WS_WIN
 #define SPECIALCHARS "specialchars%:.pdf"
-#else
-#define SPECIALCHARS "specialchars%.pdf"
-#endif
 
 Q_DECLARE_METATYPE(KFileItemList)
 
@@ -80,7 +76,7 @@ void KDirModelTest::recreateTestData()
     if (m_tempDir) {
         kDebug() << "Deleting old tempdir" << m_tempDir->name();
         delete m_tempDir;
-        qApp->processEvents(); // process inotify events so they don't pollute us later on
+        qApp->processEvents(); // process events so they don't pollute us later on
     }
 
 
@@ -406,12 +402,7 @@ void KDirModelTest::testModifyFile()
     // "Touch" the file
     setTimeStamp(file, s_referenceTimeStamp.addSecs(20) );
 
-    // In stat mode, kdirwatch doesn't notice file changes; we need to trigger it
-    // by creating a file.
-    //createTestFile(m_tempDir->name() + "toplevelfile_5");
-    KDirWatch::self()->setDirty(m_tempDir->name());
-
-    // Wait for KDirWatch to notify the change (especially when using Stat)
+    // Wait for KDirWatch to notify the change
     enterLoop();
 
     // If we come here, then dataChanged() was emitted - all good.
@@ -700,13 +691,11 @@ void KDirModelTest::testExpandToUrl_data()
     QTest::newRow("subdir/subsubdir/testfile sync")
         << int(NoFlag) << subsubdirfile << (QStringList()<<"subdir"<<subsubdir<<subsubdirfile);
 
-#ifndef Q_WS_WIN
     // Expand a symlink to a directory (#219547)
     const QString dirlink = m_tempDir->name() + "dirlink";
     createTestSymlink(dirlink, "/");
     QTest::newRow("dirlink")
         << int(NoFlag) << "dirlink/tmp" << (QStringList()<<"dirlink"<<"dirlink/tmp");
-#endif
 
     // Do a cold-cache test too, but nowadays it doesn't change anything anymore,
     // apart from testing different code paths inside KDirLister.
@@ -1036,36 +1025,6 @@ void KDirModelTest::testZipFile() // # 171721
     QVERIFY(index.isValid());
 }
 
-void KDirModelTest::testSmb()
-{
-    const KUrl smbUrl("smb:/");
-    // TODO: feed a KDirModel without using a KDirLister.
-    // Calling the slots directly.
-    // This requires that KDirModel does not ask the KDirLister for its rootItem anymore,
-    // but that KDirLister emits the root item whenever it changes.
-    if (!KProtocolInfo::isKnownProtocol("smb")) {
-        QSKIP("kio_smb not installed", SkipAll);
-    }
-    KDirLister* dirLister = m_dirModel->dirLister();
-    dirLister->openUrl(smbUrl, KDirLister::NoFlags);
-    connect(dirLister, SIGNAL(completed()), this, SLOT(slotListingCompleted()));
-    connect(dirLister, SIGNAL(canceled()), this, SLOT(slotListingCompleted()));
-    QSignalSpy spyCanceled(dirLister, SIGNAL(canceled()));
-    enterLoop(); // wait for completed signal
-
-    if (spyCanceled.count() > 0) {
-        QSKIP("smb:/ returns an error, probably no network available", SkipAll);
-    }
-
-    QModelIndex index = m_dirModel->index(0, 0);
-    if (index.isValid()) {
-        QVERIFY(m_dirModel->canFetchMore(index));
-        m_dirModel->fetchMore(index);
-        enterLoop(); // wait for completed signal
-        disconnect(dirLister, SIGNAL(completed()), this, SLOT(slotListingCompleted()));
-    }
-}
-
 class MyDirLister : public KDirLister
 {
 public:
@@ -1300,7 +1259,7 @@ void KDirModelTest::testDeleteDirectory()
     connect( m_dirModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
              &m_eventLoop, SLOT(exitLoop()) );
 
-    QSignalSpy spyDirWatchDeleted(KDirWatch::self(), SIGNAL(deleted(QString)));
+    QSignalSpy spyDirWatchDeleted(KDirWatch::self(), SIGNAL(dirty(QString)));
 
     KIO::DeleteJob* job = KIO::del(url, KIO::HideProgressInfo);
     QVERIFY(job->exec());
@@ -1318,8 +1277,7 @@ void KDirModelTest::testDeleteDirectory()
     QModelIndex dirIndex = m_dirModel->indexForUrl(KUrl(path + "subdir"));
     QVERIFY(dirIndex.isValid());
 
-    // TODO!!! Bug in KDirWatch? ###
-    // QCOMPARE(spyDirWatchDeleted.count(), 1);
+    QCOMPARE(spyDirWatchDeleted.count(), 3);
 }
 
 void KDirModelTest::testDeleteCurrentDirectory()
@@ -1332,9 +1290,6 @@ void KDirModelTest::testDeleteCurrentDirectory()
     connect( m_dirModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
              &m_eventLoop, SLOT(exitLoop()) );
 
-
-    KDirWatch::self()->statistics();
-
     KIO::DeleteJob* job = KIO::del(url, KIO::HideProgressInfo);
     QVERIFY(job->exec());
 
@@ -1368,13 +1323,6 @@ void KDirModelTest::testDeleteCurrentDirectory()
     QVERIFY(!fileIndex.isValid());
 }
 
-#if QT_VERSION < 0x040700
-// The old slow way. (this isn't QUrl's fault, I'm just using QUrl in order
-// to be able to test a different hashing function than the KUrl one).
-inline uint qHash(const QUrl& qurl) {
-    return qHash(qurl.toEncoded());
-}
-#endif
 
 void KDirModelTest::testKUrlHash()
 {
