@@ -1,6 +1,6 @@
 #include "kfdtest.h"
 
-#include <QtCore/QMutableStringListIterator>
+#include <QtCore/qstringlist.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <QtCore/QTimer>
@@ -30,4 +30,4 @@ void KFDTest::doit()
 //     qApp->quit();
 }
 
-#include "kfdtest.moc"
+#include "moc_kfdtest.cpp"
