@@ -31,6 +31,8 @@
 
 #include "kioslavetest.h"
 
+#include <sys/stat.h>
+
 using namespace KIO;
 
 KioslaveTest::KioslaveTest( QString src, QString dest, uint op, uint pr )
@@ -169,13 +171,6 @@ KioslaveTest::KioslaveTest( QString src, QString dest, uint op, uint pr )
 
   main_widget->setMinimumSize( main_widget->sizeHint() );
   setCentralWidget( main_widget );
-
-  slave = 0;
-//  slave = KIO::Scheduler::getConnectedSlave(KUrl("ftp://ftp.kde.org"));
-  KIO::Scheduler::connect(SIGNAL(slaveConnected(KIO::Slave*)),
-	this, SLOT(slotSlaveConnected()));
-  KIO::Scheduler::connect(SIGNAL(slaveError(KIO::Slave*,int,QString)),
-	this, SLOT(slotSlaveError()));
 }
 
 void KioslaveTest::slotQuit(){
@@ -289,9 +284,8 @@ void KioslaveTest::startJob() {
   }
   if (myJob)
   {
-    if (slave)
-      KIO::Scheduler::assignJobToSlave(slave, myJob);
     job = myJob;
+    KIO::Scheduler::doJob(myJob);
   }
 
   statusBar()->addWidget( statusTracker->widget(job), 0 );
@@ -335,17 +329,6 @@ void KioslaveTest::slotResult( KJob * _job )
   //statusBar()->removeWidget( statusTracker->widget(job) );
 }
 
-void KioslaveTest::slotSlaveConnected()
-{
-   kDebug() << "Slave connected.";
-}
-
-void KioslaveTest::slotSlaveError()
-{
-   kDebug() << "Error connected.";
-   slave = 0;
-}
-
 void KioslaveTest::printUDSEntry( const KIO::UDSEntry & entry )
 {
     // It's rather rare to iterate that way, usually you'd use numberValue/stringValue directly.
@@ -397,28 +380,11 @@ void KioslaveTest::printUDSEntry( const KIO::UDSEntry & entry )
 void KioslaveTest::slotEntries(KIO::Job* job, const KIO::UDSEntryList& list) {
 
     KUrl url = static_cast<KIO::ListJob*>( job )->url();
-    KProtocolInfo::ExtraFieldList extraFields = KProtocolInfo::extraFields(url);
     UDSEntryList::ConstIterator it=list.begin();
     for (; it != list.end(); ++it) {
         // For each file...
         QString name = (*it).stringValue( KIO::UDSEntry::UDS_NAME );
         kDebug() << name;
-
-        KProtocolInfo::ExtraFieldList::Iterator extraFieldsIt = extraFields.begin();
-        const QList<uint> fields = it->listFields();
-        QList<uint>::ConstIterator it2 = fields.begin();
-        for( ; it2 != fields.end(); it2++ ) {
-            if ( *it2 >= UDSEntry::UDS_EXTRA && *it2 <= UDSEntry::UDS_EXTRA_END) {
-                if ( extraFieldsIt != extraFields.end() ) {
-                    QString column = (*extraFieldsIt).name;
-                    //QString type = (*extraFieldsIt).type;
-                    kDebug() << "  Extra data (" << column << ") :" << it->stringValue(*it2);
-                    ++extraFieldsIt;
-                } else {
-                    kDebug() << "  Extra data (UNDEFINED) :" << it->stringValue(*it2);
-                }
-            }
-        }
     }
 }
 
@@ -426,11 +392,11 @@ void KioslaveTest::slotData(KIO::Job*, const QByteArray &data)
 {
     if (data.size() == 0)
     {
-       kDebug(0) << "Data: <End>";
+       kDebug() << "Data: <End>";
     }
     else
     {
-       kDebug(0) << "Data: \"" << QString( data ) << "\"";
+       kDebug() << "Data: \"" << QString( data ) << "\"";
     }
 }
 
@@ -453,14 +419,14 @@ void KioslaveTest::slotDataReq(KIO::Job*, QByteArray &data)
 
     if (!fileData)
     {
-       kDebug(0) << "DataReq: <End>";
+       kDebug() << "DataReq: <End>";
        return;
     }
     if (!strncmp(fileData, "BIG", 3))
 	data.fill(0, 8*1024*1024);
     else
 	data = QByteArray(fileData, strlen(fileData));
-    kDebug(0) << "DataReq: \"" << fileData << "\"";
+    kDebug() << "DataReq: \"" << fileData << "\"";
     sleep(1); // want to see progress info...
 }
 
@@ -544,4 +510,4 @@ int main(int argc, char **argv) {
 }
 
 
-#include "kioslavetest.moc"
+#include "moc_kioslavetest.cpp"
