@@ -18,11 +18,8 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#undef QT_USE_FAST_OPERATOR_PLUS
-#undef QT_USE_FAST_CONCATENATION
-
 #include "krununittest.h"
-#include "krununittest.moc"
+#include "moc_krununittest.cpp"
 #include <qtest_kde.h>
 QTEST_KDEMAIN( KRunUnitTest, NoGUI )
 
@@ -111,8 +108,8 @@ void KRunUnitTest::testProcessDesktopExec()
             "/bin/sh -c 'echo $PWD '", // 1
             "x-term -T ' - just_a_test' -e /bin/date -u", // 2
             "x-term -T ' - just_a_test' -e /bin/sh -c 'echo $PWD '", // 3
-            /* kdesu */ " -u sprallo -c '/bin/date -u'", // 4
-            /* kdesu */ " -u sprallo -c '/bin/sh -c '\\''echo $PWD '\\'''", // 5
+            /* kdesudo */ " -u sprallo -c '/bin/date -u'", // 4
+            /* kdesudo */ " -u sprallo -c '/bin/sh -c '\\''echo $PWD '\\'''", // 5
             "x-term -T ' - just_a_test' -e su sprallo -c '/bin/date -u'", // 6
             "x-term -T ' - just_a_test' -e su sprallo -c '/bin/sh -c '\\''echo $PWD '\\'''", // 7
         };
@@ -130,8 +127,13 @@ void KRunUnitTest::testProcessDesktopExec()
             for (int ex = 0; ex < 2; ex++) {
                 int pt = ex+te*2+su*4;
                 QString exe;
-                if (pt == 4 || pt == 5)
-                    exe = KStandardDirs::findExe("kdesu");
+                if (pt == 4 || pt == 5) {
+                    exe = KStandardDirs::findExe("kdesudo");
+                    if (exe.isEmpty()) {
+                        qWarning() << "kdesudo not found, skipping test";
+                        continue;
+                    }
+                }
                 const QString result = QString::fromLatin1(rslts[pt])
                     .replace("/bin/sh", shellPath)
                     .replace("/bin/date", datePath);
@@ -167,28 +169,29 @@ void KRunUnitTest::testProcessDesktopExecNoFile_data()
         QVERIFY(!kmailservice.isEmpty());
     }
 
+    // NOTE: using QString() for concats to avoid QStringBuilder metatype, which is not valid
     QTest::newRow("%U l0") << "kdeinit4 %U" << l0 << false << kdeinit;
-    QTest::newRow("%U l1") << "kdeinit4 %U" << l1 << false << kdeinit + " /tmp";
-    QTest::newRow("%U l2") << "kdeinit4 %U" << l2 << false << kdeinit + " http://localhost/foo";
-    QTest::newRow("%U l3") << "kdeinit4 %U" << l3 << false << kdeinit + " /local/file http://remotehost.org/bar";
+    QTest::newRow("%U l1") << "kdeinit4 %U" << l1 << false << QString(kdeinit + " /tmp");
+    QTest::newRow("%U l2") << "kdeinit4 %U" << l2 << false << QString(kdeinit + " http://localhost/foo");
+    QTest::newRow("%U l3") << "kdeinit4 %U" << l3 << false << QString(kdeinit + " /local/file http://remotehost.org/bar");
 
     //QTest::newRow("%u l0") << "kdeinit4 %u" << l0 << false << kdeinit; // gives runtime warning
-    QTest::newRow("%u l1") << "kdeinit4 %u" << l1 << false << kdeinit + " /tmp";
-    QTest::newRow("%u l2") << "kdeinit4 %u" << l2 << false << kdeinit + " http://localhost/foo";
+    QTest::newRow("%u l1") << "kdeinit4 %u" << l1 << false << QString(kdeinit + " /tmp");
+    QTest::newRow("%u l2") << "kdeinit4 %u" << l2 << false << QString(kdeinit + " http://localhost/foo");
     //QTest::newRow("%u l3") << "kdeinit4 %u" << l3 << false << kdeinit; // gives runtime warning
 
     QTest::newRow("%F l0") << "kdeinit4 %F" << l0 << false << kdeinit;
-    QTest::newRow("%F l1") << "kdeinit4 %F" << l1 << false << kdeinit + " /tmp";
-    QTest::newRow("%F l2") << "kdeinit4 %F" << l2 << false << kioexec + " 'kdeinit4 %F' http://localhost/foo";
-    QTest::newRow("%F l3") << "kdeinit4 %F" << l3 << false << kioexec + " 'kdeinit4 %F' file:///local/file http://remotehost.org/bar";
+    QTest::newRow("%F l1") << "kdeinit4 %F" << l1 << false << QString(kdeinit + " /tmp");
+    QTest::newRow("%F l2") << "kdeinit4 %F" << l2 << false << QString(kioexec + " 'kdeinit4 %F' http://localhost/foo");
+    QTest::newRow("%F l3") << "kdeinit4 %F" << l3 << false << QString(kioexec + " 'kdeinit4 %F' file:///local/file http://remotehost.org/bar");
 
-    QTest::newRow("%F l1 tempfile") << "kdeinit4 %F" << l1 << true << kioexec + " --tempfiles 'kdeinit4 %F' file:///tmp";
+    QTest::newRow("%F l1 tempfile") << "kdeinit4 %F" << l1 << true << QString(kioexec + " --tempfiles 'kdeinit4 %F' file:///tmp");
 
     QTest::newRow("sh -c kdeinit4 %F") << "sh -c \"kdeinit4 \"'\\\"'\"%F\"'\\\"'"
-                                   << l1 << false << m_sh + " -c 'kdeinit4 \\\"/tmp\\\"'";
+                                   << l1 << false << QString(m_sh + " -c 'kdeinit4 \\\"/tmp\\\"'");
 
-    QTest::newRow("kmailservice %u l1") << "kmailservice %u" << l1 << false << kmailservice + " /tmp";
-    QTest::newRow("kmailservice %u l4") << "kmailservice %u" << l4 << false << kmailservice + " http://login:password@www.kde.org";
+    QTest::newRow("kmailservice %u l1") << "kmailservice %u" << l1 << false << QString(kmailservice + " /tmp");
+    QTest::newRow("kmailservice %u l4") << "kmailservice %u" << l4 << false << QString(kmailservice + " http://login:password@www.kde.org");
 }
 
 void KRunUnitTest::testProcessDesktopExecNoFile()
@@ -207,12 +210,17 @@ public:
     KRunImpl(const KUrl& url, bool isLocalFile = false)
         : KRun(url, 0, 0, isLocalFile, false) {}
 
-    virtual void foundMimeType(const QString& type) {
+    void foundMimeType(const QString& type) final {
         m_mimeType = type;
         // don't call KRun::foundMimeType, we don't want to start an app ;-)
         setFinished(true);
     }
 
+    void error(const QString& message) final {
+        // don't show message box, this is unit test
+        Q_UNUSED(message);
+    }
+
     QString mimeTypeFound() const { return m_mimeType; }
 
 private:
