@@ -35,36 +35,26 @@
 #include <sys/wait.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
-#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#endif
-
 #include <assert.h>
 #include <dirent.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <grp.h>
-#include <pwd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
 #include <time.h>
 #include <utime.h>
 #include <unistd.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#endif
 
-#include <QtCore/QByteRef>
-#include <QtCore/QDate>
+#include <QtCore/qbytearray.h>
+#include <QtCore/qdatetime.h>
 #include <QtCore/QVarLengthArray>
 #include <QtCore/QCoreApplication>
 #include <QtCore/QRegExp>
 #include <QtCore/QFile>
-#ifdef Q_WS_WIN
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#endif
+#include <QtCore/QProcess>
 
 #include <kdebug.h>
 #include <kurl.h>
@@ -77,29 +67,23 @@
 #include <kshell.h>
 #include <kmountpoint.h>
 #include <kstandarddirs.h>
-
-#ifdef HAVE_VOLMGT
-#include <volmgt.h>
-#include <sys/mnttab.h>
-#endif
-
 #include <kdirnotify.h>
 #include <kio/ioslave_defaults.h>
 #include <kde_file.h>
 #include <kglobal.h>
 #include <kmimetype.h>
+#include <kuser.h>
 
 using namespace KIO;
 
 #define MAX_IPC_SIZE (1024*32)
 
-static QString readLogFile( const QByteArray&_filename );
 #ifdef HAVE_POSIX_ACL
 static void appendACLAtoms( const QByteArray & path, UDSEntry& entry,
                             mode_t type, bool withACL );
 #endif
 
-extern "C" int KDE_EXPORT kdemain( int argc, char **argv )
+extern "C" int Q_DECL_EXPORT kdemain( int argc, char **argv )
 {
   QCoreApplication app( argc, argv ); // needed for QSocketNotifier
   KComponentData componentData( "kio_file", "kdelibs4" );
@@ -278,10 +262,10 @@ void FileProtocol::get( const KUrl& url )
 {
     if (!url.isLocalFile()) {
         KUrl redir(url);
-	redir.setProtocol(config()->readEntry("DefaultRemoteProtocol", "smb"));
-	redirection(redir);
-	finished();
-	return;
+        redir.setProtocol(config()->readEntry("DefaultRemoteProtocol", "sftp"));
+        redirection(redir);
+        finished();
+        return;
     }
 
     const QString path(url.toLocalFile());
@@ -342,8 +326,6 @@ void FileProtocol::get( const KUrl& url )
     }
 
     char buffer[ MAX_IPC_SIZE ];
-    QByteArray array;
-
     while( 1 )
     {
        int n = ::read( fd, buffer, MAX_IPC_SIZE );
@@ -358,9 +340,7 @@ void FileProtocol::get( const KUrl& url )
        if (n == 0)
           break; // Finished
 
-       array = QByteArray::fromRawData(buffer, n);
-       data( array );
-       array.clear();
+       data( QByteArray::fromRawData(buffer, n) );
 
        processed_size += n;
        processedSize( processed_size );
@@ -471,8 +451,7 @@ void FileProtocol::read(KIO::filesize_t bytes)
         } while (res == -1 && errno == EINTR);
 
         if (res > 0) {
-            QByteArray array = QByteArray::fromRawData(buffer.data(), res);
-            data( array );
+            data( QByteArray::fromRawData(buffer.data(), res) );
             bytes -= res;
         } else {
             // empty array designates eof
@@ -709,7 +688,7 @@ void FileProtocol::put( const KUrl& url, int _mode, KIO::JobFlags _flags )
             error(KIO::ERR_CANNOT_RENAME_PARTIAL, dest_orig);
             return;
         }
-        org::kde::KDirNotify::emitFileRenamed(KUrl(dest).url(), KUrl(dest_orig).url());
+        org::kde::KDirNotify::emitFileRenamed(dest, dest_orig);
     }
 
     // set final permissions
@@ -751,12 +730,11 @@ void FileProtocol::put( const KUrl& url, int _mode, KIO::JobFlags _flags )
 QString FileProtocol::getUserName( uid_t uid ) const
 {
     if ( !mUsercache.contains( uid ) ) {
-        struct passwd *user = getpwuid( uid );
-        if ( user ) {
-            mUsercache.insert( uid, QString::fromLatin1(user->pw_name) );
-        }
-        else
+        const KUser kuser( uid );
+        if ( !kuser.isValid() ) {
             return QString::number( uid );
+        }
+        mUsercache.insert( uid, kuser.loginName() );
     }
     return mUsercache[uid];
 }
@@ -764,12 +742,11 @@ QString FileProtocol::getUserName( uid_t uid ) const
 QString FileProtocol::getGroupName( gid_t gid ) const
 {
     if ( !mGroupcache.contains( gid ) ) {
-        struct group *grp = getgrgid( gid );
-        if ( grp ) {
-            mGroupcache.insert( gid, QString::fromLatin1(grp->gr_name) );
-        }
-        else
+        const KUserGroup kusergroup( gid );
+        if ( !kusergroup.isValid() ) {
             return QString::number( gid );
+        }
+        mGroupcache.insert( gid, kusergroup.name() );
     }
     return mGroupcache[gid];
 }
@@ -799,11 +776,8 @@ bool FileProtocol::createUDSEntry( const QString & filename, const QByteArray &
         if (S_ISLNK(buff.st_mode)) {
 
             char buffer2[ 1000 ];
-            int n = readlink( path.data(), buffer2, 999 );
-            if ( n != -1 ) {
-                buffer2[ n ] = 0;
-            }
-
+            ::memset(buffer2, 0, 1000 * sizeof(char));
+            readlink( path.data(), buffer2, 999 );
             entry.insert( KIO::UDSEntry::UDS_LINK_DEST, QFile::decodeName( buffer2 ) );
 
             // A symlink -> follow it only if details>1
@@ -863,383 +837,127 @@ void FileProtocol::special( const QByteArray &data)
 
     stream >> tmp;
     switch (tmp) {
-    case 1:
-      {
-	QString fstype, dev, point;
-	qint8 iRo;
+        case 1: {
+            QString fstype, dev, point;
+            qint8 iRo;
 
-	stream >> iRo >> fstype >> dev >> point;
+            stream >> iRo >> fstype >> dev >> point;
 
-	bool ro = ( iRo != 0 );
+            bool ro = ( iRo != 0 );
 
-	kDebug(7101) << "MOUNTING fstype=" << fstype << " dev=" << dev << " point=" << point << " ro=" << ro;
-	bool ok = pmount( dev );
-	if (ok)
-	    finished();
-	else
-	    mount( ro, fstype.toLatin1(), dev, point );
+            kDebug(7101) << "MOUNTING fstype=" << fstype << " dev=" << dev << " point=" << point << " ro=" << ro;
+            mount( ro, fstype.toLatin1(), dev, point );
+            break;
+        }
+        case 2: {
+            QString point;
+            stream >> point;
 
-      }
-      break;
-    case 2:
-      {
-	QString point;
-	stream >> point;
-	bool ok = pumount( point );
-	if (ok)
-	    finished();
-	else
-	    unmount( point );
-      }
-      break;
+            kDebug(7101) << "UNMOUNTING point=" << point;
+            unmount( point );
+            break;
+        }
 
-    default:
-      break;
+        default:
+            break;
     }
 }
 
+
+/*************************************
+ *
+ * mount/unmount handling
+ *
+ *************************************/
+
 void FileProtocol::mount( bool _ro, const char *_fstype, const QString& _dev, const QString& _point )
 {
-    kDebug(7101) << "fstype=" << _fstype;
+    const QString kdesudoProg = KStandardDirs::findExe(QLatin1String("kdesudo"));
+    if (kdesudoProg.isEmpty()) {
+        error( KIO::ERR_COULD_NOT_MOUNT, i18n("Could not find program \"kdesudo\""));
+        return;
+    }
 
-#ifndef _WIN32_WCE
-#ifdef HAVE_VOLMGT
-	/*
-	 *  support for Solaris volume management
-	 */
-	QString err;
-	QByteArray devname = QFile::encodeName( _dev );
+    const QString mountProg = KStandardDirs::findRootExe(QLatin1String("mount"));
+    if (mountProg.isEmpty()) {
+        error( KIO::ERR_COULD_NOT_MOUNT, i18n("Could not find program \"mount\""));
+        return;
+    }
 
-	if( volmgt_running() ) {
-//		kDebug(7101) << "VOLMGT: vold ok.";
-		if( volmgt_check( devname.data() ) == 0 ) {
-			kDebug(7101) << "VOLMGT: no media in "
-					<< devname.data();
-			err = i18n("No Media inserted or Media not recognized.");
-			error( KIO::ERR_COULD_NOT_MOUNT, err );
-			return;
-		} else {
-			kDebug(7101) << "VOLMGT: " << devname.data()
-				<< ": media ok";
-			finished();
-			return;
-		}
-	} else {
-		err = i18n("\"vold\" is not running.");
-		kDebug(7101) << "VOLMGT: " << err;
-		error( KIO::ERR_COULD_NOT_MOUNT, err );
-		return;
-	}
+    QProcess mountProc;
+    QStringList mountArgs = QStringList() << mountProg;
+    if (_ro) {
+#if defined(Q_OS_SOLARIS)
+        mountArgs << QLatin1String("-oro");
 #else
-
-
-    KTemporaryFile tmpFile;
-    tmpFile.setAutoRemove(false);
-    tmpFile.open();
-    QByteArray tmpFileName = QFile::encodeName(tmpFile.fileName());
-    QByteArray dev;
+        mountArgs << QLatin1String("-r");
+#endif
+    }
+    if (_fstype && *_fstype) {
+#if defined(Q_OS_SOLARIS)
+        mountArgs << QLatin1String("-F");
+#else
+        mountArgs << QLatin1String("-t");
+#endif
+        mountArgs << KShell::quoteArg(QString::fromLatin1(_fstype));
+    }
     if (_dev.startsWith(QLatin1String("LABEL="))) { // turn LABEL=foo into -L foo (#71430)
         QString labelName = _dev.mid( 6 );
-        dev = "-L ";
-        dev += QFile::encodeName( KShell::quoteArg( labelName ) ); // is it correct to assume same encoding as filesystem?
+        mountArgs << QLatin1String("-L");
+        mountArgs << KShell::quoteArg( labelName );
     } else if (_dev.startsWith(QLatin1String("UUID="))) { // and UUID=bar into -U bar
         QString uuidName = _dev.mid( 5 );
-        dev = "-U ";
-        dev += QFile::encodeName( KShell::quoteArg( uuidName ) );
+        mountArgs << QLatin1String("-U");
+        mountArgs << KShell::quoteArg( uuidName );
+    } else {
+        mountArgs << KShell::quoteArg(_dev);
     }
-    else
-        dev = QFile::encodeName( KShell::quoteArg(_dev) ); // get those ready to be given to a shell
-
-    QByteArray point = QFile::encodeName( KShell::quoteArg(_point) );
-    bool fstype_empty = !_fstype || !*_fstype;
-    QByteArray fstype = KShell::quoteArg(QString::fromLatin1(_fstype)).toLatin1(); // good guess
-    QByteArray readonly = _ro ? "-r" : "";
-    QString epath = QString::fromLocal8Bit(qgetenv("PATH"));
-    QString path = QLatin1String("/sbin:/bin");
-    if(!epath.isEmpty())
-        path += QLatin1String(":") + epath;
-    QByteArray mountProg = KGlobal::dirs()->findExe(QLatin1String("mount"), path).toLocal8Bit();
-    if (mountProg.isEmpty()){
-      error( KIO::ERR_COULD_NOT_MOUNT, i18n("Could not find program \"mount\""));
-      return;
+    if (!_point.isEmpty()) {
+        mountArgs << KShell::quoteArg(_point);
     }
+    mountProc.start(kdesudoProg, mountArgs);
+    mountProc.waitForFinished();
 
-    // Two steps, in case mount doesn't like it when we pass all options
-    for ( int step = 0 ; step <= 1 ; step++ )
-    {
-        QByteArray buffer = mountProg + ' ';
-        // Mount using device only if no fstype nor mountpoint (KDE-1.x like)
-        if ( !dev.isEmpty() && _point.isEmpty() && fstype_empty )
-            buffer += dev;
-        else
-          // Mount using the mountpoint, if no fstype nor device (impossible in first step)
-          if ( !_point.isEmpty() && dev.isEmpty() && fstype_empty )
-              buffer += point;
-          else
-            // mount giving device + mountpoint but no fstype
-            if ( !_point.isEmpty() && !dev.isEmpty() && fstype_empty )
-                buffer += readonly + ' ' + dev + ' ' + point;
-            else
-              // mount giving device + mountpoint + fstype
-#if defined(__svr4__) && defined(Q_OS_SOLARIS) // MARCO for Solaris 8 and I
-                // believe this is true for SVR4 in general
-                buffer += "-F " + fstype + ' ' + (_ro ? "-oro" : "") + ' ' + dev + ' ' + point;
-#else
-                buffer += readonly + " -t " + fstype + ' ' + dev + ' ' + point;
-#endif
-        buffer += " 2>" + tmpFileName;
-        kDebug(7101) << buffer;
-
-        int mount_ret = system( buffer.constData() );
-
-        QString err = readLogFile( tmpFileName );
-        if ( err.isEmpty() && mount_ret == 0)
-        {
-            finished();
-            return;
-        }
-        else
-        {
-            // Didn't work - or maybe we just got a warning
-            KMountPoint::Ptr mp = KMountPoint::currentMountPoints().findByDevice( _dev );
-            // Is the device mounted ?
-            if ( mp && mount_ret == 0)
-            {
-                kDebug(7101) << "mount got a warning:" << err;
-                warning( err );
-                finished();
-                return;
-            }
-            else
-            {
-                if ( (step == 0) && !_point.isEmpty())
-                {
-                    kDebug(7101) << err;
-                    kDebug(7101) << "Mounting with those options didn't work, trying with only mountpoint";
-                    fstype = "";
-                    fstype_empty = true;
-                    dev = "";
-                    // The reason for trying with only mountpoint (instead of
-                    // only device) is that some people (hi Malte!) have the
-                    // same device associated with two mountpoints
-                    // for different fstypes, like /dev/fd0 /mnt/e2floppy and
-                    // /dev/fd0 /mnt/dosfloppy.
-                    // If the user has the same mountpoint associated with two
-                    // different devices, well they shouldn't specify the
-                    // mountpoint but just the device.
-                }
-                else
-                {
-                    error( KIO::ERR_COULD_NOT_MOUNT, err );
-                    return;
-                }
-            }
+    if ( mountProc.exitCode() == 0 ) {
+        finished();
+    } else {
+        QByteArray erroroutput = mountProc.readAllStandardError();
+        if (erroroutput.isEmpty()) {
+            erroroutput = mountProc.readAllStandardOutput();
         }
+        error( KIO::ERR_COULD_NOT_MOUNT, QString::fromLocal8Bit(erroroutput) );
     }
-#endif /* ! HAVE_VOLMGT */
-#else
-    QString err;
-    err = i18n("mounting is not supported by wince.");
-    error( KIO::ERR_COULD_NOT_MOUNT, err );
-#endif
-
 }
 
 
-void FileProtocol::unmount( const QString& _point )
+void FileProtocol::unmount( const QString& point )
 {
-#ifndef _WIN32_WCE
-    QByteArray buffer;
-
-    KTemporaryFile tmpFile;
-    tmpFile.setAutoRemove(false);
-    tmpFile.open();
-    QByteArray tmpFileName = QFile::encodeName(tmpFile.fileName());
-    QString err;
-
-#ifdef HAVE_VOLMGT
-	/*
-	 *  support for Solaris volume management
-	 */
-	char *devname;
-	char *ptr;
-	FILE *mnttab;
-	struct mnttab mnt;
-
-	if( volmgt_running() ) {
-		kDebug(7101) << "VOLMGT: looking for "
-			<< _point.toLocal8Bit();
-
-		if( (mnttab = KDE_fopen( MNTTAB, "r" )) == NULL ) {
-			err = QLatin1String("could not open mnttab");
-			kDebug(7101) << "VOLMGT: " << err;
-			error( KIO::ERR_COULD_NOT_UNMOUNT, err );
-			return;
-		}
-
-		/*
-		 *  since there's no way to derive the device name from
-		 *  the mount point through the volmgt library (and
-		 *  media_findname() won't work in this case), we have to
-		 *  look ourselves...
-		 */
-		devname = NULL;
-		rewind( mnttab );
-		while( getmntent( mnttab, &mnt ) == 0 ) {
-			if( strcmp( _point.toLocal8Bit(), mnt.mnt_mountp ) == 0 ){
-				devname = mnt.mnt_special;
-				break;
-			}
-		}
-		fclose( mnttab );
-
-		if( devname == NULL ) {
-			err = QLatin1String("not in mnttab");
-			kDebug(7101) << "VOLMGT: "
-				<< QFile::encodeName(_point).data()
-				<< ": " << err;
-			error( KIO::ERR_COULD_NOT_UNMOUNT, err );
-			return;
-		}
-
-		/*
-		 *  strip off the directory name (volume name)
-		 *  the eject(1) command will handle unmounting and
-		 *  physically eject the media (if possible)
-		 */
-		ptr = strrchr( devname, '/' );
-		*ptr = '\0';
-                QByteArray qdevname(QFile::encodeName(KShell::quoteArg(QFile::decodeName(QByteArray(devname)))).data());
-		buffer = "/usr/bin/eject " + qdevname + " 2>" + tmpFileName;
-		kDebug(7101) << "VOLMGT: eject " << qdevname;
-
-		/*
-		 *  from eject(1): exit status == 0 => need to manually eject
-		 *                 exit status == 4 => media was ejected
-		 */
-		if( WEXITSTATUS( system( buffer.constData() )) == 4 ) {
-			/*
-			 *  this is not an error, so skip "readLogFile()"
-			 *  to avoid wrong/confusing error popup. The
-			 *  temporary file is removed by KTemporaryFile's
-			 *  destructor, so don't do that manually.
-			 */
-			finished();
-			return;
-		}
-	} else {
-		/*
-		 *  eject(1) should do its job without vold(1M) running,
-		 *  so we probably could call eject anyway, but since the
-		 *  media is mounted now, vold must've died for some reason
-		 *  during the user's session, so it should be restarted...
-		 */
-		err = i18n("\"vold\" is not running.");
-		kDebug(7101) << "VOLMGT: " << err;
-		error( KIO::ERR_COULD_NOT_UNMOUNT, err );
-		return;
-	}
-#else
-    QString epath = QString::fromLocal8Bit(qgetenv("PATH"));
-    QString path = QLatin1String("/sbin:/bin");
-    if (!epath.isEmpty())
-       path += QLatin1Char(':') + epath;
-    QByteArray umountProg = KGlobal::dirs()->findExe(QLatin1String("umount"), path).toLocal8Bit();
+    const QString kdesudoProg = KStandardDirs::findExe(QLatin1String("kdesudo"));
+    if (kdesudoProg.isEmpty()) {
+        error( KIO::ERR_COULD_NOT_UNMOUNT, i18n("Could not find program \"kdesudo\""));
+        return;
+    }
 
+    const QString umountProg = KStandardDirs::findRootExe(QLatin1String("umount"));
     if (umountProg.isEmpty()) {
         error( KIO::ERR_COULD_NOT_UNMOUNT, i18n("Could not find program \"umount\""));
         return;
     }
-    buffer = umountProg + ' ' + QFile::encodeName(KShell::quoteArg(_point)) + " 2>" + tmpFileName;
-    system( buffer.constData() );
-#endif /* HAVE_VOLMGT */
 
-    err = readLogFile( tmpFileName );
-    if ( err.isEmpty() )
+    QProcess umountProc;
+    const QStringList umountArgs = QStringList() << umountProg << KShell::quoteArg(point);
+    umountProc.start(kdesudoProg, umountArgs);
+    umountProc.waitForFinished();
+
+    if ( umountProc.exitCode() == 0 ) {
         finished();
-    else
-        error( KIO::ERR_COULD_NOT_UNMOUNT, err );
-#else
-    QString err;
-    err = i18n("unmounting is not supported by wince.");
-    error( KIO::ERR_COULD_NOT_MOUNT, err );
-#endif
-}
-
-/*************************************
- *
- * pmount handling
- *
- *************************************/
-
-bool FileProtocol::pmount(const QString &dev)
-{
-#ifndef _WIN32_WCE
-    QString epath = QString::fromLocal8Bit(qgetenv("PATH"));
-    QString path = QLatin1String("/sbin:/bin");
-    if (!epath.isEmpty())
-        path += QLatin1Char(':') + epath;
-    QString pmountProg = KGlobal::dirs()->findExe(QLatin1String("pmount"), path);
-
-    if (pmountProg.isEmpty())
-        return false;
-
-    QByteArray buffer = QFile::encodeName(pmountProg) + ' ' +
-                        QFile::encodeName(KShell::quoteArg(dev));
-
-    int res = system( buffer.constData() );
-
-    return res==0;
-#else
-    return false;
-#endif
-}
-
-bool FileProtocol::pumount(const QString &point)
-{
-#ifndef _WIN32_WCE
-    KMountPoint::Ptr mp = KMountPoint::currentMountPoints(KMountPoint::NeedRealDeviceName).findByPath(point);
-    if (!mp)
-        return false;
-    QString dev = mp->realDeviceName();
-    if (dev.isEmpty()) return false;
-
-    QString epath = QString::fromLocal8Bit(qgetenv("PATH"));
-    QString path = QLatin1String("/sbin:/bin");
-    if (!epath.isEmpty())
-        path += QLatin1Char(':') + epath;
-    QString pumountProg = KGlobal::dirs()->findExe(QLatin1String("pumount"), path);
-
-    if (pumountProg.isEmpty())
-        return false;
-
-    QByteArray buffer = QFile::encodeName(pumountProg);
-    buffer += ' ';
-    buffer += QFile::encodeName(KShell::quoteArg(dev));
-
-    int res = system( buffer.data() );
-
-    return res==0;
-#else
-    return false;
-#endif
-}
-
-/*************************************
- *
- * Utilities
- *
- *************************************/
-
-static QString readLogFile( const QByteArray& _filename )
-{
-    QString result;
-    QFile file(QFile::decodeName(_filename));
-    if (file.open(QIODevice::ReadOnly)) {
-        result = QString::fromLocal8Bit(file.readAll());
+    } else {
+        QByteArray erroroutput = umountProc.readAllStandardError();
+        if (erroroutput.isEmpty()) {
+            erroroutput = umountProc.readAllStandardOutput();
+        }
+        error( KIO::ERR_COULD_NOT_UNMOUNT, QString::fromLocal8Bit(erroroutput) );
     }
-    (void)file.remove();
-    return result;
 }
 
 /*************************************
@@ -1329,4 +1047,4 @@ bool FileProtocol::deleteRecursive(const QString& path)
     return true;
 }
 
-#include "file.moc"
+#include "moc_file.cpp"
