@@ -37,19 +37,15 @@
 #include <kdebug.h>
 #include <kconfiggroup.h>
 #include <kmountpoint.h>
+#include <kuser.h>
 
 #include <dirent.h>
+#include <string.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <grp.h>
 #include <utime.h>
-#include <pwd.h>
 #include <stdlib.h>
 
-#if defined(HAVE_LIMITS_H)
-#include <limits.h>  // PATH_MAX
-#endif
-
 //sendfile has different semantics in different platforms
 #if defined HAVE_SENDFILE && defined Q_OS_LINUX
 #define USE_SENDFILE 1
@@ -94,16 +90,16 @@ void FileProtocol::copy( const KUrl &srcUrl, const KUrl &destUrl,
            error(KIO::ERR_ACCESS_DENIED, src);
         else
            error(KIO::ERR_DOES_NOT_EXIST, src);
-	return;
+        return;
     }
 
     if ( S_ISDIR( buff_src.st_mode ) ) {
-	error(KIO::ERR_IS_DIRECTORY, src);
-	return;
+        error(KIO::ERR_IS_DIRECTORY, src);
+        return;
     }
     if ( S_ISFIFO( buff_src.st_mode ) || S_ISSOCK ( buff_src.st_mode ) ) {
-	error(KIO::ERR_CANNOT_OPEN_FOR_READING, src);
-	return;
+        error(KIO::ERR_CANNOT_OPEN_FOR_READING, src);
+        return;
     }
 
     KDE_struct_stat buff_dest;
@@ -140,8 +136,8 @@ void FileProtocol::copy( const KUrl &srcUrl, const KUrl &destUrl,
 
     int src_fd = KDE_open( _src.data(), O_RDONLY);
     if ( src_fd < 0 ) {
-	error(KIO::ERR_CANNOT_OPEN_FOR_READING, src);
-	return;
+        error(KIO::ERR_CANNOT_OPEN_FOR_READING, src);
+        return;
     }
 
 #if HAVE_FADVISE
@@ -157,7 +153,7 @@ void FileProtocol::copy( const KUrl &srcUrl, const KUrl &destUrl,
 
     int dest_fd = KDE_open(_dest.data(), O_CREAT | O_TRUNC | O_WRONLY, initialMode);
     if ( dest_fd < 0 ) {
-	kDebug(7101) << "###### COULD NOT WRITE " << dest;
+        kDebug(7101) << "###### COULD NOT WRITE " << dest;
         if ( errno == EACCES ) {
             error(KIO::ERR_WRITE_ACCESS_DENIED, dest);
         } else {
@@ -192,7 +188,7 @@ void FileProtocol::copy( const KUrl &srcUrl, const KUrl &destUrl,
 #ifdef USE_SENDFILE
        if (use_sendfile) {
             off_t sf = processed_size;
-            n = KDE_sendfile( dest_fd, src_fd, &sf, MAX_IPC_SIZE );
+            n = ::sendfile( dest_fd, src_fd, &sf, MAX_IPC_SIZE );
             processed_size = sf;
             if ( n == -1 && ( errno == EINVAL || errno == ENOSYS ) ) { //not all filesystems support sendfile()
                 kDebug(7101) << "sendfile() not supported, falling back ";
@@ -310,7 +306,7 @@ void FileProtocol::listDir( const KUrl& url)
 {
     if (!url.isLocalFile()) {
         KUrl redir(url);
-        redir.setProtocol(config()->readEntry("DefaultRemoteProtocol", "smb"));
+        redir.setProtocol(config()->readEntry("DefaultRemoteProtocol", "sftp"));
         redirection(redir);
         kDebug(7101) << "redirecting to " << redir.url();
         finished();
@@ -328,16 +324,15 @@ void FileProtocol::listDir( const KUrl& url)
             error(KIO::ERR_IS_FILE, path);
             break;
 #ifdef ENOMEDIUM
-	case ENOMEDIUM:
-            error(ERR_SLAVE_DEFINED,
-                  i18n("No media in device for %1", path));
+        case ENOMEDIUM:
+            error(ERR_SLAVE_DEFINED, i18n("No media in device for %1", path));
             break;
 #endif
         default:
             error(KIO::ERR_CANNOT_ENTER_DIRECTORY, path);
             break;
         }
-	return;
+        return;
     }
 
     /* set the current dir to the path to speed up
@@ -419,7 +414,6 @@ void FileProtocol::listDir( const KUrl& url)
 void FileProtocol::rename( const KUrl &srcUrl, const KUrl &destUrl,
                            KIO::JobFlags _flags )
 {
-    char off_t_should_be_64_bits[sizeof(off_t) >= 8 ? 1 : -1]; (void) off_t_should_be_64_bits;
     const QString src = srcUrl.toLocalFile();
     const QString dest = destUrl.toLocalFile();
     const QByteArray _src(QFile::encodeName(src));
@@ -458,7 +452,7 @@ void FileProtocol::rename( const KUrl &srcUrl, const KUrl &destUrl,
         }
     }
 
-    if ( KDE_rename( _src.data(), _dest.data()))
+    if ( KDE_rename( _src.data(), _dest.data()) == -1)
     {
         if (( errno == EACCES ) || (errno == EPERM)) {
             error(KIO::ERR_ACCESS_DENIED, dest);
@@ -527,37 +521,37 @@ void FileProtocol::del(const KUrl& url, bool isfile)
      *****/
 
     if (isfile) {
-	kDebug(7101) << "Deleting file "<< url;
+        kDebug(7101) << "Deleting file "<< url;
 
-	if ( unlink( _path.data() ) == -1 ) {
+        if ( unlink( _path.data() ) == -1 ) {
             if ((errno == EACCES) || (errno == EPERM))
                error(KIO::ERR_ACCESS_DENIED, path);
             else if (errno == EISDIR)
                error(KIO::ERR_IS_DIRECTORY, path);
             else
                error(KIO::ERR_CANNOT_DELETE, path);
-	    return;
-	}
+            return;
+        }
     } else {
 
       /*****
        * Delete empty directory
        *****/
 
-      kDebug( 7101 ) << "Deleting directory " << url.url();
-      if (metaData(QLatin1String("recurse")) == QLatin1String("true")) {
-          if (!deleteRecursive(path))
-              return;
-      }
-      if ( ::rmdir( _path.data() ) == -1 ) {
-	if ((errno == EACCES) || (errno == EPERM))
-	  error(KIO::ERR_ACCESS_DENIED, path);
-	else {
-	  kDebug( 7101 ) << "could not rmdir " << perror;
-	  error(KIO::ERR_COULD_NOT_RMDIR, path);
-	  return;
-	}
-      }
+        kDebug( 7101 ) << "Deleting directory " << url.url();
+        if (metaData(QLatin1String("recurse")) == QLatin1String("true")) {
+            if (!deleteRecursive(path))
+                return;
+        }
+        if ( ::rmdir( _path.data() ) == -1 ) {
+            if ((errno == EACCES) || (errno == EPERM)) {
+                error(KIO::ERR_ACCESS_DENIED, path);
+            } else {
+                kDebug( 7101 ) << "could not rmdir " << ::strerror(errno);
+                error(KIO::ERR_COULD_NOT_RMDIR, path);
+                return;
+            }
+        }
     }
 
     finished();
@@ -572,28 +566,28 @@ void FileProtocol::chown( const KUrl& url, const QString& owner, const QString&
 
     // get uid from given owner
     {
-        struct passwd *p = ::getpwnam(owner.toLatin1());
+        const KUser kuser(owner);
 
-        if ( ! p ) {
+        if ( ! kuser.isValid() ) {
             error( KIO::ERR_SLAVE_DEFINED,
                    i18n( "Could not get user id for given user name %1", owner ) );
             return;
         }
 
-        uid = p->pw_uid;
+        uid = kuser.uid();
     }
 
     // get gid from given group
     {
-        struct group *p = ::getgrnam(group.toLatin1());
+        const KUserGroup kusergroup(group);
 
-        if ( ! p ) {
+        if ( ! kusergroup.isValid() ) {
             error( KIO::ERR_SLAVE_DEFINED,
                    i18n( "Could not get group id for given group name %1", group ) );
             return;
         }
 
-        gid = p->gr_gid;
+        gid = kusergroup.gid();
     }
 
     if ( ::chown(_path, uid, gid) == -1 ) {
@@ -616,11 +610,11 @@ void FileProtocol::stat( const KUrl & url )
 {
     if (!url.isLocalFile()) {
         KUrl redir(url);
-	redir.setProtocol(config()->readEntry("DefaultRemoteProtocol", "smb"));
-	redirection(redir);
-	kDebug(7101) << "redirecting to " << redir.url();
-	finished();
-	return;
+        redir.setProtocol(config()->readEntry("DefaultRemoteProtocol", "sftp"));
+        redirection(redir);
+        kDebug(7101) << "redirecting to " << redir.url();
+        finished();
+        return;
     }
 
     /* directories may not have a slash at the end if
