@@ -29,28 +29,18 @@
 */
 
 
-#define  KIO_FTP_PRIVATE_INCLUDE
 #include "ftp.h"
 
-#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#endif
-
-#if TIME_WITH_SYS_TIME
 #include <ctime>
-#endif
-
 #include <cctype>
 #include <cerrno>
 #include <cstdlib>
 #include <cstring>
 
-#include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
-#include <QtNetwork/QHostAddress>
-#include <QtNetwork/QTcpSocket>
-#include <QtNetwork/QTcpServer>
-#include <QtNetwork/QAuthenticator>
+#include <QtCore/QDateTime>
+#include <QtGui/QApplication>
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -60,7 +50,6 @@
 #include <kio/ioslave_defaults.h>
 #include <kio/slaveconfig.h>
 #include <kremoteencoding.h>
-#include <ksocketfactory.h>
 #include <kde_file.h>
 #include <kconfiggroup.h>
 
@@ -103,16 +92,6 @@ static char ftpModeFromPath(const QString& path, char defaultMode = '\0')
     return defaultMode;
 }
 
-static bool supportedProxyScheme(const QString& scheme)
-{
-    return (scheme == QLatin1String("ftp") || scheme == QLatin1String("socks"));
-}
-
-static bool isSocksProxy()
-{
-    return (QNetworkProxy::applicationProxy().type() == QNetworkProxy::Socks5Proxy);
-}
-
 
 // JPF: somebody should find a better solution for this or move this to KIO
 // JPF: anyhow, in KDE 3.2.0 I found diffent MAX_IPC_SIZE definitions!
@@ -168,9 +147,9 @@ KIO::filesize_t Ftp::UnknownSize = (KIO::filesize_t)-1;
 
 using namespace KIO;
 
-extern "C" int KDE_EXPORT kdemain( int argc, char **argv )
+extern "C" int Q_DECL_EXPORT kdemain( int argc, char **argv )
 {
-  QCoreApplication app(argc, argv);
+  QApplication app(argc, argv);
   KComponentData componentData( "kio_ftp", "kdelibs4" );
   ( void ) KGlobal::locale();
 
@@ -203,7 +182,6 @@ Ftp::Ftp( const QByteArray &pool, const QByteArray &app )
 
   // init other members
   m_port = 0;
-  m_socketProxyAuth = 0;
 }
 
 
@@ -323,10 +301,6 @@ void Ftp::setHost( const QString& _host, quint16 _port, const QString& _user,
 {
   kDebug(7102) << _host << "port=" << _port << "user=" << _user;
 
-  m_proxyURL.clear();
-  m_proxyUrls = config()->readEntry("ProxyUrls", QStringList());
-  kDebug(7102) << "proxy urls:" << m_proxyUrls;
-
   if ( m_host != _host || m_port != _port ||
        m_user != _user || m_pass != _pass )
     closeConnection();
@@ -413,45 +387,7 @@ bool Ftp::ftpOpenConnection (LoginMode loginMode)
  */
 bool Ftp::ftpOpenControlConnection()
 {
-  if (m_proxyUrls.isEmpty())
-      return ftpOpenControlConnection(m_host, m_port);
-
-  int errorCode = 0;
-  QString errorMessage;
-
-  Q_FOREACH (const QString& proxyUrl, m_proxyUrls) {
-    const KUrl url (proxyUrl);
-    const QString scheme (url.protocol());
-
-    if (!supportedProxyScheme(scheme)) {
-      // TODO: Need a new error code to indicate unsupported URL scheme.
-      errorCode = ERR_COULD_NOT_CONNECT;
-      errorMessage = url.url();
-      continue;
-    }
-
-    if (scheme == QLatin1String("socks")) {
-      kDebug(7102) << "Connecting to SOCKS proxy @" << url;
-      const int proxyPort = url.port();
-      QNetworkProxy proxy (QNetworkProxy::Socks5Proxy, url.host(), (proxyPort == -1 ? 0 : proxyPort));
-      QNetworkProxy::setApplicationProxy(proxy);
-      if (ftpOpenControlConnection(m_host, m_port)) {
-        return true;
-      }
-      QNetworkProxy::setApplicationProxy(QNetworkProxy::NoProxy);
-    } else {
-      if (ftpOpenControlConnection(url.host(), url.port())) {
-        m_proxyURL = url;
-        return true;
-      }
-    }
-  }
-
-  if (errorCode) {
-    error(errorCode, errorMessage);
-  }
-
-  return false;
+  return ftpOpenControlConnection(m_host, m_port);
 }
 
 bool Ftp::ftpOpenControlConnection( const QString &host, int port )
@@ -463,9 +399,9 @@ bool Ftp::ftpOpenControlConnection( const QString &host, int port )
   // now connect to the server and read the login message ...
   if (port == 0)
     port = 21;                  // default FTP port
-  m_control = KSocketFactory::synchronousConnectToHost(QLatin1String("ftp"), host, port, connectTimeout() * 1000);
-  connect(m_control, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)),
-          this, SLOT(proxyAuthentication(QNetworkProxy,QAuthenticator*)));
+  m_control = new QTcpSocket();
+  m_control->connectToHost(host, port);
+  m_control->waitForConnected(connectTimeout() * 1000);
   int iErrorCode = m_control->state() == QAbstractSocket::ConnectedState ? 0 : ERR_COULD_NOT_CONNECT;
 
   // on connect success try to read the server message...
@@ -580,7 +516,6 @@ bool Ftp::ftpLogin(bool* userChanged)
       info.commentLabel = i18n( "Site:" );
       info.comment = i18n("<b>%1</b>",  m_host );
       info.keepPassword = true; // Prompt the user for persistence as well.
-      info.setModified(false);  // Default the modified flag since we reuse authinfo.
 
       bool disablePassDlg = config()->readEntry( "DisablePassDlg", false );
       if ( disablePassDlg || !openPasswordDialog( info, errorMsg ) )
@@ -607,16 +542,6 @@ bool Ftp::ftpLogin(bool* userChanged)
 
     tempbuf = "USER ";
     tempbuf += user.toLatin1();
-    if ( m_proxyURL.isValid() )
-    {
-      tempbuf += '@';
-      tempbuf += m_host.toLatin1();
-      if ( m_port > 0 && m_port != DEFAULT_FTP_PORT )
-      {
-        tempbuf += ':';
-        tempbuf += QString::number(m_port).toLatin1();
-      }
-    }
 
     kDebug(7102) << "Sending Login name: " << tempbuf;
 
@@ -909,8 +834,10 @@ int Ftp::ftpOpenPASVDataConnection()
 
   // now connect the data socket ...
   quint16 port = i[4] << 8 | i[5];
-  const QString host = (isSocksProxy() ? m_host : address.toString());
-  m_data = KSocketFactory::synchronousConnectToHost("ftp-data", host, port, connectTimeout() * 1000);
+  const QString host = (address.toString());
+  m_data = new QTcpSocket();
+  m_data->connectToHost(host, port);
+  m_data->waitForConnected(connectTimeout() * 1000);
 
   return m_data->state() == QAbstractSocket::ConnectedState ? 0 : ERR_INTERNAL;
 }
@@ -945,8 +872,10 @@ int Ftp::ftpOpenEPSVDataConnection()
   if ( !start || sscanf(start, "|||%d|", &portnum) != 1)
     return ERR_INTERNAL;
 
-  const QString host = (isSocksProxy() ? m_host : address.toString());
-  m_data = KSocketFactory::synchronousConnectToHost("ftp-data", host, portnum, connectTimeout() * 1000);
+  const QString host = (address.toString());
+  m_data = new QTcpSocket();
+  m_data->connectToHost(host, portnum);
+  m_data->waitForConnected(connectTimeout() * 1000);
   return m_data->isOpen() ? 0 : ERR_INTERNAL;
 }
 
@@ -1019,8 +948,10 @@ int Ftp::ftpOpenPortDataConnection()
   if (m_extControl & eprtUnknown)
     return ERR_INTERNAL;
 
-  if (!m_server)
-    m_server = KSocketFactory::listen("ftp-data");
+  if (!m_server) {
+    m_server = new QTcpServer();
+    m_server->listen(QHostAddress::Any, 0);
+  }
 
   if (!m_server->isListening()) {
     delete m_server;
@@ -1781,7 +1712,12 @@ bool Ftp::ftpReadDir(FtpEntry& de)
 
       // First get current time - we need the current month and year
       time_t currentTime = time( 0L );
+#ifdef _POSIX_THREAD_SAFE_FUNCTIONS
+      struct tm tmpres;
+      struct tm * tmptr = gmtime_r(&currentTime, &tmpres);
+#else
       struct tm * tmptr = gmtime( &currentTime );
+#endif
       int currentMonth = tmptr->tm_mon;
       //kDebug(7102) << "Current time :" << asctime( tmptr );
       // Reset time fields
@@ -2257,41 +2193,58 @@ Ftp::StatusCode Ftp::ftpPut(int& iError, int iCopyFile, const KUrl& dest_url,
   return statusSuccess;
 }
 
-/** Use the SIZE command to get the file size.
-    Warning : the size depends on the transfer mode, hence the second arg. */
-bool Ftp::ftpSize( const QString & path, char mode )
+const char* Ftp::ftpSendSizeCmd(const QString& path)
 {
-  m_size = UnknownSize;
-  if( !ftpDataMode(mode) )
-      return false;
+  // Some servers do not allow absolute path for SIZE; so we use
+  // relative paths whenever possible. #326292
+  QString currentPath(m_currentPath);
+  if (!currentPath.endsWith(QLatin1Char('/'))) {
+    currentPath += QLatin1Char('/');
+  }
 
   QByteArray buf;
   buf = "SIZE ";
-  buf += remoteEncoding()->encode(path);
-  if( !ftpSendCmd( buf ) || (m_iRespType != 2) )
-    return false;
+  if (path.startsWith(currentPath)) {
+    buf += remoteEncoding()->encode(path.mid(currentPath.length()));
+  } else {
+    buf += remoteEncoding()->encode(path);
+  }
+
+  if (!ftpSendCmd(buf) || m_iRespType != 2) {
+    return 0;
+  }
 
   // skip leading "213 " (response code)
-  QByteArray psz (ftpResponse(4));
-  if(psz.isEmpty())
+  return ftpResponse(4);
+}
+
+
+/** Use the SIZE command to get the file size.
+    Warning : the size depends on the transfer mode, hence the second arg. */
+bool Ftp::ftpSize(const QString & path, char mode)
+{
+  m_size = UnknownSize;
+  if (!ftpDataMode(mode)) {
     return false;
+  }
+
+  const QByteArray psz(ftpSendSizeCmd(path));
+  if (psz.isEmpty()) {
+    return false;
+  }
+
   bool ok = false;
   m_size = psz.trimmed().toLongLong(&ok);
-  if (!ok) m_size = UnknownSize;
+  if (!ok) {
+    m_size = UnknownSize;
+  }
+
   return true;
 }
 
 bool Ftp::ftpFileExists(const QString& path)
 {
-  QByteArray buf;
-  buf = "SIZE ";
-  buf += remoteEncoding()->encode(path);
-  if( !ftpSendCmd( buf ) || (m_iRespType != 2) )
-    return false;
-
-  // skip leading "213 " (response code)
-  const char* psz = ftpResponse(4);
-  return psz != 0;
+  return ftpSendSizeCmd(path) != 0;
 }
 
 // Today the differences between ASCII and BINARY are limited to
@@ -2359,33 +2312,40 @@ void Ftp::copy( const KUrl &src, const KUrl &dest, int permissions, KIO::JobFlag
   bool bDestLocal = dest.isLocalFile();
   QString  sCopyFile;
 
-  if(bSrcLocal && !bDestLocal)                    // File -> Ftp
-  {
+  if(bSrcLocal && !bDestLocal) {                    // File -> Ftp
     sCopyFile = src.toLocalFile();
     kDebug(7102) << "local file" << sCopyFile << "-> ftp" << dest.path();
     cs = ftpCopyPut(iError, iCopyFile, sCopyFile, dest, permissions, flags);
-    if( cs == statusServerError) sCopyFile = dest.url();
-  }
-  else if(!bSrcLocal && bDestLocal)               // Ftp -> File
-  {
+    if(cs == statusServerError) {
+      sCopyFile = dest.url();
+    }
+  } else if(!bSrcLocal && bDestLocal) {               // Ftp -> File
     sCopyFile = dest.toLocalFile();
     kDebug(7102) << "ftp" << src.path() << "-> local file" << sCopyFile;
     cs = ftpCopyGet(iError, iCopyFile, sCopyFile, src, permissions, flags);
-    if( cs == statusServerError ) sCopyFile = src.url();
-  }
-  else {
-    error( ERR_UNSUPPORTED_ACTION, QString() );
+    if(cs == statusServerError) {
+      sCopyFile = src.url();
+    }
+  } else {
+    error(ERR_UNSUPPORTED_ACTION, QString());
     return;
   }
 
   // perform clean-ups and report error (if any)
-  if(iCopyFile != -1)
+  if(iCopyFile != -1) {
     ::close(iCopyFile);
+  }
+
   ftpCloseCommand();                        // must close command!
-  if(iError)
-    error(iError, sCopyFile);
-  else
+
+  if (cs == statusSuccess) {
     finished();
+    return;
+  }
+
+  if(iError) {
+    error(iError, sCopyFile);
+  }
 }
 
 
@@ -2551,6 +2511,12 @@ Ftp::StatusCode Ftp::ftpCopyGet(int& iError, int& iCopyFile, const QString &sCop
 
 Ftp::StatusCode Ftp::ftpSendMimeType(int& iError, const KUrl& url)
 {
+  // Emit proper mimetype for zero sized files. #323491
+  if (m_size == 0) {
+    mimeType(QLatin1String("application/x-zerosize"));
+    return statusSuccess;
+  }
+
   const int totalSize = ((m_size == UnknownSize || m_size > 1024) ? 1024 : m_size);
   QByteArray buffer(totalSize, '\0');
 
@@ -2585,74 +2551,6 @@ Ftp::StatusCode Ftp::ftpSendMimeType(int& iError, const KUrl& url)
   return statusSuccess;
 }
 
-void Ftp::proxyAuthentication(const QNetworkProxy& proxy, QAuthenticator* authenticator)
-{
-    Q_UNUSED(proxy);
-    kDebug(7102) << "Authenticator received -- realm:" << authenticator->realm() << "user:"
-                 << authenticator->user();
-
-    AuthInfo info;
-    info.url = m_proxyURL;
-    info.realmValue = authenticator->realm();
-    info.verifyPath = true;    //### whatever
-    info.username = authenticator->user();
-
-    const bool haveCachedCredentials = checkCachedAuthentication(info);
-
-    // if m_socketProxyAuth is a valid pointer then authentication has been attempted before,
-    // and it was not successful. see below and saveProxyAuthenticationForSocket().
-    if (!haveCachedCredentials || m_socketProxyAuth) {
-        // Save authentication info if the connection succeeds. We need to disconnect
-        // this after saving the auth data (or an error) so we won't save garbage afterwards!
-        connect(m_control, SIGNAL(connected()), this, SLOT(saveProxyAuthentication()));
-        //### fillPromptInfo(&info);
-        info.prompt = i18n("You need to supply a username and a password for "
-                           "the proxy server listed below before you are allowed "
-                           "to access any sites.");
-        info.keepPassword = true;
-        info.commentLabel = i18n("Proxy:");
-        info.comment = i18n("<b>%1</b> at <b>%2</b>", info.realmValue, m_proxyURL.host());
-        const bool dataEntered = openPasswordDialog(info, i18n("Proxy Authentication Failed."));
-        if (!dataEntered) {
-            kDebug(7102) << "looks like the user canceled proxy authentication.";
-            error(ERR_USER_CANCELED, m_proxyURL.host());
-            return;
-        }
-    }
-    authenticator->setUser(info.username);
-    authenticator->setPassword(info.password);
-    authenticator->setOption(QLatin1String("keepalive"), info.keepPassword);
-
-    if (m_socketProxyAuth) {
-        *m_socketProxyAuth = *authenticator;
-    } else {
-        m_socketProxyAuth = new QAuthenticator(*authenticator);
-    }
-
-    m_proxyURL.setUser(info.username);
-    m_proxyURL.setPassword(info.password);
-}
-
-void Ftp::saveProxyAuthentication()
-{
-    kDebug(7102);
-    disconnect(m_control, SIGNAL(connected()), this, SLOT(saveProxyAuthentication()));
-    Q_ASSERT(m_socketProxyAuth);
-    if (m_socketProxyAuth) {
-        kDebug(7102) << "-- realm:" << m_socketProxyAuth->realm() << "user:" << m_socketProxyAuth->user();
-        KIO::AuthInfo a;
-        a.verifyPath = true;
-        a.url = m_proxyURL;
-        a.realmValue = m_socketProxyAuth->realm();
-        a.username = m_socketProxyAuth->user();
-        a.password = m_socketProxyAuth->password();
-        a.keepPassword = m_socketProxyAuth->option(QLatin1String("keepalive")).toBool();
-        cacheAuthentication(a);
-    }
-    delete m_socketProxyAuth;
-    m_socketProxyAuth = 0;
-}
-
 void Ftp::fixupEntryName(FtpEntry* e)
 {
     Q_ASSERT(e);
