@@ -24,7 +24,7 @@
 #include <QtCore/QTimer>
 #include <QtCore/QObject>
 #include <QtCore/QMap>
-#include <QtCore/QMetaEnum>
+#include <QtCore/qmetaobject.h>
 #include <QtCore/QRegExp>
 #include <QtGui/QTextDocument>
 
@@ -33,7 +33,6 @@
 #include <kmessagebox.h>
 #include <kurifilter.h>
 #include <kglobal.h>
-#include <assert.h>
 
 using namespace KParts;
 
@@ -236,207 +235,6 @@ bool BrowserArguments::forcesNewWindow() const
 namespace KParts
 {
 
-class WindowArgsPrivate : public QSharedData
-{
-public:
-    WindowArgsPrivate()
-        : x(-1), y(-1), width(-1), height(-1),
-          fullscreen(false),
-          menuBarVisible(true),
-          toolBarsVisible(true),
-          statusBarVisible(true),
-          resizable(true),
-          lowerWindow(false),
-          scrollBarsVisible(true)
-    {
-    }
-
-    // Position
-    int x;
-    int y;
-    // Size
-    int width;
-    int height;
-    bool fullscreen; //defaults to false
-    bool menuBarVisible; //defaults to true
-    bool toolBarsVisible; //defaults to true
-    bool statusBarVisible; //defaults to true
-    bool resizable; //defaults to true
-
-    bool lowerWindow; //defaults to false
-    bool scrollBarsVisible; //defaults to true
-};
-
-}
-
-WindowArgs::WindowArgs()
-    : d(new WindowArgsPrivate)
-{
-}
-
-WindowArgs::WindowArgs( const WindowArgs &args )
-    : d(args.d)
-{
-}
-
-WindowArgs::~WindowArgs()
-{
-}
-
-WindowArgs &WindowArgs::operator=( const WindowArgs &args )
-{
-    if ( this == &args ) return *this;
-
-    d = args.d;
-    return *this;
-}
-
-WindowArgs::WindowArgs( const QRect &_geometry, bool _fullscreen, bool _menuBarVisible,
-                        bool _toolBarsVisible, bool _statusBarVisible, bool _resizable )
-    : d(new WindowArgsPrivate)
-{
-    d->x = _geometry.x();
-    d->y = _geometry.y();
-    d->width = _geometry.width();
-    d->height = _geometry.height();
-    d->fullscreen = _fullscreen;
-    d->menuBarVisible = _menuBarVisible;
-    d->toolBarsVisible = _toolBarsVisible;
-    d->statusBarVisible = _statusBarVisible;
-    d->resizable = _resizable;
-    d->lowerWindow = false;
-}
-
-WindowArgs::WindowArgs( int _x, int _y, int _width, int _height, bool _fullscreen,
-                        bool _menuBarVisible, bool _toolBarsVisible,
-                        bool _statusBarVisible, bool _resizable )
-    : d(new WindowArgsPrivate)
-{
-    d->x = _x;
-    d->y = _y;
-    d->width = _width;
-    d->height = _height;
-    d->fullscreen = _fullscreen;
-    d->menuBarVisible = _menuBarVisible;
-    d->toolBarsVisible = _toolBarsVisible;
-    d->statusBarVisible = _statusBarVisible;
-    d->resizable = _resizable;
-    d->lowerWindow = false;
-}
-
-void WindowArgs::setX(int x)
-{
-    d->x = x;
-}
-
-int WindowArgs::x() const
-{
-    return d->x;
-}
-
-void WindowArgs::setY(int y)
-{
-    d->y = y;
-}
-
-int WindowArgs::y() const
-{
-    return d->y;
-}
-
-void WindowArgs::setWidth(int w)
-{
-    d->width = w;
-}
-
-int WindowArgs::width() const
-{
-    return d->width;
-}
-
-void WindowArgs::setHeight(int h)
-{
-    d->height = h;
-}
-
-int WindowArgs::height() const
-{
-    return d->height;
-}
-
-void WindowArgs::setFullScreen(bool fs)
-{
-    d->fullscreen = fs;
-}
-
-bool WindowArgs::isFullScreen() const
-{
-    return d->fullscreen;
-}
-
-void WindowArgs::setMenuBarVisible(bool visible)
-{
-    d->menuBarVisible = visible;
-}
-
-bool WindowArgs::isMenuBarVisible() const
-{
-    return d->menuBarVisible;
-}
-
-void WindowArgs::setToolBarsVisible(bool visible)
-{
-    d->toolBarsVisible = visible;
-}
-
-bool WindowArgs::toolBarsVisible() const
-{
-    return d->toolBarsVisible;
-}
-
-void WindowArgs::setStatusBarVisible(bool visible)
-{
-    d->statusBarVisible = visible;
-}
-
-bool WindowArgs::isStatusBarVisible() const
-{
-    return d->statusBarVisible;
-}
-
-void WindowArgs::setResizable(bool resizable)
-{
-    d->resizable = resizable;
-}
-
-bool WindowArgs::isResizable() const
-{
-    return d->resizable;
-}
-
-void WindowArgs::setLowerWindow(bool lower)
-{
-    d->lowerWindow = lower;
-}
-
-bool WindowArgs::lowerWindow() const
-{
-    return d->lowerWindow;
-}
-
-void WindowArgs::setScrollBarsVisible(bool visible)
-{
-    d->scrollBarsVisible = visible;
-}
-
-bool WindowArgs::scrollBarsVisible() const
-{
-    return d->scrollBarsVisible;
-}
-
-namespace KParts
-{
-
 // Internal class, use to store the status of the actions
 class KBitArray
 {
@@ -455,7 +253,6 @@ class BrowserExtension::BrowserExtensionPrivate
 public:
   BrowserExtensionPrivate( KParts::ReadOnlyPart *parent )
     : m_urlDropHandlingEnabled(false),
-      m_browserInterface(0),
       m_part( parent )
   {}
 
@@ -469,7 +266,6 @@ public:
   bool m_urlDropHandlingEnabled;
   KBitArray m_actionStatus;
   QMap<int, QString> m_actionText;
-  BrowserInterface *m_browserInterface;
 
   static void createActionSlotMap();
 
@@ -483,21 +279,21 @@ K_GLOBAL_STATIC(BrowserExtension::ActionNumberMap, s_actionNumberMap)
 
 void BrowserExtension::BrowserExtensionPrivate::createActionSlotMap()
 {
-    s_actionSlotMap->insert( "cut", SLOT( cut() ) );
-    s_actionSlotMap->insert( "copy", SLOT( copy() ) );
-    s_actionSlotMap->insert( "paste", SLOT( paste() ) );
-    s_actionSlotMap->insert( "print", SLOT( print() ) );
+    s_actionSlotMap->insert( "cut", SLOT(cut()) );
+    s_actionSlotMap->insert( "copy", SLOT(copy()) );
+    s_actionSlotMap->insert( "paste", SLOT(paste()) );
+    s_actionSlotMap->insert( "print", SLOT(print()) );
     // Tricky. Those aren't actions in fact, but simply methods that a browserextension
     // can have or not. No need to return them here.
-    //s_actionSlotMap->insert( "reparseConfiguration", SLOT( reparseConfiguration() ) );
-    //s_actionSlotMap->insert( "refreshMimeTypes", SLOT( refreshMimeTypes() ) );
+    //s_actionSlotMap->insert( "reparseConfiguration", SLOT(reparseConfiguration()) );
+    //s_actionSlotMap->insert( "refreshMimeTypes", SLOT(refreshMimeTypes()) );
 
     // Create the action-number map
     ActionSlotMap::ConstIterator it = s_actionSlotMap->constBegin();
     ActionSlotMap::ConstIterator itEnd = s_actionSlotMap->constEnd();
     for ( int i=0 ; it != itEnd ; ++it, ++i )
     {
-        //kDebug(1202) << " action " << it.key() << " number " << i;
+        //kDebug(1000) << " action " << it.key() << " number " << i;
         s_actionNumberMap->insert( it.key(), i );
     }
 }
@@ -535,14 +331,14 @@ BrowserExtension::BrowserExtension( KParts::ReadOnlyPart *parent )
       d->m_actionStatus.setBit( i, slotNames.contains( it.key()+"()" ) );
   }
 
-  connect( d->m_part, SIGNAL( completed() ),
-           this, SLOT( slotCompleted() ) );
-  connect( this, SIGNAL( openUrlRequest( const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments & ) ),
-           this, SLOT( slotOpenUrlRequest( const KUrl &, const KParts::OpenUrlArguments &, const KParts::BrowserArguments & ) ) );
-  connect( this, SIGNAL( enableAction( const char *, bool ) ),
-           this, SLOT( slotEnableAction( const char *, bool ) ) );
-  connect( this, SIGNAL( setActionText( const char *, const QString& ) ),
-           this, SLOT( slotSetActionText( const char *, const QString& ) ) );
+  connect( d->m_part, SIGNAL(completed()),
+           this, SLOT(slotCompleted()) );
+  connect( this, SIGNAL(openUrlRequest(KUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)),
+           this, SLOT(slotOpenUrlRequest(KUrl,KParts::OpenUrlArguments,KParts::BrowserArguments)) );
+  connect( this, SIGNAL(enableAction(const char*,bool)),
+           this, SLOT(slotEnableAction(const char*,bool)) );
+  connect( this, SIGNAL(setActionText(const char*,QString)),
+           this, SLOT(slotSetActionText(const char*,QString)) );
 }
 
 BrowserExtension::~BrowserExtension()
@@ -657,7 +453,7 @@ void BrowserExtension::slotOpenUrlRequest( const KUrl &url, const KParts::OpenUr
     req.m_delayedArgs = args;
     req.m_delayedBrowserArgs = browserArgs;
     d->m_requests.append( req );
-    QTimer::singleShot( 0, this, SLOT( slotEmitOpenUrlRequestDelayed() ) );
+    QTimer::singleShot( 0, this, SLOT(slotEmitOpenUrlRequestDelayed()) );
 }
 
 void BrowserExtension::slotEmitOpenUrlRequestDelayed()
@@ -669,16 +465,6 @@ void BrowserExtension::slotEmitOpenUrlRequestDelayed()
     // tricky: do not do anything here! (no access to member variables, etc.)
 }
 
-void BrowserExtension::setBrowserInterface( BrowserInterface *impl )
-{
-    d->m_browserInterface = impl;
-}
-
-BrowserInterface *BrowserExtension::browserInterface() const
-{
-    return d->m_browserInterface;
-}
-
 void BrowserExtension::slotEnableAction( const char * name, bool enabled )
 {
     //kDebug() << "BrowserExtension::slotEnableAction " << name << " " << enabled;
@@ -700,7 +486,7 @@ bool BrowserExtension::isActionEnabled( const char * name ) const
 
 void BrowserExtension::slotSetActionText( const char * name, const QString& text )
 {
-    kDebug() << "BrowserExtension::slotSetActionText " << name << " " << text;
+    //kDebug() << "BrowserExtension::slotSetActionText " << name << " " << text;
     ActionNumberMap::ConstIterator it = s_actionNumberMap->constFind( name );
     if ( it != s_actionNumberMap->constEnd() )
     {
@@ -737,87 +523,4 @@ BrowserExtension *BrowserExtension::childObject( QObject *obj )
     return KGlobal::findDirectChild<KParts::BrowserExtension *>(obj);
 }
 
-namespace KParts
-{
-
-class BrowserHostExtension::BrowserHostExtensionPrivate
-{
-public:
-  BrowserHostExtensionPrivate()
-  {
-  }
-  ~BrowserHostExtensionPrivate()
-  {
-  }
-
-  KParts::ReadOnlyPart *m_part;
-};
-
-}
-
-BrowserHostExtension::BrowserHostExtension( KParts::ReadOnlyPart *parent )
- : QObject( parent ), d( new BrowserHostExtensionPrivate )
-{
-  d->m_part = parent;
-}
-
-BrowserHostExtension::~BrowserHostExtension()
-{
-  delete d;
-}
-
-QStringList BrowserHostExtension::frameNames() const
-{
-  return QStringList();
-}
-
-const QList<KParts::ReadOnlyPart*> BrowserHostExtension::frames() const
-{
-  return QList<KParts::ReadOnlyPart*>();
-}
-
-bool BrowserHostExtension::openUrlInFrame( const KUrl &,
-                                           const KParts::OpenUrlArguments&,
-                                           const KParts::BrowserArguments & )
-{
-  return false;
-}
-
-BrowserHostExtension *BrowserHostExtension::childObject( QObject *obj )
-{
-    return KGlobal::findDirectChild<KParts::BrowserHostExtension *>(obj);
-}
-
-BrowserHostExtension *
-BrowserHostExtension::findFrameParent(KParts::ReadOnlyPart *callingPart, const QString &frame)
-{
-    Q_UNUSED(callingPart);
-    Q_UNUSED(frame);
-    return 0;
-}
-
-LiveConnectExtension::LiveConnectExtension( KParts::ReadOnlyPart *parent )
- : QObject( parent ), d( 0 ) {}
-
-LiveConnectExtension::~LiveConnectExtension() {}
-
-bool LiveConnectExtension::get( const unsigned long, const QString &, Type &, unsigned long &, QString & ) {
-    return false;
-}
-
-bool LiveConnectExtension::put( const unsigned long, const QString &, const QString & ) {
-    return false;
-}
-
-bool LiveConnectExtension::call( const unsigned long, const QString &, const QStringList &, Type &, unsigned long &, QString & ) {
-    return false;
-}
-
-void LiveConnectExtension::unregister( const unsigned long ) {}
-
-LiveConnectExtension *LiveConnectExtension::childObject( QObject *obj )
-{
-    return KGlobal::findDirectChild<KParts::LiveConnectExtension *>(obj);
-}
-
-#include "browserextension.moc"
+#include "moc_browserextension.cpp"
