@@ -26,24 +26,19 @@
 #include <kparts/part.h>
 #include <kparts/event.h>
 
-#include <QtCore/QSharedDataPointer>
-
-template <class T1, class T2> struct QPair;
-template<typename T> class Q3PtrList;
-template <class Key, class T> class QMap;
-template<typename T> class QList;
+#include <QPair>
+#include <QMap>
+#include <QList>
+#include <QDataStream>
+#include <QPoint>
+#include <QString>
+#include <QStringList>
 
 class KFileItem;
 class KFileItemList;
-class QDataStream;
-class QPoint;
-class QString;
-class QStringList;
 
 namespace KParts {
 
-class BrowserInterface;
-
 struct BrowserArgumentsPrivate;
 
 /**
@@ -76,7 +71,7 @@ struct KPARTS_EXPORT BrowserArguments
 
   /**
    * This buffer can be used by the part to save and restore its contents.
-   * See KHTMLPart for instance.
+   * See KWebKitPart for instance.
    */
   QStringList docState;
 
@@ -182,63 +177,6 @@ private:
   BrowserArgumentsPrivate *d;
 };
 
-class WindowArgsPrivate;
-
-/**
- * The WindowArgs are used to specify arguments to the "create new window"
- * call (see the createNewWindow variant that uses WindowArgs).
- * The primary reason for this is the javascript window.open function.
- */
-class KPARTS_EXPORT WindowArgs
-{
-public:
-    WindowArgs();
-    ~WindowArgs();
-    WindowArgs( const WindowArgs &args );
-    WindowArgs &operator=( const WindowArgs &args );
-    WindowArgs( const QRect &_geometry, bool _fullscreen, bool _menuBarVisible,
-                bool _toolBarsVisible, bool _statusBarVisible, bool _resizable );
-    WindowArgs( int _x, int _y, int _width, int _height, bool _fullscreen,
-                bool _menuBarVisible, bool _toolBarsVisible,
-                bool _statusBarVisible, bool _resizable );
-
-    void setX(int x);
-    int x() const;
-
-    void setY(int y);
-    int y() const;
-
-    void setWidth(int w);
-    int width() const;
-
-    void setHeight(int h);
-    int height() const;
-
-    void setFullScreen(bool fs);
-    bool isFullScreen() const;
-
-    void setMenuBarVisible(bool visible);
-    bool isMenuBarVisible() const;
-
-    void setToolBarsVisible(bool visible);
-    bool toolBarsVisible() const;
-
-    void setStatusBarVisible(bool visible);
-    bool isStatusBarVisible() const;
-
-    void setResizable(bool resizable);
-    bool isResizable() const;
-
-    void setLowerWindow(bool lower);
-    bool lowerWindow() const;
-
-    void setScrollBarsVisible(bool visible);
-    bool scrollBarsVisible() const;
-
-private:
-    QSharedDataPointer<WindowArgsPrivate> d;
-};
-
 /**
  * The KParts::OpenUrlEvent event informs that a given part has opened a given URL.
  * Applications can use this event to send this information to interested plugins.
@@ -288,7 +226,7 @@ private:
   * actions are provided by the browser, but implemented by the part
   * (for the actions it supports).
   *
-  * The following standard actions are defined by the host of the view :
+  * The following standard actions are defined by the host of the view:
   *
   * [selection-dependent actions]
   * @li @p cut : Copy selected items to clipboard and store 'not cut' in clipboard.
@@ -417,9 +355,6 @@ public:
    */
   void setURLDropHandlingEnabled( bool enable );
 
-  void setBrowserInterface( BrowserInterface *impl );
-  BrowserInterface *browserInterface() const;
-
   /**
    * @return the status (enabled/disabled) of an action.
    * When the enableAction signal is emitted, the browserextension
@@ -493,10 +428,8 @@ public:
     typedef QMap<QString, QList<QAction *> > ActionGroupMap;
 
 Q_SIGNALS:
-#ifndef Q_MOC_RUN
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-public:  // yes, those signals are public; don't tell moc or doxygen :)
-#endif
+#if !defined(Q_MOC_RUN) && !defined(DOXYGEN_SHOULD_SKIP_THIS) && !defined(IN_IDE_PARSER)
+public:  // yes, those signals are public; don't tell moc, doxygen or kdevelop :)
 #endif
   /**
    * Enables or disable a standard action held by the browser.
@@ -577,8 +510,7 @@ public:  // yes, those signals are public; don't tell moc or doxygen :)
     void createNewWindow( const KUrl &url,
                           const KParts::OpenUrlArguments& arguments = KParts::OpenUrlArguments(),
                           const KParts::BrowserArguments &browserArguments = KParts::BrowserArguments(),
-                          const KParts::WindowArgs &windowArgs = KParts::WindowArgs(),
-                          KParts::ReadOnlyPart** part = 0 ); // TODO consider moving to BrowserHostExtension?
+                          KParts::ReadOnlyPart** part = 0 );
 
   /**
    * Since the part emits the jobid in the started() signal,
@@ -627,7 +559,7 @@ public:  // yes, those signals are public; don't tell moc or doxygen :)
    * @param actionGroups named groups of actions which should be inserted into the popup, see ActionGroupMap
    */
   void popupMenu( const QPoint &global, const KUrl &url,
-                  mode_t mode = (mode_t)-1,
+                  mode_t mode = static_cast<mode_t>(-1),
                   const KParts::OpenUrlArguments &args = KParts::OpenUrlArguments(),
                   const KParts::BrowserArguments &browserArgs = KParts::BrowserArguments(),
                   KParts::BrowserExtension::PopupFlags flags = KParts::BrowserExtension::DefaultPopupItems,
@@ -706,110 +638,6 @@ private:
   BrowserExtensionPrivate * const d;
 };
 
-/**
- * An extension class for container parts, i.e. parts that contain
- * other parts.
- * For instance a KHTMLPart hosts one part per frame.
- */
-class KPARTS_EXPORT BrowserHostExtension : public QObject
-{
-  Q_OBJECT
-public:
-  BrowserHostExtension( KParts::ReadOnlyPart *parent );
-
-  virtual ~BrowserHostExtension();
-
-  /**
-   * Returns a list of the names of all hosted child objects.
-   *
-   * Note that this method does not query the child objects recursively.
-   */
-  virtual QStringList frameNames() const;
-
-  /**
-   * Returns a list of pointers to all hosted child objects.
-   *
-   * Note that this method does not query the child objects recursively.
-   */
-  virtual const QList<KParts::ReadOnlyPart*> frames() const;
-
-  /**
-   * Returns the part that contains @p frame and that may be accessed
-   * by @p callingPart
-   */
-  virtual BrowserHostExtension *findFrameParent(KParts::ReadOnlyPart *callingPart, const QString &frame);
-
-  /**
-   * Opens the given url in a hosted child frame. The frame name is specified in the
-   * frameName variable in the @p browserArguments parameter (see KParts::BrowserArguments ) .
-   */
-  virtual bool openUrlInFrame( const KUrl &url,
-                               const KParts::OpenUrlArguments& arguments,
-                               const KParts::BrowserArguments &browserArguments );
-
-  /**
-   * Queries @p obj for a child object which inherits from this
-   * BrowserHostExtension class. Convenience method.
-   */
-  static BrowserHostExtension *childObject( QObject *obj );
-
-private:
-  class BrowserHostExtensionPrivate;
-  BrowserHostExtensionPrivate * const d;
-};
-
-/**
- * An extension class for LiveConnect, i.e. a call from JavaScript
- * from a HTML page which embeds this part.
- * A part can have an object hierarchie by using objid as a reference
- * to an object.
- */
-class KPARTS_EXPORT LiveConnectExtension : public QObject
-{
-  Q_OBJECT
-public:
-  enum Type {
-      TypeVoid=0, TypeBool, TypeFunction, TypeNumber, TypeObject, TypeString
-  };
-  typedef QList<QPair<Type, QString> > ArgList;
-
-  LiveConnectExtension( KParts::ReadOnlyPart *parent );
-
-  virtual ~LiveConnectExtension();
-  /**
-   * get a field value from objid, return true on success
-   */
-  virtual bool get( const unsigned long objid, const QString & field, Type & type, unsigned long & retobjid, QString & value );
-  /**
-   * put a field value in objid, return true on success
-   */
-  virtual bool put( const unsigned long objid, const QString & field, const QString & value );
-  /**
-   * calls a function of objid, return true on success
-   */
-  virtual bool call( const unsigned long objid, const QString & func, const QStringList & args, Type & type, unsigned long & retobjid, QString & value );
-  /**
-   * notifies the part that there is no reference anymore to objid
-   */
-  virtual void unregister( const unsigned long objid );
-
-  static LiveConnectExtension *childObject( QObject *obj );
-Q_SIGNALS:
-#ifndef Q_MOC_RUN
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-public:  // yes, those signals are public; don't tell moc or doxygen :)
-#endif
-#endif
-  /**
-   * notify a event from the part of object objid
-   */
-  void partEvent( const unsigned long objid, const QString & event, const KParts::LiveConnectExtension::ArgList & args );
-
-private:
-  class LiveConnectExtensionPrivate;
-  LiveConnectExtensionPrivate * const d;
-};
-
 }
 
 Q_DECLARE_OPERATORS_FOR_FLAGS( KParts::BrowserExtension::PopupFlags )
