@@ -19,9 +19,7 @@
 */
 
 #include "part.h"
-#include <kprotocolinfo.h>
 #include "event.h"
-#include "plugin.h"
 #include "mainwindow.h"
 #include "partmanager.h"
 #include "browserextension.h"
@@ -32,6 +30,7 @@
 #include <QtGui/QPainter>
 #include <QtCore/QPoint>
 
+#include <kprotocolinfo.h>
 #include <kdirnotify.h>
 #include <kfiledialog.h>
 #include <kcomponentdata.h>
@@ -60,20 +59,10 @@ public:
     Q_DECLARE_PUBLIC(PartBase)
 
     PartBasePrivate(PartBase *q): q_ptr(q)
-    {
-        m_pluginLoadingMode = PartBase::LoadPlugins;
-        m_pluginInterfaceVersion = 0;
-        m_obj = 0;
-    }
-
-    virtual ~PartBasePrivate()
     {
     }
 
     PartBase *q_ptr;
-    PartBase::PluginLoadingMode m_pluginLoadingMode;
-    int m_pluginInterfaceVersion;
-    QObject *m_obj;
 };
 
 class PartPrivate: public PartBasePrivate
@@ -120,84 +109,35 @@ PartBase::~PartBase()
     delete d_ptr;
 }
 
-void PartBase::setPartObject( QObject *obj )
-{
-    Q_D(PartBase);
-
-    d->m_obj = obj;
-}
-
-QObject *PartBase::partObject() const
-{
-    Q_D(const PartBase);
-
-    return d->m_obj;
-}
-
 void PartBase::setComponentData(const KComponentData &componentData)
 {
-    setComponentData(componentData, true);
-}
-
-void PartBase::setComponentData(const KComponentData &componentData, bool bLoadPlugins)
-{
-    Q_D(PartBase);
-
     KXMLGUIClient::setComponentData(componentData);
     KGlobal::locale()->insertCatalog(componentData.catalogName());
     // install 'instancename'data resource type
     KGlobal::dirs()->addResourceType(QString(componentData.componentName() + "data").toUtf8(),
                                      "data", componentData.componentName());
-    if (bLoadPlugins) {
-        loadPlugins(d->m_obj, this, componentData);
-    }
-}
-
-void PartBase::loadPlugins(QObject *parent, KXMLGUIClient *parentGUIClient, const KComponentData &instance)
-{
-    Q_D(PartBase);
-
-    if( d->m_pluginLoadingMode != DoNotLoadPlugins )
-        Plugin::loadPlugins( parent, parentGUIClient, instance, d->m_pluginLoadingMode == LoadPlugins, d->m_pluginInterfaceVersion );
-}
-
-void PartBase::setPluginLoadingMode( PluginLoadingMode loadingMode )
-{
-    Q_D(PartBase);
-
-    d->m_pluginLoadingMode = loadingMode;
-}
-
-void KParts::PartBase::setPluginInterfaceVersion( int version )
-{
-    Q_D(PartBase);
-
-    d->m_pluginInterfaceVersion = version;
 }
 
 Part::Part( QObject *parent )
     : QObject( parent ), PartBase( *new PartPrivate(this) )
 {
-    PartBase::setPartObject( this );
 }
 
 Part::Part(PartPrivate &dd, QObject *parent)
     : QObject( parent ), PartBase( dd )
 {
-    PartBase::setPartObject( this );
 }
 
 Part::~Part()
 {
     Q_D(Part);
 
-    //kDebug(1000) << this;
+    // kDebug(1000) << this;
 
     if ( d->m_widget )
     {
-        // We need to disconnect first, to avoid calling it !
-        disconnect( d->m_widget, SIGNAL(destroyed()),
-                    this, SLOT(slotWidgetDestroyed()) );
+        // We need to disconnect first to avoid calling slotWidgetDestroyed() !
+        disconnect( d->m_widget, 0, this, 0 );
     }
 
     if ( d->m_manager )
@@ -233,6 +173,13 @@ void Part::setAutoDeleteWidget(bool autoDeleteWidget)
 {
     Q_D(Part);
     d->m_autoDeleteWidget = autoDeleteWidget;
+    if (d->m_widget) {
+        if (autoDeleteWidget) {
+            connect( d->m_widget, SIGNAL(destroyed()), this, SLOT(slotWidgetDestroyed()), Qt::UniqueConnection );
+        } else {
+            disconnect( d->m_widget, 0, this, 0 );
+        }
+    }
 }
 
 void Part::setAutoDeletePart(bool autoDeletePart)
@@ -241,8 +188,6 @@ void Part::setAutoDeletePart(bool autoDeletePart)
     d->m_autoDeletePart = autoDeletePart;
 }
 
-
-
 KIconLoader* Part::iconLoader()
 {
     Q_D(Part);
@@ -282,8 +227,7 @@ void Part::setWidget( QWidget *widget )
 {
     Q_D(Part);
     d->m_widget = widget;
-    connect( d->m_widget, SIGNAL(destroyed()),
-             this, SLOT(slotWidgetDestroyed()), Qt::UniqueConnection );
+    connect( d->m_widget, SIGNAL(destroyed()), this, SLOT(slotWidgetDestroyed()), Qt::UniqueConnection );
 }
 
 void Part::setSelectable( bool selectable )
@@ -350,15 +294,10 @@ void Part::slotWidgetDestroyed()
     d->m_widget = 0;
     if (d->m_autoDeletePart) {
         kDebug(1000) << "deleting part" << objectName();
-        this->deleteLater();
+        delete this; // ouch, this should probably be deleteLater()
     }
 }
 
-void Part::loadPlugins()
-{
-    PartBase::loadPlugins(this, this, componentData());
-}
-
 //////////////////////////////////////////////////
 
 namespace KParts
@@ -369,17 +308,19 @@ class ReadOnlyPartPrivate: public PartPrivate
 public:
     Q_DECLARE_PUBLIC(ReadOnlyPart)
 
-    ReadOnlyPartPrivate(ReadOnlyPart *q): PartPrivate(q)
+    ReadOnlyPartPrivate(ReadOnlyPart *q): PartPrivate(q),
+        m_job(0),
+        m_statJob(0),
+        m_uploadJob(0),
+        m_showProgressInfo(true),
+        m_saveOk(false),
+        m_waitForSave(false),
+        m_duringSaveAs(false),
+        m_bTemp(false),
+        m_bAutoDetectedMime(false),
+        m_url(0),
+        m_file("")
     {
-        m_job = 0;
-        m_statJob = 0;
-        m_uploadJob = 0;
-        m_showProgressInfo = true;
-        m_saveOk = false;
-        m_waitForSave = false;
-        m_duringSaveAs = false;
-        m_bTemp = false;
-        m_bAutoDetectedMime = false;
     }
 
     ~ReadOnlyPartPrivate()
@@ -491,23 +432,7 @@ void ReadOnlyPart::setLocalFilePath( const QString &localFilePath )
     d->m_file = localFilePath;
 }
 
-#ifndef KDE_NO_DEPRECATED
-bool ReadOnlyPart::isLocalFileTemporary() const
-{
-    Q_D(const ReadOnlyPart);
 
-    return d->m_bTemp;
-}
-#endif
-
-#ifndef KDE_NO_DEPRECATED
-void ReadOnlyPart::setLocalFileTemporary( bool temp )
-{
-    Q_D(ReadOnlyPart);
-
-    d->m_bTemp = temp;
-}
-#endif
 
 void ReadOnlyPart::setProgressInfoEnabled( bool show )
 {
@@ -523,15 +448,6 @@ bool ReadOnlyPart::isProgressInfoEnabled() const
     return d->m_showProgressInfo;
 }
 
-#ifndef KDE_NO_COMPAT
-void ReadOnlyPart::showProgressInfo( bool show )
-{
-    Q_D(ReadOnlyPart);
-
-    d->m_showProgressInfo = show;
-}
-#endif
-
 bool ReadOnlyPart::openUrl( const KUrl &url )
 {
     Q_D(ReadOnlyPart);
@@ -557,7 +473,7 @@ bool ReadOnlyPart::openUrl( const KUrl &url )
         // Maybe we can use a "local path", to avoid a temp copy?
         KIO::JobFlags flags = d->m_showProgressInfo ? KIO::DefaultFlags : KIO::HideProgressInfo;
         d->m_statJob = KIO::mostLocalUrl(d->m_url, flags);
-        d->m_statJob->ui()->setWindow( widget() ? widget()->topLevelWidget() : 0 );
+        d->m_statJob->ui()->setWindow( widget() ? widget()->window() : 0 );
         connect(d->m_statJob, SIGNAL(result(KJob*)), this, SLOT(_k_slotStatJobFinished(KJob*)));
         return true;
     } else {
@@ -609,18 +525,14 @@ void ReadOnlyPartPrivate::openRemoteFile()
     QString extension;
     if (!ext.isEmpty() && m_url.query().isNull()) // not if the URL has a query, e.g. cgi.pl?something
         extension = '.'+ext; // keep the '.'
-    KTemporaryFile tempFile;
-    tempFile.setSuffix(extension);
-    tempFile.setAutoRemove(false);
-    tempFile.open();
-    m_file = tempFile.fileName();
+    m_file = KTemporaryFile::filePath(QString::fromLatin1("XXXXXXXXXX%1").arg(extension));
 
     KUrl destURL;
     destURL.setPath( m_file );
     KIO::JobFlags flags = m_showProgressInfo ? KIO::DefaultFlags : KIO::HideProgressInfo;
     flags |= KIO::Overwrite;
     m_job = KIO::file_copy(m_url, destURL, 0600, flags);
-    m_job->ui()->setWindow(q->widget() ? q->widget()->topLevelWidget() : 0);
+    m_job->ui()->setWindow(q->widget() ? q->widget()->window() : 0);
     emit q->started(m_job);
     QObject::connect(m_job, SIGNAL(result(KJob*)), q, SLOT(_k_slotJobFinished(KJob*)));
     QObject::connect(m_job, SIGNAL(mimetype(KIO::Job*,QString)),
@@ -794,7 +706,7 @@ void ReadWritePart::setModified( bool modified )
     kDebug(1000) << "setModified(" << (modified ? "true" : "false") << ")";
     if ( !d->m_bReadWrite && modified )
     {
-        kError(1000) << "Can't set a read-only document to 'modified' !" << endl;
+        kError(1000) << "Can't set a read-only document to 'modified' !";
         return;
     }
     d->m_bModified = modified;
@@ -889,7 +801,7 @@ bool ReadWritePart::saveAs( const KUrl & kurl )
 
     if (!kurl.isValid())
     {
-        kError(1000) << "saveAs: Malformed URL " << kurl.url() << endl;
+        kError(1000) << "saveAs: Malformed URL " << kurl.url();
         return false;
     }
     d->m_duringSaveAs = true;
@@ -930,10 +842,7 @@ void ReadWritePartPrivate::prepareSaving()
         // We haven't saved yet, or we did but locally - provide a temp file
         if ( m_file.isEmpty() || !m_bTemp )
         {
-            KTemporaryFile tempFile;
-            tempFile.setAutoRemove(false);
-            tempFile.open();
-            m_file = tempFile.fileName();
+            m_file = KTemporaryFile::filePath();
             m_bTemp = true;
         }
         // otherwise, we already had a temp file
@@ -964,10 +873,7 @@ bool ReadWritePart::saveToUrl()
             d->m_uploadJob->kill();
             d->m_uploadJob = 0;
         }
-        KTemporaryFile *tempFile = new KTemporaryFile();
-        tempFile->open();
-        QString uploadFile = tempFile->fileName();
-        delete tempFile;
+        QString uploadFile = KTemporaryFile::filePath();
         KUrl uploadUrl;
         uploadUrl.setPath( uploadFile );
         // Create hardlink
@@ -977,7 +883,7 @@ bool ReadWritePart::saveToUrl()
             return false;
         }
         d->m_uploadJob = KIO::file_move( uploadUrl, d->m_url, -1, KIO::Overwrite );
-        d->m_uploadJob->ui()->setWindow( widget() ? widget()->topLevelWidget() : 0 );
+        d->m_uploadJob->ui()->setWindow( widget() ? widget()->window() : 0 );
         connect( d->m_uploadJob, SIGNAL(result(KJob*)), this, SLOT(_k_slotUploadFinished(KJob*)) );
         return true;
     }
@@ -1040,7 +946,7 @@ bool ReadWritePart::waitSaveComplete()
 
     d->m_waitForSave = true;
 
-    d->m_eventLoop.exec(QEventLoop::ExcludeUserInputEvents);
+    d->m_eventLoop.exec();
 
     d->m_waitForSave = false;
 
@@ -1148,4 +1054,4 @@ void KParts::OpenUrlArguments::setActionRequestedByUser(bool userRequested)
     d->actionRequestedByUser = userRequested;
 }
 
-#include "part.moc"
+#include "moc_part.cpp"
