@@ -17,13 +17,15 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef _KPART_H
-#define _KPART_H
+#ifndef KPART_H
+#define KPART_H
 
 #include <QtCore/QPointer>
 #include <QtCore/QEvent>
-#include <QtCore/QSharedDataPointer>
-#include <QtXml/QDomElement> // KDE5: remove
+#include <QtCore/qshareddata.h>
+#include <QWidget>
+#include <QEvent>
+#include <QPoint>
 
 #include <kurl.h>
 #include <kxmlguiclient.h>
@@ -37,10 +39,6 @@
 
 class KIconLoader;
 class KComponentData;
-class QWidget;
-class QEvent;
-class QPoint;
-struct QUnknownInterface;
 
 class KJob;
 namespace KIO {
@@ -51,7 +49,6 @@ namespace KParts
 {
 
 class PartManager;
-class Plugin;
 class PartPrivate;
 class PartActivateEvent;
 class PartSelectEvent;
@@ -77,14 +74,6 @@ public:
    */
   virtual ~PartBase();
 
-  /**
-   *  Internal method. Called by KParts::Part to specify the parent object for plugin objects.
-   *
-   * @internal
-   */
-  void setPartObject( QObject *object );
-  QObject *partObject() const;
-
 protected:
   /**
    * Set the componentData(KComponentData) for this part.
@@ -94,90 +83,6 @@ protected:
    */
   virtual void setComponentData(const KComponentData &componentData);
 
-  /**
-   * Set the componentData(KComponentData) for this part.
-   *
-   * Call this *first* in the inherited class constructor,
-   * because it loads the i18n catalogs.
-   *
-   * It is recommended to call setComponentData with loadPlugins set to false,
-   * and to load plugins at the end of your part constructor (in the case of
-   * KParts::MainWindow, plugins are automatically loaded in createGUI anyway,
-   * so set loadPlugins to false for KParts::MainWindow as well).
-   */
-  virtual void setComponentData(const KComponentData &componentData, bool loadPlugins);
-  // TODO KDE5: merge the above two methods, using loadPlugins=true. Or better, remove loadPlugins
-  // altogether and change plugins to call loadPlugins() manually at the end of their ctor.
-    // In the case of KParts MainWindows, plugins are automatically loaded in createGUI anyway,
-    // so setComponentData() should really not load the plugins.
-
-  /**
-   * We have three different policies, whether to load new plugins or not. The
-   * value in the KConfig object of the KComponentData object always overrides
-   * LoadPlugins and LoadPluginsIfEnabled.
-   */
-  enum PluginLoadingMode {
-    /**
-     * Don't load any plugins at all.
-     */
-    DoNotLoadPlugins = 0,
-    /**
-     * Load new plugins automatically. Can be
-     * overridden by the plugin if it sets
-     * EnabledByDefault=false in the corresponding
-     * .desktop file.
-     */
-    LoadPlugins = 1,
-    /**
-     * New plugins are disabled by default. Can be
-     * overridden by the plugin if it sets
-     * EnabledByDefault=true in the corresponding
-     * .desktop file.
-     */
-    LoadPluginsIfEnabled = 2
-  };
-
-  /**
-   * Load the Plugins honoring the PluginLoadingMode.
-   *
-   * If you call this method in an already constructed GUI (like when the user
-   * has changed which plugins are enabled) you need to add the new plugins to
-   * the KXMLGUIFactory:
-   * \code
-   * if( factory() )
-   * {
-   *   QList<KParts::Plugin *> plugins = KParts::Plugin::pluginObjects( this );
-   *   for(int i = 0; i != plugins.size(); ++i) {
-   *      factory()->addClient( plugins[i] );
-   *   }
-   * }
-   * \endcode
-   */
-  void loadPlugins(QObject *parent, KXMLGUIClient *parentGUIClient, const KComponentData &componentData);
-
-  /**
-   * Set how plugins should be loaded
-   * @param loadingMode see PluginLoadingMode
-   *
-   * For a KParts::Part: call this before setComponentData.
-   * For a KParts::MainWindow: call this before createGUI.
-   */
-  void setPluginLoadingMode( PluginLoadingMode loadingMode );
-
-  /**
-   * If you change the binary interface offered by your part, you can avoid crashes
-   * from old plugins lying around by setting X-KDE-InterfaceVersion=2 in the
-   * .desktop files of the plugins, and calling setPluginInterfaceVersion( 2 ), so that
-   * the old plugins are not loaded. Increase both numbers every time a
-   * binary incompatible change in the application's plugin interface is made.
-   *
-   * @param version the interface version that plugins must have in order to be loaded.
-   *
-   * For a KParts::Part: call this before setComponentData.
-   * For a KParts::MainWindow: call this before createGUI.
-   */
-  void setPluginInterfaceVersion( int version );
-
 protected:
   PartBase(PartBasePrivate &dd);
 
@@ -364,15 +269,6 @@ protected:
      */
     QWidget *hostContainer( const QString &containerName );
 
-    /**
-     * Load this part's plugins now.
-     * Normally you want to call this at the end of the part constructor,
-     * if you used setComponentData(componentData, false)
-     * @since 4.1
-     */
-    void loadPlugins();
-    using PartBase::loadPlugins;
-
 protected Q_SLOTS:
     /**
      * @internal
@@ -429,7 +325,7 @@ public:
     void setXOffset(int x);
 
     /**
-     * yOffset is the horizontal scrolling of the part's widget
+     * yOffset is the vertical scrolling of the part's widget
      * (in case it's a scrollview). This is saved into the history
      * and restored when going back in the history.
      */
@@ -520,10 +416,6 @@ public:
      */
     bool isProgressInfoEnabled() const;
 
-#ifndef KDE_NO_COMPAT
-    void showProgressInfo( bool show );
-#endif
-
 public Q_SLOTS:
     /**
      * Only reimplement openUrl if you don't want the network transparency support
@@ -686,20 +578,6 @@ protected:
      */
     virtual void guiActivateEvent( GUIActivateEvent *event );
 
-    /**
-     * @internal
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED bool isLocalFileTemporary() const;
-#endif
-
-    /**
-     * @internal
-     */
-#ifndef KDE_NO_DEPRECATED
-    KDE_DEPRECATED void setLocalFileTemporary( bool temp );
-#endif
-
     /**
      * Sets the url associated with this part.
      */
