@@ -45,8 +45,9 @@ public:
         m_selectedWidget = 0;
         m_bAllowNestedParts = false;
         m_bIgnoreScrollBars = false;
-        m_activationButtonMask = Qt::LeftButton | Qt::MidButton | Qt::RightButton;
+        m_activationButtonMask = Qt::LeftButton | Qt::MiddleButton | Qt::RightButton;
         m_reason = PartManager::NoReason;
+        m_bIgnoreExplicitFocusRequest = false;
     }
     ~PartManagerPrivate()
     {
@@ -58,7 +59,7 @@ public:
             QMouseEvent* mev = static_cast<QMouseEvent *>( ev );
             m_reason = mev->button() == Qt::LeftButton
                        ? PartManager::ReasonLeftClick
-                       : ( mev->button() == Qt::MidButton
+                       : ( mev->button() == Qt::MiddleButton
                            ? PartManager::ReasonMidClick
                            : PartManager::ReasonRightClick );
             break;
@@ -72,6 +73,15 @@ public:
         }
     }
 
+    bool allowExplicitFocusEvent(QEvent* ev) const
+    {
+        if (ev->type() == QEvent::FocusIn) {
+            QFocusEvent* fev = static_cast<QFocusEvent*>(ev);
+            return (!m_bIgnoreExplicitFocusRequest || fev->reason() != Qt::OtherFocusReason);
+        }
+        return true;
+    }
+
     Part * m_activePart;
     QWidget *m_activeWidget;
 
@@ -87,6 +97,7 @@ public:
     bool m_bIgnoreScrollBars;
     bool m_bAllowNestedParts;
     int m_reason;
+    bool m_bIgnoreExplicitFocusRequest;
 };
 
 }
@@ -117,8 +128,8 @@ PartManager::~PartManager()
 {
     foreach( const QWidget* w, d->m_managedTopLevelWidgets )
     {
-        disconnect( w, SIGNAL( destroyed() ),
-                    this, SLOT( slotManagedTopLevelWidgetDestroyed() ) );
+        disconnect( w, SIGNAL(destroyed()),
+                    this, SLOT(slotManagedTopLevelWidgetDestroyed()) );
     }
 
     foreach( Part* it, d->m_parts )
@@ -204,7 +215,7 @@ bool PartManager::eventFilter( QObject *obj, QEvent *ev )
     {
         QPoint pos;
 
-        if ( !d->m_managedTopLevelWidgets.contains( w->topLevelWidget() ) )
+        if ( !d->m_managedTopLevelWidgets.contains( w->window() ) )
             return false;
 
         if ( d->m_bIgnoreScrollBars && ::qobject_cast<QScrollBar *>(w) )
@@ -247,7 +258,7 @@ bool PartManager::eventFilter( QObject *obj, QEvent *ev )
                         setSelectedPart( part, w );
                     else {
 #ifdef DEBUG_PARTMANAGER
-                        kDebug(1000) << "Part " << part << " (non-selectable) made active because " << w->className() << " got event" << " " << evType;
+                        kDebug(1000) << "Part " << part << " (non-selectable) made active because " << w->metaObject()->className() << " got event" << " " << evType;
 #endif
                         d->setReason( ev );
                         setActivePart( part, w );
@@ -258,7 +269,7 @@ bool PartManager::eventFilter( QObject *obj, QEvent *ev )
                 else if ( d->m_selectedWidget == w && d->m_selectedPart == part )
                 {
 #ifdef DEBUG_PARTMANAGER
-                    kDebug(1000) << "Part " << part << " made active (from selected) because " << w->className() << " got event" << " " << evType;
+                    kDebug(1000) << "Part " << part << " made active (from selected) because " << w->metaObject()->className() << " got event" << " " << evType;
 #endif
                     d->setReason( ev );
                     setActivePart( part, w );
@@ -273,10 +284,10 @@ bool PartManager::eventFilter( QObject *obj, QEvent *ev )
 
                 return false;
             }
-            else if ( part != d->m_activePart )
+            else if ( part != d->m_activePart && d->allowExplicitFocusEvent(ev) )
             {
 #ifdef DEBUG_PARTMANAGER
-                kDebug(1000) << "Part " << part << " made active because " << w->className() << " got event" << " " << evType;
+                kDebug(1000) << "Part " << part << " made active because " << w->metaObject()->className() << " got event" << " " << evType;
 #endif
                 d->setReason( ev );
                 setActivePart( part, w );
@@ -292,7 +303,7 @@ bool PartManager::eventFilter( QObject *obj, QEvent *ev )
                     ( w->windowFlags() & Qt::Popup ) || ( w->windowFlags() & Qt::Tool ) ) )
         {
 #ifdef DEBUG_PARTMANAGER
-            kDebug(1000) << QString("No part made active although %1/%2 got event - loop aborted").arg(obj->name()).arg(obj->className());
+            kDebug(1000) << QString("No part made active although %1/%2 got event - loop aborted").arg(obj->objectName()).arg(obj->metaObject()->className());
 #endif
             return false;
         }
@@ -300,7 +311,7 @@ bool PartManager::eventFilter( QObject *obj, QEvent *ev )
     }
 
 #ifdef DEBUG_PARTMANAGER
-    kDebug(1000) << QString("No part made active although %1/%2 got event").arg(obj->name()).arg(obj->className());
+    kDebug(1000) << QString("No part made active although %1/%2 got event").arg(obj->objectName()).arg(obj->metaObject()->className());
 #endif
     return false;
 }
@@ -350,12 +361,12 @@ void PartManager::addPart( Part *part, bool setActive )
             if ( w->focusPolicy() == Qt::NoFocus ) {
                 kWarning(1000) << "Part '" << part->objectName() << "' has a widget "
                                << w->objectName() << " with a focus policy of NoFocus. It should have at least a"
-                               << "ClickFocus policy, for part activation to work well." << endl;
+                               << "ClickFocus policy, for part activation to work well.";
             }
             if ( part->widget() && part->widget()->focusPolicy() == Qt::TabFocus ) {
                 kWarning(1000) << "Part '" << part->objectName() << "' has a widget "
                                << w->objectName() << " with a focus policy of TabFocus. It should have at least a"
-                               << "ClickFocus policy, for part activation to work well." << endl;
+                               << "ClickFocus policy, for part activation to work well.";
             }
             w->setFocus();
             w->show();
@@ -366,18 +377,13 @@ void PartManager::addPart( Part *part, bool setActive )
 
 void PartManager::removePart( Part *part )
 {
-    if ( !d->m_parts.contains( part ) )
-    {
-        kFatal(1000) << QString("Can't remove part %1, not in KPartManager's list.").arg(part->objectName());
+    if (!d->m_parts.contains(part)) {
         return;
     }
 
-    //Warning. The part could be already deleted
-    //kDebug(1000) << QString("Part %1 removed").arg(part->name());
-    int nb = d->m_parts.count();
-    bool ok = d->m_parts.removeAll( part );
-    Q_ASSERT( ok );
-    Q_ASSERT( (int)d->m_parts.count() == nb-1 );
+    const int nb = d->m_parts.removeAll(part);
+    Q_ASSERT(nb == 1);
+    Q_UNUSED(nb); // no warning in release mode
     part->setManager(0);
 
     emit partRemoved( part );
@@ -429,7 +435,7 @@ void PartManager::setActivePart( Part *part, QWidget *widget )
 
 #ifdef DEBUG_PARTMANAGER
     kDebug(1000) << "PartManager::setActivePart d->m_activePart=" << d->m_activePart << "<->part=" << part
-                 << " d->m_activeWidget=" << d->m_activeWidget << "<->widget=" << widget << endl;
+                 << " d->m_activeWidget=" << d->m_activeWidget << "<->widget=" << widget;
 #endif
 
     // don't activate twice
@@ -454,8 +460,8 @@ void PartManager::setActivePart( Part *part, QWidget *widget )
         QApplication::sendEvent( oldActivePart, &ev );
         if ( oldActiveWidget )
         {
-            disconnect( oldActiveWidget, SIGNAL( destroyed() ),
-                        this, SLOT( slotWidgetDestroyed() ) );
+            disconnect( oldActiveWidget, SIGNAL(destroyed()),
+                        this, SLOT(slotWidgetDestroyed()) );
             QApplication::sendEvent( oldActiveWidget, &ev );
         }
 
@@ -472,8 +478,8 @@ void PartManager::setActivePart( Part *part, QWidget *widget )
         QApplication::sendEvent( d->m_activePart, &ev );
         if ( d->m_activeWidget )
         {
-            connect( d->m_activeWidget, SIGNAL( destroyed() ),
-                     this, SLOT( slotWidgetDestroyed() ) );
+            connect( d->m_activeWidget, SIGNAL(destroyed()),
+                     this, SLOT(slotWidgetDestroyed()) );
             QApplication::sendEvent( d->m_activeWidget, &ev );
         }
     }
@@ -569,8 +575,8 @@ void PartManager::addManagedTopLevelWidget( const QWidget *topLevel )
         return;
 
     d->m_managedTopLevelWidgets.append( topLevel );
-    connect( topLevel, SIGNAL( destroyed() ),
-             this, SLOT( slotManagedTopLevelWidgetDestroyed() ) );
+    connect( topLevel, SIGNAL(destroyed()),
+             this, SLOT(slotManagedTopLevelWidgetDestroyed()) );
 }
 
 void PartManager::removeManagedTopLevelWidget( const QWidget *topLevel )
@@ -592,4 +598,9 @@ int PartManager::reason() const
     return d->m_reason;
 }
 
-#include "partmanager.moc"
+void PartManager::setIgnoreExplictFocusRequests(bool ignore)
+{
+    d->m_bIgnoreExplicitFocusRequest = ignore;
+}
+
+#include "moc_partmanager.cpp"
