@@ -173,4 +173,4 @@ int main( int argc, char **argv )
     return 0;
 }
 
-#include "testmainwindow.moc"
+#include "moc_testmainwindow.cpp"
