@@ -26,7 +26,7 @@
 #include <QtGui/QBoxLayout>
 #include <QtGui/QApplication>
 #include <QtGui/QCheckBox>
-#include <QtGui/QStyleOptionViewItemV4>
+#include <QtGui/qstyleoption.h>
 
 #include <kdebug.h>
 #include <klineedit.h>
@@ -71,7 +71,7 @@ void KPluginSelector::Private::updateDependencies(PluginEntry *pluginEntry, bool
         }
 
         for (int i = 0; i < pluginModel->rowCount(); i++) {
-            QModelIndex index = pluginModel->index(i, 0);
+            const QModelIndex index = pluginModel->index(i, 0);
             PluginEntry *pe = static_cast<PluginEntry*>(index.internalPointer());
 
             if ((pe->pluginInfo.pluginName() != pluginEntry->pluginInfo.pluginName()) &&
@@ -83,7 +83,7 @@ void KPluginSelector::Private::updateDependencies(PluginEntry *pluginEntry, bool
         }
     } else {
         for (int i = 0; i < pluginModel->rowCount(); i++) {
-            QModelIndex index = pluginModel->index(i, 0);
+            const QModelIndex index = pluginModel->index(i, 0);
             PluginEntry *pe = static_cast<PluginEntry*>(index.internalPointer());
 
             if ((pe->pluginInfo.pluginName() != pluginEntry->pluginInfo.pluginName()) &&
@@ -256,6 +256,8 @@ KPluginSelector::KPluginSelector(QWidget *parent)
     d->lineEdit->setClearButtonShown(true);
     d->lineEdit->setClickMessage(i18n("Search Plugins"));
     d->listView = new KCategorizedView(this);
+    d->listView->setVerticalScrollMode(QListView::ScrollPerPixel);
+    d->listView->setAlternatingRowColors(true);
     d->listView->setCategoryDrawer(d->categoryDrawer);
     d->dependenciesWidget = new Private::DependenciesWidget(this);
 
@@ -283,6 +285,7 @@ KPluginSelector::KPluginSelector(QWidget *parent)
 
 KPluginSelector::~KPluginSelector()
 {
+    delete d->listView->itemDelegate();
     delete d->listView; // depends on some other things in d, make sure this dies first.
     delete d;
 }
@@ -308,6 +311,7 @@ void KPluginSelector::addPlugins(const QString &componentName,
     kDebug( 702 ) << "cfgGroup = " << &cfgGroup;
 
     d->pluginModel->addPlugins(pluginInfoList, categoryName, categoryKey, cfgGroup);
+    d->proxyModel->sort(0);
 }
 
 void KPluginSelector::addPlugins(const KComponentData &instance,
@@ -331,12 +335,13 @@ void KPluginSelector::addPlugins(const QList<KPluginInfo> &pluginInfoList,
     kDebug( 702 ) << "cfgGroup = " << &cfgGroup;
 
     d->pluginModel->addPlugins(pluginInfoList, categoryName, categoryKey, cfgGroup, pluginLoadMethod, true /* manually added */);
+    d->proxyModel->sort(0);
 }
 
 void KPluginSelector::load()
 {
     for (int i = 0; i < d->pluginModel->rowCount(); i++) {
-        QModelIndex index = d->pluginModel->index(i, 0);
+        const QModelIndex index = d->pluginModel->index(i, 0);
         PluginEntry *pluginEntry = static_cast<PluginEntry*>(index.internalPointer());
         pluginEntry->pluginInfo.load(pluginEntry->cfgGroup);
         d->pluginModel->setData(index, pluginEntry->pluginInfo.isPluginEnabled(), Qt::CheckStateRole);
@@ -348,7 +353,7 @@ void KPluginSelector::load()
 void KPluginSelector::save()
 {
     for (int i = 0; i < d->pluginModel->rowCount(); i++) {
-        QModelIndex index = d->pluginModel->index(i, 0);
+        const QModelIndex index = d->pluginModel->index(i, 0);
         PluginEntry *pluginEntry = static_cast<PluginEntry*>(index.internalPointer());
         pluginEntry->pluginInfo.setPluginEnabled(pluginEntry->checked);
         pluginEntry->pluginInfo.save(pluginEntry->cfgGroup);
@@ -361,7 +366,7 @@ void KPluginSelector::save()
 void KPluginSelector::defaults()
 {
     for (int i = 0; i < d->pluginModel->rowCount(); i++) {
-        QModelIndex index = d->pluginModel->index(i, 0);
+        const QModelIndex index = d->pluginModel->index(i, 0);
         PluginEntry *pluginEntry = static_cast<PluginEntry*>(index.internalPointer());
         d->pluginModel->setData(index, pluginEntry->pluginInfo.isPluginEnabledByDefault(), Qt::CheckStateRole);
     }
@@ -369,10 +374,23 @@ void KPluginSelector::defaults()
     emit changed(true);
 }
 
+bool KPluginSelector::isDefault() const
+{
+    for (int i = 0; i < d->pluginModel->rowCount(); i++) {
+        const QModelIndex index = d->pluginModel->index(i, 0);
+        PluginEntry *pluginEntry = static_cast<PluginEntry*>(index.internalPointer());
+        if (d->pluginModel->data(index, Qt::CheckStateRole).toBool() != pluginEntry->pluginInfo.isPluginEnabledByDefault()) {
+            return false;
+        }
+    }
+
+    return true;
+}
+
 void KPluginSelector::updatePluginsState()
 {
     for (int i = 0; i < d->pluginModel->rowCount(); i++) {
-        QModelIndex index = d->pluginModel->index(i, 0);
+        const QModelIndex index = d->pluginModel->index(i, 0);
         PluginEntry *pluginEntry = static_cast<PluginEntry*>(index.internalPointer());
         if (pluginEntry->manuallyAdded) {
             pluginEntry->pluginInfo.setPluginEnabled(pluginEntry->checked);
@@ -621,8 +639,6 @@ void KPluginSelector::Private::PluginDelegate::paint(QPainter *painter, const QS
 
     painter->restore();
     painter->restore();
-
-    KWidgetItemDelegate::paintWidgets(painter, option, index);
 }
 
 QSize KPluginSelector::Private::PluginDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -643,7 +659,7 @@ QSize KPluginSelector::Private::PluginDelegate::sizeHint(const QStyleOptionViewI
 
     return QSize(qMax(fmTitle.width(index.model()->data(index, Qt::DisplayRole).toString()),
                       option.fontMetrics.width(index.model()->data(index, CommentRole).toString())) +
-                      pluginSelector_d->showIcons ? KIconLoader::SizeMedium : 0 + MARGIN * i + pushButton->sizeHint().width() * j,
+                      (pluginSelector_d->showIcons ? KIconLoader::SizeMedium : 0) + MARGIN * i + pushButton->sizeHint().width() * j,
                  qMax(KIconLoader::SizeMedium + MARGIN * 2, fmTitle.height() + option.fontMetrics.height() + MARGIN * 2));
 }
 
@@ -664,13 +680,16 @@ QList<QWidget*> KPluginSelector::Private::PluginDelegate::createItemWidgets() co
     connect(configurePushButton, SIGNAL(clicked(bool)), this, SLOT(slotConfigureClicked()));
 
     setBlockedEventTypes(enabledCheckBox, QList<QEvent::Type>() << QEvent::MouseButtonPress
-                            << QEvent::MouseButtonRelease << QEvent::MouseButtonDblClick);
+                            << QEvent::MouseButtonRelease << QEvent::MouseButtonDblClick
+                            << QEvent::KeyPress << QEvent::KeyRelease);
 
     setBlockedEventTypes(aboutPushButton, QList<QEvent::Type>() << QEvent::MouseButtonPress
-                            << QEvent::MouseButtonRelease << QEvent::MouseButtonDblClick);
-
+                            << QEvent::MouseButtonRelease << QEvent::MouseButtonDblClick
+                            << QEvent::KeyPress << QEvent::KeyRelease);
+                            
     setBlockedEventTypes(configurePushButton, QList<QEvent::Type>() << QEvent::MouseButtonPress
-                            << QEvent::MouseButtonRelease << QEvent::MouseButtonDblClick);
+                            << QEvent::MouseButtonRelease << QEvent::MouseButtonDblClick
+                            << QEvent::KeyPress << QEvent::KeyRelease);
 
     widgetList << enabledCheckBox << configurePushButton << aboutPushButton;
 
@@ -745,6 +764,7 @@ void KPluginSelector::Private::PluginDelegate::slotAboutClicked()
             const KAboutData *aboutData = factory->componentData().aboutData();
             if (!aboutData->programName().isEmpty()) { // Be sure the about data is not completely empty
                 KAboutApplicationDialog aboutPlugin(aboutData, itemView());
+                aboutPlugin.setWindowTitle(i18nc("Used only for plugins", "About %1", aboutData->programName()));
                 aboutPlugin.exec();
                 return;
             }
@@ -763,8 +783,8 @@ void KPluginSelector::Private::PluginDelegate::slotAboutClicked()
     aboutData.setProgramIconName(index.model()->data(index, Qt::DecorationRole).toString());
     const QStringList authors = author.split(',');
     const QStringList emails = email.split(',');
-    int i = 0;
     if (authors.count() == emails.count()) {
+	int i = 0;
         foreach (const QString &author, authors) {
             if (!author.isEmpty()) {
                 aboutData.addAuthor(ki18n(author.toUtf8()), ki18n(QByteArray()), emails[i].toUtf8(), 0);
@@ -773,6 +793,7 @@ void KPluginSelector::Private::PluginDelegate::slotAboutClicked()
         }
     }
     KAboutApplicationDialog aboutPlugin(&aboutData, itemView());
+    aboutPlugin.setWindowTitle(i18nc("Used only for plugins", "About %1", aboutData.programName()));
     aboutPlugin.exec();
 }
 
@@ -878,5 +899,5 @@ QFont KPluginSelector::Private::PluginDelegate::titleFont(const QFont &baseFont)
     return retFont;
 }
 
-#include "kpluginselector_p.moc"
-#include "kpluginselector.moc"
+#include "moc_kpluginselector_p.cpp"
+#include "moc_kpluginselector.cpp"
