@@ -161,7 +161,7 @@ QSet<KCModuleInfo> DialogPrivate::instanceServices()
 			}
 			else
 				kWarning( 700 ) << "KServiceGroup::childGroup returned"
-					" something else than a KService" << endl;
+					" something else than a KService";
 		}
 	}
 
@@ -370,8 +370,7 @@ void DialogPrivate::createDialogFromServices()
                         if (plugin != pinfo) {
                             kError(700) << "A group contains more than one plugin: '"
                                 << plugin.pluginName() << "' and '" << pinfo.pluginName()
-                                << "'. Now it won't be possible to enable/disable the plugin."
-                                << endl;
+                                << "'. Now it won't be possible to enable/disable the plugin.";
                             parent->setCheckable(false);
                             q->disconnect(parent, SIGNAL(toggled(bool)), q, SLOT(_k_updateEnabledState(bool)));
                         }
@@ -558,6 +557,6 @@ void DialogPrivate::_k_updateEnabledState(bool enabled)
 
 } //namespace
 
-#include "dialog.moc"
+#include "moc_dialog.cpp"
 
 // vim: ts=4
