@@ -52,4 +52,4 @@ void AbstractDialogManager::showDialog(QWidget *widget, Plasma::Applet *applet)
 
 }
 
-#include "abstractdialogmanager.moc"
+#include "moc_abstractdialogmanager.cpp"
