@@ -24,8 +24,8 @@
 #include <QMenu>
 #include <QMimeData>
 #include <QMutex>
-#include <QMutexLocker>
 #include <QTimer>
+#include <QDateTime>
 
 #include <kdebug.h>
 #include <kicon.h>
@@ -33,25 +33,16 @@
 #include <kservicetypetrader.h>
 #include <kstandarddirs.h>
 
-#include <plasma/package.h>
 #include <plasma/querymatch.h>
 
 #include "private/abstractrunner_p.h"
 #include "runnercontext.h"
-#include "scripting/runnerscript.h"
 
 namespace Plasma
 {
 
 K_GLOBAL_STATIC(QMutex, s_bigLock)
 
-AbstractRunner::AbstractRunner(QObject *parent, const QString &path)
-    : QObject(parent),
-      d(new AbstractRunnerPrivate(this))
-{
-    d->init(path);
-}
-
 AbstractRunner::AbstractRunner(const KService::Ptr service, QObject *parent)
     : QObject(parent),
       d(new AbstractRunnerPrivate(this))
@@ -78,7 +69,7 @@ AbstractRunner::~AbstractRunner()
 
 KConfigGroup AbstractRunner::config() const
 {
-    QString group = objectName();
+    QString group = id();
     if (group.isEmpty()) {
         group = "UnnamedRunner";
     }
@@ -89,9 +80,6 @@ KConfigGroup AbstractRunner::config() const
 
 void AbstractRunner::reloadConfiguration()
 {
-    if (d->script) {
-        emit d->script->reloadConfiguration();
-    }
 }
 
 void AbstractRunner::addSyntax(const RunnerSyntax &syntax)
@@ -125,6 +113,10 @@ void AbstractRunner::performMatch(Plasma::RunnerContext &localContext)
     static const int reasonableRunTime = 1500;
     static const int fastEnoughTime = 250;
 
+    if (d->suspendMatching) {
+        return;
+    }
+
     QTime time;
     time.restart();
 
@@ -159,9 +151,6 @@ QList<QAction*> AbstractRunner::actionsForMatch(const Plasma::QueryMatch &match)
 {
     Q_UNUSED(match)
     QList<QAction*> ret;
-    if (d->script) {
-        emit d->script->actionsForMatch(match, &ret);
-    }
     return ret;
 }
 
@@ -217,30 +206,18 @@ void AbstractRunner::setHasRunOptions(bool hasRunOptions)
 
 void AbstractRunner::createRunOptions(QWidget *parent)
 {
-    if (d->script) {
-        emit d->script->createRunOptions(parent);
-    }
+    Q_UNUSED(parent)
 }
 
 AbstractRunner::Speed AbstractRunner::speed() const
 {
-    // the only time the read lock will fail is if we were slow are going to speed up
-    // or if we were fast and are going to slow down; so don't wait in this case, just
-    // say we're slow. we either will be soon or were just a moment ago and it doesn't
-    // hurt to do one more run the slow way
-    if (!d->speedLock.tryLockForRead()) {
-        return SlowSpeed;
-    }
-    Speed s = d->speed;
-    d->speedLock.unlock();
-    return s;
+    return d->speed;
 }
 
 void AbstractRunner::setSpeed(Speed speed)
 {
-    d->speedLock.lockForWrite();
+    QMutexLocker locker(&d->speedMutex);
     d->speed = speed;
-    d->speedLock.unlock();
 }
 
 AbstractRunner::Priority AbstractRunner::priority() const
@@ -275,16 +252,13 @@ QMutex* AbstractRunner::bigLock()
 
 void AbstractRunner::run(const Plasma::RunnerContext &search, const Plasma::QueryMatch &action)
 {
-    if (d->script) {
-        return d->script->run(search, action);
-    }
+    Q_UNUSED(search)
+    Q_UNUSED(action)
 }
 
 void AbstractRunner::match(Plasma::RunnerContext &search)
 {
-    if (d->script) {
-        return d->script->match(search);
-    }
+    Q_UNUSED(search)
 }
 
 QString AbstractRunner::name() const
@@ -293,10 +267,6 @@ QString AbstractRunner::name() const
         return d->runnerDescription.name();
     }
 
-    if (d->package) {
-        return d->package->metadata().name();
-    }
-
     return objectName();
 }
 
@@ -306,10 +276,6 @@ QIcon AbstractRunner::icon() const
         return KIcon(d->runnerDescription.icon());
     }
 
-    if (d->package) {
-        return KIcon(d->package->metadata().icon());
-    }
-
     return QIcon();
 }
 
@@ -319,10 +285,6 @@ QString AbstractRunner::id() const
         return d->runnerDescription.pluginName();
     }
 
-    if (d->package) {
-        return d->package->metadata().pluginName();
-    }
-
     return objectName();
 }
 
@@ -332,25 +294,12 @@ QString AbstractRunner::description() const
         return d->runnerDescription.property("Comment").toString();
     }
 
-    if (d->package) {
-        return d->package->metadata().description();
-    }
-
     return objectName();
 }
 
-const Package* AbstractRunner::package() const
-{
-    return d->package;
-}
-
-
 void AbstractRunner::init()
 {
-    if (d->script) {
-        d->setupScriptSupport();
-        d->script->init();
-    }
+    reloadConfiguration();
 }
 
 DataEngine *AbstractRunner::dataEngine(const QString &name) const
@@ -358,100 +307,42 @@ DataEngine *AbstractRunner::dataEngine(const QString &name) const
     return d->dataEngine(name);
 }
 
+bool AbstractRunner::isMatchingSuspended() const
+{
+    return d->suspendMatching;
+}
+
+void AbstractRunner::suspendMatching(bool suspend)
+{
+    if (d->suspendMatching == suspend) {
+        return;
+    }
+
+    d->suspendMatching = suspend;
+    emit matchingSuspended(suspend);
+}
+
 AbstractRunnerPrivate::AbstractRunnerPrivate(AbstractRunner *r)
     : priority(AbstractRunner::NormalPriority),
       speed(AbstractRunner::NormalSpeed),
       blackListed(0),
-      script(0),
       runner(r),
       fastRuns(0),
-      package(0),
+      defaultSyntax(0),
       hasRunOptions(false),
-      defaultSyntax(0)
+      suspendMatching(false)
 {
 }
 
 AbstractRunnerPrivate::~AbstractRunnerPrivate()
 {
-    delete script;
-    script = 0;
-    delete package;
-    package = 0;
 }
 
 void AbstractRunnerPrivate::init(const KService::Ptr service)
 {
     runnerDescription = KPluginInfo(service);
-    if (runnerDescription.isValid()) {
-        const QString api = runnerDescription.property("X-Plasma-API").toString();
-        if (!api.isEmpty()) {
-            const QString path = KStandardDirs::locate("data", "plasma/runners/" + runnerDescription.pluginName() + '/');
-            prepScripting(path, api);
-            if (!script) {
-                kDebug() << "Could not create a(n)" << api << "ScriptEngine for the" << runnerDescription.name() << "Runner.";
-            }
-        }
-    }
-}
-
-void AbstractRunnerPrivate::init(const QString &path)
-{
-    prepScripting(path);
-}
-
-void AbstractRunnerPrivate::prepScripting(const QString &path, QString api)
-{
-    if (script) {
-        return;
-    }
-
-    if (package) {
-        delete package;
-    }
-
-    PackageStructure::Ptr structure = Plasma::packageStructure(api, Plasma::RunnerComponent);
-    structure->setPath(path);
-    package = new Package(path, structure);
-
-    if (!package->isValid()) {
-        kDebug() << "Invalid Runner package at" << path;
-        delete package;
-        package = 0;
-        return;
-    }
-
-    if (api.isEmpty()) {
-        api = package->metadata().implementationApi();
-    }
-
-    script = Plasma::loadScriptEngine(api, runner);
-    if (!script) {
-        delete package;
-        package = 0;
-    }
-}
-
-// put all setup routines for script here. at this point we can assume that
-// package exists and that we have a script engine
-void AbstractRunnerPrivate::setupScriptSupport()
-{
-    if (!package) {
-        return;
-    }
-
-    kDebug() << "setting up script support, package is in" << package->path()
-             << "which is a" << package->structure()->type() << "package"
-             << ", main script is" << package->filePath("mainscript");
-
-    QString translationsPath = package->filePath("translations");
-    if (!translationsPath.isEmpty()) {
-        //FIXME: we should _probably_ use a KComponentData to segregate the applets
-        //       from each other; but I want to get the basics working first :)
-        KGlobal::dirs()->addResourceDir("locale", translationsPath);
-        KGlobal::locale()->insertCatalog(package->metadata().pluginName());
-    }
 }
 
 } // Plasma namespace
 
-#include "abstractrunner.moc"
+#include "moc_abstractrunner.cpp"
