@@ -9,7 +9,7 @@
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
+ *   GNU Library General Public License for more details
  *
  *   You should have received a copy of the GNU Library General Public
  *   License along with this program; if not, write to the
@@ -26,15 +26,15 @@
 
 #include <kconfiggroup.h>
 #include <kservice.h>
+#include <kdeversion.h>
 
 #include <plasma/plasma_export.h>
 #include <plasma/querymatch.h>
 #include <plasma/runnercontext.h>
 #include <plasma/runnersyntax.h>
-#include <plasma/version.h>
 
-class QAction;
-class QMimeData;
+#include <QAction>
+#include <QMimeData>
 
 class KCompletion;
 
@@ -42,8 +42,6 @@ namespace Plasma
 {
 
 class DataEngine;
-class Package;
-class RunnerScript;
 class QueryMatch;
 class AbstractRunnerPrivate;
 
@@ -63,7 +61,11 @@ class AbstractRunnerPrivate;
 class PLASMA_EXPORT AbstractRunner : public QObject
 {
     Q_OBJECT
-
+    Q_PROPERTY(bool matchingSuspended READ isMatchingSuspended WRITE suspendMatching NOTIFY matchingSuspended)
+    Q_PROPERTY(QString id READ id)
+    Q_PROPERTY(QString description READ description)
+    Q_PROPERTY(QString name READ name)
+    Q_PROPERTY(QIcon icon READ icon)
     public:
         /** Specifies a nominal speed for the runner */
         enum Speed {
@@ -100,7 +102,7 @@ class PLASMA_EXPORT AbstractRunner : public QObject
          *
          * Each runner is executed in its own thread. Whenever the user input changes this
          * method is called again. Thus, it needs to be thread-safe. Also, all matches need
-         * to be reported once this method returns. Asyncroneous runners therefore need
+         * to be reported once this method returns. Asynchronous runners therefore need
          * to make use of a local event loop to wait for all matches.
          *
          * It is recommended to use local status data in async runners. The simplest way is
@@ -140,7 +142,7 @@ class PLASMA_EXPORT AbstractRunner : public QObject
         /**
          * Triggers a call to match. This will call match() internally.
          *
-         * @arg context the search context used in executing this match.
+         * @param context the search context used in executing this match.
          */
         void performMatch(Plasma::RunnerContext &context);
 
@@ -215,16 +217,6 @@ class PLASMA_EXPORT AbstractRunner : public QObject
          */
         QIcon icon() const;
 
-        /**
-         * Accessor for the associated Package object if any.
-         *
-         * Note that the returned pointer is only valid for the lifetime of
-         * the runner.
-         *
-         * @return the Package object, or 0 if none
-         **/
-        const Package *package() const;
-
         /**
          * Signal runner to reload its configuration.
          */
@@ -257,6 +249,13 @@ class PLASMA_EXPORT AbstractRunner : public QObject
          */
         RunnerSyntax *defaultSyntax() const;
 
+        /**
+         * @return true if the runner is currently busy with non-interuptable work, signaling that
+         * new threads should not be created for it at this time
+         * @since 4.6
+         */
+        bool isMatchingSuspended() const;
+
     Q_SIGNALS:
         /**
          * This signal is emitted when matching is about to commence, giving runners
@@ -277,15 +276,27 @@ class PLASMA_EXPORT AbstractRunner : public QObject
          */
         void teardown();
 
+        /**
+         * Emitted when the runner enters or exits match suspension
+         * @see matchingSuspended
+         * @since 4.6
+         */
+        void matchingSuspended(bool suspended);
+
     protected:
         friend class RunnerManager;
         friend class RunnerManagerPrivate;
 
-        explicit AbstractRunner(QObject *parent = 0, const QString &path = QString());
         explicit AbstractRunner(const KService::Ptr service, QObject *parent = 0);
 
         AbstractRunner(QObject *parent, const QVariantList &args);
 
+        /**
+         * Sets whether or not the runner is available for match requests. Useful to
+         * prevent more thread spawning when the thread is in a busy state.
+         */
+        void suspendMatching(bool suspend);
+
         /**
          * Provides access to the runner's configuration object.
          */
@@ -316,8 +327,8 @@ class PLASMA_EXPORT AbstractRunner : public QObject
          * a measure of safety for runners running their own threads. This should
          * be used instead of calling KServiceTypeTrader::query(..) directly.
          *
-         * @arg serviceType a service type like "Plasma/Applet" or "KFilePlugin"
-         * @arg constraint a constraint to limit the choices returned.
+         * @param serviceType a service type like "Plasma/Applet"
+         * @param constraint a constraint to limit the choices returned.
          * @see KServiceTypeTrader::query(const QString&, const QString&)
          *
          * @return a list of services that satisfy the query.
@@ -439,6 +450,11 @@ class PLASMA_EXPORT AbstractRunner : public QObject
         Q_INVOKABLE DataEngine *dataEngine(const QString &name) const;
 
     protected Q_SLOTS:
+        /**
+         * Reimplement this slot to run any initialization routines on first load.
+         * By default, it calls reloadConfiguration(); for scripted Runners this
+         * method also sets up the ScriptEngine.
+         */
         void init();
 
         /**
@@ -449,17 +465,14 @@ class PLASMA_EXPORT AbstractRunner : public QObject
         QMimeData * mimeDataForMatch(const Plasma::QueryMatch *match);
 
     private:
-        friend class RunnerScript;
-
         AbstractRunnerPrivate *const d;
 };
 
 } // Plasma namespace
 
 #define K_EXPORT_PLASMA_RUNNER( libname, classname )     \
-K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
-K_EXPORT_PLUGIN(factory("plasma_runner_" #libname)) \
-K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+K_PLUGIN_FACTORY(classname ## Factory, registerPlugin<classname>();) \
+K_EXPORT_PLUGIN(classname ## Factory("plasma_runner_" #libname))
 
 /**
  * These plugins are Used by the plugin selector dialog to show
@@ -467,8 +480,7 @@ K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
  * must be runner global and not pertain to a specific match.
  */
 #define K_EXPORT_RUNNER_CONFIG( name, classname )     \
-K_PLUGIN_FACTORY(ConfigFactory, registerPlugin<classname>();) \
-K_EXPORT_PLUGIN(ConfigFactory("kcm_krunner_" #name)) \
-K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+K_PLUGIN_FACTORY(classname ## Factory, registerPlugin<classname>("kcm_krunner_" #name);) \
+K_EXPORT_PLUGIN(classname ## Factory("kcm_krunner_" #name))
 
 #endif
