@@ -16,7 +16,7 @@
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QGraphicsRotation>
+#include <QtGui/qgraphicstransform.h>
 #include <QEasingCurve>
 #include <QVector3D>
 
@@ -88,62 +88,69 @@ void RotationAnimation::updateState(QAbstractAnimation::State newState, QAbstrac
 
     if (axis() == Qt::XAxis) {
         switch (reference()) {
-            case Center:
+            case Center: {
                 vector.setX(widgetWidth/2);
                 vector.setY(widgetHeight/2);
                 break;
-            case Up:
+            }
+            case Up: {
                 vector.setX(widgetWidth/2);
                 vector.setY(0);
                 break;
-            case Down:
+            }
+            case Down: {
                 vector.setX(widgetWidth/2);
                 vector.setY(widgetHeight);
                 break;
+            }
         }
 
     } else if(axis() == Qt::YAxis) {
         switch (reference()) {
-            case Center:
+            case Center: {
                 vector.setX(widgetWidth/2);
                 vector.setY(widgetHeight/2);
                 break;
-            case Left:
+            }
+            case Left: {
                 vector.setX(0);
                 vector.setY(widgetHeight/2);
                 break;
-            case Right:
+            }
+            case Right: {
                 vector.setX(widgetWidth);
                 vector.setY(widgetHeight/2);
                 break;
+            }
         }
 
     } else if (axis() == Qt::ZAxis) {
         switch (reference()) {
-            case Center:
+            case Center: {
                 vector.setX(widgetWidth/2);
                 vector.setY(widgetHeight/2);
                 break;
-
-            case Center|Up:
+            }
+            case Center|Up: {
                 vector.setX(widgetWidth/2);
                 vector.setY(0);
                 break;
-
-            case Center|Down:
+            }
+            case Center|Down: {
                 vector.setX(widgetWidth/2);
                 vector.setY(widgetHeight);
                 break;
-
-            case Center|Left:
+            }
+            case Center|Left: {
                 vector.setX(0);
                 vector.setY(widgetHeight/2);
                 break;
-
-            case Center|Right:
+            }
+            case Center|Right: {
                 vector.setX(widgetWidth);
                 vector.setY(widgetHeight/2);
                 break;
+            }
         }
     }
 
@@ -165,4 +172,4 @@ void RotationAnimation::updateEffectiveTime(int currentTime)
 
 }
 
-#include "rotation_p.moc"
+#include "moc_rotation_p.cpp"
