@@ -19,7 +19,7 @@
 
 #include "slide_p.h"
 
-#include <QPointF>
+#include <QtCore/qpoint.h>
 #include <kdebug.h>
 
 namespace Plasma
@@ -126,4 +126,4 @@ void SlideAnimation::updateState(QAbstractAnimation::State newState, QAbstractAn
 
 } //namespace Plasma
 
-#include "slide_p.moc"
+#include "moc_slide_p.cpp"
