@@ -27,21 +27,20 @@
 #include <QtGui/QIcon>
 
 #include <kconfiggroup.h>
-#include <kgenericfactory.h>
 #include <kplugininfo.h>
 #include <kshortcut.h>
+#include <kdeversion.h>
 
 #include <plasma/configloader.h>
 #include <plasma/packagestructure.h>
 #include <plasma/plasma.h>
 #include <plasma/animator.h>
-#include <plasma/version.h>
 #include <plasma/framesvg.h>
 
-class QWidget;
+#include <QWidget>
 
 class KConfigDialog;
-class QGraphicsView;
+#include <QGraphicsView>
 class KActionCollection;
 
 namespace Plasma
@@ -270,11 +269,6 @@ class PLASMA_EXPORT Applet : public QGraphicsWidget
          */
         virtual Location location() const;
 
-        /**
-         * Returns the workspace context which the applet is operating in
-         */
-        Context *context() const;
-
         /**
          * @return the preferred aspect ratio mode for placement and resizing
          */
@@ -334,20 +328,6 @@ class PLASMA_EXPORT Applet : public QGraphicsWidget
         static QStringList listCategories(const QString &parentApp = QString(),
                                           bool visibleOnly = true);
 
-        /**
-         * Sets the list of custom categories that are used in addition to the default
-         * set of categories known to libplasma for Applets.
-         * @param categories a list of categories
-         * @since 4.3
-         */
-        void setCustomCategories(const QStringList &categories);
-
-        /**
-         * @return the list of custom categories known to libplasma
-         * @since 4.3
-         */
-        QStringList customCategories();
-
         /**
          * Attempts to load an applet from a package
          *
@@ -726,17 +706,6 @@ class PLASMA_EXPORT Applet : public QGraphicsWidget
          */
         void releaseVisualFocus();
 
-#if QT_VERSION >= 0x040700
-    protected:
-        void geometryChanged(); // in QGraphicsWidget now; preserve BC
-#else
-        /**
-         * Emitted whenever the applet makes a geometry change, so that views
-         * can coordinate themselves with these changes if they desire.
-         */
-        void geometryChanged();
-#endif
-
     Q_SIGNALS:
         /**
          * Emitted when the user completes a transformation of the applet.
@@ -902,18 +871,6 @@ class PLASMA_EXPORT Applet : public QGraphicsWidget
          */
         void setStatus(const ItemStatus stat);
 
-        /**
-         * Publishes and optionally announces this applet on the network for remote access.
-         * @param methods the methods to use for announcing this applet.
-         * @param resourceName the name under which this applet will be published (has to be unique
-         * for each machine)
-         */
-        void publish(Plasma::AnnouncementMethods methods, const QString &resourceName);
-
-        void unpublish();
-
-        bool isPublished() const;
-
         /**
          * Open the application associated to this applet, if it's not set
          * but some urls are, open those urls with the proper application
@@ -1091,20 +1048,10 @@ class PLASMA_EXPORT Applet : public QGraphicsWidget
          */
         QSizeF sizeHint(Qt::SizeHint which, const QSizeF & constraint = QSizeF()) const;
 
-        /**
-         * Reimplemented from QGraphicsLayoutItem
-         */
-        void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
-
-        /**
-         * Reimplemented from QGraphicsLayoutItem
-         */
-        void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
-
         /**
          * Reimplemented from QObject
          */
-        void timerEvent (QTimerEvent *event);
+        void timerEvent(QTimerEvent *event);
 
 
     private:
@@ -1126,7 +1073,6 @@ class PLASMA_EXPORT Applet : public QGraphicsWidget
         Q_PRIVATE_SLOT(d, void destroyMessageOverlay())
         Q_PRIVATE_SLOT(d, void configDialogFinished())
         Q_PRIVATE_SLOT(d, void updateShortcuts())
-        Q_PRIVATE_SLOT(d, void publishCheckboxStateChanged(int state))
         Q_PRIVATE_SLOT(d, void globalShortcutChanged())
         Q_PRIVATE_SLOT(d, void propagateConfigChanged())
         Q_PRIVATE_SLOT(d, void handleDisappeared(AppletHandle *handle))
@@ -1168,7 +1114,6 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(Plasma::Applet::BackgroundHints)
  */
 #define K_EXPORT_PLASMA_APPLET(libname, classname) \
 K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
-K_EXPORT_PLUGIN(factory("plasma_applet_" #libname)) \
-K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+K_EXPORT_PLUGIN(factory("plasma_applet_" #libname))
 
 #endif // multiple inclusion guard
