@@ -23,9 +23,9 @@
 #include <QColor>
 #include <QFont>
 #include <QHash>
-#include <QXmlContentHandler>
-#include <QXmlInputSource>
-#include <QXmlSimpleReader>
+#include <QtXml/qxml.h>
+#include <QtXml/qxml.h>
+#include <QtXml/qxml.h>
 
 #include <kdebug.h>
 #include <kurl.h>
@@ -235,8 +235,6 @@ void ConfigLoaderHandler::addItem()
         }
 
         item = intItem;
-    } else if (m_type == "password") {
-        item = m_config->addItemPassword(m_name, *d->newString(), m_default, m_key);
     } else if (m_type == "path") {
         item = m_config->addItemPath(m_name, *d->newString(), m_default, m_key);
     } else if (m_type == "string") {
@@ -381,7 +379,7 @@ ConfigLoader::ConfigLoader(KSharedConfigPtr config, QIODevice *xml, QObject *par
 //       but KConfigSkeleton does not currently support this. it will eventually though,
 //       at which point this can be addressed properly
 ConfigLoader::ConfigLoader(const KConfigGroup *config, QIODevice *xml, QObject *parent)
-    : KConfigSkeleton(KSharedConfig::openConfig(config->config()->name()), parent),
+    : KConfigSkeleton(KSharedConfig::openConfig(config->config()->name(), KConfig::SimpleConfig), parent),
       d(new ConfigLoaderPrivate)
 {
     KConfigGroup group = config->parent();
