@@ -27,16 +27,15 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QFile>
-#include <QGraphicsSceneContextMenuEvent>
+#include <QtGui/qgraphicssceneevent.h>
 #include <QGraphicsView>
 #include <QMimeData>
 #include <QPainter>
-#include <QStyleOptionGraphicsItem>
+#include <QtGui/qstyleoption.h>
 #include <QGraphicsLayout>
 #include <QGraphicsLinearLayout>
 
 #include <kaction.h>
-#include <kauthorized.h>
 #include <kicon.h>
 #include <kmenu.h>
 #include <kmessagebox.h>
@@ -54,7 +53,6 @@
 
 #include "abstracttoolbox.h"
 #include "animator.h"
-#include "context.h"
 #include "containmentactions.h"
 #include "containmentactionspluginsconfig.h"
 #include "corona.h"
@@ -63,9 +61,6 @@
 #include "svg.h"
 #include "wallpaper.h"
 
-#include "remote/accessappletjob.h"
-#include "remote/accessmanager.h"
-
 #include "private/applet_p.h"
 #include "private/containmentactionspluginsconfig_p.h"
 #include "private/extenderitemmimedata_p.h"
@@ -159,7 +154,7 @@ void Containment::init()
     setFlag(QGraphicsItem::ItemIsMovable, false);
     setFlag(QGraphicsItem::ItemClipsChildrenToShape, true);
     setAcceptDrops(true);
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 
     if (d->type == NoContainmentType) {
         setContainmentType(DesktopContainment);
@@ -207,11 +202,6 @@ void Containment::init()
     }
     if (d->type != PanelContainment && d->type != CustomPanelContainment) {
         if (corona()) {
-            //FIXME this is just here because of the darn keyboard shortcut :/
-            act = corona()->action("manage activities");
-            if (act) {
-                d->actions()->addAction("manage activities", act);
-            }
             //a stupid hack to make this one's keyboard shortcut work
             act = corona()->action("configure shortcuts");
             if (act) {
@@ -239,17 +229,9 @@ void ContainmentPrivate::addDefaultActions(KActionCollection *actions, Containme
 
     //adjust applet actions
     KAction *appAction = qobject_cast<KAction*>(actions->action("remove"));
-    appAction->setShortcut(KShortcut("alt+d, alt+r"));
+    appAction->setShortcut(KShortcut("alt+r"));
     if (c && c->d->isPanelContainment()) {
         appAction->setText(i18n("Remove this Panel"));
-    } else {
-        appAction->setText(i18n("Remove this Activity"));
-    }
-
-    appAction = qobject_cast<KAction*>(actions->action("configure"));
-    if (appAction) {
-        appAction->setShortcut(KShortcut("alt+d, alt+s"));
-        appAction->setText(i18n("Activity Settings"));
     }
 
     //add our own actions
@@ -257,19 +239,19 @@ void ContainmentPrivate::addDefaultActions(KActionCollection *actions, Containme
     appletBrowserAction->setAutoRepeat(false);
     appletBrowserAction->setText(i18n("Add Widgets..."));
     appletBrowserAction->setIcon(KIcon("list-add"));
-    appletBrowserAction->setShortcut(KShortcut("alt+d, a"));
+    appletBrowserAction->setShortcut(KShortcut("alt+a"));
     appletBrowserAction->setData(AbstractToolBox::AddTool);
 
     KAction *action = actions->addAction("next applet");
     action->setText(i18n("Next Widget"));
     //no icon
-    action->setShortcut(KShortcut("alt+d, n"));
+    action->setShortcut(KShortcut("alt+n"));
     action->setData(AbstractToolBox::ControlTool);
 
     action = actions->addAction("previous applet");
     action->setText(i18n("Previous Widget"));
     //no icon
-    action->setShortcut(KShortcut("alt+d, p"));
+    action->setShortcut(KShortcut("alt+p"));
     action->setData(AbstractToolBox::ControlTool);
 }
 
@@ -327,11 +309,6 @@ void Containment::restore(KConfigGroup &group)
     d->lastScreen = group.readEntry("lastScreen", d->lastScreen);
     d->lastDesktop = group.readEntry("lastDesktop", d->lastDesktop);
     d->setScreen(group.readEntry("screen", d->screen), group.readEntry("desktop", d->desktop), false);
-    QString activityId = group.readEntry("activityId", QString());
-    if (!activityId.isEmpty()) {
-        d->context()->setCurrentActivityId(activityId);
-    }
-    setActivity(group.readEntry("activity", QString()));
 
     flushPendingConstraintsEvents();
     restoreContents(group);
@@ -354,11 +331,6 @@ void Containment::restore(KConfigGroup &group)
         if (source == "Global") {
             cfg = KConfigGroup(corona()->config(), "ActionPlugins");
             d->containmentActionsSource = ContainmentPrivate::Global;
-        } else if (source == "Activity") {
-            cfg = KConfigGroup(corona()->config(), "Activities");
-            cfg = KConfigGroup(&cfg, activityId);
-            cfg = KConfigGroup(&cfg, "ActionPlugins");
-            d->containmentActionsSource = ContainmentPrivate::Activity;
         } else if (source == "Local") {
             cfg = group;
             d->containmentActionsSource = ContainmentPrivate::Local;
@@ -382,10 +354,10 @@ void Containment::restore(KConfigGroup &group)
     } else { //shell defaults
         ContainmentActionsPluginsConfig conf = corona()->containmentActionsDefaults(d->type);
         //steal the data directly, for efficiency
-        QHash<QString,QString> defaults = conf.d->plugins;
-        for (QHash<QString,QString>::const_iterator it = defaults.constBegin(),
-                end = defaults.constEnd(); it != end; ++it) {
-            setContainmentActions(it.key(), it.value());
+        QHashIterator<QString,QString> defaults(conf.d->plugins);
+        while(defaults.hasNext()) {
+            defaults.next();
+            setContainmentActions(defaults.key(), defaults.value());
         }
     }
 
@@ -423,8 +395,6 @@ void Containment::save(KConfigGroup &g) const
     group.writeEntry("lastDesktop", d->lastDesktop);
     group.writeEntry("formfactor", (int)d->formFactor);
     group.writeEntry("location", (int)d->location);
-    group.writeEntry("activity", d->context()->currentActivity());
-    group.writeEntry("activityId", d->context()->currentActivityId());
 
 
     QMetaObject::invokeMethod(d->toolBox.data(), "save", Q_ARG(KConfigGroup, group));
@@ -619,7 +589,7 @@ void Containment::showContextMenu(const QPointF &containmentPos, const QPoint &s
 
 void Containment::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 {
-    if (!isContainment() || !KAuthorized::authorizeKAction("plasma/containment_context_menu")) {
+    if (!isContainment()) {
         Applet::contextMenuEvent(event);
         return;
     }
@@ -671,12 +641,6 @@ void Containment::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 
 void ContainmentPrivate::addContainmentActions(KMenu &desktopMenu, QEvent *event)
 {
-    if (static_cast<Corona*>(q->scene())->immutability() != Mutable &&
-        !KAuthorized::authorizeKAction("plasma/containment_actions")) {
-        //kDebug() << "immutability";
-        return;
-    }
-
     const QString trigger = ContainmentActions::eventToString(event);
     prepareContainmentActions(trigger, QPoint(), &desktopMenu);
 }
@@ -987,8 +951,6 @@ void ContainmentPrivate::setScreen(int newScreen, int newDesktop, bool preventIn
         newDesktop = -1;
     }
 
-    //kDebug() << activity() << "setting screen to " << newScreen << newDesktop << "and type is" << type;
-
     Containment *swapScreensWith(0);
     const bool isDesktopContainment = type == Containment::DesktopContainment ||
                                       type == Containment::CustomContainment;
@@ -1008,7 +970,6 @@ void ContainmentPrivate::setScreen(int newScreen, int newDesktop, bool preventIn
             if (currently && currently != q) {
                 kDebug() << "currently is on screen" << currently->screen()
                          << "desktop" << currently->desktop()
-                         << "and is" << currently->activity()
                          << (QObject*)currently << "i'm" << (QObject*)q;
                 currently->setScreen(-1, currently->desktop());
                 swapScreensWith = currently;
@@ -1214,7 +1175,6 @@ void ContainmentPrivate::showDropZoneDelayed()
 
 void Containment::dragMoveEvent(QGraphicsSceneDragDropEvent *event)
 {
-    QGraphicsItem *item = scene()->itemAt(event->scenePos());
     //event->setAccepted(item == this || item == d->toolBox.data() || !item);
     //kDebug() << event->isAccepted() << d->showDropZoneDelayTimer->isActive();
     if (!event->isAccepted()) {
@@ -1306,48 +1266,35 @@ void ContainmentPrivate::dropData(QPointF scenePos, QPoint screenPos, QGraphicsS
         //      to create widgets out of the matching URLs, if any
         const KUrl::List urls = KUrl::List::fromMimeData(mimeData);
         foreach (const KUrl &url, urls) {
-            if (AccessManager::supportedProtocols().contains(url.protocol())) {
-                AccessAppletJob *job = AccessManager::self()->accessRemoteApplet(url);
-                if (dropEvent) {
-                    dropPoints[job] = dropEvent->pos();
-                } else {
-                    dropPoints[job] = scenePos;
-                }
-                QObject::connect(AccessManager::self(), SIGNAL(finished(Plasma::AccessAppletJob*)),
-                                 q, SLOT(remoteAppletReady(Plasma::AccessAppletJob*)));
-            }
 #ifndef PLASMA_NO_KIO
-            else {
-                KMimeType::Ptr mime = KMimeType::findByUrl(url);
-                QString mimeName = mime->name();
-                QRectF geom(pos, QSize());
-                QVariantList args;
-                args << url.url();
-                kDebug() << "can decode" << mimeName << args;
+            KMimeType::Ptr mime = KMimeType::findByUrl(url);
+            QString mimeName = mime->name();
+            QRectF geom(pos, QSize());
+            QVariantList args;
+            args << url.url();
+            kDebug() << "can decode" << mimeName << args;
 
-                // It may be a directory or a file, let's stat
-                KIO::JobFlags flags = KIO::HideProgressInfo;
-                KIO::MimetypeJob *job = KIO::mimetype(url, flags);
-                if (dropEvent) {
-                    dropPoints[job] = dropEvent->pos();
-                } else {
-                    dropPoints[job] = scenePos;
-                }
-
-                QObject::connect(job, SIGNAL(result(KJob*)), q, SLOT(dropJobResult(KJob*)));
-                QObject::connect(job, SIGNAL(mimetype(KIO::Job*,QString)),
-                                 q, SLOT(mimeTypeRetrieved(KIO::Job*,QString)));
-
-                KMenu *choices = new KMenu("Content dropped");
-                choices->addAction(KIcon("process-working"), i18n("Fetching file type..."));
-                if (dropEvent) {
-                    choices->popup(dropEvent->screenPos());
-                } else {
-                    choices->popup(screenPos);
-                }
-
-                dropMenus[job] = choices;
+            // It may be a directory or a file, let's stat
+            KIO::MimetypeJob *job = KIO::mimetype(url, KIO::HideProgressInfo);
+            if (dropEvent) {
+                dropPoints[job] = dropEvent->pos();
+            } else {
+                dropPoints[job] = scenePos;
             }
+
+            QObject::connect(job, SIGNAL(result(KJob*)), q, SLOT(dropJobResult(KJob*)));
+            QObject::connect(job, SIGNAL(mimetype(KIO::Job*,QString)),
+                                q, SLOT(mimeTypeRetrieved(KIO::Job*,QString)));
+
+            KMenu *choices = new KMenu("Content dropped");
+            choices->addAction(KIcon("process-working"), i18n("Fetching file type..."));
+            if (dropEvent) {
+                choices->popup(dropEvent->screenPos());
+            } else {
+                choices->popup(screenPos);
+            }
+
+            dropMenus[job] = choices;
 #endif
         }
 
@@ -1443,27 +1390,10 @@ void ContainmentPrivate::clearDataForMimeJob(KIO::Job *job)
 #endif // PLASMA_NO_KIO
 }
 
-void ContainmentPrivate::remoteAppletReady(Plasma::AccessAppletJob *job)
-{
-    QPointF pos = dropPoints.take(job);
-    if (job->error()) {
-        //TODO: nice user visible error handling (knotification probably?)
-        kDebug() << "remote applet access failed: " << job->errorText();
-        return;
-    }
-
-    if (!job->applet()) {
-        kDebug() << "how did we end up here? if applet is null, the job->error should be nonzero";
-        return;
-    }
-
-    q->addApplet(job->applet(), pos);
-}
-
 void ContainmentPrivate::dropJobResult(KJob *job)
 {
 #ifndef PLASMA_NO_KIO
-    KIO::TransferJob* tjob = dynamic_cast<KIO::TransferJob*>(job);
+    KIO::TransferJob* tjob = qobject_cast<KIO::TransferJob*>(job);
     if (!tjob) {
         kDebug() << "job is not a KIO::TransferJob, won't handle the drop...";
         clearDataForMimeJob(tjob);
@@ -1482,7 +1412,7 @@ void ContainmentPrivate::mimeTypeRetrieved(KIO::Job *job, const QString &mimetyp
 {
 #ifndef PLASMA_NO_KIO
     kDebug() << "Mimetype Job returns." << mimetype;
-    KIO::TransferJob* tjob = dynamic_cast<KIO::TransferJob*>(job);
+    KIO::TransferJob* tjob = qobject_cast<KIO::TransferJob*>(job);
     if (!tjob) {
         kDebug() << "job should be a TransferJob, but isn't";
         clearDataForMimeJob(job);
@@ -1605,12 +1535,6 @@ void ContainmentPrivate::mimeTypeRetrieved(KIO::Job *job, const QString &mimetyp
 #endif // PLASMA_NO_KIO
 }
 
-#ifndef KDE_NO_DEPRECATED
-const QGraphicsItem *Containment::toolBoxItem() const
-{
-    return d->toolBox.data();
-}
-#endif
 
 void Containment::setToolBox(AbstractToolBox *toolBox)
 {
@@ -1698,14 +1622,16 @@ QVariant Containment::itemChange(GraphicsItemChange change, const QVariant &valu
          change == QGraphicsItem::ItemPositionHasChanged)) {
         switch (d->type) {
             case PanelContainment:
-            case CustomPanelContainment:
+            case CustomPanelContainment: {
                 d->positionPanel();
                 break;
-            default:
+            }
+            default: {
                 if (corona()) {
                     QMetaObject::invokeMethod(corona(), "layoutContainments");
                 }
                 break;
+            }
         }
     }
 
@@ -1905,13 +1831,14 @@ void Containment::setContainmentActions(const QString &trigger, const QString &p
         }
     } else {
         switch (d->containmentActionsSource) {
-        case ContainmentPrivate::Activity:
-            //FIXME
-        case ContainmentPrivate::Local:
-            plugin = ContainmentActions::load(this, pluginName);
-            break;
-        default:
-            plugin = ContainmentActions::load(0, pluginName);
+            case ContainmentPrivate::Local: {
+                plugin = ContainmentActions::load(this, pluginName);
+                break;
+            }
+            default: {
+                plugin = ContainmentActions::load(0, pluginName);
+                break;
+            }
         }
         if (plugin) {
             cfg.writeEntry(trigger, pluginName);
@@ -1936,62 +1863,6 @@ QString Containment::containmentActions(const QString &trigger)
     return c ? c->pluginName() : QString();
 }
 
-void Containment::setActivity(const QString &activity)
-{
-    Context *context = d->context();
-    if (context->currentActivity() != activity) {
-        context->setCurrentActivity(activity);
-    }
-}
-
-void ContainmentPrivate::onContextChanged(Plasma::Context *con)
-{
-    foreach (Applet *a, applets) {
-        a->updateConstraints(ContextConstraint);
-    }
-
-    KConfigGroup c = q->config();
-    QString act = con->currentActivityId();
-
-    //save anything that's been set (boy I hope this avoids overwriting things)
-    //FIXME of course if the user sets the name to an empty string we have a bug
-    //but once we get context retrieving the name as soon as the id is set, this issue should go away
-    if (!act.isEmpty()) {
-        c.writeEntry("activityId", act);
-    }
-    act = con->currentActivity();
-    if (!act.isEmpty()) {
-        c.writeEntry("activity", act);
-    }
-
-    if (toolBox) {
-        toolBox.data()->update();
-    }
-    emit q->configNeedsSaving();
-    emit q->contextChanged(con);
-}
-
-QString Containment::activity() const
-{
-    return d->context()->currentActivity();
-}
-
-Context *Containment::context() const
-{
-    return d->context();
-}
-
-Context *ContainmentPrivate::context()
-{
-    if (!con) {
-        con = new Context(q);
-        q->connect(con, SIGNAL(changed(Plasma::Context*)),
-                   q, SLOT(onContextChanged(Plasma::Context*)));
-    }
-
-    return con;
-}
-
 KActionCollection* ContainmentPrivate::actions()
 {
     return static_cast<Applet*>(q)->d->actions;
@@ -2124,7 +1995,7 @@ void Containment::destroy(bool confirm)
 
 void ContainmentPrivate::createToolBox()
 {
-    if (!toolBox && KAuthorized::authorizeKAction("plasma/containment_context_menu")) {
+    if (!toolBox) {
         toolBox = Plasma::AbstractToolBox::load(q->corona()->preferredToolBoxPlugin(type), QVariantList(), q);
 
         if (toolBox) {
@@ -2435,17 +2306,15 @@ KConfigGroup Containment::containmentActionsConfig()
 {
     KConfigGroup cfg;
     switch (d->containmentActionsSource) {
-    case ContainmentPrivate::Local:
-        cfg = config();
-        cfg = KConfigGroup(&cfg, "ActionPlugins");
-        break;
-    case ContainmentPrivate::Activity:
-        cfg = KConfigGroup(corona()->config(), "Activities");
-        cfg = KConfigGroup(&cfg, d->context()->currentActivityId());
-        cfg = KConfigGroup(&cfg, "ActionPlugins");
-        break;
-    default:
-        cfg = KConfigGroup(corona()->config(), "ActionPlugins");
+        case ContainmentPrivate::Local: {
+            cfg = config();
+            cfg = KConfigGroup(&cfg, "ActionPlugins");
+            break;
+        }
+        default: {
+            cfg = KConfigGroup(corona()->config(), "ActionPlugins");
+            break;
+        }
     }
     return cfg;
 }
@@ -2453,8 +2322,6 @@ KConfigGroup Containment::containmentActionsConfig()
 QHash<QString, ContainmentActions*> * ContainmentPrivate::actionPlugins()
 {
     switch (containmentActionsSource) {
-        case Activity:
-            //FIXME
         case Local:
             return &localActionPlugins;
         default:
@@ -2464,5 +2331,5 @@ QHash<QString, ContainmentActions*> * ContainmentPrivate::actionPlugins()
 
 } // Plasma namespace
 
-#include "containment.moc"
+#include "moc_containment.cpp"
 
