@@ -24,11 +24,10 @@
 
 #include <QtGui/QGraphicsItem>
 #include <QtGui/QWidget>
-#include <QtGui/QStyleOptionGraphicsItem>
+#include <QtGui/qstyleoption.h>
 
 #include <kplugininfo.h>
 #include <ksharedconfig.h>
-#include <kgenericfactory.h>
 
 #include <plasma/applet.h>
 #include <plasma/animator.h>
@@ -56,7 +55,7 @@ class AbstractToolBox;
  * Containment objects provide the means to group applets into functional sets.
  * They also provide the following:
  *
- * creation of focussing event
+ * creation of focusing event
  * - drawing of the background image (which can be interactive)
  * - form factors (e.g. panel, desktop, full screen, etc)
  * - applet layout management
@@ -355,24 +354,6 @@ class PLASMA_EXPORT Containment : public Applet
          */
         Plasma::Wallpaper *wallpaper() const;
 
-        /**
-         * Sets the current activity by name
-         *
-         * @param activity the name of the activity
-         */
-        void setActivity(const QString &activity);
-
-        /**
-         * @return the current activity name associated with this containment
-         */
-        QString activity() const;
-
-        /**
-         * @return the context for this containment
-         * @since 4.5
-         */
-        Context* context() const;
-
         /**
          * Shows the context menu for the containment directly, bypassing Applets
          * altogether.
@@ -427,12 +408,6 @@ Q_SIGNALS:
          */
         void appletRemoved(Plasma::Applet *applet);
 
-        /**
-         * Emitted when the containment requests zooming in or out one step.
-         * @deprecated
-         */
-        void zoomRequested(Plasma::Containment *containment, Plasma::ZoomDirection direction);
-
         /**
          * Emitted when the user clicks on the toolbox
          */
@@ -474,11 +449,6 @@ Q_SIGNALS:
          */
         void configureRequested(Plasma::Containment *containment);
 
-        /**
-         * The context associated to this containment has changed
-         */
-        void contextChanged(Plasma::Context *context);
-
     public Q_SLOTS:
         /**
          * Informs the Corona as to what position it is in. This is informational
@@ -610,9 +580,6 @@ Q_SIGNALS:
         /**
          * @returns the toolbox associated with this containment, or a null pointer if none
          */
-#ifndef KDE_NO_DEPRECATED
-        KDE_DEPRECATED const QGraphicsItem *toolBoxItem() const;
-#endif
 
         /**
          * Sets a custom ToolBox
@@ -649,8 +616,6 @@ Q_SIGNALS:
         Q_PRIVATE_SLOT(d, void updateToolBoxVisibility())
         Q_PRIVATE_SLOT(d, void showDropZoneDelayed())
         Q_PRIVATE_SLOT(d, void checkStatus(Plasma::ItemStatus))
-        Q_PRIVATE_SLOT(d, void remoteAppletReady(Plasma::AccessAppletJob *))
-        Q_PRIVATE_SLOT(d, void onContextChanged(Plasma::Context *con))
         /**
         * This slot is called when the 'stat' after a job event has finished.
         */
