@@ -23,12 +23,12 @@
 #include <QList>
 
 #include <kplugininfo.h>
+#include <kdeversion.h>
 
 #include <plasma/plasma.h>
 #include <plasma/packagestructure.h>
-#include <plasma/version.h>
 
-class QAction;
+#include <QAction>
 
 namespace Plasma
 {
@@ -211,11 +211,6 @@ class PLASMA_EXPORT ContainmentActions : public QObject
          */
         QPoint popupPosition(const QSize &s, QEvent *event);
 
-        /**
-         * @reimplemented
-         */
-        bool event(QEvent *e);
-
         /**
          * @p newContainment the containment the plugin should be associated with.
          * @since 4.6
@@ -272,7 +267,6 @@ class PLASMA_EXPORT ContainmentActions : public QObject
  */
 #define K_EXPORT_PLASMA_CONTAINMENTACTIONS(libname, classname) \
 K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
-K_EXPORT_PLUGIN(factory("plasma_containmentactions_" #libname)) \
-K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+K_EXPORT_PLUGIN(factory("plasma_containmentactions_" #libname))
 
 #endif // PLASMA_CONTAINMENTACTIONS_H
