@@ -16,13 +16,11 @@
  *   Free Software Foundation, Inc.,
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
-
 #include "datacontainer.h"
 #include "private/datacontainer_p.h"
 
-#include <QVariant>
-
 #include <kdebug.h>
+#include <QDateTime>
 
 #include "plasma.h"
 
@@ -31,7 +29,7 @@ namespace Plasma
 
 DataContainer::DataContainer(QObject *parent)
     : QObject(parent),
-      d(new DataContainerPrivate)
+      d(new DataContainerPrivate(this))
 {
 }
 
@@ -54,7 +52,7 @@ void DataContainer::setData(const QString &key, const QVariant &value)
     }
 
     d->dirty = true;
-    d->updateTs.start();
+    d->updateTimer.start();
 }
 
 void DataContainer::removeAllData()
@@ -66,7 +64,7 @@ void DataContainer::removeAllData()
 
     d->data.clear();
     d->dirty = true;
-    d->updateTs.start();
+    d->updateTimer.start();
 }
 
 bool DataContainer::visualizationIsConnected(QObject *visualization) const
@@ -136,6 +134,21 @@ void DataContainer::connectVisualization(QObject *visualization, uint pollingInt
     }
 }
 
+DataEngine* DataContainer::getDataEngine()
+{
+    QObject *o = this;
+    DataEngine *de = NULL;
+    while (de == NULL)
+    {
+        o = qobject_cast<QObject *> (o->parent());
+        if (o == NULL) {
+            return NULL;
+        }
+        de = qobject_cast<DataEngine *> (o);
+    }
+    return de;
+}
+
 void DataContainer::disconnectVisualization(QObject *visualization)
 {
     QMap<QObject *, SignalRelay *>::iterator objIt = d->relayObjects.find(visualization);
@@ -190,9 +203,7 @@ void DataContainer::forceImmediateUpdate()
 
 uint DataContainer::timeSinceLastUpdate() const
 {
-    //FIXME: we still assume it's been <24h
-    //and ignore possible daylight savings changes
-    return d->updateTs.elapsed();
+    return d->updateTimer.elapsed();
 }
 
 void DataContainer::setNeedsUpdate(bool update)
@@ -202,14 +213,25 @@ void DataContainer::setNeedsUpdate(bool update)
 
 void DataContainer::checkUsage()
 {
-    if (d->relays.count() < 1 &&
-        receivers(SIGNAL(dataUpdated(QString, Plasma::DataEngine::Data))) < 1) {
-        // DO NOT CALL ANYTHING AFTER THIS LINE AS IT MAY GET DELETED!
-        emit becameUnused(objectName());
+    if (!d->checkUsageTimer.isActive()) {
+        d->checkUsageTimer.start(10, this);
+    }
+}
+
+void DataContainer::timerEvent(QTimerEvent * event)
+{
+    if (event->timerId() == d->checkUsageTimer.timerId()) {
+        if (d->relays.count() < 1 &&
+            receivers(SIGNAL(dataUpdated(QString,Plasma::DataEngine::Data))) < 1) {
+            // DO NOT CALL ANYTHING AFTER THIS LINE AS IT MAY GET DELETED!
+            kDebug() << objectName() << "is unused";
+            emit becameUnused(objectName());
+        }
+        d->checkUsageTimer.stop();
     }
 }
 
 } // Plasma namespace
 
-#include "datacontainer.moc"
+#include "moc_datacontainer.cpp"
 
