@@ -23,8 +23,8 @@
 
 #include <QQueue>
 #include <QTimer>
-#include <QTime>
-#include <QTimerEvent>
+#include <QtCore/qdatetime.h>
+#include <QtCore/qcoreevent.h>
 #include <QVariant>
 
 #include <kdebug.h>
@@ -32,17 +32,10 @@
 #include <kservice.h>
 #include <kstandarddirs.h>
 
-#include "authorizationmanager.h"
 #include "datacontainer.h"
-#include "package.h"
 #include "service.h"
-#include "scripting/dataenginescript.h"
-
-#include "private/authorizationmanager_p.h"
 #include "private/dataengineservice_p.h"
-#include "private/remotedataengine_p.h"
 #include "private/service_p.h"
-#include "private/storage_p.h"
 
 namespace Plasma
 {
@@ -67,22 +60,11 @@ DataEngine::~DataEngine()
 
 QStringList DataEngine::sources() const
 {
-    if (d->script) {
-        return d->script->sources();
-    } else {
-        return d->sources.keys();
-    }
+    return d->sources.keys();
 }
 
 Service *DataEngine::serviceForSource(const QString &source)
 {
-    if (d->script) {
-        Service * s = d->script->serviceForSource(source);
-        if (s) {
-            return s;
-        }
-    }
-
     return new NullService(source, this);
 }
 
@@ -152,33 +134,22 @@ DataEngine::Data DataEngine::query(const QString &source) const
 
 void DataEngine::init()
 {
-    if (d->script) {
-        d->setupScriptSupport();
-        d->script->init();
-    } else {
-        // kDebug() << "called";
-        // default implementation does nothing. this is for engines that have to
-        // start things in motion external to themselves before they can work
-    }
+    // kDebug() << "called";
+    // default implementation does nothing. this is for engines that have to
+    // start things in motion external to themselves before they can work
 }
 
 bool DataEngine::sourceRequestEvent(const QString &name)
 {
-    if (d->script) {
-        return d->script->sourceRequestEvent(name);
-    } else {
-        return false;
-    }
+    Q_UNUSED(name)
+    return false;
 }
 
 bool DataEngine::updateSourceEvent(const QString &source)
 {
-    if (d->script) {
-        return d->script->updateSourceEvent(source);
-    } else {
-        //kDebug() << source;
-        return false; //TODO: should this be true to trigger, even needless, updates on every tick?
-    }
+    Q_UNUSED(source)
+    //kDebug() << source;
+    return false; //TODO: should this be true to trigger, even needless, updates on every tick?
 }
 
 void DataEngine::setData(const QString &source, const QVariant &value)
@@ -317,7 +288,6 @@ void DataEngine::removeSource(const QString &source)
             }
         }
 
-        s->d->store();
         s->disconnect(this);
         s->deleteLater();
         d->sources.erase(it);
@@ -370,12 +340,12 @@ void DataEngine::timerEvent(QTimerEvent *event)
         }
 
         // minPollingInterval
-        if (d->updateTimestamp.elapsed() < d->minPollingInterval) {
+        if (d->updateTimer.elapsed() < d->minPollingInterval) {
             //kDebug() << "hey now.. slow down!";
             return;
         }
 
-        d->updateTimestamp.restart();
+        d->updateTimer.start();
         updateAllSources();
     } else if (event->timerId() == d->checkSourcesTimerId) {
         killTimer(d->checkSourcesTimerId);
@@ -441,43 +411,6 @@ Service* DataEngine::createDefaultService(QObject *parent)
     return Service::load(d->serviceName, args, parent);
 }
 
-void DataEnginePrivate::publish(AnnouncementMethods methods, const QString &name)
-{
-    if (!publishedService) {
-        publishedService = new DataEngineService(q);
-    }
-
-    //QString resourceName =
-    //i18nc("%1 is the name of a dataengine, %2 the name of the machine that engine is published
-//on",
-          //"%1 dataengine on %2", name(), AuthorizationManager::self()->d->myCredentials.name());
-    kDebug() << "name: " << name;
-    publishedService->d->publish(methods, name);
-}
-
-void DataEnginePrivate::unpublish(const QString &name)
-{
-    Q_UNUSED(name)
-
-    if (publishedService) {
-        publishedService->d->unpublish();
-    }
-}
-
-bool DataEnginePrivate::isPublished() const
-{
-    if (publishedService) {
-        return publishedService->d->isPublished();
-    } else {
-        return false;
-    }
-}
-
-const Package *DataEngine::package() const
-{
-    return d->package;
-}
-
 void DataEngine::scheduleSourcesUpdated()
 {
     if (d->checkSourcesTimerId) {
@@ -498,14 +431,6 @@ void DataEngine::setName(const QString &name)
     setObjectName(name);
 }
 
-void DataEngine::setStorageEnabled(const QString &source, bool store)
-{
-    DataContainer *s = d->source(source, false);
-    if (s) {
-        s->setStorageEnabled(store);
-    }
-}
-
 // Private class implementations
 DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginInfo &info)
     : q(e),
@@ -516,11 +441,9 @@ DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginInfo &info)
       minPollingInterval(-1),
       limit(0),
       valid(true),
-      script(0),
-      package(0),
       publishedService(0)
 {
-    updateTimestamp.start();
+    updateTimer.start();
 
     if (!info.isValid()) {
         engineName = i18n("Unnamed");
@@ -533,35 +456,10 @@ DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginInfo &info)
     }
     e->setObjectName(engineName);
     icon = info.icon();
-
-    if (dataEngineDescription.isValid()) {
-        QString api = dataEngineDescription.property("X-Plasma-API").toString();
-
-        if (!api.isEmpty()) {
-            const QString path =
-                KStandardDirs::locate("data",
-                                      "plasma/dataengines/" + dataEngineDescription.pluginName() + '/');
-            PackageStructure::Ptr structure = Plasma::packageStructure(api, Plasma::DataEngineComponent);
-            structure->setPath(path);
-            package = new Package(path, structure);
-
-            script = Plasma::loadScriptEngine(api, q);
-            if (!script) {
-                kDebug() << "Could not create a" << api << "ScriptEngine for the"
-                        << dataEngineDescription.name() << "DataEngine.";
-                delete package;
-                package = 0;
-            }
-        }
-    }
 }
 
 DataEnginePrivate::~DataEnginePrivate()
 {
-    delete script;
-    script = 0;
-    delete package;
-    package = 0;
 }
 
 void DataEnginePrivate::internalUpdateSource(DataContainer *source)
@@ -645,10 +543,6 @@ void DataEnginePrivate::connectSource(DataContainer *s, QObject *visualization,
 {
     //kDebug() << "connect source called" << s->objectName() << "with interval" << pollingInterval;
 
-    //FIXME: at the moment a remote dataengine can only poll, a push mechanism will be needed instead
-    if (pollingInterval == 0 && qobject_cast<RemoteDataEngine *>(q)) {
-        pollingInterval = 5000;
-    }
     if (pollingInterval > 0) {
         // never more frequently than allowed, never more than 20 times per second
         uint min = qMax(50, minPollingInterval); // for qMax below
@@ -732,29 +626,6 @@ void DataEnginePrivate::trimQueue()
     }
 }
 
-// put all setup routines for script here. at this point we can assume that
-// package exists and that we have a script engine
-void DataEnginePrivate::setupScriptSupport()
-{
-    if (!package) {
-        return;
-    }
-
-    /*
-    kDebug() << "sletting up script support, package is in" << package->path()
-             << "which is a" << package->structure()->type() << "package"
-             << ", main script is" << package->filePath("mainscript");
-    */
-
-    QString translationsPath = package->filePath("translations");
-    if (!translationsPath.isEmpty()) {
-        //FIXME: we should _probably_ use a KComponentData to segregate the applets
-        //       from each other; but I want to get the basics working first :)
-        KGlobal::dirs()->addResourceDir("locale", translationsPath);
-        KGlobal::locale()->insertCatalog(package->metadata().pluginName());
-    }
 }
 
-}
-
-#include "dataengine.moc"
+#include "moc_dataengine.cpp"
