@@ -24,17 +24,16 @@
 #include <QtCore/QObject>
 #include <QtCore/QStringList>
 
-#include <kgenericfactory.h>
 #include <kservice.h>
+#include <kdeversion.h>
 
-#include <plasma/version.h>
 #include <plasma/plasma.h>
+#include <plasma/service.h>
 
 namespace Plasma
 {
 
 class DataContainer;
-class DataEngineScript;
 class Package;
 class Service;
 class DataEnginePrivate;
@@ -60,6 +59,7 @@ class PLASMA_EXPORT DataEngine : public QObject
     Q_PROPERTY(QStringList sources READ sources)
     Q_PROPERTY(bool valid READ isValid)
     Q_PROPERTY(QString icon READ icon WRITE setIcon)
+    Q_PROPERTY(QString name READ name)
 
     public:
         typedef QHash<QString, DataEngine*> Dict;
@@ -81,7 +81,10 @@ class PLASMA_EXPORT DataEngine : public QObject
          * This method is called when the DataEngine is started. When this
          * method is called the DataEngine is fully constructed and ready to be
          * used. This method should be reimplemented by DataEngine subclasses
-         * which have the need to perform a startup routine.
+         * which need to perform a startup routine.
+         *
+         * The default implementation does nothing. Reimplementations in
+         * subclasses don't need to call this one.
          **/
         virtual void init();
 
@@ -91,12 +94,12 @@ class PLASMA_EXPORT DataEngine : public QObject
          *         the default implementation provides) or not is up to the
          *         DataEngine to decide.
          **/
-        Q_INVOKABLE virtual QStringList sources() const;
+        virtual QStringList sources() const;
 
         /**
          * @param source the source to target the Service at
          * @return a Service that has the source as a destination. The service
-         *         is parented to the DataEngine, but may be deleted by the
+         *         is parented to the DataEngine, but should be deleted by the
          *         caller when finished with it
          */
         Q_INVOKABLE virtual Service *serviceForSource(const QString &source);
@@ -104,7 +107,7 @@ class PLASMA_EXPORT DataEngine : public QObject
         /**
          * Returns the engine name for the DataEngine
          */
-        Q_INVOKABLE QString name() const;
+        QString name() const;
 
         /**
          * Connects a source to an object for data updates. The object must
@@ -145,7 +148,7 @@ class PLASMA_EXPORT DataEngine : public QObject
          * without side-effects. This can be useful to change the pollingInterval.
          *
          * Note that this method does not automatically connect sources that
-         * may appear later on. Connecting and responding to the sourceAdded sigal
+         * may appear later on. Connecting and responding to the sourceAdded signal
          * is still required to achieve that.
          *
          * @param visualization the object to connect the data source to
@@ -160,10 +163,11 @@ class PLASMA_EXPORT DataEngine : public QObject
          * @param intervalAlignment the number of ms to align the interval to
          **/
         Q_INVOKABLE void connectAllSources(QObject *visualization, uint pollingInterval = 0,
-                                           Plasma::IntervalAlignment intervalAlignment = NoAlignment) const;
+                                           Plasma::IntervalAlignment intervalAlignment =
+NoAlignment) const;
 
         /**
-         * Disconnects a source to an object that was receiving data updates.
+         * Disconnects a source from an object that was receiving data updates.
          *
          * @param source the name of the data source
          * @param visualization the object to connect the data source to
@@ -171,7 +175,7 @@ class PLASMA_EXPORT DataEngine : public QObject
         Q_INVOKABLE void disconnectSource(const QString &source, QObject *visualization) const;
 
         /**
-         * Retrevies a pointer to the DataContainer for a given source. This method
+         * Retrieves a pointer to the DataContainer for a given source. This method
          * should not be used if possible. An exception is for script engines that
          * can not provide a QMetaObject as required by connectSource for the initial
          * call to dataUpdated. Using this method, such engines can provide their own
@@ -196,12 +200,16 @@ class PLASMA_EXPORT DataEngine : public QObject
 
         /**
          * Returns true if this engine is valid, otherwise returns false
+         *
+         * @return true if the engine is valid
          **/
         bool isValid() const;
 
         /**
          * Returns true if the data engine is empty, which is to say that it has no
          * data sources currently.
+         * 
+         * @return true if the engine has no sources currently
          */
         bool isEmpty() const;
 
@@ -220,17 +228,22 @@ class PLASMA_EXPORT DataEngine : public QObject
         QString icon() const;
 
         /**
-         * Accessor for the associated Package object if any.
-         *
-         * @return the Package object, or 0 if none
-         **/
-        const Package *package() const;
-
-        /**
-         * Returns the plugin name for the applet
+         * @return the plugin name for the applet
          */
         QString pluginName() const;
 
+        /**
+         * Initializes and returns a new service from the name that was set
+         * with setDefaultService. (service name is set internally). Remember to dispose
+         * of the Service* when you are finished with it (even if a parent is passed)
+         * A DataEngine* is sent to the created service via the QVariantList arguments.
+         * 
+         *  @see setDefaultService
+         *  @param the parent of the object, if any, for the returned service
+         *  @return the newly created service
+         *  @since 4.5
+         */
+        Q_INVOKABLE Service* createDefaultService(QObject *parent = 0);
 
     Q_SIGNALS:
         /**
@@ -359,6 +372,8 @@ class PLASMA_EXPORT DataEngine : public QObject
          * due to multiple update requests coming in, which can be useful for
          * expensive (time- or resource-wise) update mechanisms.
          *
+         * The default minimumPollingInterval is -1, or "never perform automatic updates"
+         *
          * @param minimumMs the minimum time lapse, in milliseconds, between updates.
          *                A value less than 0 means to never perform automatic updates,
          *                a value of 0 means update immediately on every update request,
@@ -381,15 +396,6 @@ class PLASMA_EXPORT DataEngine : public QObject
          **/
         void setPollingInterval(uint frequency);
 
-        /**
-         * Returns the current update frequency.
-         * @see setPollingInterval
-         NOTE: This is not implemented to prevent having to store the value internally.
-               When there is a good use case for needing access to this value, we can
-               add another member to the Private class and add this method.
-        uint pollingInterval();
-         **/
-
         /**
          * Removes all data sources
          **/
@@ -424,6 +430,22 @@ class PLASMA_EXPORT DataEngine : public QObject
          **/
         void setIcon(const QString &icon);
 
+        /**
+         *  Should be set if there will be 1 main service.
+         *  This saves any users of this DataEngine from having to know the service name to load.
+         *  It is not created until createDefaultService is called.
+         *
+         *  @code
+         *  DataEngine *engine = dataEngine("foo");
+         *  Service *service = engine->createDefaultService(this);
+         *  @endcode
+         *
+         *  @see createDefaultService
+         *  @param serviceName the name of the service to load (plugin name)
+         *  @since 4.5
+         */
+        void setDefaultService(const QString &serviceName);
+
     protected Q_SLOTS:
         /**
          * Call this method when you call setData directly on a DataContainer instead
@@ -443,13 +465,26 @@ class PLASMA_EXPORT DataEngine : public QObject
          */
         void updateAllSources();
 
+        /**
+         * Forces an immediate update to all connected sources, even those with
+         * timeouts that haven't yet expired. This should _only_ be used when
+         * there was no data available, e.g. due to network non-availability,
+         * and then it becomes available. Normal changes in data values due to
+         * calls to updateSource or in the natural progression of the monitored
+         * object (e.g. CPU heat) should not result in a call to this method!
+         *
+         * @since 4.4
+         */
+        void forceImmediateUpdateOfAllVisualizations();
+
     private:
         friend class DataEnginePrivate;
-        friend class DataEngineScript;
         friend class DataEngineManager;
+        friend class PlasmoidServiceJob;
         friend class NullEngine;
 
         Q_PRIVATE_SLOT(d, void internalUpdateSource(DataContainer *source))
+        Q_PRIVATE_SLOT(d, void sourceDestroyed(QObject *object))
 
         DataEnginePrivate *const d;
 };
@@ -461,8 +496,8 @@ class PLASMA_EXPORT DataEngine : public QObject
  */
 #define K_EXPORT_PLASMA_DATAENGINE(libname, classname) \
 K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
-K_EXPORT_PLUGIN(factory("plasma_engine_" #libname)) \
-K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+K_EXPORT_PLUGIN(factory("plasma_engine_" #libname))
+
+Q_DECLARE_METATYPE(Plasma::DataEngine*)
 
 #endif // multiple inclusion guard
-
