@@ -21,6 +21,7 @@
 
 #include <QFile>
 #include <QTextStream>
+#include <QDateTime>
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -212,7 +213,7 @@ void DataEngineManager::timerEvent(QTimerEvent *)
     while (it.hasNext()) {
         it.next();
         DataEngine *engine = it.value();
-        out << "DataEngine: " << it.key() << ' ' << engine << endl;
+        out << "DataEngine: " << it.key() << ' ' << (QString::fromLatin1("0x") + QString::number(quintptr(ptr), 16)) << endl;
         out << "            Claimed # of sources: " << engine->sources().count() << endl;
         out << "            Actual # of sources: " << engine->containerDict().count() << endl;
         out << endl << "            Source Details" << endl;
@@ -220,7 +221,6 @@ void DataEngineManager::timerEvent(QTimerEvent *)
         foreach (DataContainer *dc, engine->containerDict()) {
             out << "                * " << dc->objectName() << endl;
             out << "                       Data count: " << dc->d->data.count() << endl;
-            out << "                       Stored: " << dc->isStorageEnabled() << ' ' << endl;
             const int directs = dc->receivers(SIGNAL(dataUpdated(QString,Plasma::DataEngine::Data)));
             if (directs > 0) {
                 out << "                       Direction Connections: " << directs << ' ' << endl;
@@ -246,4 +246,4 @@ void DataEngineManager::timerEvent(QTimerEvent *)
 
 } // namespace Plasma
 
-#include "dataenginemanager.moc"
+#include "moc_dataenginemanager.cpp"
