@@ -29,9 +29,10 @@
 #include <QApplication>
 #include <QFontMetrics>
 #include <QIcon>
-#include <QModelIndex>
+#include <QAbstractItemModel>
 #include <QPainter>
-#include <QStyleOptionViewItem>
+#include <QStyleOption>
+#include <QPen>
 
 // KDE
 #include <kcolorutils.h>
@@ -489,5 +490,5 @@ bool Delegate::showToolTip() const
 
 }
 
-#include "delegate.moc"
+#include "moc_delegate.cpp"
 
