@@ -24,11 +24,9 @@
 #include "private/dialog_p.h"
 
 #include <QPainter>
-#include <QSvgRenderer>
-#include <QResizeEvent>
-#include <QMouseEvent>
+#include <QtGui/qevent.h>
 #ifdef Q_WS_X11
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #endif
 #include <QBitmap>
 #include <QTimer>
@@ -51,7 +49,6 @@
 #include "plasma/corona.h"
 #include "plasma/extenders/extender.h"
 #include "plasma/private/extender_p.h"
-#include "plasma/private/dialogshadows_p.h"
 #include "plasma/framesvg.h"
 #include "plasma/theme.h"
 #include "plasma/widgets/scrollwidget.h"
@@ -100,7 +97,6 @@ void DialogPrivate::themeChanged()
     // WA_NoSystemBackground is going to fail combined with sliding popups, but is needed
     // when we aren't compositing
     q->setAttribute(Qt::WA_NoSystemBackground, !translucency);
-    WindowEffects::overrideShadow(q->winId(), !DialogShadows::self()->enabled());
     updateMask();
     q->update();
 }
@@ -108,8 +104,6 @@ void DialogPrivate::themeChanged()
 void DialogPrivate::updateMask()
 {
     const bool translucency = Plasma::Theme::defaultTheme()->windowTranslucencyEnabled();
-    WindowEffects::enableBlurBehind(q->winId(), translucency,
-                                    translucency ? background->mask() : QRegion());
     if (translucency) {
         q->clearMask();
     } else {
@@ -141,7 +135,7 @@ void DialogPrivate::checkBorders(bool updateMaskIfNeeded)
     Plasma::Applet *applet = appletPtr.data();
 
     //used to remove borders at the edge of the desktop
-    QRect avail;
+    QRegion avail;
     QRect screenGeom;
     QDesktopWidget *desktop = QApplication::desktop();
     Plasma::Corona *c = 0;
@@ -151,17 +145,10 @@ void DialogPrivate::checkBorders(bool updateMaskIfNeeded)
         c = qobject_cast<Plasma::Corona *>(graphicsWidget->scene());
     }
     if (c) {
-        QRegion r = c->availableScreenRegion(desktop->screenNumber(q));
-        QRect maxRect;
-        foreach (QRect rect, r.rects()) {
-            if (rect.width() > maxRect.width() && rect.height() > maxRect.height()) {
-                maxRect = rect;
-            }
-        }
-        avail = maxRect;
+        avail = c->availableScreenRegion(desktop->screenNumber(q));
         screenGeom = c->screenGeometry(desktop->screenNumber(q));
     } else {
-        avail = desktop->availableGeometry(desktop->screenNumber(q));
+        avail = QRegion(desktop->availableGeometry(desktop->screenNumber(q)));
         screenGeom = desktop->screenGeometry(desktop->screenNumber(q));
     }
 
@@ -187,7 +174,7 @@ void DialogPrivate::checkBorders(bool updateMaskIfNeeded)
                 rightWidth = 0;
                 bottomHeight = 0;
             }
-        break;
+            break;
 
         case TopEdge:
             if (applet->containment() &&
@@ -198,7 +185,7 @@ void DialogPrivate::checkBorders(bool updateMaskIfNeeded)
                 leftWidth = 0;
                 rightWidth = 0;
             }
-        break;
+            break;
 
         case LeftEdge:
             if (applet->containment() &&
@@ -208,7 +195,7 @@ void DialogPrivate::checkBorders(bool updateMaskIfNeeded)
                 leftWidth = 0;
                 rightWidth = 0;
             }
-        break;
+            break;
 
         case RightEdge:
             if (applet->containment() &&
@@ -218,32 +205,32 @@ void DialogPrivate::checkBorders(bool updateMaskIfNeeded)
                 leftWidth = 0;
                 rightWidth = 0;
             }
-        break;
+            break;
 
         default:
-        break;
+            break;
         }
     }
 
     //decide if to disable the other borders
     if (q->isVisible() && !q->testAttribute(Qt::WA_X11NetWmWindowTypeToolTip)) {
-        if (dialogGeom.left() <= avail.left()) {
+        if (!avail.contains(QPoint(dialogGeom.left()-1, dialogGeom.center().y()))) {
             borders &= ~FrameSvg::LeftBorder;
         }
-        if (dialogGeom.top() <= avail.top()) {
+        if (!avail.contains(QPoint(dialogGeom.center().x(), dialogGeom.top()-1))) {
             borders &= ~FrameSvg::TopBorder;
         }
         //FIXME: that 2 pixels offset has probably something to do with kwin
-        if (dialogGeom.right() + 2 > avail.right()) {
+        if (!avail.contains(QPoint(dialogGeom.right()+1, dialogGeom.center().y()))) {
             borders &= ~FrameSvg::RightBorder;
         }
-        if (dialogGeom.bottom() + 2 > avail.bottom()) {
+        if (!avail.contains(QPoint(dialogGeom.center().x(), dialogGeom.bottom()+1))) {
             borders &= ~FrameSvg::BottomBorder;
         }
     }
 
     background->setEnabledBorders(borders);
-    DialogShadows::self()->addWindow(q, borders);
+    dialogshadows->addWindow(q, borders);
 
     if (extender)  {
         FrameSvg::EnabledBorders disabledBorders = FrameSvg::NoBorder;
@@ -373,13 +360,10 @@ int DialogPrivate::calculateWidthForHeightAndRatio(int height, qreal ratio)
     switch (aspectRatioMode) {
         case KeepAspectRatio:
             return qRound(height * ratio);
-            break;
         case Square:
             return height;
-            break;
         case ConstrainedSquare:
             return height;
-            break;
         default:
             return -1;
     }
@@ -391,6 +375,7 @@ Dialog::Dialog(QWidget *parent, Qt::WindowFlags f)
 {
     setMouseTracking(true);
     setAttribute(Qt::WA_TranslucentBackground);
+    d->dialogshadows = new DialogShadows(this);
     d->background = new FrameSvg(this);
     d->background->setImagePath("dialogs/background");
     d->background->setEnabledBorders(FrameSvg::AllBorders);
@@ -400,7 +385,6 @@ Dialog::Dialog(QWidget *parent, Qt::WindowFlags f)
     QPalette pal = palette();
     pal.setColor(backgroundRole(), Qt::transparent);
     setPalette(pal);
-    WindowEffects::overrideShadow(winId(), !DialogShadows::self()->enabled());
 
     d->adjustViewTimer = new QTimer(this);
     d->adjustViewTimer->setSingleShot(true);
@@ -415,7 +399,7 @@ Dialog::Dialog(QWidget *parent, Qt::WindowFlags f)
 
 Dialog::~Dialog()
 {
-    DialogShadows::self()->removeWindow(this);
+    d->dialogshadows->removeWindow(this);
     delete d;
 }
 
@@ -451,7 +435,7 @@ void Dialog::mouseMoveEvent(QMouseEvent *event)
         qreal aspectRatio = (qreal)width() / (qreal)height();
 
         switch(d->resizeStartCorner) {
-            case Dialog::NorthEast:
+            case Dialog::NorthEast: {
                 newHeight = qMin(maximumHeight(), qMax(minimumHeight(), height() - event->y()));
                 newWidth = d->calculateWidthForHeightAndRatio(newHeight, aspectRatio);
                 if (newWidth == -1) {
@@ -459,7 +443,8 @@ void Dialog::mouseMoveEvent(QMouseEvent *event)
                 }
                 position = QPoint(x(), y() + height() - newHeight);
                 break;
-            case Dialog::NorthWest:
+            }
+            case Dialog::NorthWest: {
                 newHeight = qMin(maximumHeight(), qMax(minimumHeight(), height() - event->y()));
                 newWidth = d->calculateWidthForHeightAndRatio(newHeight, aspectRatio);
                 if (newWidth == -1) {
@@ -467,7 +452,8 @@ void Dialog::mouseMoveEvent(QMouseEvent *event)
                 }
                 position = QPoint(x() + width() - newWidth, y() + height() - newHeight);
                 break;
-            case Dialog::SouthWest:
+            }
+            case Dialog::SouthWest: {
                 newHeight = qMin(maximumHeight(), qMax(minimumHeight(), event->y()));
                 newWidth = d->calculateWidthForHeightAndRatio(newHeight, aspectRatio);
                 if (newWidth == -1) {
@@ -475,7 +461,8 @@ void Dialog::mouseMoveEvent(QMouseEvent *event)
                 }
                 position = QPoint(x() + width() - newWidth, y());
                 break;
-            case Dialog::SouthEast:
+            }
+            case Dialog::SouthEast: {
                 newHeight = qMin(maximumHeight(), qMax(minimumHeight(), event->y()));
                 newWidth = d->calculateWidthForHeightAndRatio(newHeight, aspectRatio);
                 if (newWidth == -1) {
@@ -483,7 +470,8 @@ void Dialog::mouseMoveEvent(QMouseEvent *event)
                 }
                 position = QPoint(x(), y());
                 break;
-             default:
+            }
+            default: {
                 newHeight = qMin(maximumHeight(), qMax(minimumHeight(), height()));
                 newWidth = d->calculateWidthForHeightAndRatio(newHeight, aspectRatio);
                 if (newWidth == -1) {
@@ -491,6 +479,7 @@ void Dialog::mouseMoveEvent(QMouseEvent *event)
                 }
                 position = QPoint(x(), y());
                 break;
+            }
         }
 
         QRect newGeom(position, QSize(newWidth, newHeight));
@@ -555,11 +544,6 @@ void Dialog::keyPressEvent(QKeyEvent *event)
     }
 }
 
-bool Dialog::event(QEvent *event)
-{
-    return QWidget::event(event);
-}
-
 void Dialog::resizeEvent(QResizeEvent *event)
 {
     Q_UNUSED(event)
@@ -671,8 +655,7 @@ void Dialog::setGraphicsWidget(QGraphicsWidget *widget)
     }
 }
 
-//KDE5 FIXME: should be const
-QGraphicsWidget *Dialog::graphicsWidget()
+QGraphicsWidget *Dialog::graphicsWidget() const
 {
     return d->graphicsWidgetPtr.data();
 }
@@ -730,8 +713,7 @@ void Dialog::showEvent(QShowEvent * event)
     }
 
     emit dialogVisible(true);
-    WindowEffects::overrideShadow(winId(), !DialogShadows::self()->enabled());
-    DialogShadows::self()->addWindow(this, d->background->enabledBorders());
+    d->dialogshadows->addWindow(this, d->background->enabledBorders());
 }
 
 void Dialog::focusInEvent(QFocusEvent *event)
@@ -813,20 +795,25 @@ void Dialog::animatedHide(Plasma::Direction direction)
 
     Location location = Desktop;
     switch (direction) {
-    case Down:
-        location = BottomEdge;
-        break;
-    case Right:
-        location = RightEdge;
-        break;
-    case Left:
-        location = LeftEdge;
-        break;
-    case Up:
-        location = TopEdge;
-        break;
-    default:
-        break;
+        case Down: {
+            location = BottomEdge;
+            break;
+        }
+        case Right: {
+            location = RightEdge;
+            break;
+        }
+        case Left: {
+            location = LeftEdge;
+            break;
+        }
+        case Up: {
+            location = TopEdge;
+            break;
+        }
+        default: {
+            break;
+        }
     }
 
     Plasma::WindowEffects::slideWindow(this, location);
@@ -890,5 +877,6 @@ void Dialog::setAspectRatioMode(Plasma::AspectRatioMode mode)
     d->aspectRatioMode = mode;
 }
 
-}
-#include "dialog.moc"
+} // Plasma namespace
+
+#include "moc_dialog.cpp"
