@@ -20,8 +20,9 @@
 #include "extender.h"
 
 #include <QAction>
+#include <QDesktopWidget>
 #include <QLabel>
-#include <QGraphicsSceneDragDropEvent>
+#include <QtGui/qgraphicssceneevent.h>
 #include <QGraphicsGridLayout>
 #include <QGraphicsLinearLayout>
 #include <QPainter>
@@ -29,6 +30,7 @@
 #include "applet.h"
 #include "containment.h"
 #include "corona.h"
+#include "dialog.h"
 #include "extendergroup.h"
 #include "extenderitem.h"
 #include "framesvg.h"
@@ -37,6 +39,7 @@
 #include "svg.h"
 #include "theme.h"
 #include "widgets/label.h"
+#include "widgets/scrollwidget.h"
 
 #include "private/applet_p.h"
 #include "private/applethandle_p.h"
@@ -44,6 +47,7 @@
 #include "private/extenderapplet_p.h"
 #include "private/extenderitem_p.h"
 #include "private/extenderitemmimedata_p.h"
+#include "private/popupapplet_p.h"
 
 namespace Plasma
 {
@@ -91,16 +95,35 @@ Extender::Extender(Applet *applet)
         kWarning() << "Applet already has an extender, and can have only one extender."
                    << "The previous extender will be destroyed.";
         delete applet->d->extender.data();
+    } else if (PopupApplet *popup = qobject_cast<PopupApplet *>(applet)) {
+        if (!popup->d->graphicsWidget) {
+            // ensure the popup gets a dialog with us as the graphics widget
+            popup->d->popupConstraintsEvent(SizeConstraint);
+        }
     }
+
     applet->d->extender = this;
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
-    setContentsMargins(0, 0, 0, 0);
-    d->layout = new QGraphicsLinearLayout(this);
+    d->scrollWidget = new ScrollWidget(this);
+    d->scrollWidget->setOverflowBordersVisible(false);
+    d->scrollWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    d->mainWidget = new QGraphicsWidget(d->scrollWidget);
+    d->scrollWidget->setWidget(d->mainWidget);
+    d->mainWidget->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+    connect(d->scrollWidget, SIGNAL(viewportGeometryChanged(QRectF)),
+            this, SLOT(viewportGeometryChanged(QRectF)));
+
+    d->layout = new QGraphicsLinearLayout(d->mainWidget);
     d->layout->setOrientation(Qt::Vertical);
     d->layout->setContentsMargins(0, 0, 0, 0);
     d->layout->setSpacing(0);
-    setLayout(d->layout);
+
+
+    QGraphicsLinearLayout *lay = new QGraphicsLinearLayout(Qt::Vertical, this);
+    lay->addItem(d->scrollWidget);
+    setContentsMargins(0, 0, 0, 0);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     d->loadExtenderItems();
 
@@ -400,6 +423,8 @@ void Extender::dragMoveEvent(QGraphicsSceneDragDropEvent *event)
 
         if (mimeData) {
             itemHoverMoveEvent(mimeData->extenderItem(), event->pos());
+
+            d->setPositionFromDragPosition(event->scenePos());
         }
     }
 }
@@ -434,7 +459,7 @@ void Extender::dragLeaveEvent(QGraphicsSceneDragDropEvent *event)
             //Hide empty internal extender containers when we drag the last item away. Avoids having
             //an ugly empty applet on the desktop temporarily.
             ExtenderApplet *extenderApplet = qobject_cast<ExtenderApplet*>(d->applet.data());
-            if (extenderApplet && sourceExtender == this && attachedItems().count() < 2 && 
+            if (extenderApplet && sourceExtender == this && attachedItems().count() < 2 &&
                 extenderApplet->formFactor() != Plasma::Horizontal &&
                 extenderApplet->formFactor() != Plasma::Vertical) {
                 kDebug() << "leaving the internal extender container, so hide the applet and it's handle.";
@@ -464,6 +489,11 @@ void Extender::dropEvent(QGraphicsSceneDragDropEvent *event)
 
 void Extender::itemAddedEvent(ExtenderItem *item, const QPointF &pos)
 {
+    ExtenderGroup *group = item->isGroup() ? static_cast<ExtenderGroup*>(item) : 0;
+    if (group && group->autoHide() && group->items().isEmpty()) {
+        return;
+    }
+
     if (!item->group()) {
         if (pos == QPointF(-1, -1)) {
             //if it was already there, reposition
@@ -483,9 +513,13 @@ void Extender::itemAddedEvent(ExtenderItem *item, const QPointF &pos)
         }
     }
 
+    d->adjustMinimumSize();
+
     //remove the empty extender message if needed.
     d->updateEmptyExtenderLabel();
     d->updateBorders();
+
+    d->adjustSize();
 }
 
 void Extender::itemRemovedEvent(ExtenderItem *item)
@@ -502,12 +536,17 @@ void Extender::itemRemovedEvent(ExtenderItem *item)
         d->spacerWidget = 0;
     }
 
+    d->adjustMinimumSize();
+
     //add the empty extender message if needed.
     d->updateEmptyExtenderLabel();
     d->updateBorders();
 
+    d->layout->updateGeometry();
+    static_cast<QGraphicsLayoutItem *>(d->scrollWidget)->updateGeometry();
     updateGeometry();
-    resize(effectiveSizeHint(Qt::PreferredSize));
+
+    d->adjustSize();
 }
 
 void Extender::itemHoverEnterEvent(ExtenderItem *item)
@@ -571,29 +610,48 @@ FrameSvg::EnabledBorders Extender::enabledBordersForItem(ExtenderItem *item) con
 
     ExtenderItem *topItem = dynamic_cast<ExtenderItem*>(d->layout->itemAt(0));
     ExtenderItem *bottomItem = dynamic_cast<ExtenderItem*>(d->layout->itemAt(d->layout->count() - 1));
+
+    FrameSvg::EnabledBorders borders = FrameSvg::NoBorder;
+
     if (item->group()) {
         return FrameSvg::NoBorder;
     } else if (d->appearance == TopDownStacked && bottomItem != item) {
-        return FrameSvg::LeftBorder | FrameSvg::BottomBorder | FrameSvg::RightBorder;
+        borders = FrameSvg::LeftBorder | FrameSvg::BottomBorder | FrameSvg::RightBorder;
     } else if (d->appearance == BottomUpStacked && topItem != item) {
-        return FrameSvg::LeftBorder | FrameSvg::TopBorder | FrameSvg::RightBorder;
+        borders =  FrameSvg::LeftBorder | FrameSvg::TopBorder | FrameSvg::RightBorder;
     } else if (d->appearance != NoBorders) {
-        return FrameSvg::LeftBorder | FrameSvg::RightBorder;
+        borders = FrameSvg::LeftBorder | FrameSvg::RightBorder;
     } else {
-        return 0;
+        return FrameSvg::NoBorder;
     }
+
+    if (d->scrollWidget->viewportGeometry().height() < d->mainWidget->boundingRect().height()) {
+        if (QApplication::layoutDirection() == Qt::RightToLeft) {
+            borders &= ~FrameSvg::LeftBorder;
+        } else {
+            borders &= ~FrameSvg::RightBorder;
+        }
+    }
+
+    //someone (i.e. a Dialog) told the extender to disable some border?
+    borders &= ~d->disabledBordersHint;
+
+
+    return borders;
 }
 
 ExtenderPrivate::ExtenderPrivate(Applet *applet, Extender *extender) :
     q(extender),
     applet(applet),
     background(new FrameSvg(extender)),
+    disabledBordersHint(FrameSvg::NoBorder),
     currentSpacerIndex(-1),
     spacerWidget(0),
     emptyExtenderMessage(QString()),
     emptyExtenderLabel(0),
     appearance(Extender::NoBorders),
-    destroying(false)
+    destroying(false),
+    scrollbarVisible(false)
 {
     background->setImagePath("widgets/extender-background");
 }
@@ -605,20 +663,22 @@ ExtenderPrivate::~ExtenderPrivate()
 void ExtenderPrivate::addExtenderItem(ExtenderItem *item, const QPointF &pos)
 {
     if (attachedExtenderItems.contains(item)) {
+        pendingItems.remove(item);
         q->itemAddedEvent(item, pos);
         return;
     }
 
-    QObject::connect(item, SIGNAL(destroyed(ExtenderItem*)), q, SLOT(extenderItemDestroyed(ExtenderItem*)));
+    QObject::connect(item, SIGNAL(destroyed(Plasma::ExtenderItem*)), q, SLOT(extenderItemDestroyed(Plasma::ExtenderItem*)));
     attachedExtenderItems.append(item);
     q->itemHoverLeaveEvent(item);
-    q->itemAddedEvent(item, pos);
-    emit q->itemAttached(item);
+    pendingItems.insert(item, pos);
+    QTimer::singleShot(0, q, SLOT(delayItemAddedEvent()));
 }
 
 void ExtenderPrivate::removeExtenderItem(ExtenderItem *item)
 {
     attachedExtenderItems.removeAll(item);
+    pendingItems.remove(item);
 
     //collapse the popupapplet if the last item is removed.
     if (attachedExtenderItems.isEmpty()) {
@@ -699,10 +759,14 @@ void ExtenderPrivate::loadExtenderItems()
             if (containment) {
                 Corona *corona = containment->corona();
 
-                foreach (Containment *containment, corona->containments()) {
-                    foreach (Applet *applet, containment->applets()) {
-                        if (applet->id() == sourceAppletId) {
-                            sourceApplet = applet;
+                if (sourceAppletId == q->applet()->id()) {
+                    sourceApplet = q->applet();
+                } else {
+                    foreach (Containment *containment, corona->containments()) {
+                        foreach (Applet *applet, containment->applets()) {
+                            if (applet->id() == sourceAppletId) {
+                                sourceApplet = applet;
+                            }
                         }
                     }
                 }
@@ -750,6 +814,15 @@ void ExtenderPrivate::updateBorders()
     }
 }
 
+void ExtenderPrivate::delayItemAddedEvent()
+{
+    QHashIterator<Plasma::ExtenderItem *, QPointF> it(pendingItems);
+    while (it.hasNext()) {
+        q->itemAddedEvent(it.key(), it.value());
+    }
+    pendingItems.clear();
+}
+
 void ExtenderPrivate::updateEmptyExtenderLabel()
 {
     if (q->isEmpty() && !emptyExtenderLabel &&
@@ -773,6 +846,21 @@ void ExtenderPrivate::updateEmptyExtenderLabel()
     }
 }
 
+void ExtenderPrivate::adjustMinimumSize()
+{
+    //FIXME: hardcoded number for the scrollbar
+    scrollWidget->setMinimumWidth(mainWidget->effectiveSizeHint(Qt::MinimumSize).width() + 32);
+    //FIXME: hardcoded number
+    scrollWidget->setMinimumHeight(qMin((qreal)300, mainWidget->effectiveSizeHint(Qt::MinimumSize).height()));
+}
+
+void ExtenderPrivate::setPositionFromDragPosition(const QPointF &pos)
+{
+    const qreal ratio = (q->mapFromScene(pos).y()/scrollWidget->size().height());
+
+    mainWidget->setPos(mainWidget->pos().x(), 30 + (ratio *(scrollWidget->size().height() - mainWidget->size().height() - 30)));
+}
+
 ExtenderGroup *ExtenderPrivate::findGroup(const QString &name) const
 {
     foreach (ExtenderItem *item, attachedExtenderItems) {
@@ -784,13 +872,57 @@ ExtenderGroup *ExtenderPrivate::findGroup(const QString &name) const
     return 0;
 }
 
-void ExtenderPrivate::extenderItemDestroyed(ExtenderItem *item)
+void ExtenderPrivate::extenderItemDestroyed(Plasma::ExtenderItem *item)
 {
-    if (item && attachedExtenderItems.contains(item)) {
+    pendingItems.remove(item);
+
+    if (attachedExtenderItems.contains(item)) {
+        // removeExtenderItem also removes the item from attachedExtenderItems
         removeExtenderItem(item);
     }
 }
 
+void ExtenderPrivate::viewportGeometryChanged(const QRectF &rect)
+{
+    if (appearance != Extender::TopDownStacked && appearance != Extender::BottomUpStacked) {
+        scrollbarVisible = (rect.height() > mainWidget->boundingRect().height());
+        return;
+    }
+
+    bool scroll = !(rect.height() >= mainWidget->boundingRect().height());
+
+    if (scroll != scrollbarVisible) {
+        scrollbarVisible = scroll;
+        updateBorders();
+    }
+}
+
+void ExtenderPrivate::setDisabledBordersHint(const FrameSvg::EnabledBorders borders)
+{
+    if (disabledBordersHint == borders) {
+        return;
+    }
+
+    disabledBordersHint = borders;
+    foreach (Plasma::ExtenderItem *item, attachedExtenderItems) {
+        item->d->themeChanged();
+    }
+}
+
+void ExtenderPrivate::adjustSize()
+{
+    QRect screenRect;
+    QSizeF size = mainWidget->effectiveSizeHint(Qt::PreferredSize);
+    if (applet) {
+        Containment *containment = applet.data()->containment();
+        if (containment && containment->corona()) {
+            screenRect = containment->corona()->screenGeometry(containment->screen());
+        }
+    }
+    q->resize(qMin(screenRect.width()/3, (int)size.width()),
+              qMin(screenRect.height()/3, (int)size.height()));
+}
+
 bool Extender::isEmpty() const
 {
     //It's empty if it doesn't have items or has only group that are empty and autohide
@@ -811,4 +943,4 @@ bool Extender::isEmpty() const
 
 } // Plasma namespace
 
-#include "extender.moc"
+#include "moc_extender.cpp"
