@@ -23,8 +23,7 @@
 #include <QApplication>
 #include <QBitmap>
 #include <QDrag>
-#include <QGraphicsSceneResizeEvent>
-#include <QGraphicsSceneMouseEvent>
+#include <QtGui/qgraphicssceneevent.h>
 #include <QGraphicsLinearLayout>
 #include <QLayout>
 #include <QMimeData>
@@ -34,6 +33,7 @@
 #include <kdebug.h>
 #include <kicon.h>
 #include <kiconloader.h>
+#include <ksharedconfig.h>
 
 #include "applet.h"
 #include "containment.h"
@@ -47,6 +47,7 @@
 #include "view.h"
 
 #include "widgets/iconwidget.h"
+#include "widgets/pushbutton.h"
 
 #include "private/applethandle_p.h"
 #include "private/extender_p.h"
@@ -95,6 +96,19 @@ public:
         m_iconSize = qMax(size.height(), (qreal) fm.height());
     }
 
+    void setBackgroundPrefix(const QString &string)
+    {
+        if (string.isEmpty() || m_background->hasElementPrefix(string)) {
+            m_background->setElementPrefix(string);
+            update();
+        }
+    }
+
+    const QString backgroundPrefix() const
+    {
+        return m_background->prefix();
+    }
+
 protected:
     void resizeEvent(QGraphicsSceneResizeEvent *)
     {
@@ -106,6 +120,7 @@ protected:
 
 private:
     FrameSvg *m_background;
+    QString m_prefix;
     qreal m_iconSize;
 };
 
@@ -143,6 +158,8 @@ ExtenderItem::ExtenderItem(Extender *hostExtender, uint extenderItemId)
     d->collapseIcon = new IconWidget(d->toolbox);
     d->collapseIcon->setCursor(Qt::ArrowCursor);
     d->titleLabel = new Label(d->toolbox);
+    d->titleLabel->setWordWrap(false);
+    d->titleLabel->setAlignment(Qt::AlignCenter);
 
     d->toolboxLayout->addItem(d->collapseIcon);
     d->toolboxLayout->addItem(d->titleLabel);
@@ -172,12 +189,19 @@ ExtenderItem::ExtenderItem(Extender *hostExtender, uint extenderItemId)
         d->group = hostExtender->d->findGroup(groupName);
 
         //Find the sourceapplet.
-        Corona *corona = hostExtender->d->applet.data()->containment()->corona();
-        foreach (Containment *containment, corona->containments()) {
-            foreach (Applet *applet, containment->applets()) {
-                if (applet->id() == sourceAppletId &&
-                        applet->pluginName() == dg.readEntry("sourceAppletPluginName", "")) {
-                    d->sourceApplet = applet;
+        Corona *corona = 0;
+        if (hostExtender && hostExtender->d->applet && hostExtender->d->applet.data()->containment()) {
+            corona = hostExtender->d->applet.data()->containment()->corona();
+        }
+        if (sourceAppletId == hostExtender->applet()->id()) {
+            d->sourceApplet = hostExtender->applet();
+        } else if (corona) {
+            foreach (Containment *containment, corona->containments()) {
+                foreach (Applet *applet, containment->applets()) {
+                    if (applet->id() == sourceAppletId &&
+                            applet->pluginName() == dg.readEntry("sourceAppletPluginName", "")) {
+                        d->sourceApplet = applet;
+                    }
                 }
             }
         }
@@ -200,7 +224,7 @@ ExtenderItem::ExtenderItem(Extender *hostExtender, uint extenderItemId)
     //show or hide the toolbox interface itmems
     d->updateToolBox();
 
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 
     connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(themeChanged()));
     d->setMovable(d->extender->d->applet.data()->immutability() == Plasma::Mutable);
@@ -217,8 +241,36 @@ KConfigGroup ExtenderItem::config() const
     if (!d->extender->d->applet) {
         return KConfigGroup();
     }
+
     KConfigGroup cg = d->extender->d->applet.data()->config("ExtenderItems");
-    return KConfigGroup(&cg, QString::number(d->extenderItemId));
+    KConfigGroup itemCg = KConfigGroup(&cg, QString::number(d->extenderItemId));
+
+    //we try to figure out if we are a transient ExtenderItem
+    //if we are, return an in memory config group (nothing will be saved on disk)
+    //if we aren't, return the ExtenderItems subgroup of our applet, as usual
+    if (d->transient) {
+        //create the dummy config group pointer if doesn't exists
+        if (!d->transientConfig) {
+            d->transientConfig = KSharedConfig::openConfig(QString(), KConfig::SimpleConfig);
+            KConfigGroup dummyGroup = KConfigGroup(d->transientConfig, "ExtenderItems");
+            itemCg.reparent(&dummyGroup);
+            return itemCg;
+        }
+        KConfigGroup dummyGroup = KConfigGroup(d->transientConfig, "ExtenderItems");
+        dummyGroup = KConfigGroup(&dummyGroup, QString::number(d->extenderItemId));
+        return dummyGroup;
+    } else {
+        //if the dummy config pointer still exists, get rid of it
+        if (d->transientConfig) {
+            KConfigGroup dummyGroup = KConfigGroup(d->transientConfig, "ExtenderItems");
+            dummyGroup = KConfigGroup(&dummyGroup, QString::number(d->extenderItemId));
+            dummyGroup.reparent(&cg);
+            delete d->transientConfig.data();
+            d->transientConfig.clear();
+            return dummyGroup;
+        }
+        return itemCg;
+    }
 }
 
 void ExtenderItem::setTitle(const QString &title)
@@ -248,25 +300,25 @@ QString ExtenderItem::name() const
 
 void ExtenderItem::setWidget(QGraphicsItem *widget)
 {
-    if (d->widget) {
-        d->widget->removeSceneEventFilter(this);
-        d->layout->removeItem(d->widget);
+    if (d->widget.data()) {
+        d->widget.data()->removeSceneEventFilter(this);
+        d->layout->removeItem(d->widget.data());
+        d->widget.data()->deleteLater();
     }
 
     if (!widget || !widget->isWidget()) {
-        d->widget = 0;
         return;
     }
 
     widget->setParentItem(this);
     d->widget = static_cast<QGraphicsWidget *>(widget);
-    d->layout->insertItem(1, d->widget);
-    d->widget->setVisible(!d->collapsed);
+    d->layout->insertItem(1, d->widget.data());
+    d->widget.data()->setVisible(!d->collapsed);
 }
 
 QGraphicsItem *ExtenderItem::widget() const
 {
-    return d->widget;
+    return d->widget.data();
 }
 
 void ExtenderItem::setIcon(const QIcon &icon)
@@ -274,6 +326,7 @@ void ExtenderItem::setIcon(const QIcon &icon)
     if (d->collapseIcon->icon().isNull() || icon.cacheKey() != d->collapseIcon->icon().cacheKey()) {
         d->iconName.clear();
         d->collapseIcon->setIcon(icon);
+        d->collapseIcon->setVisible(!icon.isNull());
     }
 }
 
@@ -317,7 +370,7 @@ void ExtenderItem::setExtender(Extender *extender, const QPointF &pos)
     d->extender->d->removeExtenderItem(this);
 
     //move the configuration.
-    if (d->hostApplet() && (extender != d->extender)) {
+    if (!d->transient && d->hostApplet() && (extender != d->extender)) {
         KConfigGroup c = extender->d->applet.data()->config("ExtenderItems");
         config().reparent(&c);
     }
@@ -344,6 +397,11 @@ void ExtenderItem::setExtender(Extender *extender, const QPointF &pos)
     }
 
     Corona *corona = qobject_cast<Corona*>(scene());
+
+    if (!corona) {
+      return;
+    }
+
     KConfigGroup extenderItemGroup(corona->config(), "DetachedExtenderItems");
 
     if (isDetached()) {
@@ -360,6 +418,8 @@ void ExtenderItem::setExtender(Extender *extender, const QPointF &pos)
         extenderItemGroup.deleteGroup(QString::number(d->extenderItemId));
     }
 
+    d->themeChanged();
+
     //we might have to enable or disable the returnToSource button.
     d->updateToolBox();
 
@@ -377,12 +437,6 @@ Extender *ExtenderItem::extender() const
     return d->extender;
 }
 
-//TODO KDE5: only one setGroup()
-void ExtenderItem::setGroup(ExtenderGroup *group)
-{
-    setGroup(group, QPointF(-1, -1));
-}
-
 void ExtenderItem::setGroup(ExtenderGroup *group, const QPointF &pos)
 {
     if (isGroup()) {
@@ -395,6 +449,7 @@ void ExtenderItem::setGroup(ExtenderGroup *group, const QPointF &pos)
     d->group = group;
 
     if (group) {
+        d->toolbox->setBackgroundPrefix("grouped");
         config().writeEntry("group", group->name());
         //TODO: move to another extender if the group we set is actually detached.
         if (group->extender() != extender()) {
@@ -403,11 +458,19 @@ void ExtenderItem::setGroup(ExtenderGroup *group, const QPointF &pos)
         }
         group->d->addItemToGroup(this, pos);
     } else {
+        if (d->extender->appearance() != Extender::NoBorders) {
+            d->toolbox->setBackgroundPrefix("root");
+        } else {
+            d->toolbox->setBackgroundPrefix(QString());
+        }
+        d->toolbox->setBackgroundPrefix(QString());
         if (oldGroup) {
             oldGroup->d->removeItemFromGroup(this);
         }
         config().deleteEntry("group");
     }
+    d->dragStarted = false;
+    d->themeChanged();
 }
 
 ExtenderGroup *ExtenderItem::group() const
@@ -531,19 +594,31 @@ void ExtenderItem::destroy()
 
 void ExtenderItem::setCollapsed(bool collapsed)
 {
+    if (extender()->d->destroying) {
+        return;
+    }
+
     config().writeEntry("isCollapsed", collapsed);
     d->collapsed = collapsed;
     d->collapseIcon->setToolTip(collapsed ? i18n("Expand this widget") : i18n("Collapse this widget"));
-    if (d->widget) {
-        d->widget->setVisible(!collapsed);
+    if (d->widget.data()) {
+        d->widget.data()->setVisible(!collapsed);
         if (collapsed) {
-            d->layout->removeItem(d->widget);
+            d->layout->removeItem(d->widget.data());
         } else {
-            d->layout->insertItem(1, d->widget);
+            d->layout->insertItem(1, d->widget.data());
         }
         updateGeometry();
+
         if (extender()) {
-            extender()->resize(extender()->effectiveSizeHint(Qt::PreferredSize));
+            extender()->d->adjustMinimumSize();
+            static_cast<QGraphicsLayoutItem *>(extender()->d->mainWidget)->updateGeometry();
+            if (group()) {
+                group()->layout()->invalidate();
+                static_cast<QGraphicsLayoutItem *>(group())->updateGeometry();
+            }
+
+            extender()->d->adjustSize();
         }
     }
 }
@@ -569,12 +644,6 @@ void ExtenderItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
     }
 }
 
-void ExtenderItem::moveEvent(QGraphicsSceneMoveEvent *event)
-{
-    Q_UNUSED(event)
-    //not needed anymore, but here for binary compatibility
-}
-
 void ExtenderItem::resizeEvent(QGraphicsSceneResizeEvent *event)
 {
     Q_UNUSED(event)
@@ -702,12 +771,6 @@ bool ExtenderItem::sceneEventFilter(QGraphicsItem *, QEvent *)
     return false;
 }
 
-void ExtenderItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
-{
-    Q_UNUSED(event)
-    //not needed anymore, but here for binary compatibility
-}
-
 void ExtenderItem::hoverMoveEvent(QGraphicsSceneHoverEvent *)
 {
 }
@@ -721,26 +784,35 @@ QSizeF ExtenderItem::sizeHint(Qt::SizeHint which, const QSizeF &constraint) cons
     return QGraphicsWidget::sizeHint(which, constraint);
 }
 
+void ExtenderItem::setTransient(const bool transient)
+{
+    d->transient = transient;
+}
+
+bool ExtenderItem::isTransient() const
+{
+    return d->transient;
+}
+
 ExtenderItemPrivate::ExtenderItemPrivate(ExtenderItem *extenderItem, Extender *hostExtender)
     : q(extenderItem),
-      widget(0),
       toolbox(0),
       extender(hostExtender),
       sourceApplet(0),
       group(0),
       background(new FrameSvg(extenderItem)),
       collapseIcon(0),
+      expirationTimer(0),
       dragStarted(false),
       destroyActionVisibility(false),
       collapsed(false),
-      expirationTimer(0)
+      transient(false)
 {
 }
 
 ExtenderItemPrivate::~ExtenderItemPrivate()
 {
-    delete widget;
-    widget = 0;
+    delete widget.data();
 }
 
 //returns a Rect containing the area of the detachable where the draghandle will be drawn.
@@ -759,37 +831,48 @@ void ExtenderItemPrivate::updateToolBox()
     Q_ASSERT(toolbox);
     Q_ASSERT(toolboxLayout);
 
+
     QAction *closeAction = actions.value("close");
     QAction *returnToSourceAction = actions.value("extenderItemReturnToSource");
     bool returnToSourceVisibility = q->isDetached() && sourceApplet && (hostApplet()->immutability() == Plasma::Mutable);
     int closeIndex = -1;
     int returnToSourceIndex = -1;
     const int startingIndex = 2; // collapse item is index 0, title label is 1
+    int lastIndex = 2;
     const QSizeF widgetSize = collapseIcon->sizeFromIconSize(toolbox->iconSize());
 
     QSet<QAction*> shownActions = actionsInOrder.toSet();
-    QHash<QAction *, IconWidget *> actionIcons;
+
+    QHash<QAction *, QGraphicsWidget *> actionWidgets;
     for (int index = startingIndex; index < toolboxLayout->count(); ++index) {
-        IconWidget *widget = dynamic_cast<IconWidget*>(toolboxLayout->itemAt(index));
+        QGraphicsWidget *widget = dynamic_cast<QGraphicsWidget*>(toolboxLayout->itemAt(index));
+        QAction *widgetAction = 0;
 
         if (!widget) {
             continue;
+        } else if (qobject_cast<IconWidget*>(widget)) {
+            widgetAction = static_cast<IconWidget*>(widget)->action();
+        } else if (qobject_cast<PushButton*>(widget)) {
+            widgetAction = static_cast<PushButton*>(widget)->action();
+        } else {
+            continue;
         }
 
+
         if (closeIndex == -1 && destroyActionVisibility &&
-            closeAction && widget->action() == closeAction) {
+            closeAction && widgetAction == closeAction) {
             closeIndex = index;
             continue;
         }
 
         if (returnToSourceIndex == -1 && returnToSourceVisibility &&
-            returnToSourceAction && widget->action() == returnToSourceAction) {
+            returnToSourceAction && widgetAction == returnToSourceAction) {
             returnToSourceIndex = index;
             continue;
         }
 
-        if (shownActions.contains(widget->action())) {
-            actionIcons.insert(widget->action(), widget);
+        if (shownActions.contains(widgetAction)) {
+            actionWidgets.insert(widgetAction, widget);
             continue;
         }
 
@@ -797,6 +880,7 @@ void ExtenderItemPrivate::updateToolBox()
         widget->deleteLater();
     }
 
+
     // ensure the collapseIcon is the correct size.
     collapseIcon->setMinimumSize(widgetSize);
     collapseIcon->setMaximumSize(widgetSize);
@@ -804,16 +888,35 @@ void ExtenderItemPrivate::updateToolBox()
     //add the actions that are actually set to visible.
     foreach (QAction *action, actionsInOrder) {
         if (action->isVisible() && action != closeAction) {
-            IconWidget *icon = actionIcons.value(action);
-            if (!icon) {
-                icon = new IconWidget(q);
-                icon->setAction(action);
-            }
+            IconWidget *icon = qobject_cast<IconWidget*>(actionWidgets.value(action));
+            PushButton *button = qobject_cast<PushButton*>(actionWidgets.value(action));
 
-            icon->setMinimumSize(widgetSize);
-            icon->setMaximumSize(widgetSize);
-            icon->setCursor(Qt::ArrowCursor);
-            toolboxLayout->insertItem(startingIndex, icon);
+            if (action->icon().isNull() && !action->text().isNull()) {
+                if (!button) {
+                    button = new PushButton(q);
+                    button->setAction(action);
+                }
+
+                button->setMinimumHeight(widgetSize.height());
+                button->setMaximumHeight(widgetSize.height());
+                button->setCursor(Qt::ArrowCursor);
+                toolboxLayout->insertItem(startingIndex, button);
+                ++lastIndex;
+            } else {
+                if (!icon) {
+                    icon = new IconWidget(q);
+                    icon->setAction(action);
+                }
+
+                if (action->icon().isNull()) {
+                    icon->setText(action->text());
+                }
+                icon->setMinimumSize(widgetSize);
+                icon->setMaximumSize(widgetSize);
+                icon->setCursor(Qt::ArrowCursor);
+                toolboxLayout->insertItem(startingIndex, icon);
+                ++lastIndex;
+            }
         }
     }
 
@@ -838,6 +941,7 @@ void ExtenderItemPrivate::updateToolBox()
         } else {
             toolboxLayout->insertItem(closeIndex - 1, returnToSourceIcon);
         }
+        ++lastIndex;
     }
 
     //add the close icon if desired.
@@ -858,6 +962,19 @@ void ExtenderItemPrivate::updateToolBox()
         destroyButton->setMaximumSize(widgetSize);
         destroyButton->setCursor(Qt::ArrowCursor);
         toolboxLayout->addItem(destroyButton);
+        ++lastIndex;
+    }
+
+    //to keep the text really centered
+    toolboxLayout->setItemSpacing(0, KIconLoader::SizeSmall * (lastIndex - 2));
+    if (lastIndex == 2) {
+        if (QApplication::layoutDirection() == Qt::RightToLeft) {
+            toolboxLayout->setContentsMargins(KIconLoader::SizeSmall, 0, 0, 0);
+        } else {
+            toolboxLayout->setContentsMargins(0, 0, KIconLoader::SizeSmall, 0);
+        }
+    } else {
+        toolboxLayout->setContentsMargins(0, 0, 0, 0);
     }
 }
 
@@ -874,7 +991,7 @@ void ExtenderItemPrivate::themeChanged()
 {
     kDebug();
     if (dragStarted) {
-        background->setImagePath("opaque/widgets/extender-background");
+        background->setImagePath("opaque/dialogs/background");
         background->setEnabledBorders(FrameSvg::AllBorders);
     } else {
         background->setImagePath("widgets/extender-background");
@@ -885,6 +1002,16 @@ void ExtenderItemPrivate::themeChanged()
     background->getMargins(left, top, right, bottom);
     layout->setContentsMargins(left, top, right, bottom);
 
+    if (group) {
+        toolbox->setBackgroundPrefix("grouped");
+    } else {
+        if (extender->items().count() <= 1 || extender->items().first() == q || extender->appearance() != Extender::NoBorders) {
+            toolbox->setBackgroundPrefix("root");
+        } else {
+            toolbox->setBackgroundPrefix(QString());
+        }
+    }
+
     toolbox->updateTheme();
 }
 
@@ -931,4 +1058,4 @@ uint ExtenderItemPrivate::s_maxExtenderItemId = 0;
 
 } // namespace Plasma
 
-#include "extenderitem.moc"
+#include "moc_extenderitem.cpp"
