@@ -36,6 +36,7 @@ class PackageMetadataPrivate
         }
 
         QString name;
+        QString icon;
         QString description;
         QStringList keywords;
         QString author;
@@ -45,12 +46,10 @@ class PackageMetadataPrivate
         QString license;
         QString app;
         QString category;
-        QString requiredVersion;
         QString pluginName;
         QString type;
         QString serviceType;
         QString api;
-        KUrl location;
 };
 
 PackageMetadata::PackageMetadata(const PackageMetadata &other)
@@ -90,9 +89,12 @@ void PackageMetadata::write(const QString &filename) const
     config.writeEntry("Encoding", "UTF-8");
 
     config.writeEntry("Name", d->name);
+    config.writeEntry("Icon", d->icon);
     config.writeEntry("Comment", d->description);
     config.writeEntry("Keywords", d->keywords);
+    config.deleteEntry("X-KDE-Keywords");
     config.writeEntry("X-KDE-ServiceTypes", d->serviceType);
+    config.deleteEntry("ServiceTypes");
     config.writeEntry("X-KDE-PluginInfo-Name", d->pluginName);
     config.writeEntry("X-KDE-PluginInfo-Author", d->author);
     config.writeEntry("X-KDE-PluginInfo-Email", d->email);
@@ -103,7 +105,6 @@ void PackageMetadata::write(const QString &filename) const
     config.writeEntry("X-Plasma-API", d->api);
     config.writeEntry("X-KDE-ParentApp", d->app);
     config.writeEntry("Type", d->type);
-    config.writeEntry("X-Plasma-RemoteLocation", d->location);
 }
 
 void PackageMetadata::read(const QString &filename)
@@ -116,9 +117,29 @@ void PackageMetadata::read(const QString &filename)
     KConfigGroup config = cfg.desktopGroup();
 
     d->name = config.readEntry("Name", d->name);
+    d->icon = config.readEntry("Icon", d->icon);
     d->description = config.readEntry("Comment", d->description);
-    d->keywords = config.readEntry("Keywords", d->keywords);
-    d->serviceType = config.readEntry("X-KDE-ServiceTypes", d->serviceType);
+    bool hasKeywords = config.hasKey("Keywords");
+    bool hasXKdeKeywords = config.hasKey("X-KDE-Keywords");
+    if (hasKeywords && hasXKdeKeywords) {
+        d->keywords = config.readEntry("Keywords", d->keywords);
+        d->keywords.append(config.readEntry("X-KDE-Keywords", d->keywords));
+    } else if (hasKeywords) {
+        d->keywords = config.readEntry("Keywords", d->keywords);
+    } else if (hasXKdeKeywords) {
+        d->keywords = config.readEntry("X-KDE-Keywords", d->keywords);
+    }
+    bool hasServiceTypes = config.hasKey("ServiceTypes");
+    bool hasXKdeServiceTypes = config.hasKey("X-KDE-ServiceTypes");
+    if (hasServiceTypes && hasXKdeServiceTypes) {
+        d->serviceType = config.readEntry("ServiceTypes", d->serviceType);
+        d->serviceType.append(',');
+        d->serviceType.append(config.readEntry("X-KDE-ServiceTypes", d->serviceType));
+    } else if (hasServiceTypes) {
+        d->serviceType = config.readEntry("ServiceTypes", d->serviceType);
+    } else if (hasXKdeServiceTypes) {
+        d->serviceType = config.readEntry("X-KDE-ServiceTypes", d->serviceType);
+    }
     d->pluginName = config.readEntry("X-KDE-PluginInfo-Name", d->pluginName);
     d->author = config.readEntry("X-KDE-PluginInfo-Author", d->author);
     d->email = config.readEntry("X-KDE-PluginInfo-Email", d->email);
@@ -129,7 +150,6 @@ void PackageMetadata::read(const QString &filename)
     d->api = config.readEntry("X-Plasma-API", d->api);
     d->app = config.readEntry("X-KDE-ParentApp", d->app);
     d->type = config.readEntry("Type", d->type);
-    d->location = config.readEntry("X-Plasma-RemoteLocation", d->location);
 }
 
 QString PackageMetadata::name() const
@@ -157,6 +177,16 @@ QString PackageMetadata::email() const
     return d->email;
 }
 
+QString PackageMetadata::icon() const
+{
+    return d->icon;
+}
+
+void PackageMetadata::setIcon(const QString &icon)
+{
+    d->icon = icon;
+}
+
 QString PackageMetadata::version() const
 {
     return d->version;
@@ -192,16 +222,6 @@ QStringList PackageMetadata::keywords() const
     return d->keywords;
 }
 
-QString PackageMetadata::requiredVersion() const
-{
-    return d->requiredVersion;
-}
-
-KUrl PackageMetadata::remoteLocation() const
-{
-    return d->location;
-}
-
 QString PackageMetadata::type() const
 {
     return d->type;
@@ -277,16 +297,6 @@ void PackageMetadata::setCategory(const QString &category)
     d->category = category;
 }
 
-void PackageMetadata::setRequiredVersion(const QString &requiredVersion)
-{
-    d->requiredVersion = requiredVersion;
-}
-
-void PackageMetadata::setRemoteLocation(const KUrl &location)
-{
-    d->location = location;
-}
-
 void PackageMetadata::setType(const QString &type)
 {
     d->type = type;
