@@ -21,9 +21,10 @@
 
 #include "config-plasma.h"
 
+#include <QDirIterator>
 #include <QDir>
 #include <QMap>
-#include <QMutableListIterator>
+#include <QtCore/qlist.h>
 #include <QFileInfo>
 
 #include <kconfiggroup.h>
@@ -34,11 +35,8 @@
 #include <kmimetype.h>
 #include <kstandarddirs.h>
 #include <kservicetypetrader.h>
-#include <ktar.h>
 #include <ktemporaryfile.h>
-#include <ktempdir.h>
 #include <kurl.h>
-#include <kzip.h>
 
 #include "package.h"
 #include "private/packages_p.h"
@@ -216,55 +214,55 @@ QString PackageStructure::type() const
     return d->type;
 }
 
-QList<const char*> PackageStructure::directories() const
+QList<QByteArray> PackageStructure::directories() const
 {
-    QList<const char*> dirs;
-    QMap<QByteArray, ContentStructure>::const_iterator it = d->contents.constBegin();
-    while (it != d->contents.constEnd()) {
+    QList<QByteArray> dirs;
+    QMapIterator<QByteArray, ContentStructure> it(d->contents);
+    while (it.hasNext()) {
+        it.next();
         if (it.value().directory) {
             dirs << it.key();
         }
-        ++it;
     }
     return dirs;
 }
 
-QList<const char*> PackageStructure::requiredDirectories() const
+QList<QByteArray> PackageStructure::requiredDirectories() const
 {
-    QList<const char*> dirs;
-    QMap<QByteArray, ContentStructure>::const_iterator it = d->contents.constBegin();
-    while (it != d->contents.constEnd()) {
+    QList<QByteArray> dirs;
+    QMapIterator<QByteArray, ContentStructure> it(d->contents);
+    while (it.hasNext()) {
+        it.next();
         if (it.value().directory &&
             it.value().required) {
             dirs << it.key();
         }
-        ++it;
     }
     return dirs;
 }
 
-QList<const char*> PackageStructure::files() const
+QList<QByteArray> PackageStructure::files() const
 {
-    QList<const char*> files;
-    QMap<QByteArray, ContentStructure>::const_iterator it = d->contents.constBegin();
-    while (it != d->contents.constEnd()) {
+    QList<QByteArray> files;
+    QMapIterator<QByteArray, ContentStructure> it(d->contents);
+    while (it.hasNext()) {
+        it.next();
         if (!it.value().directory) {
             files << it.key();
         }
-        ++it;
     }
     return files;
 }
 
-QList<const char*> PackageStructure::requiredFiles() const
+QList<QByteArray> PackageStructure::requiredFiles() const
 {
-    QList<const char*> files;
-    QMap<QByteArray, ContentStructure>::const_iterator it = d->contents.constBegin();
-    while (it != d->contents.constEnd()) {
+    QList<QByteArray> files;
+    QMapIterator<QByteArray, ContentStructure> it(d->contents);
+    while (it.hasNext()) {
+        it.next();
         if (!it.value().directory && it.value().required) {
             files << it.key();
         }
-        ++it;
     }
     return files;
 }
@@ -282,7 +280,7 @@ QStringList PackageStructure::entryList(const char *key)
         // no prefixes is the same as d->contentsPrefixPths with QStringList() << QString()
         list << d->entryList(QString(), p);
     } else {
-        foreach (QString prefix, d->contentsPrefixPaths) {
+        foreach (const QString &prefix, d->contentsPrefixPaths) {
             list << d->entryList(prefix, p);
         }
     }
@@ -352,14 +350,7 @@ void PackageStructure::removeDefinition(const char *key)
 
 QString PackageStructure::path(const char *key) const
 {
-    //kDebug() << "looking for" << key;
-    QMap<QByteArray, ContentStructure>::const_iterator it = d->contents.constFind(key);
-    if (it == d->contents.constEnd()) {
-        return QString();
-    }
-
-    //kDebug() << "found" << key << "and the value is" << it.value().paths.first();
-    return it.value().paths.first();
+    return searchPath(key).first();
 }
 
 QStringList PackageStructure::searchPath(const char *key) const
@@ -438,11 +429,11 @@ void PackageStructure::setPath(const QString &path)
     KUrl url(path);
     QDir dir(url.toLocalFile());
     QString basePath = dir.canonicalPath();
-    bool valid = QFile::exists(basePath);
+    QFileInfo baseInfo(basePath);
+    bool valid = baseInfo.exists();
 
     if (valid) {
-        QFileInfo info(basePath);
-        if (info.isDir() && !basePath.endsWith('/')) {
+        if (baseInfo.isDir() && !basePath.endsWith('/')) {
             basePath.append('/');
         }
         //kDebug() << "basePath is" << basePath;
@@ -511,8 +502,9 @@ void PackageStructure::write(KConfigBase *config) const
     general.writeEntry("DefaultPackageRoot", d->packageRoot);
     general.writeEntry("AllowExternalPaths", d->externalPaths);
 
-    QMap<QByteArray, ContentStructure>::const_iterator it = d->contents.constBegin();
-    while (it != d->contents.constEnd()) {
+    QMapIterator<QByteArray, ContentStructure> it(d->contents);
+    while (it.hasNext()) {
+        it.next();
         KConfigGroup group = config->group(it.key());
         group.writeEntry("Path", it.value().paths);
         group.writeEntry("Name", it.value().name);
@@ -525,8 +517,6 @@ void PackageStructure::write(KConfigBase *config) const
         if (it.value().required) {
             group.writeEntry("Required", true);
         }
-
-        ++it;
     }
 }
 
@@ -535,12 +525,6 @@ QString PackageStructure::contentsPrefix() const
     return d->contentsPrefixPaths.isEmpty() ? QString() : d->contentsPrefixPaths.first();
 }
 
-void PackageStructure::setContentsPrefix(const QString &prefix)
-{
-    d->contentsPrefixPaths.clear();
-    d->contentsPrefixPaths << prefix;
-}
-
 QStringList PackageStructure::contentsPrefixPaths() const
 {
     return d->contentsPrefixPaths;
@@ -557,27 +541,11 @@ void PackageStructure::setContentsPrefixPaths(const QStringList &prefixPaths)
         it.next();
 
         if (!it.value().endsWith('/')) {
-            it.setValue(it.value() % '/');
+            it.setValue(it.value() + '/');
         }
     }
 }
 
-bool PackageStructure::installPackage(const QString &package, const QString &packageRoot)
-{
-    return Package::installPackage(package, packageRoot, d->servicePrefix);
-}
-
-bool PackageStructure::uninstallPackage(const QString &packageName, const QString &packageRoot)
-{
-    return Package::uninstallPackage(packageName, packageRoot, d->servicePrefix);
-}
-
-void PackageStructure::createNewWidgetBrowser(QWidget *parent)
-{
-    Q_UNUSED(parent)
-    emit newWidgetBrowserFinished();
-}
-
 QString PackageStructure::defaultPackageRoot() const
 {
     return d->packageRoot;
@@ -612,37 +580,12 @@ void PackageStructurePrivate::createPackageMetadata(const QString &path)
     metadata = new PackageMetadata(metadataPath);
 }
 
-//FIXME KDE5: should be const
 PackageMetadata PackageStructure::metadata()
 {
     if (!d->metadata && !d->path.isEmpty()) {
         QFileInfo fileInfo(d->path);
-
         if (fileInfo.isDir()) {
             d->createPackageMetadata(d->path);
-        } else if (fileInfo.exists()) {
-            KArchive *archive = 0;
-            KMimeType::Ptr mimetype = KMimeType::findByPath(d->path);
-
-            if (mimetype->is("application/zip")) {
-                archive = new KZip(d->path);
-            } else if (mimetype->is("application/x-compressed-tar") || mimetype->is("application/x-gzip") ||
-                       mimetype->is("application/x-tar")|| mimetype->is("application/x-bzip-compressed-tar")) {
-                archive = new KTar(d->path);
-            } else {
-                kWarning() << "Could not open package file, unsupported archive format:" << d->path << mimetype->name();
-            }
-
-            if (archive && archive->open(QIODevice::ReadOnly)) {
-                const KArchiveDirectory *source = archive->directory();
-                KTempDir tempdir;
-                source->copyTo(tempdir.name());
-                d->createPackageMetadata(tempdir.name());
-            } else {
-                kWarning() << "Could not open package file:" << d->path;
-            }
-
-            delete archive;
         }
     }
 
@@ -665,5 +608,5 @@ void PackageStructure::setAllowExternalPaths(bool allow)
 
 } // Plasma namespace
 
-#include "packagestructure.moc"
+#include "moc_packagestructure.cpp"
 
