@@ -23,11 +23,11 @@
 #include <QtCore/QStringList>
 #include <QtCore/QSharedData>
 
-#include <kgenericfactory.h>
+#include <kpluginfactory.h>
 #include <klocale.h>
 #include <ksharedptr.h>
+#include <kdeversion.h>
 
-#include <plasma/version.h>
 #include "packagemetadata.h"
 
 class KConfigBase;
@@ -79,7 +79,7 @@ public:
     /**
      * Default constructor for a package structure definition
      *
-     * @arg type the type of package. This is often application specific.
+     * @param type the type of package. This is often application specific.
      **/
     explicit PackageStructure(QObject *parent = 0,
                               const QString &type = i18nc("A non-functional package", "Invalid"));
@@ -97,7 +97,7 @@ public:
     /**
      * Loads a package format by name.
      *
-     * @arg format If not empty, attempts to locate the given format, either
+     * @param format If not empty, attempts to locate the given format, either
      *             from built-ins or via plugins.
      * @return a package that matches the format, if available. The caller
      *         is responsible for deleting the object.
@@ -112,27 +112,30 @@ public:
     /**
      * The directories defined for this package
      **/
-    QList<const char*> directories() const;
+    QList<QByteArray> directories() const;
 
     /**
      * The required directories defined for this package
      **/
-    QList<const char*> requiredDirectories() const;
+    QList<QByteArray> requiredDirectories() const;
 
     /**
      * The individual files, by key, that are defined for this package
      **/
-    QList<const char*> files() const;
+    QList<QByteArray> files() const;
 
     /**
      * The individual required files, by key, that are defined for this package
      **/
-    QList<const char*> requiredFiles() const;
+    QList<QByteArray> requiredFiles() const;
 
     /**
      * Adds a directory to the structure of the package. It is added as
      * a not-required element with no associated mimetypes.
      *
+     * Starting in 4.6, if an entry with the given key
+     * already exists, the path is added to it as a search alternative.
+     *
      * @param key  used as an internal label for this directory
      * @param path the path within the package for this directory
      * @param name the user visible (translated) name for the directory
@@ -143,21 +146,40 @@ public:
      * Adds a file to the structure of the package. It is added as
      * a not-required element with no associated mimetypes.
      *
+     * Starting in 4.6, if an entry with the given key
+     * already exists, the path is added to it as a search alternative.
+     *
      * @param key  used as an internal label for this file
      * @param path the path within the package for this file
      * @param name the user visible (translated) name for the file
      **/
     void addFileDefinition(const char *key, const QString &path, const QString &name);
 
+    /**
+     * Removes a definition from the structure of the package.
+     * @since 4.6
+     * @param key the internal label of the file or directory to remove
+     */
+    void removeDefinition(const char *key);
+
     /**
      * @return path relative to the package root for the given entry
+     * @deprecatd use searchPaths instead
      **/
     QString path(const char *key) const;
 
+    /**
+     * @return a list of paths relative to the package root for the given entry.
+     *         They are orted by importance: when searching for a file the paths
+     *         will be searched in order
+     * @since 4.6
+     **/
+    QStringList searchPath(const char *key) const;
+
     /**
      * Get the list of files of a given type.
      *
-     * @arg key the type of file to look for
+     * @param key the type of file to look for
      * @return list of files by name
      * @since 4.3
      */
@@ -228,44 +250,18 @@ public:
      */
     void write(KConfigBase *config) const;
 
-    /**
-     * Installs a package matching this package structure. By default installs a
-     * native Plasma::Package.
-     *
-     * @param archivePath path to the package archive file
-     * @param packageRoot path to the directory where the package should be
-     *                    installed to
-     * @return true on successful installation, false otherwise
-     **/
-    virtual bool installPackage(const QString &archivePath, const QString &packageRoot);
-
-    /**
-     * Uninstalls a package matching this package structure.
-     *
-     * @arg packageName the name of the package to remove
-     * @arg packageRoot path to the directory where the package should be installed to
-     * @return true on successful removal of the package, false otherwise
-     */
-    virtual bool uninstallPackage(const QString &packageName, const QString &packageRoot);
-
-    /**
-     * When called, the package plugin should display a window to the user
-     * that they can use to browser, select and then install widgets supported by
-     * this package plugin with.
-     *
-     * The user interface may be an in-process dialog or an out-of-process application.
-     *
-     * When the process is complete, the newWidgetBrowserFinished() signal must be
-     * emitted.
-     *
-     * @param parent the parent widget to use for the widget
-     */
-    virtual void createNewWidgetBrowser(QWidget *parent = 0);
-
     /**
      * @return the prefix inserted between the base path and content entries
+     * @deprecated use contentsPrefixPaths() instead.
      */
-    QString contentsPrefix() const;
+    PLASMA_DEPRECATED QString contentsPrefix() const;
+
+    /**
+     * @return the prefix paths inserted between the base path and content entries, in order of priority.
+     *         When searching for a file, all paths will be tried in order.
+     * @since 4.6
+     */
+    QStringList contentsPrefixPaths() const;
 
     /**
      * @return preferred package root. This defaults to plasma/plasmoids/
@@ -293,29 +289,26 @@ public:
      */
     bool allowExternalPaths() const;
 
-Q_SIGNALS:
-    /**
-     * Emitted when the new widget browser process completes.
-     */
-    void newWidgetBrowserFinished();
-
 protected:
     /**
      * Sets whether or not external paths/symlinks can be followed by a package
-     * @arg allow true if paths/symlinks outside of the package should be followed,
+     * @param allow true if paths/symlinks outside of the package should be followed,
      *             false if they should be rejected.
      */
     void setAllowExternalPaths(bool allow);
 
     /**
-     * Sets the prefix that all the contents in this package should
+     * Sets the prefixes that all the contents in this package should
      * appear under. This defaults to "contents/" and is added automatically
      * between the base path and the entries as defined by the package
-     * structure
+     * structure. Multiple entries can be added.
+     * In this case each file request will be searched in all prefixes in order,
+     * and the first found will be returned.
      *
-     * @arg prefix the directory prefix to use
+     * @param prefix paths the directory prefix to use
+     * @since 4.6
      */
-    void setContentsPrefix(const QString &prefix);
+    void setContentsPrefixPaths(const QStringList &prefixPaths);
 
     /**
      * Sets preferred package root.
@@ -337,8 +330,7 @@ private:
  */
 #define K_EXPORT_PLASMA_PACKAGESTRUCTURE(libname, classname) \
 K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
-K_EXPORT_PLUGIN(factory("plasma_packagestructure_" #libname)) \
-K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+K_EXPORT_PLUGIN(factory("plasma_packagestructure_" #libname))
 
 } // Plasma namespace
 #endif
