@@ -25,8 +25,10 @@
 #include <QPaintEngine>
 #include <QPixmap>
 
+#include "kiconeffect.h"
 #include "private/effects/blur.cpp"
 #include "private/effects/halopainter_p.h"
+#include "svg.h"
 
 namespace Plasma
 {
@@ -36,19 +38,11 @@ namespace PaintUtils
 
 void shadowBlur(QImage &image, int radius, const QColor &color)
 {
-    if (radius < 1) {
-        return;
-    }
-    if (image.isNull()) {
+    if (radius < 1 || image.isNull()) {
         return;
     }
 
-    expblur<16, 7>(image, radius);
-
-    QPainter p(&image);
-    p.setCompositionMode(QPainter::CompositionMode_SourceIn);
-    p.fillRect(image.rect(), color);
-    p.end();
+    KIconEffect::shadowBlur(image, float(radius), color);
 }
 
 //TODO: we should have shadowText methods that paint the results directly into a QPainter passed in
@@ -82,8 +76,7 @@ QPixmap shadowText(QString text, const QFont &font, QColor textColor, QColor sha
     p.end();
 
     //Draw blurred shadow
-    QImage img(textRect.size() + QSize(radius * 2, radius * 2),
-    QImage::Format_ARGB32_Premultiplied);
+    QImage img(textRect.size() + QSize(radius * 2, radius * 2), QImage::Format_ARGB32_Premultiplied);
     img.fill(0);
     p.begin(&img);
     p.drawImage(QPoint(radius, radius), textPixmap.toImage());
@@ -91,37 +84,66 @@ QPixmap shadowText(QString text, const QFont &font, QColor textColor, QColor sha
     shadowBlur(img, radius, shadowColor);
 
     //Compose text and shadow
-    int addSizeX;
-    int addSizeY;
-    if (offset.x() > radius) {
-        addSizeX = abs(offset.x()) - radius;
-    } else {
-        addSizeX = 0;
-    }
-    if (offset.y() > radius) {
-        addSizeY = abs(offset.y()) - radius;
-    } else {
-        addSizeY = 0;
-    }
+    int addSizeX = qMax(0, qAbs(offset.x()) - radius);
+    int addSizeY = qMax(0, qAbs(offset.y()) - radius);
 
     QPixmap finalPixmap(img.size() + QSize(addSizeX, addSizeY));
     finalPixmap.fill(Qt::transparent);
     p.begin(&finalPixmap);
-    QPointF offsetF(offset);
-    QPointF textTopLeft(finalPixmap.rect().topLeft() +
-                        QPointF ((finalPixmap.width() - textPixmap.width()) / 2.0, (finalPixmap.height() - textPixmap.height()) / 2.0) -
-                        (offsetF / 2.0));
-    QPointF shadowTopLeft(finalPixmap.rect().topLeft() +
-                          QPointF ((finalPixmap.width() - img.width()) / 2.0, (finalPixmap.height() - img.height()) / 2.0) +
-                          (offsetF / 2.0));
-
-    p.drawImage(shadowTopLeft, img);
-    p.drawPixmap(textTopLeft, textPixmap);
+    p.drawImage(qMax(0, offset.x()), qMax(0, offset.y()), img);
+    p.drawPixmap(radius + qMax(0, -offset.x()), radius + qMax(0, -offset.y()), textPixmap);
     p.end();
 
     return finalPixmap;
 }
 
+QPixmap texturedText(const QString &text, const QFont &font, Plasma::Svg *texture)
+{
+    QFontMetrics fm(font);
+    //the text will be moved a bit from contentsRect
+    QRect contentsRect = fm.boundingRect(text).adjusted(0, 0, 2, 2);
+    contentsRect.moveTo(0,0);
+
+    QPixmap pixmap(contentsRect.size());
+    pixmap.fill(Qt::transparent);
+
+    QPainter buffPainter(&pixmap);
+    buffPainter.setPen(Qt::black);
+
+    buffPainter.setFont(font);
+    buffPainter.drawText(contentsRect, Qt::AlignCenter, text);
+    buffPainter.setCompositionMode(QPainter::CompositionMode_SourceIn);
+    texture->paint(&buffPainter, contentsRect, "foreground");
+    buffPainter.end();
+
+    //do the shadow
+    QImage image(pixmap.size() + QSize(2, 2), QImage::Format_ARGB32_Premultiplied);
+    image.fill(Qt::transparent);
+    buffPainter.begin(&image);
+    buffPainter.setFont(font);
+    buffPainter.drawText(contentsRect.translated(1, 1), Qt::AlignCenter, text);
+    buffPainter.setCompositionMode(QPainter::CompositionMode_SourceIn);
+    texture->paint(&buffPainter, contentsRect.adjusted(-1, -1, 1, 1), "shadow");
+    buffPainter.end();
+
+    expblur<16, 7>(image, 1);
+    //hole in the shadow
+    buffPainter.begin(&image);
+    buffPainter.setCompositionMode(QPainter::CompositionMode_DestinationOut);
+    buffPainter.setFont(font);
+    buffPainter.drawText(contentsRect.translated(1, 1), Qt::AlignCenter, text);
+    buffPainter.end();
+
+    QPixmap ret(image.size());
+    ret.fill(Qt::transparent);
+    buffPainter.begin(&ret);
+    buffPainter.setCompositionMode(QPainter::CompositionMode_SourceOver);
+    buffPainter.drawImage(QPoint(0,0), image);
+    buffPainter.drawPixmap(QPoint(1,1), pixmap);
+    buffPainter.end();
+    return ret;
+}
+
 void drawHalo(QPainter *painter, const QRectF &rect)
 {
     HaloPainter::instance()->drawHalo(painter, rect.toRect());
@@ -147,6 +169,7 @@ void centerPixmaps(QPixmap &from, QPixmap &to)
     if (from.size() == to.size() && from.hasAlphaChannel() && to.hasAlphaChannel()) {
         return;
     }
+
     QRect fromRect(from.rect());
     QRect toRect(to.rect());
  
@@ -181,103 +204,65 @@ QPixmap transition(const QPixmap &from, const QPixmap &to, qreal amount)
         return from;
     }
 
-    QPixmap startPixmap(from);
-    QPixmap targetPixmap(to);
-
-    if (from.size() != to.size() || !from.hasAlphaChannel() || !to.hasAlphaChannel()) {
-        centerPixmaps(startPixmap, targetPixmap);
+    if (qFuzzyCompare(amount + 1, qreal(1.0))) {
+        return from;
     }
 
-    //paint to in the center of from
-    QRect toRect = to.rect();
-
-    QColor color;
-    color.setAlphaF(amount);
+    QRect startRect(from.rect());
+    QRect targetRect(to.rect());
+    QSize pixmapSize = startRect.size().expandedTo(targetRect.size());
+    QRect toRect = QRect(QPoint(0,0), pixmapSize);
+    targetRect.moveCenter(toRect.center());
+    startRect.moveCenter(toRect.center());
 
+    //paint to in the center of from, skipping setAlphaF()
+    QColor color(0, 0, 0, amount);
 
     // If the native paint engine supports Porter/Duff compositing and CompositionMode_Plus
     QPaintEngine *paintEngine = from.paintEngine();
     if (paintEngine && 
         paintEngine->hasFeature(QPaintEngine::PorterDuff) &&
         paintEngine->hasFeature(QPaintEngine::BlendModes)) {
+        QPixmap startPixmap(pixmapSize);
+        startPixmap.fill(Qt::transparent);
+
+        QPixmap targetPixmap(pixmapSize);
+        targetPixmap.fill(Qt::transparent);
 
         QPainter p;
         p.begin(&targetPixmap);
+        p.drawPixmap(targetRect, to);
         p.setCompositionMode(QPainter::CompositionMode_DestinationIn);
-        p.fillRect(targetPixmap.rect(), color);
+        p.fillRect(targetRect, color);
         p.end();
 
         p.begin(&startPixmap);
+        p.drawPixmap(startRect, from);
         p.setCompositionMode(QPainter::CompositionMode_DestinationOut);
-        p.fillRect(startPixmap.rect(), color);
+        p.fillRect(startRect, color);
         p.setCompositionMode(QPainter::CompositionMode_Plus);
-        p.drawPixmap(toRect.topLeft(), targetPixmap);
+        p.drawPixmap(targetRect, targetPixmap);
         p.end();
 
         return startPixmap;
-    }
-#if defined(Q_WS_X11) && defined(HAVE_XRENDER)
-    // We have Xrender support
-    else if (paintEngine && paintEngine->hasFeature(QPaintEngine::PorterDuff)) {
-        // QX11PaintEngine doesn't implement CompositionMode_Plus in Qt 4.3,
-        // which we need to be able to do a transition from one pixmap to
-        // another.
-        //
-        // In order to avoid the overhead of converting the pixmaps to images
-        // and doing the operation entirely in software, this function has a
-        // specialized path for X11 that uses Xrender directly to do the
-        // transition. This operation can be fully accelerated in HW.
-        //
-        // This specialization can be removed when QX11PaintEngine supports
-        // CompositionMode_Plus.
-        QPixmap source(targetPixmap), destination(startPixmap);
-
-        source.detach();
-        destination.detach();
-
-        Display *dpy = QX11Info::display();
-
-        XRenderPictFormat *format = XRenderFindStandardFormat(dpy, PictStandardA8);
-        XRenderPictureAttributes pa;
-        pa.repeat = 1; // RepeatNormal
-
-        // Create a 1x1 8 bit repeating alpha picture
-        Pixmap pixmap = XCreatePixmap(dpy, destination.handle(), 1, 1, 8);
-        Picture alpha = XRenderCreatePicture(dpy, pixmap, format, CPRepeat, &pa);
-        XFreePixmap(dpy, pixmap);
-
-        // Fill the alpha picture with the opacity value
-        XRenderColor xcolor;
-        xcolor.alpha = quint16(0xffff * amount);
-        XRenderFillRectangle(dpy, PictOpSrc, alpha, &xcolor, 0, 0, 1, 1);
-
-        // Reduce the alpha of the destination with 1 - opacity
-        XRenderComposite(dpy, PictOpOutReverse, alpha, None, destination.x11PictureHandle(),
-                         0, 0, 0, 0, 0, 0, destination.width(), destination.height());
-
-        // Add source * opacity to the destination
-        XRenderComposite(dpy, PictOpAdd, source.x11PictureHandle(), alpha,
-                         destination.x11PictureHandle(),
-                         toRect.x(), toRect.y(), 0, 0, 0, 0, destination.width(), destination.height());
-
-        XRenderFreePicture(dpy, alpha);
-        return destination;
-    }
-#endif
-    else {
+    } else {
         // Fall back to using QRasterPaintEngine to do the transition.
-        QImage under = startPixmap.toImage();
-        QImage over  = targetPixmap.toImage();
+        QImage under(pixmapSize, QImage::Format_ARGB32_Premultiplied);
+        under.fill(Qt::transparent);
+        QImage over(pixmapSize, QImage::Format_ARGB32_Premultiplied);
+        over.fill(Qt::transparent);
 
         QPainter p;
         p.begin(&over);
+        p.drawPixmap(targetRect, to);
         p.setCompositionMode(QPainter::CompositionMode_DestinationIn);
         p.fillRect(over.rect(), color);
         p.end();
 
         p.begin(&under);
+        p.drawPixmap(startRect, from);
         p.setCompositionMode(QPainter::CompositionMode_DestinationOut);
-        p.fillRect(under.rect(), color);
+        p.fillRect(startRect, color);
         p.setCompositionMode(QPainter::CompositionMode_Plus);
         p.drawImage(toRect.topLeft(), over);
         p.end();
