@@ -30,7 +30,7 @@
 #include <QDeclarativeItem>
 
 #ifdef Q_WS_X11
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 #endif
 
 #include <kicon.h>
@@ -104,7 +104,7 @@ void PopupApplet::setPopupIcon(const QString &iconName)
     }
 
     // Attempt 2: is it a svg in the icons directory?
-    QString name = QString("icons/") + iconName.split("-").first();
+    const QString name = QString("icons/") + iconName.split("-").first();
     if (!Plasma::Theme::defaultTheme()->imagePath(name).isEmpty()) {
         d->createIconWidget();
         d->icon->setSvg(name, iconName);
@@ -139,7 +139,7 @@ void PopupApplet::setWidget(QWidget *widget)
 
             QLayout *existingLayout = dialog->layout();
             if (existingLayout) {
-                lay = dynamic_cast<QVBoxLayout *>(existingLayout);
+                lay = qobject_cast<QVBoxLayout *>(existingLayout);
                 if (!lay) {
                     delete existingLayout;
                 }
@@ -283,9 +283,10 @@ void PopupAppletPrivate::popupConstraintsEvent(Plasma::Constraints constraints)
         }
 
         //Applet on desktop
-        if ((!parentApplet || parentApplet->isContainment() ) && icon && (!icon->svg().isEmpty() || !icon->icon().isNull()) && ((f != Plasma::Vertical && f != Plasma::Horizontal) ||
-            ((f == Plasma::Vertical && parentSize.width() >= minimum.width()) ||
-             (f == Plasma::Horizontal && parentSize.height() >= minimum.height())))) {
+        if ((((!parentApplet || parentApplet->isContainment() ) && icon && (!icon->svg().isEmpty() || !icon->icon().isNull()) && ((f != Plasma::Vertical && f != Plasma::Horizontal))) ||
+            (((f == Plasma::Vertical && parentSize.width() >= minimum.width()) ||
+             (f == Plasma::Horizontal && parentSize.height() >= minimum.height())) &&
+             (!q->parentWidget() || (q->parentWidget()->size().width() >= minimum.width() && q->parentWidget()->size().height() >= minimum.height()))))) {
             //kDebug() << "we are expanding the popupapplet";
 
 
@@ -470,8 +471,9 @@ QSizeF PopupApplet::sizeHint(Qt::SizeHint which, const QSizeF & constraint) cons
             const int size = IconSize(KIconLoader::Panel);
             return QSizeF(size, size);
         }
-        default:
+        default: {
             break;
+        }
     }
 
     const int size = IconSize(KIconLoader::Desktop);
@@ -965,28 +967,31 @@ void PopupAppletPrivate::updateDialogPosition(bool move)
 
     Dialog::ResizeCorners resizeCorners = Dialog::NoCorner;
     switch (q->location()) {
-    case BottomEdge:
-        resizeCorners = Dialog::NorthEast | Dialog::NorthWest;
-        popupPlacement = reverse ? TopPosedLeftAlignedPopup : TopPosedRightAlignedPopup;
-        break;
-    case TopEdge:
-        resizeCorners = Dialog::SouthEast | Dialog::SouthWest;
-        popupPlacement = reverse ? Plasma::BottomPosedLeftAlignedPopup : Plasma::BottomPosedRightAlignedPopup;
-        break;
-    case LeftEdge:
-        resizeCorners = Dialog::SouthEast | Dialog::NorthEast;
-        popupPlacement = reverse ? RightPosedTopAlignedPopup : RightPosedBottomAlignedPopup;
-        break;
-
-    case RightEdge:
-        resizeCorners = Dialog::SouthWest | Dialog::NorthWest;
-        popupPlacement = reverse ? LeftPosedTopAlignedPopup : LeftPosedBottomAlignedPopup;
-        break;
-
-    default:
-        popupPlacement = FloatingPopup;
-        resizeCorners = Dialog::All;
-        break;
+        case BottomEdge: {
+            resizeCorners = Dialog::NorthEast | Dialog::NorthWest;
+            popupPlacement = reverse ? TopPosedLeftAlignedPopup : TopPosedRightAlignedPopup;
+            break;
+        }
+        case TopEdge: {
+            resizeCorners = Dialog::SouthEast | Dialog::SouthWest;
+            popupPlacement = reverse ? Plasma::BottomPosedLeftAlignedPopup : Plasma::BottomPosedRightAlignedPopup;
+            break;
+        }
+        case LeftEdge: {
+            resizeCorners = Dialog::SouthEast | Dialog::NorthEast;
+            popupPlacement = reverse ? RightPosedTopAlignedPopup : RightPosedBottomAlignedPopup;
+            break;
+        }
+        case RightEdge: {
+            resizeCorners = Dialog::SouthWest | Dialog::NorthWest;
+            popupPlacement = reverse ? LeftPosedTopAlignedPopup : LeftPosedBottomAlignedPopup;
+            break;
+        }
+        default: {
+            popupPlacement = FloatingPopup;
+            resizeCorners = Dialog::All;
+            break;
+        }
     }
 
     dialog->setResizeHandleCorners(resizeCorners);
@@ -997,5 +1002,5 @@ void PopupAppletPrivate::updateDialogPosition(bool move)
 
 } // Plasma namespace
 
-#include "popupapplet.moc"
+#include "moc_popupapplet.cpp"
 
