@@ -21,15 +21,15 @@
 
 #include <QApplication>
 #include <QBitmap>
-#include <QtGui/QGraphicsSceneMouseEvent>
-#include <QtGui/QLinearGradient>
+#include <QtGui/qgraphicssceneevent.h>
+#include <QtGui/qbrush.h>
 #include <QtGui/QPainter>
 #include <QtGui/QApplication>
 #include <QtGui/QMenu>
-#include <QTouchEvent>
+#include <QtGui/qevent.h>
 #include <QMatrix>
 #include <QTransform>
-#include <QWeakPointer>
+#include <QtCore/qsharedpointer.h>
 #include <QPropertyAnimation>
 
 #include <kcolorscheme.h>
@@ -76,7 +76,6 @@ AppletHandle::AppletHandle(Containment *containment, Applet *applet, const QPoin
     setFlags(flags() | QGraphicsItem::ItemStacksBehindParent);
     KColorScheme colorScheme(QPalette::Active, KColorScheme::View,
                              Theme::defaultTheme()->colorScheme());
-    setAcceptTouchEvents(true);
     m_gradientColor = colorScheme.background(KColorScheme::NormalBackground).color();
     m_originalGeom = mapToScene(QRectF(QPoint(0,0), m_applet->size())).boundingRect();
     m_originalTransform = m_applet->transform();
@@ -96,7 +95,7 @@ AppletHandle::AppletHandle(Containment *containment, Applet *applet, const QPoin
     connect(m_leaveTimer, SIGNAL(timeout()), this, SLOT(leaveTimeout()));
     connect(m_applet, SIGNAL(appletDestroyed(Plasma::Applet*)), this, SLOT(appletDestroyed()));
 
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
     m_hoverTimer->start();
 
     //icons
@@ -160,35 +159,6 @@ QPainterPath AppletHandle::shape() const
     }
 }
 
-QPainterPath handleRect(const QRectF &rect, int radius, bool onRight)
-{
-    QPainterPath path;
-    if (onRight) {
-        // make the left side straight
-        path.moveTo(rect.left(), rect.top());              // Top left
-        path.lineTo(rect.right() - radius, rect.top());    // Top side
-        path.quadTo(rect.right(), rect.top(),
-                    rect.right(), rect.top() + radius);    // Top right corner
-        path.lineTo(rect.right(), rect.bottom() - radius); // Right side
-        path.quadTo(rect.right(), rect.bottom(),
-                    rect.right() - radius, rect.bottom()); // Bottom right corner
-        path.lineTo(rect.left(), rect.bottom());           // Bottom side
-    } else {
-        // make the right side straight
-        path.moveTo(QPointF(rect.left(), rect.top() + radius));
-        path.quadTo(rect.left(), rect.top(),
-                    rect.left() + radius, rect.top());     // Top left corner
-        path.lineTo(rect.right(), rect.top());             // Top side
-        path.lineTo(rect.right(), rect.bottom());          // Right side
-        path.lineTo(rect.left() + radius, rect.bottom());  // Bottom side
-        path.quadTo(rect.left(), rect.bottom(),
-                    rect.left(), rect.bottom() - radius);  // Bottom left corner
-    }
-
-    path.closeSubpath();
-    return path;
-}
-
 void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
     Q_UNUSED(option);
@@ -315,7 +285,7 @@ void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
     //XXX this code is duplicated in the next function
     QPointF basePoint = m_rect.topLeft() + QPointF(HANDLE_MARGIN, iconMargin);
     QPointF step = QPointF(0, m_iconSize + iconMargin);
-    QPointF separator = step + QPointF(0, iconMargin);
+    // QPointF separator = step + QPointF(0, iconMargin);
     //end duplicate code
 
     QPointF shiftC;
@@ -324,25 +294,30 @@ void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
     QPointF shiftM;
     QPointF shiftMx;
 
-    switch(m_pressedButton)
-    {
-    case ConfigureButton:
-        shiftC = QPointF(2, 2);
-        break;
-    case RemoveButton:
-        shiftD = QPointF(2, 2);
-        break;
-    case RotateButton:
-        shiftR = QPointF(2, 2);
-        break;
-    case ResizeButton:
-        shiftM = QPointF(2, 2);
-        break;
-    case MaximizeButton:
-        shiftMx = QPointF(2, 2);
-        break;
-    default:
-        break;
+    switch(m_pressedButton) {
+        case ConfigureButton: {
+            shiftC = QPointF(2, 2);
+            break;
+        }
+        case RemoveButton: {
+            shiftD = QPointF(2, 2);
+            break;
+        }
+        case RotateButton: {
+            shiftR = QPointF(2, 2);
+            break;
+        }
+        case ResizeButton: {
+            shiftM = QPointF(2, 2);
+            break;
+        }
+        case MaximizeButton: {
+            shiftMx = QPointF(2, 2);
+            break;
+        }
+        default: {
+            break;
+        }
     }
 
     QRectF sourceIconRect(QPointF(0, m_decorationRect.height() + 1), iconSize);
@@ -402,8 +377,8 @@ AppletHandle::ButtonType AppletHandle::mapToButton(const QPointF &point) const
     //XXX this code is duplicated in the prev. function
     QPointF basePoint = m_rect.topLeft() + QPointF(HANDLE_MARGIN, iconMargin);
     QPointF step = QPointF(0, m_iconSize + iconMargin);
-    QPointF separator = step + QPointF(0, iconMargin);
-   //end duplicate code
+    // QPointF separator = step + QPointF(0, iconMargin);
+    //end duplicate code
 
     QRectF activeArea = QRectF(basePoint, QSizeF(m_iconSize, m_iconSize));
 
@@ -522,20 +497,21 @@ void AppletHandle::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 
     if (m_applet && event->button() == Qt::LeftButton) {
         switch (m_pressedButton) {
-        case ConfigureButton:
-            //FIXME: Remove this call once the configuration management change was done
-            if (m_pressedButton == releasedAtButton) {
-                m_applet->showConfigurationInterface();
+            case ConfigureButton: {
+                //FIXME: Remove this call once the configuration management change was done
+                if (m_pressedButton == releasedAtButton) {
+                    m_applet->showConfigurationInterface();
+                }
+                break;
             }
-            break;
-        case RemoveButton:
-            if (m_pressedButton == releasedAtButton) {
-                forceDisappear();
-                m_applet->destroy();
+            case RemoveButton: {
+                if (m_pressedButton == releasedAtButton) {
+                    forceDisappear();
+                    m_applet->destroy();
+                }
+                break;
             }
-            break;
-        case MoveButton:
-        {
+            case MoveButton: {
                 // test for containment change
                 //kDebug() << "testing for containment change, sceneBoundingRect = "
                 //         << m_containment->sceneBoundingRect();
@@ -561,15 +537,17 @@ void AppletHandle::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
                         }
                     }
                 }
-            break;
-        }
-        case MaximizeButton:
-            if (m_applet) {
-                m_applet->runAssociatedApplication();
+                break;
+            }
+            case MaximizeButton: {
+                if (m_applet) {
+                    m_applet->runAssociatedApplication();
+                }
+                break;
+            }
+            default: {
+                break;
             }
-            break;
-        default:
-            break;
         }
     }
 
@@ -742,63 +720,6 @@ void AppletHandle::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
     }
 }
 
-bool AppletHandle::sceneEvent(QEvent *event)
-{
-    switch (event->type()) {
-    case QEvent::TouchEnd: {
-        QTransform t = m_applet->transform();
-        QRectF geom = m_applet->geometry();
-        QPointF translation(t.m31(), t.m32());
-        QPointF center = geom.center();
-        geom.setWidth(geom.width()*qAbs(t.m11()));
-        geom.setHeight(geom.height()*qAbs(t.m22()));
-        geom.moveCenter(center);
-
-        m_applet->setGeometry(geom);
-        t.reset();
-        t.translate(m_applet->size().width()/2, m_applet->size().height()/2);
-        t.rotateRadians(m_angle);
-        t.translate(-m_applet->size().width()/2, -m_applet->size().height()/2);
-
-
-        m_applet->setTransform(t);
-        return true;
-    }
-    case QEvent::TouchBegin:
-    case QEvent::TouchUpdate:
-    {
-        QList<QTouchEvent::TouchPoint> touchPoints = static_cast<QTouchEvent *>(event)->touchPoints();
-        if (touchPoints.count() == 2) {
-            const QTouchEvent::TouchPoint &touchPoint0 = touchPoints.first();
-            const QTouchEvent::TouchPoint &touchPoint1 = touchPoints.last();
-
-            //rotation
-            QLineF line0(touchPoint0.lastScenePos(), touchPoint1.lastScenePos());
-            QLineF line1(touchPoint0.scenePos(), touchPoint1.scenePos());
-            m_angle = m_angle+(line1.angleTo(line0)*M_PI_2/90);
-            QTransform t = m_applet->transform();
-            t.translate(m_applet->size().width()/2, m_applet->size().height()/2);
-            t.rotate(line1.angleTo(line0));
-
-            //scaling
-            qreal scaleFactor = 1;
-            if (line0.length() > 0) {
-                scaleFactor = line1.length() / line0.length();
-            }
-
-            t.scale(scaleFactor, scaleFactor);
-            t.translate(-m_applet->size().width()/2, -m_applet->size().height()/2);
-            m_applet->setTransform(t);
-
-        }
-        return true;
-    }
-    default:
-        break;
-    }
-    return QGraphicsItem::sceneEvent(event);
-}
-
 //pos relative to scene
 void AppletHandle::switchContainment(Containment *containment, const QPointF &pos)
 {
@@ -865,41 +786,6 @@ bool AppletHandle::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
 {
     if (watched == m_applet && event->type() == QEvent::GraphicsSceneHoverLeave) {
         hoverLeaveEvent(static_cast<QGraphicsSceneHoverEvent*>(event));
-    } else if (watched == m_applet && event->type() == QEvent::GraphicsSceneMousePress) {
-        QGraphicsSceneMouseEvent *me = static_cast<QGraphicsSceneMouseEvent *>(event);
-
-        QPointF pos = mapFromScene(me->scenePos());
-        if (m_applet->contentsRect().contains(pos)) {
-            return false;
-        }
-
-        me->setPos(pos);
-        mousePressEvent(me);
-        return true;
-    } else if (watched == m_applet && event->type() == QEvent::GraphicsSceneMouseRelease) {
-        if (m_pressedButton == NoButton) {
-            return false;
-        }
-
-        QGraphicsSceneMouseEvent *me = static_cast<QGraphicsSceneMouseEvent *>(event);
-
-        QPointF pos = mapFromScene(me->scenePos());
-        me->setPos(pos);
-        mouseReleaseEvent(me);
-        return true;
-    } else if (watched == m_applet && event->type() == QEvent::GraphicsSceneMouseMove) {
-        if (m_pressedButton == NoButton) {
-            return false;
-        }
-
-        QGraphicsSceneMouseEvent *me = static_cast<QGraphicsSceneMouseEvent *>(event);
-
-        QPointF pos = mapFromScene(me->scenePos());
-
-
-        me->setPos(pos);
-        mouseMoveEvent(me);
-        return true;
     }
 
     return false;
@@ -1023,7 +909,7 @@ void AppletHandle::startFading(FadeType anim, const QPointF &hoverPos, bool pres
 
     m_animType = anim;
     //kDebug() << "animating for " << time << "ms";
-    if (m_animType == FadeIn) {
+    if (m_animType == FadeIn && propAnim) {
         propAnim->setDirection(QAbstractAnimation::Forward);
         propAnim->start();
     } else if (propAnim) {
@@ -1034,7 +920,7 @@ void AppletHandle::startFading(FadeType anim, const QPointF &hoverPos, bool pres
 
 void AppletHandle::forceDisappear()
 {
-    setAcceptsHoverEvents(false);
+    setAcceptHoverEvents(false);
     startFading(FadeOut, m_entryPos);
 }
 
@@ -1107,5 +993,5 @@ void AppletHandle::calculateSize()
 
 } // Plasma Namespace
 
-#include "applethandle_p.moc"
+#include "moc_applethandle_p.cpp"
 
