@@ -21,13 +21,17 @@
 #define PLASMA_APPLETHANDLE_P_H
 
 #include <QtCore/QObject>
-#include <QGraphicsObject>
+#include <QtGui/qgraphicsitem.h>
 #include <QTimer>
+#include <QtCore/qsharedpointer.h>
+#include <QPropertyAnimation>
+#include <QtGui/qgraphicsview.h>
+#include <QtGui/qgraphicsitem.h>
 
 #include "animator.h"
 #include "svg.h"
 
-class QGraphicsView;
+#include <QGraphicsView>
 
 namespace Plasma
 {
@@ -39,6 +43,7 @@ class View;
 class AppletHandle : public QGraphicsObject
 {
     Q_OBJECT
+    Q_PROPERTY(qreal fadeAnimation READ fadeAnimation WRITE setFadeAnimation)
     Q_INTERFACES(QGraphicsItem)
     public:
         enum FadeType {
@@ -58,8 +63,9 @@ class AppletHandle : public QGraphicsObject
         AppletHandle(Containment *parent, Applet *applet, const QPointF &hoverPos);
         virtual ~AppletHandle();
 
-        void detachApplet ();
+        bool shown() const;
 
+        void detachApplet();
         Applet *applet() const;
 
         QRectF boundingRect() const;
@@ -76,18 +82,19 @@ class AppletHandle : public QGraphicsObject
         void hoverMoveEvent(QGraphicsSceneHoverEvent *event);
         void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
         bool sceneEventFilter(QGraphicsItem *watched, QEvent *event);
-        bool sceneEvent(QEvent*);
 
     Q_SIGNALS:
        void disappearDone(AppletHandle *self);
 
     private Q_SLOTS:
-        void fadeAnimation(qreal progress);
+        void setFadeAnimation(qreal progress);
+        qreal fadeAnimation() const;
         void appletDestroyed();
         void appletResized();
         void hoverTimeout();
         void leaveTimeout();
         void emitDisappear();
+        void scheduleUpdate();
 
     private:
         static const int HANDLE_MARGIN = 3;
@@ -113,14 +120,14 @@ class AppletHandle : public QGraphicsObject
         Applet *m_applet;
         int m_iconSize;
         qreal m_opacity;
-        FadeType m_anim;
-        int m_animId;
+        FadeType m_animType;
+        QWeakPointer<QPropertyAnimation> m_anim;
         qreal m_angle;
         QColor m_gradientColor;
         QTimer *m_hoverTimer;
         QTimer *m_leaveTimer;
         QPixmap *m_backgroundBuffer;
-        QGraphicsView *m_currentView;
+        QWeakPointer<QGraphicsView> m_currentView;
 
         Svg *m_configureIcons;
         FrameSvg *m_background;
