@@ -22,12 +22,12 @@
 
 #include <QString>
 #include <QList>
-#include <QPointF>
+#include <QtCore/qpoint.h>
 #include "plasma/extenders/extender.h"
 
-class QGraphicsGridLayout;
-class QGraphicsLinearLayout;
-class QGraphicsWidget;
+#include <QGraphicsGridLayout>
+#include <QGraphicsLinearLayout>
+#include <QGraphicsWidget>
 
 namespace Plasma
 {
@@ -37,9 +37,28 @@ class Extender;
 class ExtenderGroup;
 class ExtenderItem;
 class Label;
-class Spacer;
+class ScrollWidget;
 class Svg;
 
+class Spacer : public QGraphicsWidget
+{
+public:
+    Spacer(QGraphicsItem *parent);
+    ~Spacer();
+
+    void setMargins(qreal left, qreal top, qreal right, qreal bottom);
+
+protected:
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget * widget = 0);
+
+
+private:
+    qreal m_left;
+    qreal m_top;
+    qreal m_right;
+    qreal m_bottom;
+};
+
 class ExtenderPrivate
 {
     public:
@@ -47,19 +66,28 @@ class ExtenderPrivate
         ~ExtenderPrivate();
 
         void addExtenderItem(ExtenderItem *item, const QPointF &pos = QPointF(-1, -1));
-        void extenderItemDestroyed(ExtenderItem *item);
+        void extenderItemDestroyed(Plasma::ExtenderItem *item);
+        void viewportGeometryChanged(const QRectF &rect);
         void removeExtenderItem(ExtenderItem *item);
         int insertIndexFromPos(const QPointF &pos) const;
         void loadExtenderItems();
         void updateBorders();
+        void delayItemAddedEvent();
         void updateEmptyExtenderLabel();
+        void adjustMinimumSize();
+        void setPositionFromDragPosition(const QPointF &pos);
         ExtenderGroup *findGroup(const QString &name) const;
+        void setDisabledBordersHint(const FrameSvg::EnabledBorders borders);
+        void adjustSize();
 
         Extender *q;
 
-        Applet *applet;
+        QWeakPointer<Applet> applet;
+        ScrollWidget *scrollWidget;
+        QGraphicsWidget *mainWidget;
         QGraphicsLinearLayout *layout;
         FrameSvg *background;
+        FrameSvg::EnabledBorders disabledBordersHint;
 
         int currentSpacerIndex;
         Spacer *spacerWidget;
@@ -72,6 +100,11 @@ class ExtenderPrivate
         Extender::Appearance appearance;
 
         static QGraphicsGridLayout *s_popupLayout;
+
+        bool destroying;
+        bool scrollbarVisible;
+
+        QHash<ExtenderItem *, QPointF> pendingItems;
 };
 
 } // namespace Plasma
