@@ -47,6 +47,7 @@ ExtenderApplet::~ExtenderApplet()
 void ExtenderApplet::init()
 {
     setPopupIcon("utilities-desktop-extra");
+    setAspectRatioMode(Plasma::IgnoreAspectRatio);
 
     extender()->setAppearance(Extender::NoBorders);
 
@@ -82,5 +83,5 @@ void ExtenderApplet::extenderGeometryChanged()
 
 } // namespace Plasma
 
-#include "extenderapplet_p.moc"
+#include "moc_extenderapplet_p.cpp"
 
