@@ -19,7 +19,6 @@
 #ifndef SERVICEJOB_P_H
 #define SERVICEJOB_P_H
 
-#include "../remote/credentials.h"
 #include "../servicejob.h"
 
 #include <QString>
@@ -45,7 +44,6 @@ public:
     QString operation;
     QMap<QString, QVariant> parameters;
     QVariant result;
-    Credentials identity;
     bool m_allowAutoStart;
 };
 
