@@ -22,7 +22,7 @@
 
 #include <QPainter>
 #include <QVarLengthArray>
-#include <QMouseEvent>
+#include <QtGui/qevent.h>
 
 #include <kwindowsystem.h>
 #include <kdebug.h>
@@ -31,7 +31,7 @@
 #include <plasma/windoweffects.h>
 
 #ifdef Q_WS_X11
-#include <QX11Info>
+#include <QtGui/qx11info_x11.h>
 
 #include <X11/Xlib.h>
 #include <fixx11h.h>
@@ -83,7 +83,7 @@ QSize WindowPreview::sizeHint() const
         return QSize();
     }
 
-    if (!windowSizes.size() == 0) {
+    if (windowSizes.size() != 0) {
         windowSizes = WindowEffects::windowSizes(ids);
     }
 
@@ -184,8 +184,8 @@ void WindowPreview::paintEvent(QPaintEvent *e)
 
     qreal left, top, right, bottom;
     m_background->getMargins(left, top, right, bottom);
-    const QSize delta(left + right, top + bottom);
-    const QPoint topLeft(left, top);
+    const QSize delta(left + right - 2, top + bottom - 2);
+    const QPoint topLeft(left -1 , top - 1);
 
     foreach (const QRect &r, m_thumbnailRects) {
         //kWarning()<<r;
@@ -231,4 +231,4 @@ void WindowPreview::leaveEvent(QEvent *event)
 
 } // namespace Plasma
 
-#include "windowpreview_p.moc"
+#include "moc_windowpreview_p.cpp"
