@@ -19,13 +19,12 @@
 
 #include "service.h"
 #include "servicejob.h"
-#include "private/authorizationmanager_p.h"
 #include "private/service_p.h"
-#include "private/serviceprovider_p.h"
 
 #include "config-plasma.h"
 
 #include <QFile>
+#include <QGraphicsWidget>
 #include <QTimer>
 
 #include <kdebug.h>
@@ -33,14 +32,9 @@
 #include <kservicetypetrader.h>
 #include <ksharedconfig.h>
 #include <kstandarddirs.h>
-#include <dnssd/publicservice.h>
-#include <dnssd/servicebrowser.h>
 
 #include "configloader.h"
-#include "version.h"
 #include "private/configloader_p.h"
-#include "private/remoteservice_p.h"
-#include "private/remoteservicejob_p.h"
 #include "pluginloader.h"
 
 namespace Plasma
@@ -61,7 +55,6 @@ Service::Service(QObject *parent, const QVariantList &args)
 
 Service::~Service()
 {
-    d->unpublish();
     delete d;
 }
 
@@ -76,11 +69,6 @@ Service *Service::load(const QString &name, const QVariantList &args, QObject *p
     return PluginLoader::pluginLoader()->loadService(name, args, parent);
 }
 
-Service *Service::access(const KUrl &url, QObject *parent)
-{
-    return new RemoteService(parent, url);
-}
-
 void ServicePrivate::jobFinished(KJob *job)
 {
     emit q->finished(static_cast<ServiceJob*>(job));
@@ -93,59 +81,7 @@ void ServicePrivate::associatedWidgetDestroyed(QObject *obj)
 
 void ServicePrivate::associatedGraphicsWidgetDestroyed(QObject *obj)
 {
-    associatedGraphicsWidgets.remove(static_cast<QGraphicsWidget*>(obj));
-}
-
-void ServicePrivate::publish(AnnouncementMethods methods, const QString &name, const PackageMetadata &metadata)
-{
-#ifdef ENABLE_REMOTE_WIDGETS
-    if (!serviceProvider) {
-        AuthorizationManager::self()->d->prepareForServicePublication();
-
-        serviceProvider = new ServiceProvider(name, q);
-
-        if (methods.testFlag(ZeroconfAnnouncement) &&
-            (DNSSD::ServiceBrowser::isAvailable() == DNSSD::ServiceBrowser::Working)) {
-            //TODO: dynamically pick a free port number.
-            publicService = new DNSSD::PublicService(name, "_plasma._tcp", 4000);
-
-            QMap<QString, QByteArray> textData;
-            textData["name"] = name.toUtf8();
-            textData["plasmoidname"] = metadata.name().toUtf8();
-            textData["description"] = metadata.description().toUtf8();
-            textData["icon"] = metadata.icon().toUtf8();
-            publicService->setTextData(textData);
-            kDebug() << "about to publish";
-
-            publicService->publishAsync();
-        } else if (methods.testFlag(ZeroconfAnnouncement) &&
-                (DNSSD::ServiceBrowser::isAvailable() != DNSSD::ServiceBrowser::Working)) {
-            kDebug() << "sorry, but your zeroconf daemon doesn't seem to be running.";
-        }
-    } else {
-        kDebug() << "already published!";
-    }
-#else
-    kWarning() << "libplasma is compiled without support for remote widgets. not publishing.";
-#endif
-}
-
-void ServicePrivate::unpublish()
-{
-        delete serviceProvider;
-        serviceProvider = 0;
-
-        delete publicService;
-        publicService = 0;
-}
-
-bool ServicePrivate::isPublished() const
-{
-    if (serviceProvider) {
-        return true;
-    } else {
-        return false;
-    }
+    associatedGraphicsWidgets.remove(static_cast<QGraphicsObject*>(obj));
 }
 
 KConfigGroup ServicePrivate::dummyGroup()
@@ -217,17 +153,7 @@ ServiceJob *Service::startOperationCall(const KConfigGroup &description, QObject
     ServiceJob *job = 0;
     const QString op = description.isValid() ? description.name() : QString();
 
-    RemoteService *rs = qobject_cast<RemoteService *>(this);
-    if (!op.isEmpty() && rs && !rs->isReady()) {
-        // if we have an operation, but a non-ready remote service, just let it through
-        kDebug() << "Remote service is not ready; queueing operation";
-        QMap<QString, QVariant> params;
-        job = createJob(op, params);
-        RemoteServiceJob *rsj = qobject_cast<RemoteServiceJob *>(job);
-        if (rsj) {
-            rsj->setDelayedDescription(description);
-        }
-    } else if (!d->config) {
+    if (!d->config) {
         kDebug() << "No valid operations scheme has been registered";
     } else if (!op.isEmpty() && d->config->hasGroup(op)) {
         if (d->disabledOperations.contains(op)) {
@@ -275,12 +201,22 @@ void Service::disassociateWidget(QWidget *widget)
 }
 
 void Service::associateWidget(QGraphicsWidget *widget, const QString &operation)
+{
+    associateItem(widget, operation);
+}
+
+void Service::disassociateWidget(QGraphicsWidget *widget)
+{
+    disassociateItem(widget);
+}
+
+void Service::associateItem(QGraphicsObject *widget, const QString &operation)
 {
     if (!widget) {
         return;
     }
 
-    disassociateWidget(widget);
+    disassociateItem(widget);
     d->associatedGraphicsWidgets.insert(widget, operation);
     connect(widget, SIGNAL(destroyed(QObject*)),
             this, SLOT(associatedGraphicsWidgetDestroyed(QObject*)));
@@ -288,7 +224,7 @@ void Service::associateWidget(QGraphicsWidget *widget, const QString &operation)
     widget->setEnabled(!d->disabledOperations.contains(operation));
 }
 
-void Service::disassociateWidget(QGraphicsWidget *widget)
+void Service::disassociateItem(QGraphicsObject *widget)
 {
     if (!widget) {
         return;
@@ -343,7 +279,7 @@ void Service::setOperationEnabled(const QString &operation, bool enable)
     }
 
     {
-        QHashIterator<QGraphicsWidget *, QString> it(d->associatedGraphicsWidgets);
+        QHashIterator<QGraphicsObject *, QString> it(d->associatedGraphicsWidgets);
         while (it.hasNext()) {
             it.next();
             if (it.value() == operation) {
@@ -380,7 +316,7 @@ void Service::setOperationsScheme(QIODevice *xml)
     }
 
     {
-        QHashIterator<QGraphicsWidget *, QString> it(d->associatedGraphicsWidgets);
+        QHashIterator<QGraphicsObject *, QString> it(d->associatedGraphicsWidgets);
         while (it.hasNext()) {
             it.next();
             it.key()->setEnabled(d->config->hasGroup(it.value()));
@@ -413,5 +349,5 @@ void Service::registerOperationsScheme()
 
 } // namespace Plasma
 
-#include "service.moc"
+#include "moc_service.cpp"
 
