@@ -30,9 +30,9 @@
 #include <plasma/plasma.h>
 #include "packagemetadata.h"
 
-class QGraphicsWidget;
-class QIODevice;
-class QWidget;
+#include <QGraphicsObject>
+#include <QIODevice>
+#include <QWidget>
 
 namespace Plasma
 {
@@ -124,12 +124,6 @@ public:
      */
     static Service *load(const QString &name, QObject *parent = 0);
 
-    /**
-     * Used to access a service from an url. Always check for the signal serviceReady() that fires
-     * when this service is actually ready for use.
-     */
-    static Service *access(const KUrl &url, QObject *parent = 0);
-
     /**
      * Sets the destination for this Service to operate on
      *
@@ -201,27 +195,41 @@ public:
     Q_INVOKABLE void disassociateWidget(QWidget *widget);
 
     /**
-     * Assoicates a widget with an operation, which allows the service to
-     * automatically manage, for example, the enabled state of a widget.
+     * This method only exists to maintain binary compatibility.
      *
-     * This will remove any previous associations the widget had with
-     * operations on this engine.
-     *
-     * @param widget the QGraphicsItem to associate with the service
-     * @param operation the operation to associate the widget with
+     * @see associateItem
      */
     Q_INVOKABLE void associateWidget(QGraphicsWidget *widget, const QString &operation);
 
     /**
-     * Disassociates a widget if it has been associated with an operation
-     * on this service.
+     * This method only exists to maintain binary compatibility.
      *
-     * This will not change the enabled state of the widget.
-     *
-     * @param widget the QGraphicsWidget to disassociate.
+     * @see disassociateItem
      */
     Q_INVOKABLE void disassociateWidget(QGraphicsWidget *widget);
 
+    /**
+     * Associates a graphics item with an operation, which allows the service to
+     * automatically manage, for example, the enabled state of the item.
+     *
+     * This will remove any previous associations the item had with
+     * operations on this engine.
+     *
+     * @param item the QGraphicsObject to associate with the service
+     * @param operation the operation to associate the item with
+     */
+    Q_INVOKABLE void associateItem(QGraphicsObject *item, const QString &operation);
+
+    /**
+     * Disassociates a graphics item if it has been associated with an operation
+     * on this service.
+     *
+     * This will not change the enabled state of the item.
+     *
+     * @param widget the QGraphicsItem to disassociate.
+     */
+    Q_INVOKABLE void disassociateItem(QGraphicsObject *widget);
+
     /**
      * @return a parameter map for the given description
      * @param description the configuration values to turn into the parameter map
@@ -325,8 +333,7 @@ Q_DECLARE_METATYPE(Plasma::Service *)
  */
 #define K_EXPORT_PLASMA_SERVICE(libname, classname) \
 K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
-K_EXPORT_PLUGIN(factory("plasma_service_" #libname)) \
-K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+K_EXPORT_PLUGIN(factory("plasma_service_" #libname))
 
 #endif // multiple inclusion guard
 
