@@ -27,7 +27,7 @@ namespace Plasma
     class ConfigLoader;
 }
 
-class QFile;
+#include <QFile>
 
 class ConfigLoaderTest : public QObject
 {
@@ -45,7 +45,6 @@ private Q_SLOTS:
     void enumDefaultValue();
     void fontDefaultValue();
     void intDefaultValue();
-    void passwordDefaultValue();
     void pathDefaultValue();
     void stringDefaultValue();
     void stringListDefaultValue();
