@@ -23,9 +23,22 @@
 #include <kconfiggroup.h>
 #include <kdebug.h>
 
+#include "plasma/package.h"
 #include "plasma/packagestructure.h"
 #include "plasma/applet.h"
 
+class NoPrefixes : public Plasma::PackageStructure
+{
+public:
+    explicit NoPrefixes()
+        : Plasma::PackageStructure(0, "StructureLess")
+    {
+        setContentsPrefixPaths(QStringList());
+        addDirectoryDefinition("bin", "bin", "bin");
+    }
+};
+
+
 void PackageStructureTest::init()
 {
     ps = Plasma::Applet::packageStructure();
@@ -35,6 +48,15 @@ void PackageStructureTest::cleanup()
 {
 }
 
+void PackageStructureTest::emptyContentsPrefix()
+{
+    Plasma::PackageStructure::Ptr structure(new NoPrefixes);
+    Plasma::Package package("/", structure);
+    QString path(package.filePath("bin", "ls"));
+    qDebug() << path;
+    QCOMPARE(path, QString("/bin/ls"));
+}
+
 void PackageStructureTest::type()
 {
     QCOMPARE(ps->type(), QString("Plasmoid"));
@@ -42,29 +64,29 @@ void PackageStructureTest::type()
 
 void PackageStructureTest::directories()
 {
-    QList<const char*> dirs;
-    dirs << "config" << "images" << "scripts" << "translations" << "ui";
+    QList<QByteArray> dirs;
+    dirs << "animations" << "config" << "data" << "images" << "scripts" << "theme" << "translations" << "ui";
 
-    QList<const char*> psDirs = ps->directories();
+    QList<QByteArray> psDirs = ps->directories();
 
     QCOMPARE(dirs.count(), psDirs.count());
+
     for (int i = 0; i < psDirs.count(); ++i) {
-        QVERIFY(qstrcmp(dirs[i], psDirs[i]) == 0);
+        QCOMPARE(dirs[i], psDirs[i]);
     }
 }
 
 void PackageStructureTest::requiredDirectories()
 {
-    QList<const char*> dirs;
-    QCOMPARE(ps->requiredDirectories(), dirs);
+    QCOMPARE(ps->requiredDirectories().size(), 0);
 }
 
 void PackageStructureTest::files()
 {
-    QList<const char*> files;
+    QList<QByteArray> files;
     files << "defaultconfig" << "mainconfigui" << "mainconfigxml" << "mainscript";
 
-    QList<const char*> psFiles = ps->files();
+    QList<QByteArray> psFiles = ps->files();
 
     //for (int i = 0; i < psFiles.count(); ++i) {
     //    qDebug() << psFiles[i];
@@ -77,10 +99,10 @@ void PackageStructureTest::files()
 
 void PackageStructureTest::requiredFiles()
 {
-    QList<const char*> files;
+    QList<QByteArray> files;
     files << "mainscript";
 
-    QList<const char*> psFiles = ps->requiredFiles();
+    QList<QByteArray> psFiles = ps->requiredFiles();
 
     QCOMPARE(files.count(), psFiles.count());
     for (int i = 0; i < files.count(); ++i) {
@@ -90,7 +112,7 @@ void PackageStructureTest::requiredFiles()
 
 void PackageStructureTest::path()
 {
-    QCOMPARE(ps->path("images"), QString("images/"));
+    QCOMPARE(ps->path("images"), QString("images"));
     QCOMPARE(ps->path("mainscript"), QString("code/main"));
 }
 
@@ -110,6 +132,7 @@ void PackageStructureTest::mimetypes()
     QStringList mimetypes;
     mimetypes << "image/svg+xml" << "image/png" << "image/jpeg";
     QCOMPARE(ps->mimetypes("images"), mimetypes);
+    QCOMPARE(ps->mimetypes("theme"), mimetypes);
 }
 
 void PackageStructureTest::read()
@@ -128,10 +151,10 @@ void PackageStructureTest::read()
     QCOMPARE(structure.path("mainscript"), QString("code/main"));
 
     // compare files
-    QList<const char *> files;
+    QList<QByteArray> files;
     files << "mainconfiggui" << "mainconfigxml" << "mainscript";
 
-    QList<const char *> psFiles = structure.files();
+    QList<QByteArray> psFiles = structure.files();
 
     QCOMPARE(psFiles.count(), files.count());
     for (int i = 0; i < files.count(); ++i) {
@@ -139,14 +162,14 @@ void PackageStructureTest::read()
     }
 
     // compare required files
-    QList<const char *> reqFiles = structure.requiredFiles();
+    QList<QByteArray> reqFiles = structure.requiredFiles();
     QCOMPARE(reqFiles.count(), 1);
-    QCOMPARE(reqFiles[0], "mainscript");
+    QCOMPARE(reqFiles[0], QByteArray("mainscript"));
 
     // compare directories
-    QList <const char *> dirs;
+    QList <QByteArray> dirs;
     dirs << "config" << "configui" << "images" << "scripts";
-    QList <const char *> psDirs = structure.directories();
+    QList <QByteArray> psDirs = structure.directories();
     QCOMPARE(psDirs.count(), dirs.count());
     for (int i = 0; i < dirs.count(); i++) {
         QCOMPARE(psDirs[i], dirs[i]);
@@ -167,9 +190,9 @@ void PackageStructureTest::write()
 
     // check groups
     QStringList groups;
-    groups << "images" << "config" << "defaultconfig" << "scripts"
+    groups << "images" << "theme" << "config" << "data" << "defaultconfig" << "scripts"
            << "mainconfigui" << "mainconfigxml" << "mainscript"
-           << "translations" << "ui";
+           << "translations" << "ui" << "animations";
     groups.sort();
 
     QStringList actualGroups = config.groupList();
