@@ -22,14 +22,12 @@
 #include <QApplication>
 #include <QFile>
 #include <QFileInfo>
-#include <QMutableListIterator>
+#include <QList>
 #include <QPair>
-#include <QStringBuilder>
 #include <QTimer>
-#ifdef Q_WS_X11
+#include <QCache>
+#include <QBuffer>
 #include <QX11Info>
-#include "private/effectwatcher_p.h"
-#endif
 
 #include <kcolorscheme.h>
 #include <kcomponentdata.h>
@@ -38,8 +36,6 @@
 #include <kdirwatch.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
-#include <kmanagerselection.h>
-#include <kimagecache.h>
 #include <ksharedconfig.h>
 #include <kstandarddirs.h>
 #include <kwindowsystem.h>
@@ -84,11 +80,9 @@ public:
           defaultWallpaperSuffix(DEFAULT_WALLPAPER_SUFFIX),
           defaultWallpaperWidth(DEFAULT_WALLPAPER_WIDTH),
           defaultWallpaperHeight(DEFAULT_WALLPAPER_HEIGHT),
-          pixmapCache(0),
           cachesToDiscard(NoCache),
           locolor(false),
           compositingActive(KWindowSystem::self()->compositingActive()),
-          blurActive(false),
           isDefault(false),
           useGlobal(true),
           hasWallpapers(false),
@@ -98,6 +92,9 @@ public:
         ThemeConfig config;
         cacheTheme = config.cacheTheme();
 
+        pixmapCache = new QSharedPointer<QCache<QString, QPixmap> >(new QCache<QString, QPixmap>());
+        pixmapCache->data()->setMaxCost(config.themeCacheKb() * 1024);
+
         saveTimer = new QTimer(q);
         saveTimer->setSingleShot(true);
         saveTimer->setInterval(600);
@@ -108,16 +105,8 @@ public:
         updateNotificationTimer->setInterval(500);
         QObject::connect(updateNotificationTimer, SIGNAL(timeout()), q, SLOT(notifyOfChanged()));
 
-        if (QPixmap::defaultDepth() > 8) {
+        if (QX11Info::appDepth() > 8) {
             QObject::connect(KWindowSystem::self(), SIGNAL(compositingChanged(bool)), q, SLOT(compositingChanged(bool)));
-#ifdef Q_WS_X11
-            //watch for blur effect property changes as well
-            if (!s_blurEffectWatcher) {
-                s_blurEffectWatcher = new EffectWatcher("_KDE_NET_WM_BLUR_BEHIND_REGION");
-            }
-
-            QObject::connect(s_blurEffectWatcher, SIGNAL(effectChanged(bool)), q, SLOT(blurBehindChanged(bool)));
-#endif
         }
     }
 
@@ -153,23 +142,18 @@ public:
     void scheduleThemeChangeNotification(CacheTypes caches);
     void notifyOfChanged();
     void colorsChanged();
-    void blurBehindChanged(bool blur);
     bool useCache();
     void settingsFileChanged(const QString &);
     void setThemeName(const QString &themeName, bool writeSettings);
-    void onAppExitCleanup();
     void processWallpaperSettings(KConfigBase *metadata);
     void processAnimationSettings(const QString &theme, KConfigBase *metadata);
 
-    const QString processStyleSheet(const QString &css);
+    QString processStyleSheet(const QString &css);
 
     static const char *defaultTheme;
     static const char *systemColorsTheme;
     static const char *themeRcFile;
     static PackageStructure::Ptr packageStructure;
-#ifdef Q_WS_X11
-    static EffectWatcher *s_blurEffectWatcher;
-#endif
 
     Theme *q;
     QString themeName;
@@ -184,7 +168,7 @@ public:
     QString defaultWallpaperSuffix;
     int defaultWallpaperWidth;
     int defaultWallpaperHeight;
-    KImageCache *pixmapCache;
+    QSharedPointer<QCache<QString, QPixmap> > *pixmapCache;
     KSharedConfigPtr svgElementsCache;
     QHash<QString, QSet<QString> > invalidElements;
     QHash<QString, QPixmap> pixmapsToCache;
@@ -202,7 +186,6 @@ public:
 
     bool locolor : 1;
     bool compositingActive : 1;
-    bool blurActive : 1;
     bool isDefault : 1;
     bool useGlobal : 1;
     bool hasWallpapers : 1;
@@ -217,17 +200,11 @@ const char *ThemePrivate::themeRcFile = "plasmarc";
 // the system colors theme is used to cache unthemed svgs with colorization needs
 // these svgs do not follow the theme's colors, but rather the system colors
 const char *ThemePrivate::systemColorsTheme = "internal-system-colors";
-#ifdef Q_WS_X11
-EffectWatcher *ThemePrivate::s_blurEffectWatcher = 0;
-#endif
 
 bool ThemePrivate::useCache()
 {
-    bool cachesTooOld = false;
-
     if (cacheTheme && !pixmapCache) {
         const bool isRegularTheme = themeName != systemColorsTheme;
-        QString cacheFile = "plasma_theme_" + themeName;
 
         // clear any cached values from the previous theme cache
         themeVersion.clear();
@@ -237,66 +214,12 @@ bool ThemePrivate::useCache()
         }
         themeMetadataPath = KStandardDirs::locate("data", "desktoptheme/" + themeName + "/metadata.desktop");
 
-        if (isRegularTheme) {
-            const QString cacheFileBase = cacheFile + "*.kcache";
-
-            // if the path is empty, then we haven't found the theme and so
-            // we will leave currentCacheFileName empty, resulting in the deletion of
-            // *all* matching cache files
-            QString currentCacheFileName;
-            if (!themeMetadataPath.isEmpty()) {
-                // now we record the theme version, if we can
-                const KPluginInfo pluginInfo(themeMetadataPath);
-                themeVersion = pluginInfo.version();
-                if (!themeVersion.isEmpty()) {
-                    cacheFile += "_v" + themeVersion;
-                    currentCacheFileName = cacheFile + ".kcache";
-                }
-
-                // watch the metadata file for changes at runtime
-                KDirWatch::self()->addFile(themeMetadataPath);
-                QObject::connect(KDirWatch::self(), SIGNAL(created(QString)),
-                                 q, SLOT(settingsFileChanged(QString)),
-                                 Qt::UniqueConnection);
-                QObject::connect(KDirWatch::self(), SIGNAL(dirty(QString)),
-                                 q, SLOT(settingsFileChanged(QString)),
-                                 Qt::UniqueConnection);
-            }
-
-            // now we check for (and remove) old caches
-            foreach (const QString &file, KGlobal::dirs()->findAllResources("cache", cacheFileBase)) {
-                if (currentCacheFileName.isEmpty() ||
-                    !file.endsWith(currentCacheFileName)) {
-                    QFile::remove(file);
-                }
-            }
-        }
-
-        // now we do a sanity check: if the metadata.desktop file is newer than the cache, drop
-        // the cache
         if (isRegularTheme && !themeMetadataPath.isEmpty()) {
-            // now we check to see if the theme metadata file itself is newer than the pixmap cache
-            // this is done before creating the pixmapCache object since that can change the mtime
-            // on the cache file
-
-            // FIXME: when using the system colors, if they change while the application is not running
-            // the cache should be dropped; we need a way to detect system color change when the
-            // application is not running.
-            // check for expired cache
-            const QString cacheFilePath = KStandardDirs::locateLocal("cache", cacheFile);
-            if (!cacheFilePath.isEmpty()) {
-                const QFileInfo cacheFileInfo(cacheFilePath);
-                const QFileInfo metadataFileInfo(themeMetadataPath);
-                cachesTooOld = cacheFileInfo.lastModified().toTime_t() > metadataFileInfo.lastModified().toTime_t();
-            }
+            // watch the metadata file for changes at runtime
+            KDirWatch::self()->addFile(themeMetadataPath);
         }
 
-        ThemeConfig config;
-        pixmapCache = new KImageCache(cacheFile, config.themeCacheKb() * 1024);
-
-        if (cachesTooOld) {
-            discardCache(PixmapCache | SvgElementsCache);
-        }
+        // TODO: discardCache(PixmapCache | SvgElementsCache); ?
     }
 
     if (cacheTheme && !svgElementsCache) {
@@ -308,7 +231,7 @@ bool ThemePrivate::useCache()
 
         // now we check for (and remove) old caches
         foreach (const QString &file, KGlobal::dirs()->findAllResources("cache", svgElementsFileNameBase + "*")) {
-            if (cachesTooOld || !file.endsWith(svgElementsFileName)) {
+            if (!file.endsWith(svgElementsFileName)) {
                 QFile::remove(file);
             }
         }
@@ -320,14 +243,6 @@ bool ThemePrivate::useCache()
     return cacheTheme;
 }
 
-void ThemePrivate::onAppExitCleanup()
-{
-    pixmapsToCache.clear();
-    delete pixmapCache;
-    pixmapCache = 0;
-    cacheTheme = false;
-}
-
 QString ThemePrivate::findInTheme(const QString &image, const QString &theme, bool cache)
 {
     if (cache && discoveries.contains(image)) {
@@ -337,19 +252,19 @@ QString ThemePrivate::findInTheme(const QString &image, const QString &theme, bo
     QString search;
 
     if (locolor) {
-        search = QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/locolor/") % image;
+        search = QLatin1String("desktoptheme/") + theme + QLatin1String("/locolor/") + image;
         search =  KStandardDirs::locate("data", search);
     } else if (!compositingActive) {
-        search = QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/opaque/") % image;
+        search = QLatin1String("desktoptheme/") + theme + QLatin1String("/opaque/") + image;
         search =  KStandardDirs::locate("data", search);
-    } else if (WindowEffects::isEffectAvailable(WindowEffects::BlurBehind)) {
-        search = QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/translucent/") % image;
+    } else {
+        search = QLatin1String("desktoptheme/") + theme + QLatin1String("/translucent/") + image;
         search =  KStandardDirs::locate("data", search);
     }
 
     //not found or compositing enabled
     if (search.isEmpty()) {
-        search = QLatin1Literal("desktoptheme/") % theme % QLatin1Char('/') % image;
+        search = QLatin1String("desktoptheme/") + theme + QLatin1Char('/') + image;
         search =  KStandardDirs::locate("data", search);
     }
 
@@ -376,13 +291,10 @@ void ThemePrivate::discardCache(CacheTypes caches)
     if (caches & PixmapCache) {
         pixmapsToCache.clear();
         saveTimer->stop();
-        if (pixmapCache) {
-            pixmapCache->clear();
-        }
-    } else {
-        // This deletes the object but keeps the on-disk cache for later use
-        delete pixmapCache;
-        pixmapCache = 0;
+    }
+    // FIXME: this is always done to properly change theme but should be done only on demand
+    if (pixmapCache) {
+        pixmapCache->data()->clear();
     }
 
     cachedStyleSheets.clear();
@@ -400,7 +312,7 @@ void ThemePrivate::scheduledCacheUpdate()
         QHashIterator<QString, QPixmap> it(pixmapsToCache);
         while (it.hasNext()) {
             it.next();
-            pixmapCache->insertPixmap(idsToCache[it.key()], it.value());
+            pixmapCache->data()->insert(idsToCache[it.key()], new QPixmap(it.value()));
         }
     }
 
@@ -417,14 +329,6 @@ void ThemePrivate::colorsChanged()
     scheduleThemeChangeNotification(PixmapCache);
 }
 
-void ThemePrivate::blurBehindChanged(bool blur)
-{
-    if (blurActive != blur) {
-        blurActive = blur;
-        scheduleThemeChangeNotification(PixmapCache | SvgElementsCache);
-    }
-}
-
 void ThemePrivate::scheduleThemeChangeNotification(CacheTypes caches)
 {
     cachesToDiscard |= caches;
@@ -439,7 +343,7 @@ void ThemePrivate::notifyOfChanged()
     emit q->themeChanged();
 }
 
-const QString ThemePrivate::processStyleSheet(const QString &css)
+QString ThemePrivate::processStyleSheet(const QString &css)
 {
     QString stylesheet;
     if (css.isEmpty()) {
@@ -511,9 +415,9 @@ const QString ThemePrivate::processStyleSheet(const QString &css)
     elements["%fontfamily"] = font.family().split('[').first();
     elements["%smallfontsize"] = QString("%1pt").arg(KGlobalSettings::smallestReadableFont().pointSize());
 
-    QHash<QString, QString>::const_iterator it = elements.constBegin();
-    QHash<QString, QString>::const_iterator itEnd = elements.constEnd();
-    for ( ; it != itEnd; ++it) {
+    QHashIterator<QString, QString> it(elements);
+    while (it.hasNext()) {
+        it.next();
         stylesheet.replace(it.key(), it.value());
     }
     return stylesheet;
@@ -528,12 +432,8 @@ public:
 
         //FIXME: if/when kconfig gets change notification, this will be unnecessary
         KDirWatch::self()->addFile(KStandardDirs::locateLocal("config", ThemePrivate::themeRcFile));
-        QObject::connect(KDirWatch::self(), SIGNAL(created(QString)),
-                         &self, SLOT(settingsFileChanged(QString)),
-                         Qt::UniqueConnection);
         QObject::connect(KDirWatch::self(), SIGNAL(dirty(QString)),
-                         &self, SLOT(settingsFileChanged(QString)),
-                         Qt::UniqueConnection);
+                         &self, SLOT(settingsFileChanged(QString)));
     }
 
    Theme self;
@@ -551,10 +451,6 @@ Theme::Theme(QObject *parent)
       d(new ThemePrivate(this))
 {
     settingsChanged();
-    if (QCoreApplication::instance()) {
-        connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()),
-                this, SLOT(onAppExitCleanup()));
-    }
 }
 
 Theme::Theme(const QString &themeName, QObject *parent)
@@ -566,14 +462,16 @@ Theme::Theme(const QString &themeName, QObject *parent)
     d->cacheTheme = false;
     setThemeName(themeName);
     d->cacheTheme = useCache;
-    if (QCoreApplication::instance()) {
-        connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()),
-                this, SLOT(onAppExitCleanup()));
-    }
 }
 
 Theme::~Theme()
 {
+    d->cacheTheme = false;
+
+    d->pixmapsToCache.clear();
+    delete d->pixmapCache;
+    d->pixmapCache = 0;
+
     if (d->svgElementsCache) {
         QHashIterator<QString, QSet<QString> > it(d->invalidElements);
         while (it.hasNext()) {
@@ -583,7 +481,6 @@ Theme::~Theme()
         }
     }
 
-    d->onAppExitCleanup();
     delete d;
 }
 
@@ -605,15 +502,15 @@ KPluginInfo::List Theme::listThemeInfo()
 
 void ThemePrivate::settingsFileChanged(const QString &file)
 {
-    if (file == themeMetadataPath) {
+    Q_UNUSED(file);
+    if (!themeMetadataPath.isEmpty()) {
         const KPluginInfo pluginInfo(themeMetadataPath);
         if (themeVersion != pluginInfo.version()) {
             scheduleThemeChangeNotification(SvgElementsCache);
         }
-    } else if (file.endsWith(themeRcFile)) {
-        config().config()->reparseConfiguration();
-        q->settingsChanged();
     }
+    config().config()->reparseConfiguration();
+    q->settingsChanged();
 }
 
 void Theme::settingsChanged()
@@ -655,7 +552,7 @@ void ThemePrivate::processWallpaperSettings(KConfigBase *metadata)
 void ThemePrivate::processAnimationSettings(const QString &theme, KConfigBase *metadata)
 {
     KConfigGroup cg(metadata, "Animations");
-    const QString animDir = QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/animations/");
+    const QString animDir = QLatin1String("desktoptheme/") + theme + QLatin1String("/animations/");
     foreach (const QString &path, cg.keyList()) {
         const QStringList anims = cg.readEntry(path, QStringList());
         foreach (const QString &anim, anims) {
@@ -665,7 +562,7 @@ void ThemePrivate::processAnimationSettings(const QString &theme, KConfigBase *m
                          << "\tpath: " << path << "\t*******\n\n\n";
                 //key: desktoptheme/default/animations/+ all.js
                 //value: ZoomAnimation
-                animationMapping.insert(anim, animDir % path);
+                animationMapping.insert(anim, animDir + path);
             } else {
                 kDebug() << "************Animation already registered!\n\n\n";
             }
@@ -691,7 +588,7 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
     // the system colors.
     bool realTheme = theme != systemColorsTheme;
     if (realTheme) {
-        QString themePath = KStandardDirs::locate("data", QLatin1Literal("desktoptheme/") % theme % QLatin1Char('/'));
+        QString themePath = KStandardDirs::locate("data", QLatin1String("desktoptheme/") + theme + QLatin1Char('/'));
         if (themePath.isEmpty() && themeName.isEmpty()) {
             themePath = KStandardDirs::locate("data", "desktoptheme/default/");
 
@@ -711,14 +608,14 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
     themeName = theme;
 
     // load the color scheme config
-    const QString colorsFile = realTheme ? KStandardDirs::locate("data", QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/colors"))
+    const QString colorsFile = realTheme ? KStandardDirs::locate("data", QLatin1String("desktoptheme/") + theme + QLatin1String("/colors"))
                                          : QString();
 
     //kDebug() << "we're going for..." << colorsFile << "*******************";
 
     // load the wallpaper settings, if any
     if (realTheme) {
-        const QString metadataPath(KStandardDirs::locate("data", QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/metadata.desktop")));
+        const QString metadataPath(KStandardDirs::locate("data", QLatin1String("desktoptheme/") + theme + QLatin1String("/metadata.desktop")));
         KConfig metadata(metadataPath);
 
         processWallpaperSettings(&metadata);
@@ -735,22 +632,18 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
         while (!fallback.isEmpty() && !fallbackThemes.contains(fallback)) {
             fallbackThemes.append(fallback);
 
-            QString metadataPath(KStandardDirs::locate("data", QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/metadata.desktop")));
+            QString metadataPath(KStandardDirs::locate("data", QLatin1String("desktoptheme/") + theme + QLatin1String("/metadata.desktop")));
             KConfig metadata(metadataPath);
             KConfigGroup cg(&metadata, "Settings");
             fallback = cg.readEntry("FallbackTheme", QString());
         }
 
-        if (!fallbackThemes.contains("oxygen")) {
-            fallbackThemes.append("oxygen");
-        }
-
         if (!fallbackThemes.contains(ThemePrivate::defaultTheme)) {
             fallbackThemes.append(ThemePrivate::defaultTheme);
         }
 
         foreach (const QString &theme, fallbackThemes) {
-            QString metadataPath(KStandardDirs::locate("data", QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/metadata.desktop")));
+            QString metadataPath(KStandardDirs::locate("data", QLatin1String("desktoptheme/") + theme + QLatin1String("/metadata.desktop")));
             KConfig metadata(metadataPath);
             processAnimationSettings(theme, &metadata);
             processWallpaperSettings(&metadata);
@@ -760,7 +653,7 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
     if (colorsFile.isEmpty()) {
         colors = 0;
         QObject::connect(KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()),
-                         q, SLOT(colorsChanged()), Qt::UniqueConnection);
+                         q, SLOT(colorsChanged()));
     } else {
         QObject::disconnect(KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()),
                             q, SLOT(colorsChanged()));
@@ -770,7 +663,7 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
     colorScheme = KColorScheme(QPalette::Active, KColorScheme::Window, colors);
     buttonColorScheme = KColorScheme(QPalette::Active, KColorScheme::Button, colors);
     viewColorScheme = KColorScheme(QPalette::Active, KColorScheme::View, colors);
-    hasWallpapers = KStandardDirs::exists(KStandardDirs::locateLocal("data", QLatin1Literal("desktoptheme/") % theme % QLatin1Literal("/wallpapers/")));
+    hasWallpapers = KGlobal::dirs()->exists(KStandardDirs::locateLocal("data", QLatin1String("desktoptheme/") + theme + QLatin1String("/wallpapers/")));
 
     if (realTheme && isDefault && writeSettings) {
         // we're the default theme, let's save our state
@@ -800,12 +693,12 @@ QString Theme::imagePath(const QString &name) const
         return QString();
     }
 
-    const QString svgzName = name % QLatin1Literal(".svgz");
+    const QString svgzName = name + QLatin1String(".svgz");
     QString path = d->findInTheme(svgzName, d->themeName);
 
     if (path.isEmpty()) {
         // try for an uncompressed svg file
-        const QString svgName = name % QLatin1Literal(".svg");
+        const QString svgName = name + QLatin1String(".svg");
         path = d->findInTheme(svgName, d->themeName);
 
         // search in fallback themes if necessary
@@ -872,10 +765,10 @@ QString Theme::wallpaperPath(const QSize &size) const
     //      to override the theme?
     if (d->hasWallpapers) {
         // check in the theme first
-        fullPath = d->findInTheme(QLatin1Literal("wallpapers/") % image, d->themeName);
+        fullPath = d->findInTheme(QLatin1String("wallpapers/") + image, d->themeName);
 
         if (fullPath.isEmpty()) {
-            fullPath = d->findInTheme(QLatin1Literal("wallpapers/") % defaultImage, d->themeName);
+            fullPath = d->findInTheme(QLatin1String("wallpapers/") + defaultImage, d->themeName);
         }
     }
 
@@ -906,8 +799,8 @@ bool Theme::currentThemeHasImage(const QString &name) const
         return false;
     }
 
-    return !(d->findInTheme(name % QLatin1Literal(".svgz"), d->themeName, false).isEmpty()) ||
-           !(d->findInTheme(name % QLatin1Literal(".svg"), d->themeName, false).isEmpty());
+    return !(d->findInTheme(name + QLatin1String(".svgz"), d->themeName, false).isEmpty()) ||
+           !(d->findInTheme(name + QLatin1String(".svg"), d->themeName, false).isEmpty());
 }
 
 KSharedConfigPtr Theme::colorScheme() const
@@ -970,20 +863,17 @@ void Theme::setFont(const QFont &font, FontRole role)
 QFont Theme::font(FontRole role) const
 {
     switch (role) {
-    case DesktopFont: {
-        KConfigGroup cg(KGlobal::config(), "General");
-        return cg.readEntry("desktopFont", d->generalFont);
+        case DesktopFont: {
+            KConfigGroup cg(KGlobal::config(), "General");
+            return cg.readEntry("desktopFont", d->generalFont);
+        }
+        case SmallestFont: {
+            return KGlobalSettings::smallestReadableFont();
+        }
+        case DefaultFont:
+        default: {
+            return d->generalFont;
         }
-        break;
-
-    case DefaultFont:
-    default:
-        return d->generalFont;
-        break;
-
-    case SmallestFont:
-        return KGlobalSettings::smallestReadableFont();
-        break;
     }
 
     return d->generalFont;
@@ -1031,30 +921,20 @@ bool Theme::findInCache(const QString &key, QPixmap &pix)
             return !pix.isNull();
         }
 
-        QPixmap temp;
-        if (d->pixmapCache->findPixmap(key, &temp) && !temp.isNull()) {
-            pix = temp;
-            return true;
+        QPixmap *temp = d->pixmapCache->data()->object(key);
+        if (temp && !temp->isNull()) {
+            pix = QPixmap::fromImage(temp->toImage());
+            return !pix.isNull();
         }
     }
 
     return false;
 }
 
-// BIC FIXME: Should be merged with the other findInCache method above when we break BC
-bool Theme::findInCache(const QString &key, QPixmap &pix, unsigned int lastModified)
-{
-    if (d->useCache() && lastModified > uint(d->pixmapCache->lastModifiedTime())) {
-        return false;
-    }
-
-    return findInCache(key, pix);
-}
-
 void Theme::insertIntoCache(const QString& key, const QPixmap& pix)
 {
     if (d->useCache()) {
-        d->pixmapCache->insertPixmap(key, pix);
+        d->pixmapCache->data()->insert(key, new QPixmap(pix));
     }
 }
 
@@ -1080,7 +960,7 @@ bool Theme::findInRectsCache(const QString &image, const QString &element, QRect
     }
 
     KConfigGroup imageGroup(d->svgElementsCache, image);
-    rect = imageGroup.readEntry(element % QLatin1Literal("Size"), QRectF());
+    rect = imageGroup.readEntry(element + QLatin1String("Size"), QRectF());
 
     if (rect.isValid()) {
         return true;
@@ -1137,7 +1017,7 @@ void Theme::insertIntoRectsCache(const QString& image, const QString &element, c
 
     if (rect.isValid()) {
         KConfigGroup imageGroup(d->svgElementsCache, image);
-        imageGroup.writeEntry(element % QLatin1Literal("Size"), rect);
+        imageGroup.writeEntry(element + QLatin1String("Size"), rect);
     } else {
         QHash<QString, QSet<QString> >::iterator it = d->invalidElements.find(image);
         if (it == d->invalidElements.end()) {
@@ -1187,10 +1067,10 @@ void Theme::setCacheLimit(int kbytes)
 
 KUrl Theme::homepage() const
 {
-    const QString metadataPath(KStandardDirs::locate("data", QLatin1Literal("desktoptheme/") % d->themeName % QLatin1Literal("/metadata.desktop")));
+    const QString metadataPath(KStandardDirs::locate("data", QLatin1String("desktoptheme/") + d->themeName + QLatin1String("/metadata.desktop")));
     KConfig metadata(metadataPath);
     KConfigGroup brandConfig(&metadata, "Branding");
-    return brandConfig.readEntry("homepage", KUrl("http://www.kde.org"));
+    return brandConfig.readEntry("homepage", KUrl(QString::fromLatin1(KDE_HOME_URL)));
 }
 
 int Theme::toolTipDelay() const
@@ -1200,4 +1080,4 @@ int Theme::toolTipDelay() const
 
 }
 
-#include <theme.moc>
+#include "moc_theme.cpp"
