@@ -29,8 +29,9 @@
 #include <QAction>
 #include <QQueue>
 #include <QTimer>
-#include <QRunnable>
-#include <QThreadPool>
+#include <QPainter>
+#include <QDateTime>
+#include <QImageWriter>
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -41,69 +42,17 @@
 #include <kio/job.h>
 #endif
 
-#ifndef PLASMA_NO_SOLID
-#include <solid/device.h>
-#include <solid/deviceinterface.h>
-#endif
-
-#include <version.h>
-
+#include "plasma/plasma.h"
 #include "plasma/package.h"
 #include "plasma/private/dataengineconsumer_p.h"
 #include "plasma/private/packages_p.h"
 #include "plasma/private/wallpaper_p.h"
 
+static const QByteArray imageFormat = QImageWriter::defaultImageFormat();
+
 namespace Plasma
 {
 
-class SaveImageThread : public QRunnable
-{
-    QImage m_image;
-    QString m_filePath;
-
-    public:
-    SaveImageThread(const QImage &image, const QString &filePath)
-    {
-        m_image = image;
-        m_filePath = filePath;
-    }
-
-    void run()
-    {
-        m_image.save(m_filePath);
-    }
-};
-    
-LoadImageThread::LoadImageThread(const QString &filePath)
-{
-    m_filePath = filePath;
-}
-
-void LoadImageThread::run()
-{
-    QImage image;
-    image.load(m_filePath);
-    emit done(image);
-}
-
-class WallpaperWithPaint : public Wallpaper
-{
-public:
-    WallpaperWithPaint(QObject *parent, const QVariantList &args)
-        : Wallpaper(parent, args)
-    {
-    }
-
-    virtual void paint(QPainter *painter, const QRectF &exposedRect)
-    {
-        if (d->script) {
-            d->script->paint(painter, exposedRect);
-        }
-    }
-};
-
-QList<WallpaperRenderThread *> WallpaperPrivate::s_renderers;
-QQueue<WallpaperPrivate::RenderRequest> WallpaperPrivate::s_renderQueue;
 PackageStructure::Ptr WallpaperPrivate::s_packageStructure(0);
 
 Wallpaper::Wallpaper(QObject * parentObject)
@@ -132,6 +81,23 @@ Wallpaper::~Wallpaper()
     delete d;
 }
 
+void Wallpaper::addUrls(const KUrl::List &urls)
+{
+    // provide compatibility with urlDropped
+    foreach (const KUrl &url, urls) {
+        emit urlDropped(url);
+    }
+}
+
+void Wallpaper::setUrls(const KUrl::List &urls)
+{
+    if (!d->initialized) {
+        d->pendingUrls = urls;
+    } else {
+       QMetaObject::invokeMethod(this, "addUrls", Q_ARG(KUrl::List, urls));
+    }
+}
+
 KPluginInfo::List Wallpaper::listWallpaperInfo(const QString &formFactor)
 {
     QString constraint;
@@ -155,6 +121,12 @@ KPluginInfo::List Wallpaper::listWallpaperInfoForMimetype(const QString &mimetyp
     return KPluginInfo::fromServices(offers);
 }
 
+bool Wallpaper::supportsMimetype(const QString &mimetype) const
+{
+    return d->wallpaperDescription.isValid() &&
+           d->wallpaperDescription.service()->hasMimeType(mimetype);
+}
+
 Wallpaper *Wallpaper::load(const QString &wallpaperName, const QVariantList &args)
 {
     if (wallpaperName.isEmpty()) {
@@ -173,18 +145,6 @@ Wallpaper *Wallpaper::load(const QString &wallpaperName, const QVariantList &arg
     QVariantList allArgs;
     allArgs << offer->storageId() << args;
 
-    if (!offer->property("X-Plasma-API").toString().isEmpty()) {
-        kDebug() << "we have a script using the"
-                 << offer->property("X-Plasma-API").toString() << "API";
-        return new WallpaperWithPaint(0, allArgs);
-    }
-
-    KPluginLoader plugin(*offer);
-
-    if (!Plasma::isPluginVersionCompatible(plugin.pluginVersion())) {
-        return 0;
-    }
-
     QString error;
     Wallpaper *wallpaper = offer->createInstance<Plasma::Wallpaper>(0, allArgs, &error);
 
@@ -270,10 +230,9 @@ bool Wallpaper::isInitialized() const
 
 void Wallpaper::setBoundingRect(const QRectF &boundingRect)
 {
-    QSizeF oldBoundingRectSize = d->boundingRect.size();
     d->boundingRect = boundingRect;
 
-    if (!d->targetSize.isValid() || d->targetSize == oldBoundingRectSize)  {
+    if (d->targetSize != boundingRect.size()) {
         d->targetSize = boundingRect.size();
         emit renderHintsChanged();
     }
@@ -302,58 +261,39 @@ void Wallpaper::restore(const KConfigGroup &config)
 {
     init(config);
     d->initialized = true;
+    if (!d->pendingUrls.isEmpty()) {
+        setUrls(d->pendingUrls);
+        d->pendingUrls.clear();
+    }
 }
 
 void Wallpaper::init(const KConfigGroup &config)
 {
-    if (d->script) {
-        d->initScript();
-        d->script->initWallpaper(config);
-    }
 }
 
 void Wallpaper::save(KConfigGroup &config)
 {
-    if (d->script) {
-        d->script->save(config);
-    }
 }
 
 QWidget *Wallpaper::createConfigurationInterface(QWidget *parent)
 {
-    if (d->script) {
-        return d->script->createConfigurationInterface(parent);
-    } else {
-        return 0;
-    }
+    return 0;
 }
 
 void Wallpaper::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
-    if (d->script) {
-        return d->script->mouseMoveEvent(event);
-    }
 }
 
 void Wallpaper::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-    if (d->script) {
-        return d->script->mousePressEvent(event);
-    }
 }
 
 void Wallpaper::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-    if (d->script) {
-        return d->script->mouseReleaseEvent(event);
-    }
 }
 
 void Wallpaper::wheelEvent(QGraphicsSceneWheelEvent *event)
 {
-    if (d->script) {
-        return d->script->wheelEvent(event);
-    }
 }
 
 DataEngine *Wallpaper::dataEngine(const QString &name) const
@@ -392,14 +332,39 @@ void Wallpaper::setUsingRenderingCache(bool useCache)
 
 void Wallpaper::setResizeMethodHint(Wallpaper::ResizeMethod resizeMethod)
 {
-    d->lastResizeMethod = resizeMethod;
-    emit renderHintsChanged();
+    const ResizeMethod method = qBound(ScaledResize, resizeMethod, LastResizeMethod);
+    if (method != d->lastResizeMethod) {
+        d->lastResizeMethod = method;
+        emit renderHintsChanged();
+    }
+}
+
+Wallpaper::ResizeMethod Wallpaper::resizeMethodHint() const
+{
+    return d->lastResizeMethod;
 }
 
 void Wallpaper::setTargetSizeHint(const QSizeF &targetSize)
 {
-    d->targetSize = targetSize;
-    emit renderHintsChanged();
+    if (targetSize != d->targetSize) {
+        d->targetSize = targetSize;
+        emit renderHintsChanged();
+    }
+}
+
+QSizeF Wallpaper::targetSizeHint() const
+{
+    return d->targetSize;
+}
+
+void Wallpaper::render(const QImage &image, const QSize &size,
+                       Wallpaper::ResizeMethod resizeMethod, const QColor &color)
+{
+    if (image.isNull()) {
+        return;
+    }
+
+    d->renderWallpaper(QString(), image, size, resizeMethod, color);
 }
 
 void Wallpaper::render(const QString &sourceImagePath, const QSize &size,
@@ -410,89 +375,163 @@ void Wallpaper::render(const QString &sourceImagePath, const QSize &size,
         return;
     }
 
-    if (d->lastResizeMethod != resizeMethod) {
-        d->lastResizeMethod = resizeMethod;
-        emit renderHintsChanged();
+    d->renderWallpaper(sourceImagePath, QImage(), size, resizeMethod, color);
+}
+
+void WallpaperPrivate::renderWallpaper(const QString &sourceImagePath, const QImage &image, const QSize &size,
+                                       Wallpaper::ResizeMethod resizeMethod, const QColor &color)
+{
+    resizeMethod = qBound(Wallpaper::ScaledResize, resizeMethod, Wallpaper::LastResizeMethod);
+    if (lastResizeMethod != resizeMethod) {
+        lastResizeMethod = resizeMethod;
+        emit q->renderHintsChanged();
     }
 
-    if (d->cacheRendering) {
+    if (cacheRendering) {
         QFileInfo info(sourceImagePath);
-        QString cache = d->cacheKey(sourceImagePath, size, resizeMethod, color);
-        if (d->findInCache(cache, info.lastModified().toTime_t())) {
+        QString cache = cacheKey(sourceImagePath, size, resizeMethod, color);
+        if (findInCache(cache, info.lastModified().toTime_t())) {
             return;
         }
     }
 
-    for (int i = 0; i < WallpaperPrivate::s_renderers.size(); i++) {
-        if (d->renderToken == WallpaperPrivate::s_renderers[i]->currentToken()) {
-            d->renderToken = WallpaperPrivate::s_renderers[i]->render(sourceImagePath, size, resizeMethod, color);
-            return;
-        }
+    kDebug() << "rendering wallpaper" << sourceImagePath;
+    QImage result(size, QImage::Format_ARGB32_Premultiplied);
+    result.fill(color.rgba());
+
+    if (sourceImagePath.isEmpty() && image.isNull() && !QFile::exists(sourceImagePath)) {
+        kDebug() << "wrong request or file does not exist";
+        return;
     }
 
-#ifndef PLASMA_NO_SOLID
-    const int numProcs = Solid::Device::listFromType(Solid::DeviceInterface::Processor).count();
-#else
-    const int numProcs = 1;
-#endif
-    if (WallpaperPrivate::s_renderers.size() < qMax(numProcs, 1)) {
-        WallpaperRenderThread *renderThread = new WallpaperRenderThread();
-        WallpaperPrivate::s_renderers.append(renderThread);
-        d->renderToken = renderThread->render(sourceImagePath, size, resizeMethod, color);
-        connect(renderThread, SIGNAL(done(WallpaperRenderThread*,int,QImage,QString,QSize,int,QColor)),
-                this, SLOT(renderCompleted(WallpaperRenderThread*,int,QImage,QString,QSize,int,QColor)), Qt::UniqueConnection);
+    QPoint pos(0, 0);
+    //const float ratio = qMax(float(1), size.width() / float(size.height()));
+    bool tiled = false;
+    QSize scaledSize;
+    QImage img;
+
+    // set image size
+    QSize imgSize(1, 1);
+    if (!image.isNull()) {
+        img = image;
+        kDebug() << "going to resize the img" << img.size();
+        imgSize = imgSize.expandedTo(img.size());
     } else {
-         WallpaperPrivate::RenderRequest request;
-         request.parent = this;
-         request.file = sourceImagePath;
-         request.size = size;
-         request.resizeMethod = resizeMethod;
-         request.color = color;
-
-         for (int i = 0; i < WallpaperPrivate::s_renderQueue.size(); i++) {
-            if (WallpaperPrivate::s_renderQueue[i].parent.data() == this){
-                WallpaperPrivate::s_renderQueue[i] = request;
-                return;
-            }
-         }
-         WallpaperPrivate::s_renderQueue.append(request);
+        // otherwise, use the natural size of the loaded image
+        img = QImage(sourceImagePath);
+        imgSize = imgSize.expandedTo(img.size());
+        //kDebug() << "loaded with" << imgSize << ratio;
     }
-    //kDebug() << "rendering" << sourceImagePath << ", token is" << d->renderToken;
+
+    // set render parameters according to resize mode
+    switch (resizeMethod) {
+        case Wallpaper::ScaledResize: {
+            scaledSize = size;
+            break;
+        }
+        case Wallpaper::CenteredResize: {
+            scaledSize = imgSize;
+            pos = QPoint((size.width() - scaledSize.width()) / 2,
+                         (size.height() - scaledSize.height()) / 2);
+
+            //If the picture is bigger than the screen, shrink it
+            if (size.width() < imgSize.width() && imgSize.width() > imgSize.height()) {
+                int width = size.width();
+                int height = width * scaledSize.height() / imgSize.width();
+                scaledSize = QSize(width, height);
+                pos = QPoint((size.width() - scaledSize.width()) / 2,
+                        (size.height() - scaledSize.height()) / 2);
+            } else if (size.height() < imgSize.height()) {
+                int height = size.height();
+                int width = height * imgSize.width() / imgSize.height();
+                scaledSize = QSize(width, height);
+                pos = QPoint((size.width() - scaledSize.width()) / 2,
+                             (size.height() - scaledSize.height()) / 2);
+            }
+
+            break;
+        }
+        case Wallpaper::MaxpectResize: {
+            float xratio = (float) size.width() / imgSize.width();
+            float yratio = (float) size.height() / imgSize.height();
+            if (xratio > yratio) {
+                int height = size.height();
+                int width = height * imgSize.width() / imgSize.height();
+                scaledSize = QSize(width, height);
+            } else {
+                int width = size.width();
+                int height = width * imgSize.height() / imgSize.width();
+                scaledSize = QSize(width, height);
+            }
+
+            pos = QPoint((size.width() - scaledSize.width()) / 2,
+                         (size.height() - scaledSize.height()) / 2);
+            break;
+        }
+        case Wallpaper::ScaledAndCroppedResize: {
+            float xratio = (float) size.width() / imgSize.width();
+            float yratio = (float) size.height() / imgSize.height();
+            if (xratio > yratio) {
+                int width = size.width();
+                int height = width * imgSize.height() / imgSize.width();
+                scaledSize = QSize(width, height);
+            } else {
+                int height = size.height();
+                int width = height * imgSize.width() / imgSize.height();
+                scaledSize = QSize(width, height);
+            }
+            pos = QPoint((size.width() - scaledSize.width()) / 2,
+                         (size.height() - scaledSize.height()) / 2);
+            break;
+        }
+        case Wallpaper::TiledResize: {
+            scaledSize = imgSize;
+            tiled = true;
+            break;
+        }
+        case Wallpaper::CenterTiledResize: {
+            scaledSize = imgSize;
+            pos = QPoint(-scaledSize.width() + ((size.width() - scaledSize.width()) / 2) % scaledSize.width(),
+                         -scaledSize.height() + ((size.height() - scaledSize.height()) / 2) % scaledSize.height());
+            tiled = true;
+            break;
+        }
+    }
+
+    QPainter p(&result);
+    // kDebug() << sourceImagePath << scalable << scaledSize << imgSize;
+    if (scaledSize != imgSize) {
+        img = img.scaled(scaledSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+    }
+
+    if (tiled) {
+        for (int x = pos.x(); x < size.width(); x += scaledSize.width()) {
+            for (int y = pos.y(); y < size.height(); y += scaledSize.height()) {
+                p.drawImage(QPoint(x, y), img);
+            }
+        }
+    } else {
+        p.drawImage(pos, img);
+    }
+
+    if (cacheRendering) {
+        q->insertIntoCache(cacheKey(sourceImagePath, size, resizeMethod, color), result);
+    }
+
+    //kDebug() << "rendering complete!";
+    emit q->renderCompleted(result);
 }
 
 WallpaperPrivate::WallpaperPrivate(KService::Ptr service, Wallpaper *wallpaper) :
     q(wallpaper),
     wallpaperDescription(service),
-    package(0),
-    renderToken(-1),
     lastResizeMethod(Wallpaper::ScaledResize),
-    script(0),
     cacheRendering(false),
     initialized(false),
     needsConfig(false),
-    scriptInitialized(false),
-    previewing(false)
+    previewing(false),
+    needsPreviewDuringConfiguration(false)
 {
-    if (wallpaperDescription.isValid()) {
-        QString api = wallpaperDescription.property("X-Plasma-API").toString();
-
-        if (!api.isEmpty()) {
-            const QString path = KStandardDirs::locate("data",
-                    "plasma/wallpapers/" + wallpaperDescription.pluginName() + '/');
-            PackageStructure::Ptr structure =
-                Plasma::packageStructure(api, Plasma::WallpaperComponent);
-            structure->setPath(path);
-            package = new Package(path, structure);
-
-            script = Plasma::loadScriptEngine(api, q);
-            if (!script) {
-                kDebug() << "Could not create a" << api << "ScriptEngine for the"
-                        << wallpaperDescription.name() << "Wallpaper.";
-                delete package;
-                package = 0;
-            }
-       }
-    }
 }
 
 QString WallpaperPrivate::cacheKey(const QString &sourceImagePath, const QSize &size,
@@ -506,96 +545,23 @@ QString WallpaperPrivate::cacheKey(const QString &sourceImagePath, const QSize &
 
 QString WallpaperPrivate::cachePath(const QString &key) const
 {
-    return KGlobal::dirs()->locateLocal("cache", "plasma-wallpapers/" + key + ".png");
-}
-
-void WallpaperPrivate::renderCompleted(WallpaperRenderThread *currentRenderer, int token, const QImage &image,
-                                       const QString &sourceImagePath, const QSize &size,
-                                       int resizeMethod, const QColor &color)
-{
-    q->disconnect(currentRenderer, SIGNAL(done(WallpaperRenderThread*,int,QImage,QString,QSize,int,QColor)),
-                    q, SLOT(renderCompleted(WallpaperRenderThread*,int,QImage,QString,QSize,int,QColor)));
-
-    if (!s_renderQueue.isEmpty()) {
-        while (!s_renderQueue.isEmpty()) {
-            WallpaperPrivate::RenderRequest request = s_renderQueue.dequeue();
-
-            if (!request.parent) {
-                continue;
-            }
-
-            currentRenderer->wait();
-            request.parent.data()->d->renderToken = currentRenderer->render(request.file, request.size, request.resizeMethod, request.color);
-            QObject::connect(currentRenderer, SIGNAL(done(WallpaperRenderThread*,int,QImage,QString,QSize,int,QColor)),
-                    request.parent.data(), SLOT(renderCompleted(WallpaperRenderThread*,int,QImage,QString,QSize,int,QColor)), Qt::UniqueConnection);
-
-            break;
-        }
-    } else {
-         for (int i = 0; i < s_renderers.size(); i++) {
-            if (s_renderers[i] == currentRenderer){
-                s_renderers.removeAt(i);
-            }
-         }
-         currentRenderer->deleteLater();
-         currentRenderer = 0;
-    }
-
-    if (token != renderToken) {
-        //kDebug() << "render token mismatch" << token << renderToken;
-        return;
-    }
-
-    if (cacheRendering) {
-        q->insertIntoCache(cacheKey(sourceImagePath, size, resizeMethod, color), image);
-    }
-
-    //kDebug() << "rendering complete!";
-    emit q->renderCompleted(image);
-}
-
-// put all setup routines for script here. at this point we can assume that
-// package exists and that we have a script engine
-void WallpaperPrivate::setupScriptSupport()
-{
-    Q_ASSERT(package);
-    kDebug() << "setting up script support, package is in" << package->path()
-             << "which is a" << package->structure()->type() << "package"
-             << ", main script is" << package->filePath("mainscript");
-
-    QString translationsPath = package->filePath("translations");
-    if (!translationsPath.isEmpty()) {
-        //FIXME: we should _probably_ use a KComponentData to segregate the applets
-        //       from each other; but I want to get the basics working first :)
-        KGlobal::dirs()->addResourceDir("locale", translationsPath);
-        KGlobal::locale()->insertCatalog(package->metadata().pluginName());
-    }
-}
-
-void WallpaperPrivate::initScript()
-{
-    if (script && !scriptInitialized) {
-        setupScriptSupport();
-        script->init();
-        scriptInitialized = true;
-    }
+    return KGlobal::dirs()->locateLocal("cache", "plasma-wallpapers/" + key + "." + imageFormat);
 }
 
 bool WallpaperPrivate::findInCache(const QString &key, unsigned int lastModified)
 {
     if (cacheRendering) {
         QString cache = cachePath(key);
-        if (QFile::exists(cache)) {
+        QFileInfo cacheinfo(cache);
+        if (cacheinfo.exists() && cacheinfo.isFile()) {
             if (lastModified > 0) {
-                QFileInfo info(cache);
-                if (info.lastModified().toTime_t() < lastModified) {
+                if (cacheinfo.lastModified().toTime_t() < lastModified) {
                     return false;
                 }
             }
 
-            LoadImageThread *loadImageT = new LoadImageThread(cache);
-            q->connect(loadImageT, SIGNAL(done(const QImage&)), q, SIGNAL(renderCompleted(const QImage&)));
-            QThreadPool::globalInstance()->start(loadImageT);
+            QImage image(cache, imageFormat);
+            emit q->renderCompleted(image);
 
             return true;
         }
@@ -608,10 +574,10 @@ bool Wallpaper::findInCache(const QString &key, QImage &image, unsigned int last
 {
     if (d->cacheRendering) {
         QString cache = d->cachePath(key);
-        if (QFile::exists(cache)) {
+        QFileInfo cacheinfo(cache);
+        if (cacheinfo.exists() && cacheinfo.isFile()) {
             if (lastModified > 0) {
-                QFileInfo info(cache);
-                if (info.lastModified().toTime_t() < lastModified) {
+                if (cacheinfo.lastModified().toTime_t() < lastModified) {
                     return false;
                 }
             }
@@ -637,22 +603,22 @@ void Wallpaper::insertIntoCache(const QString& key, const QImage &image)
             KIO::file_delete(d->cachePath(key));
 #else
             QFile f(d->cachePath(key));
-            f.remove():
+            f.remove();
 #endif
         } else {
-            QThreadPool::globalInstance()->start(new SaveImageThread(image, d->cachePath(key)));
+            image.save(d->cachePath(key), imageFormat, 100);
         }
     }
 }
 
 QList<QAction*> Wallpaper::contextualActions() const
 {
-    return contextActions;
+    return d->contextActions;
 }
 
 void Wallpaper::setContextualActions(const QList<QAction*> &actions)
 {
-    contextActions = actions;
+    d->contextActions = actions;
 }
 
 bool Wallpaper::isPreviewing() const
@@ -665,12 +631,16 @@ void Wallpaper::setPreviewing(bool previewing)
     d->previewing = previewing;
 }
 
-const Package *Wallpaper::package() const
+bool Wallpaper::needsPreviewDuringConfiguration() const
 {
-    return d->package;
+    return d->needsPreviewDuringConfiguration;
+}
+
+void Wallpaper::setPreviewDuringConfiguration(const bool preview)
+{
+    d->needsPreviewDuringConfiguration = preview;
 }
 
 } // Plasma namespace
 
-#include "wallpaper.moc"
-#include "private/wallpaper_p.moc"
+#include "moc_wallpaper.cpp"
