@@ -25,19 +25,19 @@
 
 #include <kmimetype.h>
 
-#include "theme.h"
+#include "private/themedwidgetinterface_p.h"
 #include "svg.h"
+#include "theme.h"
 
 namespace Plasma
 {
 
-class CheckBoxPrivate
+class CheckBoxPrivate : public ThemedWidgetInterface<CheckBox>
 {
 public:
     CheckBoxPrivate(CheckBox *c)
-        : q(c),
-          svg(0),
-          customFont(false)
+        : ThemedWidgetInterface<CheckBox>(c),
+          svg(0)
     {
     }
 
@@ -76,24 +76,9 @@ public:
         static_cast<QCheckBox*>(q->widget())->setIcon(QIcon(pm));
     }
 
-    void setPalette()
-    {
-        QCheckBox *native = q->nativeWidget();
-        QColor color = Theme::defaultTheme()->color(Theme::TextColor);
-        QPalette p = native->palette();
-        p.setColor(QPalette::Normal, QPalette::WindowText, color);
-        p.setColor(QPalette::Inactive, QPalette::WindowText, color);
-        native->setPalette(p);
-        if (!customFont) {
-            q->nativeWidget()->setFont(Plasma::Theme::defaultTheme()->font(Plasma::Theme::DefaultFont));
-        }
-    }
-
-    CheckBox *q;
     QString imagePath;
     QString absImagePath;
     Svg *svg;
-    bool customFont;
 };
 
 CheckBox::CheckBox(QGraphicsWidget *parent)
@@ -102,10 +87,11 @@ CheckBox::CheckBox(QGraphicsWidget *parent)
 {
     QCheckBox *native = new QCheckBox;
     connect(native, SIGNAL(toggled(bool)), this, SIGNAL(toggled(bool)));
-    setWidget(native);
-    d->setPalette();
+    d->setWidget(native);
+    native->setWindowIcon(QIcon());
     native->setAttribute(Qt::WA_NoSystemBackground);
-    connect(Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(setPalette()));
+
+    d->initTheming();
 }
 
 CheckBox::~CheckBox()
@@ -134,11 +120,7 @@ void CheckBox::setImage(const QString &path)
     d->imagePath = path;
 
     bool absolutePath = !path.isEmpty() &&
-                        #ifdef Q_WS_WIN
-                            !QDir::isRelativePath(path)
-                        #else
                             (path[0] == '/' || path.startsWith(QLatin1String(":/")))
-                        #endif
         ;
 
     if (absolutePath) {
@@ -189,15 +171,11 @@ bool CheckBox::isChecked() const
 
 void CheckBox::changeEvent(QEvent *event)
 {
-    if (event->type() == QEvent::FontChange) {
-        d->customFont = true;
-        nativeWidget()->setFont(font());
-    }
-
+    d->changeEvent(event);
     QGraphicsProxyWidget::changeEvent(event);
 }
 
 } // namespace Plasma
 
-#include <checkbox.moc>
+#include "moc_checkbox.cpp"
 
