@@ -24,7 +24,7 @@
 #include <QtCore/QString>
 #include <QtCore/QTimeLine>
 #include <QtCore/QTimer>
-#include <QtCore/QWeakPointer>
+#include <QtCore/qsharedpointer.h>
 #include <QtGui/QPainter>
 #include <QtGui/QPixmap>
 #include <QtGui/QColor>
@@ -243,11 +243,8 @@ void FlashingLabel::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
     if (d->anim.data() && d->anim.data()->state() == QAbstractAnimation::Running) {
         Plasma::Animation *animation = d->anim.data();
         painter->drawPixmap(0, 0, qvariant_cast<QPixmap>(animation->property("currentPixmap")));
-    } else {
-
-        if (d->state == FlashingLabelPrivate::Visible) {
-            painter->drawPixmap(0, 0, d->renderedPixmap);
-        }
+    } else if (d->state == FlashingLabelPrivate::Visible) {
+        painter->drawPixmap(0, 0, d->renderedPixmap);
     }
 }
 
@@ -331,4 +328,4 @@ void FlashingLabelPrivate::setPalette()
     q->update();
 }
 
-#include "flashinglabel.moc"
+#include "moc_flashinglabel.cpp"
