@@ -27,11 +27,11 @@
 
 #include <QAction>
 #include <QApplication>
-#include <QGraphicsSceneMouseEvent>
+#include <QtGui/qgraphicssceneevent.h>
 #include <QGraphicsView>
 #include <QMenu>
 #include <QPainter>
-#include <QStyleOptionGraphicsItem>
+#include <QtGui/qstyleoption.h>
 #include <QTextLayout>
 #include <QTimer>
 
@@ -277,47 +277,38 @@ bool IconAction::event(QEvent::Type type, const QPointF &pos)
     }
 
     switch (type) {
-    case QEvent::GraphicsSceneMousePress:
-    {
-        setSelected(m_rect.contains(pos));
-        return isSelected();
-    }
-    break;
-
-    case QEvent::GraphicsSceneMouseMove:
-    {
-        bool wasSelected = isSelected();
-        bool active = m_rect.contains(pos);
-        setSelected(wasSelected && active);
-        return (wasSelected != isSelected()) || active;
-    }
-    break;
-
-    case QEvent::GraphicsSceneMouseRelease:
-    {
-        // kDebug() << "IconAction::event got a QEvent::MouseButtonRelease, " << isSelected();
-        bool wasSelected = isSelected();
-        setSelected(false);
-        if (wasSelected) {
-            m_action->trigger();
+        case QEvent::GraphicsSceneMousePress: {
+            setSelected(m_rect.contains(pos));
+            return isSelected();
+        }
+        case QEvent::GraphicsSceneMouseMove: {
+            bool wasSelected = isSelected();
+            bool active = m_rect.contains(pos);
+            setSelected(wasSelected && active);
+            return (wasSelected != isSelected()) || active;
+        }
+        case QEvent::GraphicsSceneMouseRelease: {
+            // kDebug() << "IconAction::event got a QEvent::MouseButtonRelease, " << isSelected();
+            bool wasSelected = isSelected();
+            setSelected(false);
+            if (wasSelected) {
+                m_action->trigger();
+            }
+            return wasSelected;
+        }
+        case QEvent::GraphicsSceneHoverEnter: {
+            m_pressed = false;
+            m_hovered = true;
+            break;
+        }
+        case QEvent::GraphicsSceneHoverLeave: {
+            m_pressed = false;
+            m_hovered = false;
+            break;
+        }
+        default: {
+            break;
         }
-
-        return wasSelected;
-    }
-    break;
-
-    case QEvent::GraphicsSceneHoverEnter:
-        m_pressed = false;
-        m_hovered = true;
-        break;
-
-    case QEvent::GraphicsSceneHoverLeave:
-        m_pressed = false;
-        m_hovered = false;
-        break;
-
-    default:
-        break;
     }
 
     return false;
@@ -389,7 +380,7 @@ void IconWidgetPrivate::init()
     QObject::connect(KGlobalSettings::self(), SIGNAL(iconChanged(int)), q, SLOT(iconConfigChanged()));
 
     // setAcceptedMouseButtons(Qt::LeftButton);
-    q->setAcceptsHoverEvents(true);
+    q->setAcceptHoverEvents(true);
     q->setCacheMode(QGraphicsItem::DeviceCoordinateCache);
 
     background = new Plasma::FrameSvg(q);
@@ -810,16 +801,33 @@ QPixmap IconWidgetPrivate::decoration(const QStyleOptionGraphicsItem *option, bo
     QIcon::Mode mode   = option->state & QStyle::State_Enabled ? QIcon::Normal : QIcon::Disabled;
     QIcon::State state = option->state & QStyle::State_Open ? QIcon::On : QIcon::Off;
 
+    QSize finalSize(iconSize.toSize());
+    //for small sizes, use a standard size
+    if (finalSize.width() < KIconLoader::SizeSmallMedium) {
+        finalSize = QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall);
+    } else if (finalSize.width() < KIconLoader::SizeMedium) {
+        finalSize = QSize(KIconLoader::SizeSmallMedium, KIconLoader::SizeSmallMedium);
+    } else if (finalSize.width() < KIconLoader::SizeLarge) {
+        finalSize = QSize(KIconLoader::SizeMedium, KIconLoader::SizeMedium);
+    }
+
     if (iconSvg) {
         if (iconSvgElementChanged || iconSvgPixmap.size() != iconSize.toSize()) {
-            iconSvg->resize(iconSize);
+            //even the svg is returned at standard sizes because:
+            // * it may have a version optimized for that size
+            // * look aligned with other icons
+            iconSvg->resize(finalSize);
             iconSvgPixmap = iconSvg->pixmap(iconSvgElement);
             iconSvgElementChanged = false;
         }
         result = iconSvgPixmap;
     } else {
-        const QSize size = icon.actualSize(iconSize.toSize(), mode, state);
-        result = icon.pixmap(size, mode, state);
+        //the QIcon isn't filled with available sizes, return a near standard size for small pixmaps
+        if (!icon.availableSizes().isEmpty()) {
+            finalSize = icon.actualSize(iconSize.toSize(), mode, state);
+        }
+
+        result = icon.pixmap(finalSize, mode, state);
     }
 
     if (usePressedEffect) {
@@ -1199,7 +1207,7 @@ void IconWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
         painter->drawImage(textBoundingRect.topLeft() + shadowPos, shadow);
     } else if (!(d->text.isEmpty() && d->infoText.isEmpty()) &&
                !textBoundingRect.isEmpty()) {
-        QRect labelRect = d->labelRectangle(option, icon, d->text).toRect();
+        // QRect labelRect = d->labelRectangle(option, icon, d->text).toRect();
 
         foreach (const QRect &rect, d->haloRects) {
             Plasma::PaintUtils::drawHalo(painter, rect);
@@ -1616,5 +1624,5 @@ void IconWidget::changeEvent(QEvent *event)
 
 } // namespace Plasma
 
-#include "iconwidget.moc"
-#include "iconwidget_p.moc"
+#include "moc_iconwidget.cpp"
+#include "moc_iconwidget_p.cpp"
