@@ -21,7 +21,7 @@
 
 #include <QPainter>
 #include <QTimer>
-#include <QStyleOptionGraphicsItem>
+#include <QtGui/qstyleoption.h>
 
 #include <QPropertyAnimation>
 
@@ -62,11 +62,6 @@ ItemBackground::ItemBackground(QGraphicsWidget *parent)
     : QGraphicsWidget(parent),
       d(new ItemBackgroundPrivate(this))
 {
-    setCacheMode(DeviceCoordinateCache);
-    setFlag(ItemIsMovable, false);
-    setFlag(ItemIsSelectable, false);
-    setFlag(ItemIsFocusable, false);
-
     d->frameSvg = new Plasma::FrameSvg(this);
     d->anim = new QPropertyAnimation(this, "animationUpdate", this);
     d->anim->setStartValue(0);
@@ -81,6 +76,13 @@ ItemBackground::ItemBackground(QGraphicsWidget *parent)
     d->frameSvg->setCacheAllRenderedFrames(true);
     d->frameSvg->setElementPrefix("hover");
 
+    setCacheMode(DeviceCoordinateCache);
+    setFlag(ItemIsMovable, false);
+    setFlag(ItemIsSelectable, false);
+    setFlag(ItemIsFocusable, false);
+
+    setFlag(QGraphicsItem::ItemSendsGeometryChanges, false);
+
     qreal l, t, r, b;
     d->frameSvg->getMargins(l, t, r, b);
     setContentsMargins(l, t, r, b);
@@ -338,6 +340,6 @@ void ItemBackgroundPrivate::refreshCurrentTarget()
 } // Plasma namespace
 
 
-#include "itembackground.moc"
+#include "moc_itembackground.cpp"
 
 
