@@ -20,30 +20,32 @@
 #include "label.h"
 
 #include <QApplication>
-#include <QLabel>
-#include <QPainter>
 #include <QDir>
-#include <QStyleOptionGraphicsItem>
-#include <QGraphicsSceneMouseEvent>
+#include <QtGui/qgraphicssceneevent.h>
+#include <QLabel>
 #include <QMenu>
+#include <QPainter>
+#include <QtGui/qstyleoption.h>
 
-#include <kmimetype.h>
-#include <kglobalsettings.h>
 #include <kcolorscheme.h>
+#include <kglobalsettings.h>
+#include <kmimetype.h>
 
-#include "theme.h"
+#include "private/themedwidgetinterface_p.h"
 #include "svg.h"
+#include "theme.h"
 
 namespace Plasma
 {
 
-class LabelPrivate
+class LabelPrivate : public ThemedWidgetInterface<Label>
 {
 public:
     LabelPrivate(Label *label)
-        : q(label),
+        : ThemedWidgetInterface<Label>(label),
           svg(0),
-          customFont(false)
+          textSelectable(false),
+          hasLinks(false)
     {
     }
 
@@ -82,31 +84,11 @@ public:
         static_cast<QLabel*>(q->widget())->setPixmap(pm);
     }
 
-    void setPalette()
-    {
-        QLabel *native = q->nativeWidget();
-        QColor color = Theme::defaultTheme()->color(Theme::TextColor);
-        QPalette p = native->palette();
-        p.setColor(QPalette::Normal, QPalette::WindowText, color);
-        p.setColor(QPalette::Inactive, QPalette::WindowText, color);
-        color.setAlphaF(0.6);
-        p.setColor(QPalette::Disabled, QPalette::WindowText, color);
-
-        p.setColor(QPalette::Normal, QPalette::Link, Theme::defaultTheme()->color(Theme::LinkColor));
-        p.setColor(QPalette::Normal, QPalette::LinkVisited, Theme::defaultTheme()->color(Theme::VisitedLinkColor));
-        native->setPalette(p);
-
-        if (!customFont) {
-            q->nativeWidget()->setFont(Plasma::Theme::defaultTheme()->font(Plasma::Theme::DefaultFont));
-        }
-    }
-
-    Label *q;
     QString imagePath;
     QString absImagePath;
     Svg *svg;
-    bool textSelectable;
-    bool customFont;
+    bool textSelectable : 1;
+    bool hasLinks : 1;
 };
 
 Label::Label(QGraphicsWidget *parent)
@@ -114,19 +96,17 @@ Label::Label(QGraphicsWidget *parent)
       d(new LabelPrivate(this))
 {
     QLabel *native = new QLabel;
+
     native->setWindowFlags(native->windowFlags()|Qt::BypassGraphicsProxyWidget);
-    d->textSelectable = false;
+    native->setAttribute(Qt::WA_NoSystemBackground);
+    native->setWordWrap(true);
+    native->setWindowIcon(QIcon());
+
     connect(native, SIGNAL(linkActivated(QString)), this, SIGNAL(linkActivated(QString)));
     connect(native, SIGNAL(linkHovered(QString)), this, SIGNAL(linkHovered(QString)));
 
-    connect(Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(setPalette()));
-    connect(KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()), this, SLOT(setPalette()));
-
-    native->setAttribute(Qt::WA_NoSystemBackground);
-    native->setWordWrap(true);
-    setWidget(native);
-    native->setWindowIcon(QIcon());
-    d->setPalette();
+    d->setWidget(native);
+    d->initTheming();
 }
 
 Label::~Label()
@@ -136,6 +116,7 @@ Label::~Label()
 
 void Label::setText(const QString &text)
 {
+    d->hasLinks = text.contains("<a ", Qt::CaseInsensitive);
     static_cast<QLabel*>(widget())->setText(text);
     updateGeometry();
 }
@@ -156,11 +137,7 @@ void Label::setImage(const QString &path)
     d->imagePath = path;
 
     bool absolutePath = !path.isEmpty() &&
-                        #ifdef Q_WS_WIN
-                            !QDir::isRelativePath(path)
-                        #else
                             (path[0] == '/' || path.startsWith(QLatin1String(":/")))
-                        #endif
         ;
 
     if (absolutePath) {
@@ -193,7 +170,7 @@ void Label::setTextSelectable(bool enable)
     if (enable) {
         nativeWidget()->setTextInteractionFlags(Qt::TextBrowserInteraction);
     } else {
-        nativeWidget()->setTextInteractionFlags(Qt::LinksAccessibleByMouse);
+        nativeWidget()->setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::LinksAccessibleByKeyboard);
     }
 
     d->textSelectable = enable;
@@ -255,9 +232,13 @@ void Label::dataUpdated(const QString &sourceName, const Plasma::DataEngine::Dat
 
 void Label::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 {
-    QContextMenuEvent contextMenuEvent(QContextMenuEvent::Reason(event->reason()),
-                                       event->pos().toPoint(), event->screenPos(), event->modifiers());
-    QApplication::sendEvent(nativeWidget(), &contextMenuEvent);
+    if (d->textSelectable || d->hasLinks){
+        QContextMenuEvent contextMenuEvent(QContextMenuEvent::Reason(event->reason()),
+                                           event->pos().toPoint(), event->screenPos(), event->modifiers());
+        QApplication::sendEvent(nativeWidget(), &contextMenuEvent);
+    }else{
+        event->ignore();
+    }
 }
 
 void Label::resizeEvent(QGraphicsSceneResizeEvent *event)
@@ -271,7 +252,7 @@ void Label::mousePressEvent(QGraphicsSceneMouseEvent *event)
     QGraphicsProxyWidget::mousePressEvent(event);
     //FIXME: when QTextControl accept()s mouse press events (as of Qt 4.6.2, it processes them
     //but never marks them as accepted) the following event->accept() can be removed
-    if (d->textSelectable) {
+    if (d->textSelectable || d->hasLinks) {
         event->accept();
     }
 }
@@ -332,20 +313,13 @@ void Label::paint(QPainter *painter,
 
 void Label::changeEvent(QEvent *event)
 {
-    if (event->type() == QEvent::FontChange && font() != QApplication::font()) {
-        d->customFont = true;
-        nativeWidget()->setFont(font());
-    }
-
+    d->changeEvent(event);
     QGraphicsProxyWidget::changeEvent(event);
 }
 
 bool Label::event(QEvent *event)
 {
-    if (event->type() == QEvent::Show && font() != QApplication::font()) {
-        d->customFont = true;
-        nativeWidget()->setFont(font());
-    }
+    d->event(event);
     return QGraphicsProxyWidget::event(event);
 }
 
@@ -369,5 +343,5 @@ QSizeF Label::sizeHint(Qt::SizeHint which, const QSizeF &constraint) const
 
 } // namespace Plasma
 
-#include <label.moc>
+#include "moc_label.cpp"
 
