@@ -21,8 +21,8 @@
 #include "scrollbar.h"
 
 #include <QApplication>
-#include <QContextMenuEvent>
-#include <QGraphicsSceneContextMenuEvent>
+#include <QtGui/qevent.h>
+#include <QtGui/qgraphicssceneevent.h>
 
 #include <plasma/private/style_p.h>
 
@@ -40,15 +40,16 @@ ScrollBar::ScrollBar(QGraphicsWidget *parent)
       d(new ScrollBarPrivate)
 {
    QScrollBar *scrollbar = new QScrollBar();
-   //disabled for now: triggers Qt bug 7254
-   //scrollbar->setWindowFlags(scrollbar->windowFlags()|Qt::BypassGraphicsProxyWidget);
+   scrollbar->setWindowFlags(scrollbar->windowFlags()|Qt::BypassGraphicsProxyWidget);
    scrollbar->setAttribute(Qt::WA_NoSystemBackground);
    setWidget(scrollbar);
+   scrollbar->setWindowIcon(QIcon());
    d->style = Plasma::Style::sharedStyle();
    scrollbar->setStyle(d->style.data());
 
    scrollbar->resize(scrollbar->sizeHint());
    connect(scrollbar, SIGNAL(valueChanged(int)), this, SIGNAL(valueChanged(int)));
+   connect(scrollbar, SIGNAL(sliderMoved(int)), this, SIGNAL(sliderMoved(int)));
 }
 
 ScrollBar::~ScrollBar()
@@ -102,6 +103,16 @@ int ScrollBar::maximum() const
    return static_cast<QScrollBar*>(widget())->maximum();
 }
 
+void ScrollBar::setMinimum(const int min) const
+{
+    static_cast<QScrollBar*>(widget())->setMinimum(min);
+}
+
+void ScrollBar::setMaximum(const int max) const
+{
+    static_cast<QScrollBar*>(widget())->setMaximum(max);
+}
+
 void ScrollBar::setStyleSheet(const QString &stylesheet)
 {
    widget()->setStyleSheet(stylesheet);
@@ -131,14 +142,11 @@ void ScrollBar::setOrientation(Qt::Orientation orientation)
 
 void ScrollBar::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 {
-    /*disabled for now: triggers Qt bug 7254
     QContextMenuEvent contextMenuEvent(QContextMenuEvent::Reason(event->reason()),
                                        event->pos().toPoint(), event->screenPos(), event->modifiers());
     QApplication::sendEvent(nativeWidget(), &contextMenuEvent);
-    */
-    QGraphicsProxyWidget::contextMenuEvent(event);
 }
 
 }
 
-#include <scrollbar.moc>
+#include "moc_scrollbar.cpp"
