@@ -22,29 +22,36 @@
 #include <cmath>
 
 //Qt
-#include <QGraphicsSceneResizeEvent>
+#include <QGraphicsSceneEvent>
 #include <QGraphicsGridLayout>
 #include <QGraphicsScene>
 #include <QApplication>
-#include <QKeyEvent>
+#include <QEvent>
 #include <QWidget>
 #include <QTimer>
-#include <QTime>
+#include <QDateTime>
 #include <QPropertyAnimation>
 #include <QSequentialAnimationGroup>
+#include <QTextBrowser>
+#include <QLabel>
 
 //KDE
 #include <kmimetype.h>
 #include <kdebug.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
+#include <ktextedit.h>
 
 //Plasma
 #include <plasma/widgets/scrollbar.h>
 #include <plasma/widgets/svgwidget.h>
+#include <plasma/widgets/label.h>
+#include <plasma/widgets/textedit.h>
+#include <plasma/widgets/textbrowser.h>
 #include <plasma/animator.h>
 #include <plasma/svg.h>
 
+
 #define DEBUG 0
 
 /*
@@ -84,13 +91,6 @@ namespace Plasma
 class ScrollWidgetPrivate
 {
 public:
-    enum Gesture {
-        GestureNone = 0,
-        GestureUndefined,
-        GestureScroll,
-        GestureZoom
-    };
-
     ScrollWidgetPrivate(ScrollWidget *parent)
         : q(parent),
           topBorder(0),
@@ -98,7 +98,7 @@ public:
           leftBorder(0),
           rightBorder(0),
           dragging(false),
-          multitouchGesture(GestureNone)
+          overflowBordersVisible(true)
     {
     }
 
@@ -112,7 +112,7 @@ public:
         q->setFiltersChildEvents(true);
         layout = new QGraphicsGridLayout(q);
         q->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-        layout->setContentsMargins(1, 1, 1, 1);
+        layout->setContentsMargins(0, 0, 0, 0);
         scrollingWidget = new QGraphicsWidget(q);
         scrollingWidget->setFlag(QGraphicsItem::ItemHasNoContents);
         scrollingWidget->installEventFilter(q);
@@ -124,6 +124,9 @@ public:
         adjustScrollbarsTimer->setSingleShot(true);
         QObject::connect(adjustScrollbarsTimer, SIGNAL(timeout()), q, SLOT(adjustScrollbars()));
 
+        wheelTimer =  new QTimer(q);
+        wheelTimer->setSingleShot(true);
+
         verticalScrollBarPolicy = Qt::ScrollBarAsNeeded;
         verticalScrollBar = new Plasma::ScrollBar(q);
         verticalScrollBar->setFocusPolicy(Qt::NoFocus);
@@ -141,6 +144,11 @@ public:
         horizontalScrollBar->nativeWidget()->setMaximum(100);
         QObject::connect(horizontalScrollBar, SIGNAL(valueChanged(int)), q, SLOT(horizontalScroll(int)));
 
+        layout->setColumnSpacing(0, 0);
+        layout->setColumnSpacing(1, 0);
+        layout->setRowSpacing(0, 0);
+        layout->setRowSpacing(1, 0);
+
         flickAnimationX = 0;
         flickAnimationY = 0;
         fixupAnimation.groupX = 0;
@@ -169,11 +177,14 @@ public:
             return;
         }
 
+        const bool verticalVisible = widget.data()->size().height() > q->size().height();
+        const bool horizontalVisible = widget.data()->size().width() > q->size().width();
+
         verticalScrollBar->nativeWidget()->setMaximum(qMax(0, int((widget.data()->size().height() - scrollingWidget->size().height())/10)));
         verticalScrollBar->nativeWidget()->setPageStep(int(scrollingWidget->size().height())/10);
 
         if (verticalScrollBarPolicy == Qt::ScrollBarAlwaysOff ||
-            verticalScrollBar->nativeWidget()->maximum() == 0) {
+            !verticalVisible) {
             if (layout->count() > 2 && layout->itemAt(2) == verticalScrollBar) {
                 layout->removeAt(2);
             } else if (layout->count() > 1 && layout->itemAt(1) == verticalScrollBar) {
@@ -189,7 +200,7 @@ public:
         horizontalScrollBar->nativeWidget()->setPageStep(int(scrollingWidget->size().width())/10);
 
         if (horizontalScrollBarPolicy == Qt::ScrollBarAlwaysOff ||
-            horizontalScrollBar->nativeWidget()->maximum() == 0) {
+            !horizontalVisible) {
             if (layout->count() > 2 && layout->itemAt(2) == horizontalScrollBar) {
                 layout->removeAt(2);
             } else if (layout->count() > 1 && layout->itemAt(1) == horizontalScrollBar) {
@@ -201,20 +212,21 @@ public:
             horizontalScrollBar->show();
         }
 
-         if (widget && !topBorder && widget.data()->size().height() > q->size().height()) {
+         if (widget && !topBorder && verticalVisible) {
             topBorder = new Plasma::SvgWidget(q);
             topBorder->setSvg(borderSvg);
             topBorder->setElementID("border-top");
             topBorder->setZValue(900);
             topBorder->resize(topBorder->effectiveSizeHint(Qt::PreferredSize));
-            topBorder->show();
+            topBorder->setVisible(overflowBordersVisible);
+
             bottomBorder = new Plasma::SvgWidget(q);
             bottomBorder->setSvg(borderSvg);
             bottomBorder->setElementID("border-bottom");
             bottomBorder->setZValue(900);
             bottomBorder->resize(bottomBorder->effectiveSizeHint(Qt::PreferredSize));
-            bottomBorder->show();
-        } else if (topBorder && widget && widget.data()->size().height() <= q->size().height()) {
+            bottomBorder->setVisible(overflowBordersVisible);
+        } else if (topBorder && widget && !verticalVisible) {
             //FIXME: in some cases topBorder->deleteLater() is deleteNever(), why?
             topBorder->hide();
             bottomBorder->hide();
@@ -225,20 +237,21 @@ public:
         }
 
 
-        if (widget && !leftBorder && widget.data()->size().width() > q->size().width()) {
+        if (widget && !leftBorder && horizontalVisible) {
             leftBorder = new Plasma::SvgWidget(q);
             leftBorder->setSvg(borderSvg);
             leftBorder->setElementID("border-left");
             leftBorder->setZValue(900);
             leftBorder->resize(leftBorder->effectiveSizeHint(Qt::PreferredSize));
-            leftBorder->show();
+            leftBorder->setVisible(overflowBordersVisible);
+
             rightBorder = new Plasma::SvgWidget(q);
             rightBorder->setSvg(borderSvg);
             rightBorder->setElementID("border-right");
             rightBorder->setZValue(900);
             rightBorder->resize(rightBorder->effectiveSizeHint(Qt::PreferredSize));
-            rightBorder->show();
-        } else if (leftBorder && widget && widget.data()->size().width() <= q->size().width()) {
+            rightBorder->setVisible(overflowBordersVisible);
+        } else if (leftBorder && widget && !horizontalVisible) {
             leftBorder->hide();
             rightBorder->hide();
             leftBorder->deleteLater();
@@ -263,10 +276,10 @@ public:
         QSizeF widgetSize = widget.data()->size();
         if (widget.data()->sizePolicy().expandingDirections() & Qt::Horizontal) {
             //keep a 1 pixel border
-            widgetSize.setWidth(scrollingWidget->size().width()-borderSize);
+            widgetSize.setWidth(scrollingWidget->size().width());
         }
         if (widget.data()->sizePolicy().expandingDirections() & Qt::Vertical) {
-            widgetSize.setHeight(scrollingWidget->size().height()-borderSize);
+            widgetSize.setHeight(scrollingWidget->size().height());
         }
         widget.data()->resize(widgetSize);
 
@@ -373,7 +386,7 @@ public:
             qreal duration = qAbs(v / deceleration);
             qreal diffY = v * duration + (0.5  * deceleration * duration * duration);
             qreal startY = val;
- 
+
             qreal endY = startY + diffY;
 
             if (velocity > 0) {
@@ -585,8 +598,10 @@ public:
 
     void handleKeyPressEvent(QKeyEvent *event)
     {
-        if (!widget.data())
+        if (!widget.data()) {
+            event->ignore();
             return;
+        }
 
         QPointF start = q->scrollPosition();
         QPointF end = start;
@@ -594,28 +609,34 @@ public:
         qreal step = 100;
 
         switch (event->key()) {
-        case Qt::Key_Left:
-            if (canXFlick()) {
-                end += QPointF(-step, 0);
+            case Qt::Key_Left: {
+                if (canXFlick()) {
+                    end += QPointF(-step, 0);
+                }
+                break;
             }
-            break;
-        case Qt::Key_Right:
-            if (canXFlick()) {
-                end += QPointF(step, 0);
+            case Qt::Key_Right: {
+                if (canXFlick()) {
+                    end += QPointF(step, 0);
+                }
+                break;
             }
-            break;
-        case Qt::Key_Up:
-            if (canYFlick()) {
-                end += QPointF(0, -step);
+            case Qt::Key_Up: {
+                if (canYFlick()) {
+                    end += QPointF(0, -step);
+                }
+                break;
             }
-            break;
-        case Qt::Key_Down:
-            if (canYFlick()) {
-                end += QPointF(0, step);
+            case Qt::Key_Down: {
+                if (canYFlick()) {
+                    end += QPointF(0, step);
+                }
+                break;
+            }
+            default: {
+                event->ignore();
+                return;
             }
-            break;
-        default:
-            break;
         }
 
         fixupAnimation.groupX->stop();
@@ -645,7 +666,6 @@ public:
             return;
         bool rejectY = false;
         bool rejectX = false;
-        bool moved = false;
 
         if (canYFlick()) {
             int dy = int(event->scenePos().y() - pressPos.y());
@@ -667,7 +687,6 @@ public:
                 }
                 if (!rejectY && stealEvent) {
                     setWidgetY(qRound(newY));
-                    moved = true;
                 }
                 if (qAbs(dy) > KGlobalSettings::dndEventDelay())
                     stealEvent = true;
@@ -694,7 +713,6 @@ public:
                 }
                 if (!rejectX && stealEvent) {
                     setWidgetX(qRound(newX));
-                    moved = true;
                 }
 
                 if (qAbs(dx) > KGlobalSettings::dndEventDelay())
@@ -772,8 +790,10 @@ public:
 
     void handleWheelEvent(QGraphicsSceneWheelEvent *event)
     {
-        if (!widget.data())
+        //only scroll when the animation is done, this avoids to receive too many events and getting mad when they arrive from a touchpad
+        if (!widget.data() || wheelTimer->isActive()) {
             return;
+        }
 
         QPointF start = q->scrollPosition();
         QPointF end = start;
@@ -816,6 +836,7 @@ public:
         directMoveAnimation->setEndValue(end);
         directMoveAnimation->setDuration(200);
         directMoveAnimation->start();
+        wheelTimer->start(50);
     }
 
     qreal minXExtent() const
@@ -869,12 +890,12 @@ public:
     bool canXFlick() const
     {
         //make the thing feel quite "fixed" don't permit to flick when the contents size is less than the viewport
-        return q->contentsSize().width() + borderSize > q->viewportGeometry().width();
+        return q->contentsSize().width() > q->viewportGeometry().width();
     }
 
     bool canYFlick() const
     {
-        return q->contentsSize().height() + borderSize > q->viewportGeometry().height();
+        return q->contentsSize().height() > q->viewportGeometry().height();
     }
 
     int elapsed(const QTime &t) const
@@ -1040,7 +1061,7 @@ public:
     QPointF dragHandleClicked;
     bool dragging;
     QTimer *adjustScrollbarsTimer;
-    static const int borderSize = 4;
+    QTimer *wheelTimer;
 
     QPointF pressPos;
     QPointF pressScrollPos;
@@ -1066,11 +1087,10 @@ public:
     QSizeF snapSize;
     bool stealEvent;
     bool hasOvershoot;
+    bool overflowBordersVisible;
 
     Qt::Alignment alignment;
 
-    Gesture multitouchGesture;
-
     bool hasContentsProperty;
     bool hasOffsetProperty;
     bool hasXProperty;
@@ -1152,6 +1172,21 @@ Qt::ScrollBarPolicy ScrollWidget::verticalScrollBarPolicy() const
     return d->verticalScrollBarPolicy;
 }
 
+bool ScrollWidget::overflowBordersVisible() const
+{
+    return d->overflowBordersVisible;
+}
+
+void ScrollWidget::setOverflowBordersVisible(const bool visible)
+{
+    if (d->overflowBordersVisible == visible) {
+        return;
+    }
+
+    d->overflowBordersVisible = visible;
+    d->adjustScrollbars();
+}
+
 void ScrollWidget::ensureRectVisible(const QRectF &rect)
 {
     if (!d->widget) {
@@ -1189,17 +1224,7 @@ void ScrollWidget::ensureItemVisible(QGraphicsItem *item)
     }
 }
 
-void ScrollWidget::registerAsDragHandle(QGraphicsWidget *item)
-{
-    Q_UNUSED(item);
-    return;
-}
 
-void ScrollWidget::unregisterAsDragHandle(QGraphicsWidget *item)
-{
-    Q_UNUSED(item);
-    return;
-}
 
 QRectF ScrollWidget::viewportGeometry() const
 {
@@ -1328,6 +1353,9 @@ void ScrollWidget::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
     if (!d->widget) {
         return;
+    } else if (!d->canYFlick() && !d->canXFlick()) {
+        event->ignore();
+        return;
     }
 
     d->handleMousePressEvent(event);
@@ -1353,6 +1381,9 @@ void ScrollWidget::wheelEvent(QGraphicsSceneWheelEvent *event)
 {
     if (!d->widget) {
         return;
+    } else if (!d->canYFlick() && !d->canXFlick()) {
+        event->ignore();
+        return;
     }
     d->handleWheelEvent(event);
     event->accept();
@@ -1371,7 +1402,23 @@ bool ScrollWidget::eventFilter(QObject *watched, QEvent *event)
         d->stopAnimations();
         d->adjustScrollbarsTimer->start(200);
         updateGeometry();
-        ensureItemVisible(d->widget.data());
+
+        QPointF newPos = d->widget.data()->pos();
+        if (d->widget.data()->size().width() <= viewportGeometry().width()) {
+            newPos.setX(d->minXExtent());
+        }
+        if (d->widget.data()->size().height() <= viewportGeometry().height()) {
+            newPos.setY(d->minYExtent());
+        }
+        //check if the content is visible
+        if (d->widget.data()->geometry().right() < 0) {
+            newPos.setX(-d->widget.data()->geometry().width()+viewportGeometry().width());
+        }
+        if (d->widget.data()->geometry().bottom() < 0) {
+            newPos.setY(-d->widget.data()->geometry().height()+viewportGeometry().height());
+        }
+        d->widget.data()->setPos(newPos);
+
     } else if (watched == d->widget.data() && event->type() == QEvent::GraphicsSceneMove) {
         d->horizontalScrollBar->blockSignals(true);
         d->verticalScrollBar->blockSignals(true);
@@ -1393,7 +1440,7 @@ QSizeF ScrollWidget::sizeHint(Qt::SizeHint which, const QSizeF & constraint) con
         return QSizeF(KIconLoader::SizeEnormous, KIconLoader::SizeEnormous);
     }
 
-    QSizeF hint = d->widget.data()->effectiveSizeHint(which, constraint)+QSize(d->borderSize*2, d->borderSize*2);
+    QSizeF hint = d->widget.data()->effectiveSizeHint(which, constraint);
     if (d->horizontalScrollBar && d->horizontalScrollBar->isVisible()) {
         hint += QSize(0, d->horizontalScrollBar->size().height());
     }
@@ -1414,6 +1461,23 @@ bool ScrollWidget::sceneEventFilter(QGraphicsItem *i, QEvent *e)
         return false;
     }
 
+    if (i->isWidget()) {
+        Plasma::Label *label = dynamic_cast<Plasma::Label *>(static_cast<QGraphicsWidget *>(i));
+        if (label && (label->nativeWidget()->textInteractionFlags() & Qt::TextSelectableByMouse)) {
+            return false;
+        }
+
+        Plasma::TextEdit *textEdit = dynamic_cast<Plasma::TextEdit *>(static_cast<QGraphicsWidget *>(i));
+        if (textEdit && (textEdit->nativeWidget()->textInteractionFlags() & Qt::TextSelectableByMouse)) {
+            return false;
+        }
+
+        Plasma::TextBrowser *textBrowser= dynamic_cast<Plasma::TextBrowser *>(static_cast<QGraphicsWidget *>(i));
+        if (textBrowser && (textBrowser->nativeWidget()->textInteractionFlags() & Qt::TextSelectableByMouse)) {
+            return false;
+        }
+    }
+
     bool stealThisEvent = d->stealEvent;
     //still pass around mouse moves: try to make still possible to make items start a drag event. thi could be either necessary or annoying, let's see how it goes. (add QEvent::GraphicsSceneMouseMove to block them)
     stealThisEvent &= (e->type() == QEvent::GraphicsSceneMousePress ||
@@ -1423,70 +1487,21 @@ bool ScrollWidget::sceneEventFilter(QGraphicsItem *i, QEvent *e)
             <<QTime::currentTime().toString(QString::fromLatin1("hh:mm:ss.zzz"));
 #endif
     switch (e->type()) {
-    case QEvent::GraphicsSceneMousePress:
-        d->handleMousePressEvent(static_cast<QGraphicsSceneMouseEvent*>(e));
-        break;
-    case QEvent::GraphicsSceneMouseMove:
-        d->handleMouseMoveEvent(static_cast<QGraphicsSceneMouseEvent*>(e));
-        break;
-    case QEvent::GraphicsSceneMouseRelease:
-        d->handleMouseReleaseEvent(static_cast<QGraphicsSceneMouseEvent*>(e));
-        break;
-    case QEvent::GraphicsSceneWheel:
-        d->handleWheelEvent(static_cast<QGraphicsSceneWheelEvent*>(e));
-    //Multitouch related events
-    case QEvent::TouchBegin:
-        d->handleMousePressEvent(static_cast<QGraphicsSceneMouseEvent*>(e));
-        break;
-    case QEvent::TouchUpdate: {
-        QList<QTouchEvent::TouchPoint> touchPoints = static_cast<QTouchEvent *>(e)->touchPoints();
-        if (touchPoints.count() == 2) {
-            const QTouchEvent::TouchPoint &touchPoint0 = touchPoints.first();
-            const QTouchEvent::TouchPoint &touchPoint1 = touchPoints.last();
-            const QLineF line0(touchPoint0.lastPos(), touchPoint1.lastPos());
-            const QLineF line1(touchPoint0.pos(), touchPoint1.pos());
-            const QLineF startLine(touchPoint0.startPos(), touchPoint1.startPos());
-            const QPointF point = line1.pointAt(0.5);
-            const QPointF lastPoint = line0.pointAt(0.5);
-
-            if (d->multitouchGesture == ScrollWidgetPrivate::GestureNone) {
-                d->multitouchGesture = ScrollWidgetPrivate::GestureUndefined;
-            }
-            if (d->multitouchGesture == ScrollWidgetPrivate::GestureUndefined) {
-                const int zoomDistance = qAbs(line1.length() - startLine.length());
-                const int dragDistance = (startLine.pointAt(0.5) - point).manhattanLength();
-
-                if (zoomDistance - dragDistance > 30) {
-                    d->multitouchGesture = ScrollWidgetPrivate::GestureZoom;
-                } else if (dragDistance - zoomDistance > 30) {
-                    d->multitouchGesture = ScrollWidgetPrivate::GestureScroll;
-                }
-            }
-
-            if (d->multitouchGesture ==  ScrollWidgetPrivate::GestureScroll) {
-                QGraphicsSceneMouseEvent fakeEvent;
-                fakeEvent.setPos(point);
-                fakeEvent.setLastPos(lastPoint);
-                d->handleMouseMoveEvent(&fakeEvent);
-            } else if (d->multitouchGesture == ScrollWidgetPrivate::GestureZoom) {
-                if (d->widget && d->widget.data()->property("zoomFactor").isValid()) {
-                    qreal scaleFactor = 1;
-                    if (line0.length() > 0) {
-                        scaleFactor = line1.length() / line0.length();
-                    }
-
-                    qreal zoom = d->widget.data()->property("zoomFactor").toReal();
-                    d->widget.data()->setProperty("zoomFactor", zoom * scaleFactor);
-                }
-            }
+        case QEvent::GraphicsSceneMousePress: {
+            d->handleMousePressEvent(static_cast<QGraphicsSceneMouseEvent*>(e));
+            break;
+        }
+        case QEvent::GraphicsSceneMouseMove: {
+            d->handleMouseMoveEvent(static_cast<QGraphicsSceneMouseEvent*>(e));
+            break;
+        }
+        case QEvent::GraphicsSceneMouseRelease: {
+            d->handleMouseReleaseEvent(static_cast<QGraphicsSceneMouseEvent*>(e));
+            break;
+        }
+        default: {
+            break;
         }
-        break;
-    }
-    case QEvent::TouchEnd:
-        d->handleMouseReleaseEvent(static_cast<QGraphicsSceneMouseEvent*>(e));
-        break;
-    default:
-        break;
     }
     if (stealThisEvent)
         return true;
@@ -1521,5 +1536,5 @@ bool ScrollWidget::hasOverShoot() const
 } // namespace Plasma
 
 
-#include <scrollwidget.moc>
+#include "moc_scrollwidget.cpp"
 
