@@ -32,6 +32,7 @@
 #include <QtGui/QPixmap>
 #include <QtGui/QPainterPath>
 #include <QtGui/QPolygon>
+#include <QtGui/QPen>
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -682,7 +683,7 @@ void SignalPlotter::drawWidget(QPainter *p, uint w, uint height, int horizontalS
         drawTopBarContents(p, separatorX, topBarWidth, top -1);
     }
 
-    p->setClipRect(0, top, w, h);
+    p->setClipRect(0, top, w, h, Qt::IntersectClip);
     // Draw scope-like grid vertical lines
     if (d->verticalLinesScroll && d->showVerticalLines && w > 60) {
         drawVerticalLines(p, top, w, h);
@@ -1104,5 +1105,5 @@ QString SignalPlotter::lastValueAsString(uint i) const
 
 } // Plasma namespace
 
-#include "signalplotter.moc"
+#include "moc_signalplotter.cpp"
 
