@@ -20,60 +20,40 @@
 
 #include "spinbox.h"
 
-#include <QApplication>
 #include <QPainter>
-#include <QStyleOptionSpinBox>
+#include <QtGui/qstyleoption.h>
+#include <QGraphicsView>
 
-#include <knuminput.h>
 #include <kmimetype.h>
+#include <knuminput.h>
 
-#include <plasma/applet.h>
-#include <plasma/theme.h>
-#include <plasma/framesvg.h>
-#include <plasma/private/style_p.h>
-#include <plasma/private/focusindicator_p.h>
+#include "applet.h"
+#include "framesvg.h"
+#include "private/focusindicator_p.h"
+#include "private/style_p.h"
+#include "private/themedwidgetinterface_p.h"
+#include "theme.h"
 
 namespace Plasma
 {
 
-class SpinBoxPrivate
+class SpinBoxPrivate : public ThemedWidgetInterface<SpinBox>
 {
 public:
     SpinBoxPrivate(SpinBox *spinBox)
-        : q(spinBox),
-          focusIndicator(0),
-          customFont(false)
+        : ThemedWidgetInterface<SpinBox>(spinBox),
+          focusIndicator(0)
     {
+        buttonColorForText = true;
     }
 
     ~SpinBoxPrivate()
     {
     }
 
-    void setPalette()
-    {
-        QSpinBox *native = q->nativeWidget();
-        QColor color = Theme::defaultTheme()->color(Theme::ButtonTextColor);
-        QPalette p = native->palette();
-
-        p.setColor(QPalette::Normal, QPalette::Text, color);
-        p.setColor(QPalette::Inactive, QPalette::Text, color);
-        p.setColor(QPalette::Normal, QPalette::ButtonText, color);
-        p.setColor(QPalette::Inactive, QPalette::ButtonText, color);
-        p.setColor(QPalette::Normal, QPalette::Base, QColor(0,0,0,0));
-        p.setColor(QPalette::Inactive, QPalette::Base, QColor(0,0,0,0));
-        native->setPalette(p);
-
-        if (!customFont) {
-            q->nativeWidget()->setFont(Plasma::Theme::defaultTheme()->font(Plasma::Theme::DefaultFont));
-        }
-    }
-
-    SpinBox *q;
     Plasma::Style::Ptr style;
     Plasma::FrameSvg *background;
     FocusIndicator *focusIndicator;
-    bool customFont;
 };
 
 SpinBox::SpinBox(QGraphicsWidget *parent)
@@ -87,7 +67,7 @@ SpinBox::SpinBox(QGraphicsWidget *parent)
 
     d->focusIndicator = new FocusIndicator(this, "widgets/lineedit");
 
-    setWidget(native);
+    d->setWidget(native);
     native->setWindowIcon(QIcon());
     native->setAttribute(Qt::WA_NoSystemBackground);
     native->setAutoFillBackground(false);
@@ -96,11 +76,18 @@ SpinBox::SpinBox(QGraphicsWidget *parent)
     d->background->setImagePath("widgets/lineedit");
     d->background->setCacheAllRenderedFrames(true);
 
+    if (d->background->hasElement("hint-focus-over-base")) {
+        d->focusIndicator->setFlag(QGraphicsItem::ItemStacksBehindParent, false);
+    }
 
     d->style = Plasma::Style::sharedStyle();
     native->setStyle(d->style.data());
-    d->setPalette();
-    connect(Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(setPalette()));
+    d->initTheming();
+
+    QStyleOptionSpinBox spinOpt;
+    spinOpt.initFrom(nativeWidget());
+    QRect controlrect = nativeWidget()->style()->subControlRect(QStyle::CC_SpinBox, &spinOpt, QStyle::SC_SpinBoxFrame, nativeWidget());
+    d->focusIndicator->setCustomGeometry(controlrect);
 }
 
 SpinBox::~SpinBox()
@@ -161,11 +148,7 @@ KIntSpinBox *SpinBox::nativeWidget() const
 
 void SpinBox::changeEvent(QEvent *event)
 {
-    if (event->type() == QEvent::FontChange) {
-        d->customFont = true;
-        nativeWidget()->setFont(font());
-    }
-
+    d->changeEvent(event);
     QGraphicsProxyWidget::changeEvent(event);
 }
 
@@ -187,6 +170,7 @@ void SpinBox::resizeEvent(QGraphicsSceneResizeEvent *event)
     QStyleOptionSpinBox spinOpt;
     spinOpt.initFrom(nativeWidget());
     QRect controlrect = nativeWidget()->style()->subControlRect(QStyle::CC_SpinBox, &spinOpt, QStyle::SC_SpinBoxFrame, nativeWidget());
+
     if (d->focusIndicator) {
         d->focusIndicator->setCustomGeometry(controlrect);
     }
@@ -229,10 +213,20 @@ void SpinBox::focusOutEvent(QFocusEvent *event)
     if (applet) {
         applet->setStatus(Plasma::UnknownStatus);
     }
+
+    QEvent closeEvent(QEvent::CloseSoftwareInputPanel);
+    if (qApp) {
+        if (QGraphicsView *view = qobject_cast<QGraphicsView*>(qApp->focusWidget())) {
+            if (view->scene() && view->scene() == scene()) {
+                QApplication::sendEvent(view, &closeEvent);
+            }
+        }
+    }
+
     QGraphicsProxyWidget::focusOutEvent(event);
 }
 
 } // namespace Plasma
 
-#include <spinbox.moc>
+#include "moc_spinbox.cpp"
 
