@@ -20,7 +20,7 @@
 #include "svgwidget.h"
 
 #include <QtGui/QPainter>
-#include <QtGui/QGraphicsSceneMouseEvent>
+#include <QtGui/qgraphicssceneevent.h>
 
 #include "kdebug.h"
 #include "svg.h"
@@ -139,4 +139,4 @@ QSizeF SvgWidget::sizeHint(Qt::SizeHint which, const QSizeF & constraint) const
 
 } // Plasma namespace
 
-#include "svgwidget.moc"
+#include "moc_svgwidget.cpp"
