@@ -21,22 +21,23 @@
 
 #include <QGraphicsLinearLayout>
 #include <QGraphicsLayoutItem>
-#include <QString>
-#include <QGraphicsScene>
 #include <QGraphicsProxyWidget>
-#include <QGraphicsSceneWheelEvent>
+#include <QGraphicsScene>
+#include <QtGui/qgraphicssceneevent.h>
 #include <QIcon>
-#include <QStyleOption>
+#include <QMenu>
 #include <QPainter>
 #include <QParallelAnimationGroup>
+#include <QString>
+#include <QStyleOption>
 
 #include <kdebug.h>
 
-#include <plasma/animator.h>
-#include <plasma/animations/animation.h>
-#include <plasma/theme.h>
-
+#include "animator.h"
+#include "animations/animation.h"
 #include "private/nativetabbar_p.h"
+#include "private/themedwidgetinterface_p.h"
+#include "theme.h"
 
 namespace Plasma
 {
@@ -67,17 +68,17 @@ public:
     NativeTabBar *native;
 };
 
-class TabBarPrivate
+class TabBarPrivate : public ThemedWidgetInterface<TabBar>
 {
 public:
     TabBarPrivate(TabBar *parent)
-        : q(parent),
+        : ThemedWidgetInterface<TabBar>(parent),
           tabProxy(0),
           currentIndex(0),
           tabWidgetMode(true),
           oldPageAnimId(-1),
           newPageAnimId(-1),
-          customFont(false)
+          tabBarShown(true)
     {
     }
 
@@ -90,11 +91,10 @@ public:
     void slidingNewPageCompleted();
     void slidingOldPageCompleted();
     void shapeChanged(const KTabBar::Shape shape);
-    void setPalette();
 
-    TabBar *q;
     TabBarProxy *tabProxy;
     QList<QGraphicsWidget *> pages;
+    QGraphicsWidget *emptyTabBarSpacer;
     QGraphicsLinearLayout *mainLayout;
     QGraphicsLinearLayout *tabWidgetLayout;
     QGraphicsLinearLayout *tabBarLayout;
@@ -108,11 +108,17 @@ public:
     Animation *oldPageAnim;
     Animation *newPageAnim;
     QParallelAnimationGroup *animGroup;
-    bool customFont;
+    bool tabBarShown;
+    QWeakPointer<QGraphicsWidget> firstPositionWidget;
+    QWeakPointer<QGraphicsWidget> lastPositionWidget;
 };
 
 void TabBarPrivate::updateTabWidgetMode()
 {
+    if (!tabBarShown) {
+        return;
+    }
+
     bool tabWidget = false;
 
     foreach (QGraphicsWidget *page, pages) {
@@ -179,59 +185,39 @@ void TabBarPrivate::shapeChanged(const QTabBar::Shape shape)
     //FIXME: QGraphicsLinearLayout doesn't have setDirection, so for now
     // North is equal to south and East is equal to West
     switch (shape) {
-    case QTabBar::RoundedWest:
-    case QTabBar::TriangularWest:
-
-    case QTabBar::RoundedEast:
-    case QTabBar::TriangularEast:
-        q->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
-        tabBarLayout->setOrientation(Qt::Vertical);
-        tabWidgetLayout->setOrientation(Qt::Horizontal);
-        tabWidgetLayout->itemAt(0)->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
-        if (tabWidgetLayout->count() > 1) {
-            tabWidgetLayout->itemAt(1)->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+        case QTabBar::RoundedWest:
+        case QTabBar::TriangularWest:
+        case QTabBar::RoundedEast:
+        case QTabBar::TriangularEast: {
+            q->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
+            tabBarLayout->setOrientation(Qt::Vertical);
+            tabWidgetLayout->setOrientation(Qt::Horizontal);
+            tabWidgetLayout->itemAt(0)->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
+            if (tabWidgetLayout->count() > 1) {
+                tabWidgetLayout->itemAt(1)->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+            }
+            tabProxy->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
+            break;
         }
-        tabProxy->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
-        break;
-
-    case QTabBar::RoundedSouth:
-    case QTabBar::TriangularSouth:
-
-    case QTabBar::RoundedNorth:
-    case QTabBar::TriangularNorth:
-    default:
-        q->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
-        tabBarLayout->setOrientation(Qt::Horizontal);
-        tabWidgetLayout->setOrientation(Qt::Vertical);
-        tabWidgetLayout->itemAt(0)->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
-        if (tabWidgetLayout->count() > 1) {
-            tabWidgetLayout->itemAt(1)->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+        case QTabBar::RoundedSouth:
+        case QTabBar::TriangularSouth:
+        case QTabBar::RoundedNorth:
+        case QTabBar::TriangularNorth:
+        default: {
+            q->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+            tabBarLayout->setOrientation(Qt::Horizontal);
+            tabWidgetLayout->setOrientation(Qt::Vertical);
+            tabWidgetLayout->itemAt(0)->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
+            if (tabWidgetLayout->count() > 1) {
+                tabWidgetLayout->itemAt(1)->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+            }
+            tabProxy->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
+            break;
         }
-        tabProxy->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     }
     tabProxy->setPreferredSize(tabProxy->native->sizeHint());
 }
 
-void TabBarPrivate::setPalette()
-{
-    QTabBar *native = q->nativeWidget();
-    QColor color = Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
-    QPalette p = native->palette();
-
-    p.setColor(QPalette::Normal, QPalette::Text, color);
-    p.setColor(QPalette::Inactive, QPalette::Text, color);
-    p.setColor(QPalette::Normal, QPalette::ButtonText, color);
-    p.setColor(QPalette::Inactive, QPalette::ButtonText, color);
-    p.setColor(QPalette::Normal, QPalette::Base, QColor(0,0,0,0));
-    p.setColor(QPalette::Inactive, QPalette::Base, QColor(0,0,0,0));
-    native->setPalette(p);
-
-    if (!customFont) {
-        q->nativeWidget()->setFont(Plasma::Theme::defaultTheme()->font(Plasma::Theme::DefaultFont));
-    }
-}
-
-
 TabBar::TabBar(QGraphicsWidget *parent)
     : QGraphicsWidget(parent),
       d(new TabBarPrivate(this))
@@ -249,7 +235,12 @@ TabBar::TabBar(QGraphicsWidget *parent)
     setLayout(d->mainLayout);
     d->mainLayout->setContentsMargins(0,0,0,0);
 
+    //simulate a page until there isn't one
+    //needed to make the widget resize well when there are no tab added
+    d->emptyTabBarSpacer = new QGraphicsWidget(this);
+
     d->tabWidgetLayout->addItem(d->tabBarLayout);
+    d->tabWidgetLayout->addItem(d->emptyTabBarSpacer);
 
     //tabBar is centered, so a stretch at begin one at the end
     d->tabBarLayout->addStretch();
@@ -272,8 +263,7 @@ TabBar::TabBar(QGraphicsWidget *parent)
             this, SLOT(shapeChanged(QTabBar::Shape)));
     connect(d->newPageAnim, SIGNAL(finished()), this, SLOT(slidingNewPageCompleted()));
     connect(d->oldPageAnim, SIGNAL(finished()), this, SLOT(slidingOldPageCompleted()));
-    connect(Theme::defaultTheme(), SIGNAL(themeChanged()),
-            this, SLOT(setPalette()));
+    d->initTheming();
 }
 
 TabBar::~TabBar()
@@ -305,6 +295,7 @@ int TabBar::insertTab(int index, const QIcon &icon, const QString &label,
     d->pages.insert(qBound(0, index, d->pages.count()), page);
 
     if (d->pages.count() == 1) {
+        d->tabWidgetLayout->removeItem(d->emptyTabBarSpacer);
         d->tabWidgetLayout->addItem(page);
         page->setVisible(true);
         page->setEnabled(true);
@@ -468,8 +459,9 @@ void TabBar::removeTab(int index)
 
     if (d->pages.count() > 0) {
         d->updateTabWidgetMode();
+    } else {
+        d->tabWidgetLayout->addItem(d->emptyTabBarSpacer);
     }
-    d->tabProxy->setPreferredSize(d->tabProxy->native->sizeHint());
 }
 
 QGraphicsLayoutItem *TabBar::takeTab(int index)
@@ -569,11 +561,15 @@ void TabBar::setTabBarShown(bool show)
     if (!show && !d->tabWidgetMode) {
         return;
     }
+    if (d->tabBarShown == show) {
+        return;
+    }
+    d->tabBarShown = show;
 
-    if (!show && d->tabProxy->isVisible()) {
+    if (!show) {
         d->tabProxy->hide();
         d->tabWidgetLayout->removeItem(d->tabBarLayout);
-    } else if (show && !d->tabProxy->isVisible()) {
+    } else {
         d->tabProxy->show();
         d->tabWidgetLayout->insertItem(0, d->tabBarLayout);
     }
@@ -581,7 +577,7 @@ void TabBar::setTabBarShown(bool show)
 
 bool TabBar::isTabBarShown() const
 {
-    return d->tabProxy->isVisible();
+    return d->tabBarShown;
 }
 
 void TabBar::setStyleSheet(const QString &stylesheet)
@@ -594,28 +590,87 @@ QString TabBar::styleSheet() const
     return d->tabProxy->native->styleSheet();
 }
 
+void TabBar::setTabHighlighted(int index, bool highlight)
+{
+    d->tabProxy->native->setTabHighlighted(index, highlight);
+}
+
+bool TabBar::isTabHighlighted(int index) const
+{
+    return d->tabProxy->native->isTabHighlighted(index);
+}
+
 KTabBar *TabBar::nativeWidget() const
 {
     return d->tabProxy->native;
 }
 
-void TabBar::wheelEvent(QGraphicsSceneWheelEvent * event)
-{
-    Q_UNUSED(event)
-    //Still here for binary compatibility
-}
-
 void TabBar::changeEvent(QEvent *event)
 {
-    if (event->type() == QEvent::FontChange) {
-        d->customFont = true;
-        nativeWidget()->setFont(font());
+    d->changeEvent(event);
+    QGraphicsWidget::changeEvent(event);
+}
+
+void TabBar::setFirstPositionWidget(QGraphicsWidget *widget)
+{
+    if (d->lastPositionWidget.data() == widget) {
+        return;
     }
 
-    QGraphicsWidget::changeEvent(event);
+    if (d->firstPositionWidget) {
+        QGraphicsWidget *widget = d->firstPositionWidget.data();
+        d->tabBarLayout->removeItem(widget);
+        scene()->removeItem(widget);
+        widget->deleteLater();
+    }
+
+    d->firstPositionWidget = widget;
+    if (widget) {
+        widget->setParentItem(this);
+        if (layoutDirection() == Qt::LeftToRight) {
+            d->tabBarLayout->insertItem(0, widget);
+        } else {
+            d->tabBarLayout->addItem(widget);
+        }
+    }
+}
+
+
+QGraphicsWidget *TabBar::firstPositionWidget() const
+{
+    return d->firstPositionWidget.data();
+}
+
+void TabBar::setLastPositionWidget(QGraphicsWidget *widget)
+{
+    if (d->lastPositionWidget.data() == widget) {
+        return;
+    }
+
+    if (d->lastPositionWidget) {
+        QGraphicsWidget *widget = d->lastPositionWidget.data();
+        d->tabBarLayout->removeItem(widget);
+        scene()->removeItem(widget);
+        widget->deleteLater();
+    }
+
+    d->lastPositionWidget = widget;
+    if (widget) {
+        widget->setParentItem(this);
+        if (layoutDirection() == Qt::LeftToRight) {
+            d->tabBarLayout->addItem(widget);
+        } else {
+            d->tabBarLayout->insertItem(0, widget);
+        }
+    }
+}
+
+QGraphicsWidget *TabBar::lastPositionWidget() const
+{
+    return d->lastPositionWidget.data();
 }
 
 } // namespace Plasma
 
-#include <tabbar.moc>
+#include "moc_tabbar.cpp"
 
