@@ -26,8 +26,8 @@
 
 #include <plasma/plasma_export.h>
 
-class QString;
-class QIcon;
+#include <QString>
+#include <QIcon>
 
 namespace Plasma
 {
@@ -48,16 +48,18 @@ class PLASMA_EXPORT TabBar : public QGraphicsWidget
     Q_OBJECT
 
     Q_PROPERTY(KTabBar *nativeWidget READ nativeWidget)
-    Q_PROPERTY(int currentIndex READ currentIndex WRITE setCurrentIndex)
+    Q_PROPERTY(int currentIndex READ currentIndex WRITE setCurrentIndex NOTIFY currentChanged)
     Q_PROPERTY(int count READ count)
     Q_PROPERTY(QString styleSheet READ styleSheet WRITE setStyleSheet)
     Q_PROPERTY(bool tabBarShown READ isTabBarShown WRITE setTabBarShown)
+    Q_PROPERTY(QGraphicsWidget *firstPositionWidget READ firstPositionWidget WRITE setFirstPositionWidget)
+    Q_PROPERTY(QGraphicsWidget *lastPositionWidget READ lastPositionWidget WRITE setLastPositionWidget)
 
 public:
     /**
      * Constructs a new TabBar
      *
-     * @arg parent the parent of this widget
+     * @param parent the parent of this widget
      */
     explicit TabBar(QGraphicsWidget *parent = 0);
     ~TabBar();
@@ -65,12 +67,12 @@ public:
     /**
      * Adds a new tab in the desired position
      *
-     * @arg index the position where to insert the new tab,
+     * @param index the position where to insert the new tab,
      *            if index <=0 will be the first position,
      *            if index >= count() will be the last
-     * @arg icon  the icon for this tab
-     * @arg label the text label of the tab
-     * @arg content the page content that will be shown by this tab
+     * @param icon  the icon for this tab
+     * @param label the text label of the tab
+     * @param content the page content that will be shown by this tab
      * @return the index of the inserted tab
      */
     Q_INVOKABLE int insertTab(int index, const QIcon &icon, const QString &label,
@@ -81,11 +83,11 @@ public:
      * This is an overloaded member provided for convenience
      * equivalent to insertTab(index, QIcon(), label);
      *
-     * @arg index the position where to insert the new tab,
+     * @param index the position where to insert the new tab,
      *            if index <=0 will be the first position,
      *            if index >= count() will be the last
-     * @arg label the text label of the tab
-     * @arg content the page content that will be shown by this tab
+     * @param label the text label of the tab
+     * @param content the page content that will be shown by this tab
      * @return the index of the inserted tab
      */
     Q_INVOKABLE int insertTab(int index, const QString &label, QGraphicsLayoutItem *content = 0);
@@ -93,9 +95,9 @@ public:
     /**
      * Adds a new tab in the last position
      *
-     * @arg icon  the icon for this tab
-     * @arg label the text label of the tab
-     * @arg content the page content that will be shown by this tab
+     * @param icon  the icon for this tab
+     * @param label the text label of the tab
+     * @param content the page content that will be shown by this tab
      * @return the index of the inserted tab
      */
     Q_INVOKABLE int addTab(const QIcon &icon, const QString &label, QGraphicsLayoutItem *content = 0);
@@ -105,8 +107,8 @@ public:
      * This is an overloaded member provided for convenience
      * equivalent to addTab(QIcon(), label, page)
      *
-     * @arg label the text label of the tab
-     * @arg content the page content that will be shown by this tab
+     * @param label the text label of the tab
+     * @param content the page content that will be shown by this tab
      * @return the index of the inserted tab
      */
     Q_INVOKABLE int addTab(const QString &label, QGraphicsLayoutItem *content = 0);
@@ -114,14 +116,14 @@ public:
     /**
      * Removes a tab, contents are deleted
      *
-     * @arg index the index of the tab to remove
+     * @param index the index of the tab to remove
      */
     Q_INVOKABLE void removeTab(int index);
 
     /**
      * Removes a tab, the page is reparented to 0 and is returned
      *
-     * @arg index the index of the tab to remove
+     * @param index the index of the tab to remove
      * @since 4.4
      */
     Q_INVOKABLE QGraphicsLayoutItem *takeTab(int index);
@@ -129,7 +131,7 @@ public:
     /**
      * Returns the contents of a page
      *
-     * @arg index the index of the tab to retrieve
+     * @param index the index of the tab to retrieve
      * @since 4.4
      */
     Q_INVOKABLE QGraphicsLayoutItem *tabAt(int index);
@@ -147,30 +149,30 @@ public:
     /**
      * Sets the text label of the given tab
      *
-     * @arg index the index of the tab to modify
-     * @arg label the new text label of the given tab
+     * @param index the index of the tab to modify
+     * @param label the new text label of the given tab
      */
     Q_INVOKABLE void setTabText(int index, const QString &label);
 
     /**
      * @return the text label of the given tab
      *
-     * @arg index the index of the tab we want to know its label
+     * @param index the index of the tab we want to know its label
      */
     Q_INVOKABLE QString tabText(int index) const;
 
     /**
      * Sets an icon for a given tab
      *
-     * @arg index the index of the tab to modify
-     * @arg icon the new icon for the given tab
+     * @param index the index of the tab to modify
+     * @param icon the new icon for the given tab
      */
     Q_INVOKABLE void setTabIcon(int index, const QIcon &icon);
 
     /**
      * @return the current icon for a given tab
      *
-     * @arg index the index of the tab we want to know its icon
+     * @param index the index of the tab we want to know its icon
      */
     Q_INVOKABLE QIcon tabIcon(int index) const;
 
@@ -179,7 +181,7 @@ public:
      * pages, when the tabbar doesn't have content pages at all this
      * function has no effect
      *
-     * @arg show true if we want to show the tabbar
+     * @param show true if we want to show the tabbar
      * @since 4.3
      */
      void setTabBarShown(bool show);
@@ -193,7 +195,7 @@ public:
     /**
      * Sets the stylesheet used to control the visual display of this TabBar
      *
-     * @arg stylesheet a CSS string
+     * @param stylesheet a CSS string
      */
     void setStyleSheet(const QString &stylesheet);
 
@@ -202,16 +204,60 @@ public:
      */
     QString styleSheet() const;
 
+    /**
+     * Highlight the specified tab
+     * @param index of the tab to highlight
+     * @param highlight true if it should be highlighted, wrong if not
+     * @since 4.7
+     */
+    Q_INVOKABLE void setTabHighlighted(int index, bool highlight);
+
+    /**
+     * @return if the tab at index is highlighted
+     * @since 4.7
+     */
+    Q_INVOKABLE bool isTabHighlighted(int index) const;
+
     /**
      * @return the native widget wrapped by this TabBar
      */
     KTabBar *nativeWidget() const;
 
+    /**
+     * Set a widget to be displayed on one side of the TabBar, depending on the
+     * LayoutDirection and the Shape.
+     * @param widget the widget to be displayed. Passing 0 will show nothing.
+     * Any previous widget will be deleted.
+     * @since 4.6
+     */
+    void setFirstPositionWidget(QGraphicsWidget *widget);
+
+    /**
+     * @return the widget in the first position
+     * @since 4.6
+     */
+    QGraphicsWidget *firstPositionWidget() const;
+
+    /**
+     * Set a widget to be displayed on one side of the TabBar, depending on the
+     * LayoutDirection and the Shape.
+     * @param widget the widget to be displayed. Passing 0 will show nothing.
+     * Any previous widget will be deleted.
+     * @since 4.6
+     */
+    void setLastPositionWidget(QGraphicsWidget *widget);
+
+    /**
+     * @return the widget in the last position
+     * @since 4.6
+     */
+    QGraphicsWidget *lastPositionWidget() const;
+
 public Q_SLOTS:
     /**
      * Activate a given tab
      *
-     * @arg index the index of the tab to activate
+     * @param index the index of the tab to activate
      */
     void setCurrentIndex(int index);
 
@@ -219,12 +265,11 @@ Q_SIGNALS:
     /**
      * Emitted when the active tab changes
      *
-     * @arg index the newly activated tab
+     * @param index the newly activated tab
      */
     void currentChanged(int index);
 
 protected:
-    void wheelEvent(QGraphicsSceneWheelEvent *event);
     void resizeEvent(QGraphicsSceneResizeEvent * event);
     void changeEvent(QEvent *event);
 
@@ -233,7 +278,8 @@ private:
 
     friend class TabBarPrivate;
 
-    Q_PRIVATE_SLOT(d, void slidingCompleted(QGraphicsItem *item))
+    Q_PRIVATE_SLOT(d, void slidingNewPageCompleted())
+    Q_PRIVATE_SLOT(d, void slidingOldPageCompleted())
     Q_PRIVATE_SLOT(d, void shapeChanged(const QTabBar::Shape shape))
     Q_PRIVATE_SLOT(d, void setPalette())
 };
