@@ -19,28 +19,29 @@
 
 #include "textedit.h"
 
+#include <QtGui/qgraphicssceneevent.h>
+#include <QMenu>
 #include <QPainter>
 #include <QScrollBar>
-#include <QMenu>
-#include <QGraphicsSceneContextMenuEvent>
+#include <QGraphicsView>
 
 #include <kmimetype.h>
 #include <ktextedit.h>
 
 #include "applet.h"
-#include "theme.h"
-#include "svg.h"
 #include "private/style_p.h"
+#include "private/themedwidgetinterface_p.h"
+#include "svg.h"
+#include "theme.h"
 
 namespace Plasma
 {
 
-class TextEditPrivate
+class TextEditPrivate : public ThemedWidgetInterface<TextEdit>
 {
 public:
     TextEditPrivate(TextEdit *textEdit)
-        : q(textEdit),
-          customFont(false)
+        : ThemedWidgetInterface<TextEdit>(textEdit)
     {
     }
 
@@ -48,39 +49,16 @@ public:
     {
     }
 
-    void setPalette()
-    {
-        KTextEdit *native = q->nativeWidget();
-        QColor color = Theme::defaultTheme()->color(Theme::TextColor);
-        QPalette p = native->palette();
-
-        p.setColor(QPalette::Normal, QPalette::Text, color);
-        p.setColor(QPalette::Inactive, QPalette::Text, color);
-        p.setColor(QPalette::Normal, QPalette::ButtonText, color);
-        p.setColor(QPalette::Inactive, QPalette::ButtonText, color);
-        p.setColor(QPalette::Normal, QPalette::Base, QColor(0,0,0,0));
-        p.setColor(QPalette::Inactive, QPalette::Base, QColor(0,0,0,0));
-        native->setPalette(p);
-
-        if (!customFont) {
-            q->nativeWidget()->setFont(Plasma::Theme::defaultTheme()->font(Plasma::Theme::DefaultFont));
-        }
-    }
-
-    TextEdit *q;
     Plasma::Style::Ptr style;
-    bool customFont;
 };
 
 TextEdit::TextEdit(QGraphicsWidget *parent)
     : QGraphicsProxyWidget(parent),
       d(new TextEditPrivate(this))
 {
-    d->style = Plasma::Style::sharedStyle();
-
     setNativeWidget(new KTextEdit);
-    connect(Theme::defaultTheme(), SIGNAL(themeChanged()),
-            this, SLOT(setPalette()));
+    d->style = Plasma::Style::sharedStyle();
+    d->initTheming();
 }
 
 TextEdit::~TextEdit()
@@ -129,11 +107,11 @@ void TextEdit::setNativeWidget(KTextEdit *nativeWidget)
 
     connect(nativeWidget, SIGNAL(textChanged()), this, SIGNAL(textChanged()));
 
-    setWidget(nativeWidget);
+    nativeWidget->setWindowIcon(QIcon());
+    d->setWidget(nativeWidget);
 
     nativeWidget->setAttribute(Qt::WA_NoSystemBackground);
     nativeWidget->setFrameShape(QFrame::NoFrame);
-    nativeWidget->setTextBackgroundColor(Qt::transparent);
     nativeWidget->viewport()->setAutoFillBackground(false);
     nativeWidget->verticalScrollBar()->setStyle(d->style.data());
     nativeWidget->horizontalScrollBar()->setStyle(d->style.data());
@@ -170,18 +148,9 @@ void TextEdit::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
     delete popup;
 }
 
-void TextEdit::resizeEvent(QGraphicsSceneResizeEvent *event)
-{
-    QGraphicsProxyWidget::resizeEvent(event);
-}
-
 void TextEdit::changeEvent(QEvent *event)
 {
-    if (event->type() == QEvent::FontChange) {
-        d->customFont = true;
-        nativeWidget()->setFont(font());
-    }
-
+    d->changeEvent(event);
     QGraphicsProxyWidget::changeEvent(event);
 }
 
@@ -214,10 +183,20 @@ void TextEdit::focusOutEvent(QFocusEvent *event)
     if (applet) {
         applet->setStatus(Plasma::UnknownStatus);
     }
+
+    QEvent closeEvent(QEvent::CloseSoftwareInputPanel);
+    if (qApp) {
+        if (QGraphicsView *view = qobject_cast<QGraphicsView*>(qApp->focusWidget())) {
+            if (view->scene() && view->scene() == scene()) {
+                QApplication::sendEvent(view, &closeEvent);
+            }
+        }
+    }
+
     QGraphicsProxyWidget::focusOutEvent(event);
 }
 
 } // namespace Plasma
 
-#include <textedit.moc>
+#include "moc_textedit.cpp"
 
