@@ -22,7 +22,7 @@
 
 #include <QtGui/QGraphicsProxyWidget>
 
-class QToolButton;
+#include <QToolButton>
 
 #include <plasma/plasma_export.h>
 
@@ -184,7 +184,6 @@ protected:
     void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
     void changeEvent(QEvent *event);
     QVariant itemChange(GraphicsItemChange change, const QVariant &value); 
-    QSizeF sizeHint(Qt::SizeHint which, const QSizeF & constraint) const;
 
 private Q_SLOTS:
     void setAnimationUpdate(qreal progress);
