@@ -18,7 +18,6 @@
  */
 
 #include "windoweffects.h"
-
 #include <QVarLengthArray>
 
 #include <kwindowsystem.h>
@@ -26,9 +25,10 @@
 #include "theme.h"
 
 #ifdef Q_WS_X11
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-#include <QX11Info>
+    #include <X11/Xlib.h>
+    #include <X11/Xatom.h>
+    #include <X11/Xutil.h>
+    #include <QtGui/qx11info_x11.h>
 #endif
 
 namespace Plasma
@@ -44,39 +44,38 @@ bool isEffectAvailable(Effect effect)
         return false;
     }
 #ifdef Q_WS_X11
-    QString effectName;
-
-    switch (effect) {
-    case Slide:
-        effectName = "_KDE_SLIDE";
-        break;
-    case WindowPreview:
-        effectName = "_KDE_WINDOW_PREVIEW";
-        break;
-    case PresentWindows:
-        effectName = "_KDE_PRESENT_WINDOWS_DESKTOP";
-        break;
-    case PresentWindowsGroup:
-        effectName = "_KDE_PRESENT_WINDOWS_GROUP";
-        break;
-    case HighlightWindows:
-        effectName = "_KDE_WINDOW_HIGHLIGHT";
-        break;
-    case OverrideShadow:
-        effectName = "_KDE_SHADOW_OVERRIDE";
-        break;
-    case BlurBehind:
-        effectName = "_KDE_NET_WM_BLUR_BEHIND_REGION";
-        break;
-    default:
-        return false;
-    }
-
     // hackish way to find out if KWin has the effect enabled,
     // TODO provide proper support
+
     Display *dpy = QX11Info::display();
-    Atom atom = XInternAtom(dpy, effectName.toLatin1(), False);
-    int cnt;
+    Atom atom = None;
+    switch (effect) {
+        case Slide: {
+            atom = XInternAtom(dpy, "_KDE_SLIDE", False);
+            break;
+        }
+        case WindowPreview: {
+            atom = XInternAtom(dpy, "_KDE_WINDOW_PREVIEW", False);
+            break;
+        }
+        case PresentWindows: {
+            atom = XInternAtom(dpy, "_KDE_PRESENT_WINDOWS_DESKTOP", False);
+            break;
+        }
+        case PresentWindowsGroup: {
+            atom = XInternAtom(dpy, "_KDE_PRESENT_WINDOWS_GROUP", False);
+            break;
+        }
+        case HighlightWindows: {
+            atom = XInternAtom(dpy, "_KDE_WINDOW_HIGHLIGHT", False);
+            break;
+        }
+        default: {
+            return false;
+        }
+    }
+
+    int cnt = 0;
     Atom *list = XListProperties(dpy, DefaultRootWindow(dpy), &cnt);
     if (list != NULL) {
         bool ret = (qFind(list, list + cnt, atom) != list + cnt);
@@ -91,8 +90,8 @@ void slideWindow(WId id, Plasma::Location location, int offset)
 {
 #ifdef Q_WS_X11
     Display *dpy = QX11Info::display();
-    Atom atom = XInternAtom( dpy, "_KDE_SLIDE", False );
-    QVarLengthArray<long, 1024> data(2);
+    Atom atom = XInternAtom(dpy, "_KDE_SLIDE", False);
+    QVarLengthArray<long, 2> data(2);
 
     data[0] = offset;
 
@@ -123,38 +122,7 @@ void slideWindow(WId id, Plasma::Location location, int offset)
 
 void slideWindow(QWidget *widget, Plasma::Location location)
 {
-#ifdef Q_WS_X11
-    Display *dpy = QX11Info::display();
-    Atom atom = XInternAtom( dpy, "_KDE_SLIDE", False );
-    QVarLengthArray<long, 1024> data(2);
-
-    switch (location) {
-    case LeftEdge:
-        data[0] = widget->geometry().left();
-        data[1] = 0;
-        break;
-    case TopEdge:
-        data[0] = widget->geometry().top();
-        data[1] = 1;
-        break;
-    case RightEdge:
-        data[0] = widget->geometry().right();
-        data[1] = 2;
-        break;
-    case BottomEdge:
-        data[0] = widget->geometry().bottom();
-        data[1] = 3;
-    default:
-        break;
-    }
-
-    if (location == Desktop || location == Floating) {
-        XDeleteProperty(dpy, widget->effectiveWinId(), atom);
-    } else {
-        XChangeProperty(dpy, widget->effectiveWinId(), atom, atom, 32, PropModeReplace,
-                        reinterpret_cast<unsigned char *>(data.data()), data.size());
-    }
-#endif
+    WindowEffects::slideWindow(widget->effectiveWinId(), location, -1);
 }
 
 QList<QSize> windowSizes(const QList<WId> &ids)
@@ -190,19 +158,19 @@ void showWindowThumbnails(WId parent, const QList<WId> &windows, const QList<QRe
 
     int numWindows = windows.size();
 
-    QVarLengthArray<long, 1024> data(1 + (6 * numWindows));
+    // 64 is enough for 10 windows and is a nice base 2 number
+    QVarLengthArray<long, 64> data(1 + (6 * numWindows));
     data[0] = numWindows;
 
-    QList<WId>::const_iterator windowsIt;
     QList<QRect>::const_iterator rectsIt = rects.constBegin();
     int i = 0;
-    for (windowsIt = windows.constBegin(); windowsIt != windows.constEnd(); ++windowsIt) {
+    foreach(const WId windowsIt, windows) {
 
         const int start = (i * 6) + 1;
         const QRect thumbnailRect = (*rectsIt);
 
         data[start] = 5;
-        data[start+1] = (*windowsIt);
+        data[start+1] = windowsIt;
         data[start+2] = thumbnailRect.x();
         data[start+3] = thumbnailRect.y();
         data[start+4] = thumbnailRect.width();
@@ -221,18 +189,9 @@ void presentWindows(WId controller, const QList<WId> &ids)
 #ifdef Q_WS_X11
     const int numWindows = ids.count();
     QVarLengthArray<long, 32> data(numWindows);
-    int actualCount = 0;
-
     for (int i = 0; i < numWindows; ++i) {
         data[i] = ids.at(i);
-        ++actualCount;
-
     }
-
-    if (actualCount != numWindows) {
-        data.resize(actualCount);
-    }
-
     if (!data.isEmpty()) {
         Display *dpy = QX11Info::display();
         Atom atom = XInternAtom(dpy, "_KDE_PRESENT_WINDOWS_GROUP", False);
@@ -245,7 +204,7 @@ void presentWindows(WId controller, const QList<WId> &ids)
 void presentWindows(WId controller, int desktop)
 {
 #ifdef Q_WS_X11
-    QVarLengthArray<long, 32> data(1);
+    QVarLengthArray<long, 1> data(1);
     data[0] = desktop;
     Display *dpy = QX11Info::display();
     Atom atom = XInternAtom(dpy, "_KDE_PRESENT_WINDOWS_DESKTOP", False);
@@ -262,23 +221,15 @@ void highlightWindows(WId controller, const QList<WId> &ids)
     Atom atom = XInternAtom(dpy, "_KDE_WINDOW_HIGHLIGHT", False);
 
     if (numWindows == 0) {
-        Atom atom = XInternAtom(dpy, "_KDE_WINDOW_HIGHLIGHT", False);
         XDeleteProperty(dpy, controller, atom);
+        return;
     }
 
     QVarLengthArray<long, 32> data(numWindows);
-    int actualCount = 0;
-
     for (int i = 0; i < numWindows; ++i) {
         data[i] = ids.at(i);
-        ++actualCount;
 
     }
-
-    if (actualCount != numWindows) {
-        data.resize(actualCount);
-    }
-
     if (!data.isEmpty()) {
         XChangeProperty(dpy, controller, atom, atom, 32, PropModeReplace,
                         reinterpret_cast<unsigned char *>(data.data()), data.size());
@@ -286,44 +237,6 @@ void highlightWindows(WId controller, const QList<WId> &ids)
 #endif
 }
 
-void overrideShadow(WId window, bool override)
-{
-#ifdef Q_WS_X11
-    Display *dpy = QX11Info::display();
-    Atom atom = XInternAtom( dpy, "_KDE_SHADOW_OVERRIDE", False );
-    QVarLengthArray<long, 1024> data(1);
-    data[0] = 1;
-
-    if (!override) {
-        XDeleteProperty(dpy, window, atom);
-    } else {
-        XChangeProperty(dpy, window, atom, atom, 32, PropModeReplace,
-                        reinterpret_cast<unsigned char *>(data.data()), data.size());
-    }
-#endif
-}
-
-void enableBlurBehind(WId window, bool enable, const QRegion &region)
-{
-#ifdef Q_WS_X11
-    Display *dpy = QX11Info::display();
-    Atom atom = XInternAtom(dpy, "_KDE_NET_WM_BLUR_BEHIND_REGION", False);
-
-    if (enable) {
-        QVector<QRect> rects = region.rects();
-        QVector<unsigned long> data;
-        foreach (const QRect &r, rects) {
-            data << r.x() << r.y() << r.width() << r.height();
-        }
-
-        XChangeProperty(dpy, window, atom, XA_CARDINAL, 32, PropModeReplace,
-                        reinterpret_cast<const unsigned char *>(data.constData()), data.size());
-    } else {
-        XDeleteProperty(dpy, window, atom);
-    }
-#endif
-}
-
 }
 
 }
