@@ -41,33 +41,17 @@ Solid::Battery::BatteryType FakeBattery::type() const
 {
     QString name = fakeDevice()->property("batteryType").toString();
 
-    if (name == "pda")
+    if (name == "primary")
     {
-        return Solid::Battery::PdaBattery;
+        return Solid::Battery::PrimaryBattery;
     }
     else if (name == "ups")
     {
         return Solid::Battery::UpsBattery;
     }
-    else if (name == "primary")
+    else if (name == "usb")
     {
-        return Solid::Battery::PrimaryBattery;
-    }
-    else if (name == "mouse")
-    {
-        return Solid::Battery::MouseBattery;
-    }
-    else if (name == "keyboard")
-    {
-        return Solid::Battery::KeyboardBattery;
-    }
-    else if (name == "keyboard_mouse")
-    {
-        return Solid::Battery::KeyboardMouseBattery;
-    }
-    else if (name == "camera")
-    {
-        return Solid::Battery::CameraBattery;
+        return Solid::Battery::UsbBattery;
     }
     else
     {
@@ -85,11 +69,26 @@ int FakeBattery::chargePercent() const
     return percent;
 }
 
+int FakeBattery::capacity() const
+{
+    int last_full = fakeDevice()->property("lastFullLevel").toInt();
+    int max = fakeDevice()->property("maxLevel").toInt();
+
+    int percent = (100 * last_full) / max;
+
+    return percent;
+}
+
 bool FakeBattery::isRechargeable() const
 {
     return fakeDevice()->property("isRechargeable").toBool();
 }
 
+bool FakeBattery::isPowerSupply() const
+{
+    return fakeDevice()->property("isPowerSupply").toBool();
+}
+
 Solid::Battery::ChargeState FakeBattery::chargeState() const
 {
     QString state = fakeDevice()->property("chargeState").toString();
@@ -102,9 +101,13 @@ Solid::Battery::ChargeState FakeBattery::chargeState() const
     {
         return Solid::Battery::Discharging;
     }
+    else if (state == "full")
+    {
+        return Solid::Battery::FullyCharged;
+    }
     else
     {
-        return Solid::Battery::NoCharge;
+        return Solid::Battery::UnknownCharge;
     }
 }
 
@@ -120,8 +123,11 @@ void FakeBattery::setChargeState(Solid::Battery::ChargeState newState)
     case Solid::Battery::Discharging:
         name = "discharging";
         break;
-    case Solid::Battery::NoCharge:
-        name = "noCharge";
+    case Solid::Battery::FullyCharged:
+        name = "full";
+        break;
+    case Solid::Battery::UnknownCharge:
+        name = "unknown";
         break;
     }
 
@@ -135,4 +141,4 @@ void FakeBattery::setChargeLevel(int newLevel)
     emit chargePercentChanged(chargePercent(), fakeDevice()->udi());
 }
 
-#include "backends/fakehw/fakebattery.moc"
+#include "backends/fakehw/moc_fakebattery.cpp"
