@@ -1,24 +1,26 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2006 Michaël Larouche <michael.larouche@kdemail.net>
+/*
+    Copyright 2006 Michaël Larouche <michael.larouche@kdemail.net>
 
     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    Lesser General Public License for more details.
 
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef SOLID_BACKENDS_FAKEHW_FAKEDEVICE_H
 #define SOLID_BACKENDS_FAKEHW_FAKEDEVICE_H
 
+#include <solid/solid_export.h>
 #include <solid/ifaces/device.h>
 
 #include <QtCore/QMap>
@@ -30,7 +32,7 @@ namespace Backends
 {
 namespace Fake
 {
-class FakeDevice : public Solid::Ifaces::Device
+class SOLID_EXPORT FakeDevice : public Solid::Ifaces::Device
 {
     Q_OBJECT
 public:
