@@ -79,4 +79,4 @@ void Solid::Backends::Fake::FakeStorageAccess::onPropertyChanged(const QMap<QStr
     }
 }
 
-#include "backends/fakehw/fakestorageaccess.moc"
+#include "backends/fakehw/moc_fakestorageaccess.cpp"
