@@ -18,15 +18,15 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "config-solid.h"
 #include "udevmanager.h"
-#include "utils.h"
-
-#include "udev.h"
+#include "udevqt.h"
 #include "udevdevice.h"
 #include "../shared/rootdevice.h"
 
 #include <QtCore/QSet>
 #include <QtCore/QFile>
+#include <QtCore/QDir>
 #include <QtCore/QDebug>
 
 using namespace Solid::Backends::UDev;
@@ -41,8 +41,6 @@ public:
 
     bool isOfInterest(const QString &udi, const UdevQt::Device &device);
     bool checkOfInterest(const UdevQt::Device &device);
-    bool isPowerBubtton(const UdevQt::Device &device);
-    bool isLidBubtton(const UdevQt::Device &device);
 
     UdevQt::Client *m_client;
     QStringList m_devicesOfInterest;
@@ -51,15 +49,17 @@ public:
 
 UDevManager::Private::Private()
 {
-    QStringList subsystems;
-    subsystems << "processor";
-    subsystems << "sound";
-    subsystems << "tty";
-    subsystems << "dvb";
-    subsystems << "video4linux";
-    subsystems << "net";
-    subsystems << "usb";
-    subsystems << "input";
+    static const QList<QByteArray> subsystems = QList<QByteArray>()
+        << "block"
+        << "power_supply"
+        << "processor"
+        << "cpu"
+        << "sound"
+        << "video4linux"
+        << "net"
+        << "usb"
+        << "input"
+        << "pci";
     m_client = new UdevQt::Client(subsystems);
 }
 
@@ -89,75 +89,45 @@ bool UDevManager::Private::checkOfInterest(const UdevQt::Device &device)
     qDebug() << "Path:" << device.sysfsPath();
     qDebug() << "Properties:" << device.deviceProperties();
     Q_FOREACH (const QString &key, device.deviceProperties()) {
-        qDebug() << "\t" << key << ":" << device.deviceProperty(key).toString();
+        qDebug() << "\t" << key << ":" << device.deviceProperty(key.toLatin1());
     }
     qDebug() << "Driver:" << device.driver();
     qDebug() << "Subsystem:" << device.subsystem();
     qDebug() << ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>";
 #endif
-    if (device.driver() == QLatin1String("processor")) {
-        // Linux ACPI reports processor slots, rather than processors.
-        // Empty slots will not have a system device associated with them.
-        return QFile::exists(device.sysfsPath() + "/sysdev");
+    if (device.subsystem() == QLatin1String("block")) {
+        return !device.deviceProperty("ID_FS_TYPE").isEmpty();
     }
-    if (device.subsystem() == QLatin1String("sound") &&
-            device.deviceProperty("SOUND_FORM_FACTOR").toString() != "internal") {
+
+    if (device.subsystem() == QLatin1String("power_supply")) {
         return true;
     }
 
-    if (device.subsystem() == QLatin1String("tty")) {
-        QString path = device.deviceProperty("DEVPATH").toString();
+    if (device.driver() == QLatin1String("processor")) {
+        // Linux ACPI reports processor slots, rather than processors.
+        // Empty slots will not have a system device associated with them.
+        QDir sysfsDir(device.sysfsPath());
+        return (sysfsDir.exists("sysdev") || sysfsDir.exists("cpufreq") || sysfsDir.exists("topology/core_id"));
+    }
+    if (device.subsystem() == QLatin1String("sound") &&
+        device.deviceProperty("SOUND_FORM_FACTOR") != "internal") {
+        return true;
+    }
 
-        int lastSlash = path.length() - path.lastIndexOf(QLatin1String("/")) -1;
-        QByteArray lastElement = path.right(lastSlash).toLatin1();
-
-        if (lastElement.startsWith("tty") && !path.startsWith("/devices/virtual")) {
-            return true;
-        }
+    if (device.subsystem() == QLatin1String("pci")) {
+        const QString pciclass = device.deviceProperty("PCI_CLASS");
+        return (pciclass == QLatin1String("30000")); // VGA controller
     }
 
     if (device.subsystem() == QLatin1String("input")) {
-        if (device.deviceProperties().contains("KEY")) {
-            return isPowerBubtton(device);
-        }
-        if (device.deviceProperties().contains("SW")) {
-            return isLidBubtton(device);
-        }
+        const QStringList deviceProperties = device.deviceProperties();
+        return (device.deviceProperty("ID_INPUT_KEY").toInt() == 1 && (deviceProperties.contains("KEY") || deviceProperties.contains("SW")));
     }
 
-    return device.subsystem() == QLatin1String("dvb") ||
-           device.subsystem() == QLatin1String("video4linux") ||
+    return device.subsystem() == QLatin1String("video4linux") ||
            device.subsystem() == QLatin1String("net") ||
-           device.deviceProperty("ID_MEDIA_PLAYER").toString().isEmpty() == false || // media-player-info recognized devices
-           device.deviceProperty("ID_GPHOTO2").toInt() == 1; // GPhoto2 cameras
-}
-
-bool UDevManager::Private::isLidBubtton(const UdevQt::Device& device)
-{
-    long bitmask[NBITS(SW_MAX)];
-    int nbits = input_str_to_bitmask(device.deviceProperty("SW").toByteArray(), bitmask, sizeof(bitmask), NBITS(SW_MAX));
-    if (nbits == 1) {
-        if (test_bit (SW_LID, bitmask)) {
-//             qDebug() << "Lid button detected";
-            return true;
-        }
-    }
-
-    return false;
-}
-
-bool UDevManager::Private::isPowerBubtton(const UdevQt::Device& device)
-{
-    long bitmask[NBITS(KEY_MAX)];
-    int nbits = input_str_to_bitmask(device.deviceProperty("KEY").toByteArray(), bitmask, sizeof(bitmask), NBITS(KEY_MAX));
-    if (nbits == 1) {
-        if (test_bit (KEY_POWER, bitmask)) {
-//             qDebug() << "Power button detected";
-            return true;
-        }
-    }
-
-    return false;
+           device.deviceProperty("ID_MEDIA_PLAYER").toInt() == 1 || // media-player-info recognized devices
+           (device.deviceProperty("ID_GPHOTO2").toInt() == 1 && device.parent().deviceProperty("ID_GPHOTO2").toInt() != 1); // GPhoto2 cameras
 }
 
 UDevManager::UDevManager(QObject *parent)
@@ -166,18 +136,26 @@ UDevManager::UDevManager(QObject *parent)
 {
     connect(d->m_client, SIGNAL(deviceAdded(UdevQt::Device)), this, SLOT(slotDeviceAdded(UdevQt::Device)));
     connect(d->m_client, SIGNAL(deviceRemoved(UdevQt::Device)), this, SLOT(slotDeviceRemoved(UdevQt::Device)));
+    connect(d->m_client, SIGNAL(deviceChanged(UdevQt::Device)), this, SLOT(slotDeviceChanged(UdevQt::Device)));
 
-    d->m_supportedInterfaces << Solid::DeviceInterface::GenericInterface
+    d->m_supportedInterfaces << Solid::DeviceInterface::StorageAccess
+                             << Solid::DeviceInterface::StorageDrive
+                             << Solid::DeviceInterface::StorageVolume
+                             << Solid::DeviceInterface::AcAdapter
+                             << Solid::DeviceInterface::Battery
                              << Solid::DeviceInterface::Processor
+#if defined(LIBCDIO_FOUND)
+                             << Solid::DeviceInterface::OpticalDrive
+                             << Solid::DeviceInterface::OpticalDisc
+#endif
                              << Solid::DeviceInterface::AudioInterface
                              << Solid::DeviceInterface::NetworkInterface
-                             << Solid::DeviceInterface::SerialInterface
                              << Solid::DeviceInterface::Camera
                              << Solid::DeviceInterface::PortableMediaPlayer
-                             << Solid::DeviceInterface::DvbInterface
                              << Solid::DeviceInterface::Block
                              << Solid::DeviceInterface::Video
-                             << Solid::DeviceInterface::Button;
+                             << Solid::DeviceInterface::Button
+                             << Solid::DeviceInterface::Graphic;
 }
 
 UDevManager::~UDevManager()
@@ -198,8 +176,7 @@ QSet<Solid::DeviceInterface::Type> UDevManager::supportedInterfaces() const
 QStringList UDevManager::allDevices()
 {
     QStringList res;
-    const UdevQt::DeviceList deviceList = d->m_client->allDevices();
-    foreach (const UdevQt::Device &device, deviceList) {
+    foreach (const UdevQt::Device &device, d->m_client->allDevices()) {
         if (d->isOfInterest(udiPrefix() + device.sysfsPath(), device)) {
             res << udiPrefix() + device.sysfsPath();
         }
@@ -270,3 +247,14 @@ void UDevManager::slotDeviceRemoved(const UdevQt::Device &device)
         d->m_devicesOfInterest.removeAll(udiPrefix() + device.sysfsPath());
     }
 }
+
+void UDevManager::slotDeviceChanged(const UdevQt::Device &device)
+{
+    if (d->isOfInterest(udiPrefix() + device.sysfsPath(), device)) {
+        if (device.subsystem() == "block") {
+            const QString idfsusage = device.deviceProperty("ID_FS_USAGE");
+            const bool hascontent = (idfsusage == "filesystem" || idfsusage == "crypto");
+            emit contentChanged(udiPrefix() + device.sysfsPath(), hascontent);
+        }
+    }
+}
