@@ -30,11 +30,17 @@ Solid::Battery::Battery(QObject *backendObject)
     connect(backendObject, SIGNAL(chargePercentChanged(int,QString)),
              this, SIGNAL(chargePercentChanged(int,QString)));
 
+    connect(backendObject, SIGNAL(capacityChanged(int,QString)),
+             this, SIGNAL(capacityChanged(int,QString)));
+
     connect(backendObject, SIGNAL(chargeStateChanged(int,QString)),
              this, SIGNAL(chargeStateChanged(int,QString)));
 
     connect(backendObject, SIGNAL(plugStateChanged(bool,QString)),
              this, SIGNAL(plugStateChanged(bool,QString)));
+
+    connect(backendObject, SIGNAL(powerSupplyStateChanged(bool,QString)),
+             this, SIGNAL(powerSupplyStateChanged(bool,QString)));
 }
 
 Solid::Battery::~Battery()
@@ -48,6 +54,12 @@ bool Solid::Battery::isPlugged() const
     return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), false, isPlugged());
 }
 
+bool Solid::Battery::isPowerSupply() const
+{
+    Q_D(const Battery);
+    return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), true, isPowerSupply());
+}
+
 Solid::Battery::BatteryType Solid::Battery::type() const
 {
     Q_D(const Battery);
@@ -60,6 +72,12 @@ int Solid::Battery::chargePercent() const
     return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), 0, chargePercent());
 }
 
+int Solid::Battery::capacity() const
+{
+    Q_D(const Battery);
+    return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), 100, capacity());
+}
+
 bool Solid::Battery::isRechargeable() const
 {
     Q_D(const Battery);
@@ -69,7 +87,7 @@ bool Solid::Battery::isRechargeable() const
 Solid::Battery::ChargeState Solid::Battery::chargeState() const
 {
     Q_D(const Battery);
-    return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), NoCharge, chargeState());
+    return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), UnknownCharge, chargeState());
 }
 
-#include "battery.moc"
+#include "moc_battery.cpp"
