@@ -1,20 +1,21 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2005-2007 Kevin Ottens <ervin@kde.org>
+/*
+    Copyright 2005-2007 Kevin Ottens <ervin@kde.org>
 
     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    Lesser General Public License for more details.
 
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "device.h"
@@ -57,15 +58,10 @@
 #include <solid/ifaces/button.h>
 #include <solid/audiointerface.h>
 #include <solid/ifaces/audiointerface.h>
-#include <solid/dvbinterface.h>
-#include <solid/ifaces/dvbinterface.h>
 #include <solid/video.h>
 #include <solid/ifaces/video.h>
-#include <solid/serialinterface.h>
-#include <solid/ifaces/serialinterface.h>
-#include <solid/smartcardreader.h>
-#include <solid/ifaces/smartcardreader.h>
-
+#include <solid/graphic.h>
+#include <solid/ifaces/graphic.h>
 
 Solid::Device::Device(const QString &udi)
 {
@@ -220,17 +216,11 @@ const Solid::DeviceInterface *Solid::Device::asDeviceInterface(const DeviceInter
             case DeviceInterface::AudioInterface:
                 iface = deviceinterface_cast(Ifaces::AudioInterface, AudioInterface, dev_iface);
                 break;
-            case DeviceInterface::DvbInterface:
-                iface = deviceinterface_cast(Ifaces::DvbInterface, DvbInterface, dev_iface);
-                break;
             case DeviceInterface::Video:
                 iface = deviceinterface_cast(Ifaces::Video, Video, dev_iface);
                 break;
-            case DeviceInterface::SerialInterface:
-                iface = deviceinterface_cast(Ifaces::SerialInterface, SerialInterface, dev_iface);
-                break;
-            case DeviceInterface::SmartCardReader:
-                iface = deviceinterface_cast(Ifaces::SmartCardReader, SmartCardReader, dev_iface);
+            case DeviceInterface::Graphic:
+                iface = deviceinterface_cast(Ifaces::Graphic, Graphic, dev_iface);
                 break;
             case DeviceInterface::Unknown:
             case DeviceInterface::Last:
@@ -242,6 +232,7 @@ const Solid::DeviceInterface *Solid::Device::asDeviceInterface(const DeviceInter
         {
             // Lie on the constness since we're simply doing caching here
             const_cast<Device *>(this)->d->setInterface(type, iface);
+            iface->d_ptr->setDevicePrivate(d.data());
         }
 
         return iface;
@@ -286,8 +277,8 @@ void Solid::DevicePrivate::setBackendObject(Ifaces::Device *object)
     m_backendObject = object;
 
     if (object) {
-        connect(object, SIGNAL(destroyed(QObject *)),
-                this, SLOT(_k_destroyed(QObject *)));
+        connect(object, SIGNAL(destroyed(QObject*)),
+                this, SLOT(_k_destroyed(QObject*)));
     }
 
     if (!m_ifaces.isEmpty()) {
@@ -312,4 +303,4 @@ void Solid::DevicePrivate::setInterface(const DeviceInterface::Type &type, Devic
     m_ifaces[type] = interface;
 }
 
-#include "device_p.moc"
+#include "moc_device_p.cpp"
