@@ -30,32 +30,36 @@
 
 #include "soliddefs_p.h"
 
-SOLID_GLOBAL_STATIC(Solid::DeviceManagerStorage, globalDeviceStorage)
+Q_GLOBAL_STATIC(Solid::DeviceManagerStorage, globalDeviceStorage)
+
+thread_local Solid::DeviceManagerPrivate* Solid::DeviceManagerStorage::m_storage = 0;
 
 Solid::DeviceManagerPrivate::DeviceManagerPrivate()
     : m_nullDevice(new DevicePrivate(QString()))
 {
     loadBackends();
 
-    QList<QObject*> backends = managerBackends();
-    foreach (QObject *backend, backends) {
+    foreach (QObject *backend, managerBackends()) {
         connect(backend, SIGNAL(deviceAdded(QString)),
                 this, SLOT(_k_deviceAdded(QString)));
         connect(backend, SIGNAL(deviceRemoved(QString)),
                 this, SLOT(_k_deviceRemoved(QString)));
+        connect(backend, SIGNAL(contentChanged(QString,bool)),
+                this, SLOT(_k_contentChanged(QString,bool)));
     }
 }
 
 Solid::DeviceManagerPrivate::~DeviceManagerPrivate()
 {
-    QList<QObject*> backends = managerBackends();
-    foreach (QObject *backend, backends) {
+    foreach (QObject *backend, managerBackends()) {
         disconnect(backend, 0, this, 0);
     }
 
     foreach (QWeakPointer<DevicePrivate> dev, m_devicesMap) {
-        if (!dev.data()->ref.deref()) {
-            delete dev.data();
+        DevicePrivate *devData = dev.data();
+        disconnect(devData, 0, this, 0);
+        if (!devData->ref.deref()) {
+            delete devData;
         }
     }
 
@@ -65,16 +69,15 @@ Solid::DeviceManagerPrivate::~DeviceManagerPrivate()
 QList<Solid::Device> Solid::Device::allDevices()
 {
     QList<Device> list;
-    QList<QObject*> backends = globalDeviceStorage->managerBackends();
 
-    foreach (QObject *backendObj, backends) {
+    foreach (QObject *backendObj, globalDeviceStorage()->managerBackends()) {
         Ifaces::DeviceManager *backend = qobject_cast<Ifaces::DeviceManager *>(backendObj);
 
-        if (backend == 0) continue;
+        if (backend == 0) {
+            continue;
+        }
 
-        QStringList udis = backend->allDevices();
-
-        foreach (const QString &udi, udis) {
+        foreach (const QString &udi, backend->allDevices()) {
             list.append(Device(udi));
         }
     }
@@ -101,17 +104,18 @@ QList<Solid::Device> Solid::Device::listFromType(const DeviceInterface::Type &ty
                                                  const QString &parentUdi)
 {
     QList<Device> list;
-    QList<QObject*> backends = globalDeviceStorage->managerBackends();
 
-    foreach (QObject *backendObj, backends) {
+    foreach (QObject *backendObj, globalDeviceStorage()->managerBackends()) {
         Ifaces::DeviceManager *backend = qobject_cast<Ifaces::DeviceManager *>(backendObj);
 
-        if (backend == 0) continue;
-        if (!backend->supportedInterfaces().contains(type)) continue;
+        if (backend == 0) {
+            continue;
+        }
+        if (!backend->supportedInterfaces().contains(type)) {
+            continue;
+        }
 
-        QStringList udis = backend->devicesFromQuery(parentUdi, type);
-
-        foreach (const QString &udi, udis) {
+        foreach (const QString &udi, backend->devicesFromQuery(parentUdi, type)) {
             list.append(Device(udi));
         }
     }
@@ -123,15 +127,16 @@ QList<Solid::Device> Solid::Device::listFromQuery(const Predicate &predicate,
                                                   const QString &parentUdi)
 {
     QList<Device> list;
-    QList<QObject*> backends = globalDeviceStorage->managerBackends();
     QSet<DeviceInterface::Type> usedTypes = predicate.usedTypes();
 
-    foreach (QObject *backendObj, backends) {
+    foreach (QObject *backendObj, globalDeviceStorage()->managerBackends()) {
         Ifaces::DeviceManager *backend = qobject_cast<Ifaces::DeviceManager *>(backendObj);
 
-        if (backend == 0) continue;
+        if (backend == 0) {
+            continue;
+        }
 
-        QSet<QString> udis;
+        QStringList udis;
         if (predicate.isValid()) {
             QSet<DeviceInterface::Type> supportedTypes = backend->supportedInterfaces();
             if (supportedTypes.intersect(usedTypes).isEmpty()) {
@@ -139,26 +144,24 @@ QList<Solid::Device> Solid::Device::listFromQuery(const Predicate &predicate,
             }
 
             foreach (DeviceInterface::Type type, supportedTypes) {
-                udis+= QSet<QString>::fromList(backend->devicesFromQuery(parentUdi, type));
+                udis += backend->devicesFromQuery(parentUdi, type);
             }
         } else {
-            udis+= QSet<QString>::fromList(backend->allDevices());
+            udis += backend->allDevices();
         }
 
-        foreach (const QString &udi, udis)
-        {
+        foreach (const QString &udi, udis) {
             Device dev(udi);
 
             bool matches = false;
 
-            if(!predicate.isValid()) {
+            if (!predicate.isValid()) {
                 matches = true;
             } else {
                 matches = predicate.matches(dev);
             }
 
-            if (matches)
-            {
+            if (matches) {
                 list.append(dev);
             }
         }
@@ -169,7 +172,7 @@ QList<Solid::Device> Solid::Device::listFromQuery(const Predicate &predicate,
 
 Solid::DeviceNotifier *Solid::DeviceNotifier::instance()
 {
-    return globalDeviceStorage->notifier();
+    return globalDeviceStorage()->notifier();
 }
 
 void Solid::DeviceManagerPrivate::_k_deviceAdded(const QString &udi)
@@ -207,6 +210,11 @@ void Solid::DeviceManagerPrivate::_k_deviceRemoved(const QString &udi)
     emit deviceRemoved(udi);
 }
 
+void Solid::DeviceManagerPrivate::_k_contentChanged(const QString &udi, const bool hascontent)
+{
+    emit contentChanged(udi, hascontent);
+}
+
 void Solid::DeviceManagerPrivate::_k_destroyed(QObject *object)
 {
     QString udi = m_reverseMap.take(object);
@@ -241,20 +249,20 @@ Solid::DevicePrivate *Solid::DeviceManagerPrivate::findRegisteredDevice(const QS
 
 Solid::Ifaces::Device *Solid::DeviceManagerPrivate::createBackendObject(const QString &udi)
 {
-    QList<QObject*> backends = globalDeviceStorage->managerBackends();
-
-    foreach (QObject *backendObj, backends) {
+    foreach (QObject *backendObj, globalDeviceStorage()->managerBackends()) {
         Ifaces::DeviceManager *backend = qobject_cast<Ifaces::DeviceManager *>(backendObj);
 
-        if (backend == 0) continue;
-        if (!udi.startsWith(backend->udiPrefix())) continue;
-
-        Ifaces::Device *iface = 0;
+        if (backend == 0) {
+            continue;
+        }
+        if (!udi.startsWith(backend->udiPrefix())) {
+            continue;
+        }
 
         QObject *object = backend->createDevice(udi);
-        iface = qobject_cast<Ifaces::Device *>(object);
+        Ifaces::Device *iface = qobject_cast<Ifaces::Device *>(object);
 
-        if (iface==0) {
+        if (iface == 0) {
             delete object;
         }
 
@@ -269,25 +277,33 @@ Solid::DeviceManagerStorage::DeviceManagerStorage()
 
 }
 
+Solid::DeviceManagerStorage::~DeviceManagerStorage()
+{
+    if (m_storage) {
+        delete m_storage;
+        m_storage = 0;
+    }
+}
+
 QList<QObject*> Solid::DeviceManagerStorage::managerBackends()
 {
     ensureManagerCreated();
-    return m_storage.localData()->managerBackends();
+    return m_storage->managerBackends();
 }
 
 Solid::DeviceNotifier *Solid::DeviceManagerStorage::notifier()
 {
     ensureManagerCreated();
-    return m_storage.localData();
+    return m_storage;
 }
 
 void Solid::DeviceManagerStorage::ensureManagerCreated()
 {
-    if (!m_storage.hasLocalData()) {
-        m_storage.setLocalData(new DeviceManagerPrivate());
+    if (!m_storage) {
+        m_storage = new DeviceManagerPrivate();
     }
 }
 
-#include "devicenotifier.moc"
-#include "devicemanager_p.moc"
+#include "moc_devicenotifier.cpp"
+#include "moc_devicemanager_p.cpp"
 
