@@ -59,6 +59,15 @@ namespace Solid
          * @param udi the old device UDI
          */
         void deviceRemoved(const QString &udi);
+
+
+        /**
+         * This signal is emitted when a device content changes, e.g. CD-ROM eject.
+         *
+         * @param udi the device UDI
+         * @param hasContent the device has/does not have content
+         */
+        void contentChanged(const QString &udi, const bool hasContent);
     };
 }
 
