@@ -92,4 +92,4 @@ bool Solid::StorageAccess::isIgnored() const
     return_SOLID_CALL(Ifaces::StorageAccess *, d->backendObject(), true, isIgnored());
 }
 
-#include "storageaccess.moc"
+#include "moc_storageaccess.cpp"
