@@ -1,20 +1,21 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2005 Kevin Ottens <ervin@kde.org>
+/*
+    Copyright 2005 Kevin Ottens <ervin@kde.org>
 
     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    Lesser General Public License for more details.
 
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "solidhwtest.h"
@@ -27,6 +28,8 @@
 #include <solid/processor.h>
 #include <solid/storageaccess.h>
 #include <solid/storagevolume.h>
+#include <solid/video.h>
+#include <solid/graphic.h>
 #include <solid/predicate.h>
 #include "solid/managerbase_p.h"
 
@@ -46,7 +49,7 @@ void SolidHwTest::initTestCase()
     setenv("SOLID_FAKEHW", FAKE_COMPUTER_XML, 1);
     Solid::ManagerBasePrivate *manager
         = dynamic_cast<Solid::ManagerBasePrivate*>(Solid::DeviceNotifier::instance());
-    fakeManager = qobject_cast<Solid::Backends::Fake::FakeManager*>(manager->managerBackend());
+    fakeManager = qobject_cast<Solid::Backends::Fake::FakeManager*>(manager->managerBackends().first());
 }
 
 void SolidHwTest::testAllDevices()
@@ -55,9 +58,9 @@ void SolidHwTest::testAllDevices()
 
     // Verify that the framework reported correctly the devices available
     // in the backend.
-    QSet<QString> expected_udis, received_udis;
+    QStringList expected_udis, received_udis;
 
-    expected_udis = QSet<QString>::fromList(fakeManager->allDevices());
+    expected_udis = fakeManager->allDevices();
 
     foreach (const Solid::Device &dev , devices)
     {
@@ -165,9 +168,9 @@ void SolidHwTest::testDeviceSignals()
     Solid::Device device("/org/kde/solid/fakehw/acpi_LID0");
 
     // We'll spy our button
-    connect(device.as<Solid::GenericInterface>(), SIGNAL(propertyChanged(const QMap<QString,int> &)),
-             this, SLOT(slotPropertyChanged(const QMap<QString,int> &)));
-    QSignalSpy condition_raised(device.as<Solid::GenericInterface>(), SIGNAL(conditionRaised(QString, QString)));
+    connect(device.as<Solid::GenericInterface>(), SIGNAL(propertyChanged(QMap<QString,int>)),
+             this, SLOT(slotPropertyChanged(QMap<QString,int>)));
+    QSignalSpy condition_raised(device.as<Solid::GenericInterface>(), SIGNAL(conditionRaised(QString,QString)));
 
     fake->setProperty("stateValue", true); // The button is now pressed (modified property)
     fake->raiseCondition("Lid Closed", "Why not?"); // Since it's a LID we notify this change
@@ -289,6 +292,8 @@ void SolidHwTest::testDeviceInterfaceIntrospection_data()
     QTest::newRow("DeviceInterface: Battery") << "Battery" << (int)Solid::DeviceInterface::Battery;
     QTest::newRow("DeviceInterface: Button") << "Button" << (int)Solid::DeviceInterface::Button;
     QTest::newRow("DeviceInterface: AudioInterface") << "AudioInterface" << (int)Solid::DeviceInterface::AudioInterface;
+    QTest::newRow("DeviceInterface: Graphic") << "Graphic" << (int)Solid::DeviceInterface::Graphic;
+    QTest::newRow("DeviceInterface: Video") << "Video" << (int)Solid::DeviceInterface::Video;
 }
 
 void SolidHwTest::testDeviceInterfaceIntrospection()
@@ -481,6 +486,54 @@ void SolidHwTest::slotPropertyChanged(const QMap<QString,int> &changes)
     m_changesList << changes;
 }
 
+#define SOLID_TEST_IFACE(UDI, DEVIFACE, SOLIFACE) \
+    { \
+        Solid::Device device(UDI); \
+        \
+        Solid::DeviceInterface *iface = device.asDeviceInterface(DEVIFACE); \
+        Solid::DeviceInterface *iface2 = device.as<SOLIFACE>(); \
+        \
+        QVERIFY(device.isDeviceInterface(DEVIFACE)); \
+        QVERIFY(iface != 0); \
+        QCOMPARE(iface, iface2); \
+        QCOMPARE(device.as<Solid::GenericInterface>(), device.as<Solid::GenericInterface>()); \
+        \
+        QPointer<SOLIFACE> p = device.as<SOLIFACE>(); \
+        QVERIFY(p != 0); \
+        fakeManager->unplug(UDI); \
+        QVERIFY(p == 0); \
+        fakeManager->plug(UDI); \
+    }
 
-#include "solidhwtest.moc"
+// any interface that is not tested with the test cases above should be tested
+// with this method
+void SolidHwTest::testMisc()
+{
+    SOLID_TEST_IFACE("/org/kde/solid/fakehw/pci_10de_0fc1_card0", Solid::DeviceInterface::Graphic, Solid::Graphic);
+    {
+        Solid::Device device("/org/kde/solid/fakehw/pci_10de_0fc1_card0");
+        Solid::Graphic* deviceptr = device.as<Solid::Graphic>();
+        QCOMPARE(deviceptr->driver(), QString("nouveau"));
+    }
+
+    SOLID_TEST_IFACE("/org/kde/solid/fakehw/pci_01ed_f0c1_video0", Solid::DeviceInterface::Video, Solid::Video);
+    {
+        Solid::Device device("/org/kde/solid/fakehw/pci_01ed_f0c1_video0");
+        Solid::Video* deviceptr = device.as<Solid::Video>();
+        QCOMPARE(deviceptr->supportedProtocols(), QStringList() << QString("video4linux"));
+        QCOMPARE(deviceptr->supportedDrivers(), QStringList() << QString("video4linux2"));
+        QCOMPARE(deviceptr->driverHandle("foo"), QVariant("/dev/video0"));
+    }
+
+    SOLID_TEST_IFACE("/org/kde/solid/fakehw/pci_ed01_c1f0_radio0", Solid::DeviceInterface::Video, Solid::Video);
+    {
+        Solid::Device device("/org/kde/solid/fakehw/pci_ed01_c1f0_radio0");
+        Solid::Video* deviceptr = device.as<Solid::Video>();
+        QCOMPARE(deviceptr->supportedProtocols(), QStringList() << QString("video4linux"));
+        QCOMPARE(deviceptr->supportedDrivers(), QStringList() << QString("video4linux1"));
+        QCOMPARE(deviceptr->driverHandle("bar"), QVariant("/dev/radio0"));
+    }
+}
+
+#include "moc_solidhwtest.cpp"
 
